return {
  auth = {
    oauth2 = {
      scopes = {
        ["https://www.googleapis.com/auth/cloud-platform"] = {
          description = "See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.",
        },
        ["https://www.googleapis.com/auth/compute"] = {
          description = "View and manage your Google Compute Engine resources",
        },
        ["https://www.googleapis.com/auth/compute.readonly"] = {
          description = "View your Google Compute Engine resources",
        },
        ["https://www.googleapis.com/auth/devstorage.full_control"] = {
          description = "Manage your data and permissions in Cloud Storage and see the email address for your Google Account",
        },
        ["https://www.googleapis.com/auth/devstorage.read_only"] = {
          description = "View your data in Google Cloud Storage",
        },
        ["https://www.googleapis.com/auth/devstorage.read_write"] = {
          description = "Manage your data in Cloud Storage and see the email address of your Google Account",
        },
      },
    },
  },
  basePath = "/compute/v1/",
  baseUrl = "https://compute.googleapis.com/compute/v1/",
  batchPath = "batch/compute/v1",
  description = "Creates and runs virtual machines on Google Cloud Platform. ",
  discoveryVersion = "v1",
  documentationLink = "https://cloud.google.com/compute/",
  icons = {
    x16 = "https://www.google.com/images/icons/product/compute_engine-16.png",
    x32 = "https://www.google.com/images/icons/product/compute_engine-32.png",
  },
  id = "compute:v1",
  kind = "discovery#restDescription",
  mtlsRootUrl = "https://compute.mtls.googleapis.com/",
  name = "compute",
  ownerDomain = "google.com",
  ownerName = "Google",
  parameters = {
    ["$.xgafv"] = {
      description = "V1 error format.",
      enum = {
        "1",
        "2",
      },
      enumDescriptions = {
        "v1 error format",
        "v2 error format",
      },
      location = "query",
      type = "string",
    },
    access_token = {
      description = "OAuth access token.",
      location = "query",
      type = "string",
    },
    alt = {
      default = "json",
      description = "Data format for response.",
      enum = {
        "json",
        "media",
        "proto",
      },
      enumDescriptions = {
        "Responses with Content-Type of application/json",
        "Media download with context-dependent Content-Type",
        "Responses with Content-Type of application/x-protobuf",
      },
      location = "query",
      type = "string",
    },
    callback = {
      description = "JSONP",
      location = "query",
      type = "string",
    },
    fields = {
      description = "Selector specifying which fields to include in a partial response.",
      location = "query",
      type = "string",
    },
    key = {
      description = "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.",
      location = "query",
      type = "string",
    },
    oauth_token = {
      description = "OAuth 2.0 token for the current user.",
      location = "query",
      type = "string",
    },
    prettyPrint = {
      default = "true",
      description = "Returns response with indentations and line breaks.",
      location = "query",
      type = "boolean",
    },
    quotaUser = {
      description = "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.",
      location = "query",
      type = "string",
    },
    uploadType = {
      description = "Legacy upload protocol for media (e.g. \"media\", \"multipart\").",
      location = "query",
      type = "string",
    },
    upload_protocol = {
      description = "Upload protocol for media (e.g. \"raw\", \"multipart\").",
      location = "query",
      type = "string",
    },
    userIp = {
      description = "Legacy name for parameter that has been superseded by `quotaUser`.",
      location = "query",
      type = "string",
    },
  },
  protocol = "rest",
  resources = {
    acceleratorTypes = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of accelerator types.",
          flatPath = "projects/{project}/aggregated/acceleratorTypes",
          httpMethod = "GET",
          id = "compute.acceleratorTypes.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/acceleratorTypes",
          response = {
            ["$ref"] = "AcceleratorTypeAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        get = {
          description = "Returns the specified accelerator type.",
          flatPath = "projects/{project}/zones/{zone}/acceleratorTypes/{acceleratorType}",
          httpMethod = "GET",
          id = "compute.acceleratorTypes.get",
          parameterOrder = {
            "project",
            "zone",
            "acceleratorType",
          },
          parameters = {
            acceleratorType = {
              description = "Name of the accelerator type to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/acceleratorTypes/{acceleratorType}",
          response = {
            ["$ref"] = "AcceleratorType",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves a list of accelerator types that are available to the specified project.",
          flatPath = "projects/{project}/zones/{zone}/acceleratorTypes",
          httpMethod = "GET",
          id = "compute.acceleratorTypes.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/acceleratorTypes",
          response = {
            ["$ref"] = "AcceleratorTypeList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    addresses = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of addresses.",
          flatPath = "projects/{project}/aggregated/addresses",
          httpMethod = "GET",
          id = "compute.addresses.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/addresses",
          response = {
            ["$ref"] = "AddressAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified address resource.",
          flatPath = "projects/{project}/regions/{region}/addresses/{address}",
          httpMethod = "DELETE",
          id = "compute.addresses.delete",
          parameterOrder = {
            "project",
            "region",
            "address",
          },
          parameters = {
            address = {
              description = "Name of the address resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/addresses/{address}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified address resource.",
          flatPath = "projects/{project}/regions/{region}/addresses/{address}",
          httpMethod = "GET",
          id = "compute.addresses.get",
          parameterOrder = {
            "project",
            "region",
            "address",
          },
          parameters = {
            address = {
              description = "Name of the address resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/addresses/{address}",
          response = {
            ["$ref"] = "Address",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an address resource in the specified project by using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/addresses",
          httpMethod = "POST",
          id = "compute.addresses.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/addresses",
          request = {
            ["$ref"] = "Address",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of addresses contained within the specified region.",
          flatPath = "projects/{project}/regions/{region}/addresses",
          httpMethod = "GET",
          id = "compute.addresses.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/addresses",
          response = {
            ["$ref"] = "AddressList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setLabels = {
          description = "Sets the labels on an Address. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/regions/{region}/addresses/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.addresses.setLabels",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/addresses/{resource}/setLabels",
          request = {
            ["$ref"] = "RegionSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    autoscalers = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of autoscalers.",
          flatPath = "projects/{project}/aggregated/autoscalers",
          httpMethod = "GET",
          id = "compute.autoscalers.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/autoscalers",
          response = {
            ["$ref"] = "AutoscalerAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified autoscaler.",
          flatPath = "projects/{project}/zones/{zone}/autoscalers/{autoscaler}",
          httpMethod = "DELETE",
          id = "compute.autoscalers.delete",
          parameterOrder = {
            "project",
            "zone",
            "autoscaler",
          },
          parameters = {
            autoscaler = {
              description = "Name of the autoscaler to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/autoscalers/{autoscaler}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified autoscaler resource. Gets a list of available autoscalers by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}/autoscalers/{autoscaler}",
          httpMethod = "GET",
          id = "compute.autoscalers.get",
          parameterOrder = {
            "project",
            "zone",
            "autoscaler",
          },
          parameters = {
            autoscaler = {
              description = "Name of the autoscaler to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/autoscalers/{autoscaler}",
          response = {
            ["$ref"] = "Autoscaler",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an autoscaler in the specified project using the data included in the request.",
          flatPath = "projects/{project}/zones/{zone}/autoscalers",
          httpMethod = "POST",
          id = "compute.autoscalers.insert",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/autoscalers",
          request = {
            ["$ref"] = "Autoscaler",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of autoscalers contained within the specified zone.",
          flatPath = "projects/{project}/zones/{zone}/autoscalers",
          httpMethod = "GET",
          id = "compute.autoscalers.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/autoscalers",
          response = {
            ["$ref"] = "AutoscalerList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates an autoscaler in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/zones/{zone}/autoscalers",
          httpMethod = "PATCH",
          id = "compute.autoscalers.patch",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            autoscaler = {
              description = "Name of the autoscaler to patch.",
              location = "query",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/autoscalers",
          request = {
            ["$ref"] = "Autoscaler",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates an autoscaler in the specified project using the data included in the request.",
          flatPath = "projects/{project}/zones/{zone}/autoscalers",
          httpMethod = "PUT",
          id = "compute.autoscalers.update",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            autoscaler = {
              description = "Name of the autoscaler to update.",
              location = "query",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/autoscalers",
          request = {
            ["$ref"] = "Autoscaler",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    backendBuckets = {
      methods = {
        addSignedUrlKey = {
          description = "Adds a key for validating requests with signed URLs for this backend bucket.",
          flatPath = "projects/{project}/global/backendBuckets/{backendBucket}/addSignedUrlKey",
          httpMethod = "POST",
          id = "compute.backendBuckets.addSignedUrlKey",
          parameterOrder = {
            "project",
            "backendBucket",
          },
          parameters = {
            backendBucket = {
              description = "Name of the BackendBucket resource to which the Signed URL Key should be added. The name should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendBuckets/{backendBucket}/addSignedUrlKey",
          request = {
            ["$ref"] = "SignedUrlKey",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified BackendBucket resource.",
          flatPath = "projects/{project}/global/backendBuckets/{backendBucket}",
          httpMethod = "DELETE",
          id = "compute.backendBuckets.delete",
          parameterOrder = {
            "project",
            "backendBucket",
          },
          parameters = {
            backendBucket = {
              description = "Name of the BackendBucket resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendBuckets/{backendBucket}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        deleteSignedUrlKey = {
          description = "Deletes a key for validating requests with signed URLs for this backend bucket.",
          flatPath = "projects/{project}/global/backendBuckets/{backendBucket}/deleteSignedUrlKey",
          httpMethod = "POST",
          id = "compute.backendBuckets.deleteSignedUrlKey",
          parameterOrder = {
            "project",
            "backendBucket",
            "keyName",
          },
          parameters = {
            backendBucket = {
              description = "Name of the BackendBucket resource to which the Signed URL Key should be added. The name should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            keyName = {
              description = "The name of the Signed URL Key to delete.",
              location = "query",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendBuckets/{backendBucket}/deleteSignedUrlKey",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified BackendBucket resource. Gets a list of available backend buckets by making a list() request.",
          flatPath = "projects/{project}/global/backendBuckets/{backendBucket}",
          httpMethod = "GET",
          id = "compute.backendBuckets.get",
          parameterOrder = {
            "project",
            "backendBucket",
          },
          parameters = {
            backendBucket = {
              description = "Name of the BackendBucket resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/backendBuckets/{backendBucket}",
          response = {
            ["$ref"] = "BackendBucket",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a BackendBucket resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/backendBuckets",
          httpMethod = "POST",
          id = "compute.backendBuckets.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendBuckets",
          request = {
            ["$ref"] = "BackendBucket",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of BackendBucket resources available to the specified project.",
          flatPath = "projects/{project}/global/backendBuckets",
          httpMethod = "GET",
          id = "compute.backendBuckets.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/backendBuckets",
          response = {
            ["$ref"] = "BackendBucketList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates the specified BackendBucket resource with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/backendBuckets/{backendBucket}",
          httpMethod = "PATCH",
          id = "compute.backendBuckets.patch",
          parameterOrder = {
            "project",
            "backendBucket",
          },
          parameters = {
            backendBucket = {
              description = "Name of the BackendBucket resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendBuckets/{backendBucket}",
          request = {
            ["$ref"] = "BackendBucket",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setEdgeSecurityPolicy = {
          description = "Sets the edge security policy for the specified backend bucket.",
          flatPath = "projects/{project}/global/backendBuckets/{backendBucket}/setEdgeSecurityPolicy",
          httpMethod = "POST",
          id = "compute.backendBuckets.setEdgeSecurityPolicy",
          parameterOrder = {
            "project",
            "backendBucket",
          },
          parameters = {
            backendBucket = {
              description = "Name of the BackendService resource to which the security policy should be set. The name should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendBuckets/{backendBucket}/setEdgeSecurityPolicy",
          request = {
            ["$ref"] = "SecurityPolicyReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates the specified BackendBucket resource with the data included in the request.",
          flatPath = "projects/{project}/global/backendBuckets/{backendBucket}",
          httpMethod = "PUT",
          id = "compute.backendBuckets.update",
          parameterOrder = {
            "project",
            "backendBucket",
          },
          parameters = {
            backendBucket = {
              description = "Name of the BackendBucket resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendBuckets/{backendBucket}",
          request = {
            ["$ref"] = "BackendBucket",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    backendServices = {
      methods = {
        addSignedUrlKey = {
          description = "Adds a key for validating requests with signed URLs for this backend service.",
          flatPath = "projects/{project}/global/backendServices/{backendService}/addSignedUrlKey",
          httpMethod = "POST",
          id = "compute.backendServices.addSignedUrlKey",
          parameterOrder = {
            "project",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to which the Signed URL Key should be added. The name should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{backendService}/addSignedUrlKey",
          request = {
            ["$ref"] = "SignedUrlKey",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        aggregatedList = {
          description = "Retrieves the list of all BackendService resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/backendServices",
          httpMethod = "GET",
          id = "compute.backendServices.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/backendServices",
          response = {
            ["$ref"] = "BackendServiceAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified BackendService resource.",
          flatPath = "projects/{project}/global/backendServices/{backendService}",
          httpMethod = "DELETE",
          id = "compute.backendServices.delete",
          parameterOrder = {
            "project",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{backendService}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        deleteSignedUrlKey = {
          description = "Deletes a key for validating requests with signed URLs for this backend service.",
          flatPath = "projects/{project}/global/backendServices/{backendService}/deleteSignedUrlKey",
          httpMethod = "POST",
          id = "compute.backendServices.deleteSignedUrlKey",
          parameterOrder = {
            "project",
            "backendService",
            "keyName",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to which the Signed URL Key should be added. The name should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            keyName = {
              description = "The name of the Signed URL Key to delete.",
              location = "query",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{backendService}/deleteSignedUrlKey",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified BackendService resource. Gets a list of available backend services.",
          flatPath = "projects/{project}/global/backendServices/{backendService}",
          httpMethod = "GET",
          id = "compute.backendServices.get",
          parameterOrder = {
            "project",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{backendService}",
          response = {
            ["$ref"] = "BackendService",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getHealth = {
          description = "Gets the most recent health check results for this BackendService. Example request body: { \"group\": \"/zones/us-east1-b/instanceGroups/lb-backend-example\" }",
          flatPath = "projects/{project}/global/backendServices/{backendService}/getHealth",
          httpMethod = "POST",
          id = "compute.backendServices.getHealth",
          parameterOrder = {
            "project",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to which the queried instance belongs.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{backendService}/getHealth",
          request = {
            ["$ref"] = "ResourceGroupReference",
          },
          response = {
            ["$ref"] = "BackendServiceGroupHealth",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/global/backendServices/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.backendServices.getIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a BackendService resource in the specified project using the data included in the request. For more information, see Backend services overview .",
          flatPath = "projects/{project}/global/backendServices",
          httpMethod = "POST",
          id = "compute.backendServices.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices",
          request = {
            ["$ref"] = "BackendService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of BackendService resources available to the specified project.",
          flatPath = "projects/{project}/global/backendServices",
          httpMethod = "GET",
          id = "compute.backendServices.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/backendServices",
          response = {
            ["$ref"] = "BackendServiceList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified BackendService resource with the data included in the request. For more information, see Backend services overview. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/backendServices/{backendService}",
          httpMethod = "PATCH",
          id = "compute.backendServices.patch",
          parameterOrder = {
            "project",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{backendService}",
          request = {
            ["$ref"] = "BackendService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setEdgeSecurityPolicy = {
          description = "Sets the edge security policy for the specified backend service.",
          flatPath = "projects/{project}/global/backendServices/{backendService}/setEdgeSecurityPolicy",
          httpMethod = "POST",
          id = "compute.backendServices.setEdgeSecurityPolicy",
          parameterOrder = {
            "project",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to which the edge security policy should be set. The name should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{backendService}/setEdgeSecurityPolicy",
          request = {
            ["$ref"] = "SecurityPolicyReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/global/backendServices/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.backendServices.setIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "GlobalSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setSecurityPolicy = {
          description = "Sets the Google Cloud Armor security policy for the specified backend service. For more information, see Google Cloud Armor Overview",
          flatPath = "projects/{project}/global/backendServices/{backendService}/setSecurityPolicy",
          httpMethod = "POST",
          id = "compute.backendServices.setSecurityPolicy",
          parameterOrder = {
            "project",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to which the security policy should be set. The name should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{backendService}/setSecurityPolicy",
          request = {
            ["$ref"] = "SecurityPolicyReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates the specified BackendService resource with the data included in the request. For more information, see Backend services overview.",
          flatPath = "projects/{project}/global/backendServices/{backendService}",
          httpMethod = "PUT",
          id = "compute.backendServices.update",
          parameterOrder = {
            "project",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/backendServices/{backendService}",
          request = {
            ["$ref"] = "BackendService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    diskTypes = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of disk types.",
          flatPath = "projects/{project}/aggregated/diskTypes",
          httpMethod = "GET",
          id = "compute.diskTypes.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/diskTypes",
          response = {
            ["$ref"] = "DiskTypeAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        get = {
          description = "Returns the specified disk type. Gets a list of available disk types by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}/diskTypes/{diskType}",
          httpMethod = "GET",
          id = "compute.diskTypes.get",
          parameterOrder = {
            "project",
            "zone",
            "diskType",
          },
          parameters = {
            diskType = {
              description = "Name of the disk type to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/diskTypes/{diskType}",
          response = {
            ["$ref"] = "DiskType",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves a list of disk types available to the specified project.",
          flatPath = "projects/{project}/zones/{zone}/diskTypes",
          httpMethod = "GET",
          id = "compute.diskTypes.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/diskTypes",
          response = {
            ["$ref"] = "DiskTypeList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    disks = {
      methods = {
        addResourcePolicies = {
          description = "Adds existing resource policies to a disk. You can only add one policy which will be applied to this disk for scheduling snapshot creation.",
          flatPath = "projects/{project}/zones/{zone}/disks/{disk}/addResourcePolicies",
          httpMethod = "POST",
          id = "compute.disks.addResourcePolicies",
          parameterOrder = {
            "project",
            "zone",
            "disk",
          },
          parameters = {
            disk = {
              description = "The disk name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{disk}/addResourcePolicies",
          request = {
            ["$ref"] = "DisksAddResourcePoliciesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        aggregatedList = {
          description = "Retrieves an aggregated list of persistent disks.",
          flatPath = "projects/{project}/aggregated/disks",
          httpMethod = "GET",
          id = "compute.disks.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/disks",
          response = {
            ["$ref"] = "DiskAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        createSnapshot = {
          description = "Creates a snapshot of a specified persistent disk. For regular snapshot creation, consider using snapshots.insert instead, as that method supports more features, such as creating snapshots in a project different from the source disk project.",
          flatPath = "projects/{project}/zones/{zone}/disks/{disk}/createSnapshot",
          httpMethod = "POST",
          id = "compute.disks.createSnapshot",
          parameterOrder = {
            "project",
            "zone",
            "disk",
          },
          parameters = {
            disk = {
              description = "Name of the persistent disk to snapshot.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            guestFlush = {
              description = "[Input Only] Whether to attempt an application consistent snapshot by informing the OS to prepare for the snapshot process.",
              location = "query",
              type = "boolean",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{disk}/createSnapshot",
          request = {
            ["$ref"] = "Snapshot",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified persistent disk. Deleting a disk removes its data permanently and is irreversible. However, deleting a disk does not delete any snapshots previously made from the disk. You must separately delete snapshots.",
          flatPath = "projects/{project}/zones/{zone}/disks/{disk}",
          httpMethod = "DELETE",
          id = "compute.disks.delete",
          parameterOrder = {
            "project",
            "zone",
            "disk",
          },
          parameters = {
            disk = {
              description = "Name of the persistent disk to delete.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{disk}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns a specified persistent disk. Gets a list of available persistent disks by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}/disks/{disk}",
          httpMethod = "GET",
          id = "compute.disks.get",
          parameterOrder = {
            "project",
            "zone",
            "disk",
          },
          parameters = {
            disk = {
              description = "Name of the persistent disk to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{disk}",
          response = {
            ["$ref"] = "Disk",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/zones/{zone}/disks/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.disks.getIamPolicy",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a persistent disk in the specified project using the data in the request. You can create a disk from a source (sourceImage, sourceSnapshot, or sourceDisk) or create an empty 500 GB data disk by omitting all properties. You can also create a disk that is larger than the default size by specifying the sizeGb property.",
          flatPath = "projects/{project}/zones/{zone}/disks",
          httpMethod = "POST",
          id = "compute.disks.insert",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sourceImage = {
              description = "Source image to restore onto a disk. This field is optional.",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks",
          request = {
            ["$ref"] = "Disk",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of persistent disks contained within the specified zone.",
          flatPath = "projects/{project}/zones/{zone}/disks",
          httpMethod = "GET",
          id = "compute.disks.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks",
          response = {
            ["$ref"] = "DiskList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        removeResourcePolicies = {
          description = "Removes resource policies from a disk.",
          flatPath = "projects/{project}/zones/{zone}/disks/{disk}/removeResourcePolicies",
          httpMethod = "POST",
          id = "compute.disks.removeResourcePolicies",
          parameterOrder = {
            "project",
            "zone",
            "disk",
          },
          parameters = {
            disk = {
              description = "The disk name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{disk}/removeResourcePolicies",
          request = {
            ["$ref"] = "DisksRemoveResourcePoliciesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        resize = {
          description = "Resizes the specified persistent disk. You can only increase the size of the disk.",
          flatPath = "projects/{project}/zones/{zone}/disks/{disk}/resize",
          httpMethod = "POST",
          id = "compute.disks.resize",
          parameterOrder = {
            "project",
            "zone",
            "disk",
          },
          parameters = {
            disk = {
              description = "The name of the persistent disk.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{disk}/resize",
          request = {
            ["$ref"] = "DisksResizeRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/zones/{zone}/disks/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.disks.setIamPolicy",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "ZoneSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets the labels on a disk. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/zones/{zone}/disks/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.disks.setLabels",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{resource}/setLabels",
          request = {
            ["$ref"] = "ZoneSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/zones/{zone}/disks/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.disks.testIamPermissions",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/disks/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    externalVpnGateways = {
      methods = {
        delete = {
          description = "Deletes the specified externalVpnGateway.",
          flatPath = "projects/{project}/global/externalVpnGateways/{externalVpnGateway}",
          httpMethod = "DELETE",
          id = "compute.externalVpnGateways.delete",
          parameterOrder = {
            "project",
            "externalVpnGateway",
          },
          parameters = {
            externalVpnGateway = {
              description = "Name of the externalVpnGateways to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/externalVpnGateways/{externalVpnGateway}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified externalVpnGateway. Get a list of available externalVpnGateways by making a list() request.",
          flatPath = "projects/{project}/global/externalVpnGateways/{externalVpnGateway}",
          httpMethod = "GET",
          id = "compute.externalVpnGateways.get",
          parameterOrder = {
            "project",
            "externalVpnGateway",
          },
          parameters = {
            externalVpnGateway = {
              description = "Name of the externalVpnGateway to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/externalVpnGateways/{externalVpnGateway}",
          response = {
            ["$ref"] = "ExternalVpnGateway",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a ExternalVpnGateway in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/externalVpnGateways",
          httpMethod = "POST",
          id = "compute.externalVpnGateways.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/externalVpnGateways",
          request = {
            ["$ref"] = "ExternalVpnGateway",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of ExternalVpnGateway available to the specified project.",
          flatPath = "projects/{project}/global/externalVpnGateways",
          httpMethod = "GET",
          id = "compute.externalVpnGateways.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/externalVpnGateways",
          response = {
            ["$ref"] = "ExternalVpnGatewayList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setLabels = {
          description = "Sets the labels on an ExternalVpnGateway. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/global/externalVpnGateways/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.externalVpnGateways.setLabels",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/externalVpnGateways/{resource}/setLabels",
          request = {
            ["$ref"] = "GlobalSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/global/externalVpnGateways/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.externalVpnGateways.testIamPermissions",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/externalVpnGateways/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    firewallPolicies = {
      methods = {
        addAssociation = {
          description = "Inserts an association for the specified firewall policy.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}/addAssociation",
          httpMethod = "POST",
          id = "compute.firewallPolicies.addAssociation",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            replaceExistingAssociation = {
              description = "Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.",
              location = "query",
              type = "boolean",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}/addAssociation",
          request = {
            ["$ref"] = "FirewallPolicyAssociation",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        addRule = {
          description = "Inserts a rule into a firewall policy.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}/addRule",
          httpMethod = "POST",
          id = "compute.firewallPolicies.addRule",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}/addRule",
          request = {
            ["$ref"] = "FirewallPolicyRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        cloneRules = {
          description = "Copies rules to the specified firewall policy.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}/cloneRules",
          httpMethod = "POST",
          id = "compute.firewallPolicies.cloneRules",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sourceFirewallPolicy = {
              description = "The firewall policy from which to copy rules.",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}/cloneRules",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified policy.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}",
          httpMethod = "DELETE",
          id = "compute.firewallPolicies.delete",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to delete.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified firewall policy.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}",
          httpMethod = "GET",
          id = "compute.firewallPolicies.get",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to get.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}",
          response = {
            ["$ref"] = "FirewallPolicy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getAssociation = {
          description = "Gets an association with the specified name.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}/getAssociation",
          httpMethod = "GET",
          id = "compute.firewallPolicies.getAssociation",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to which the queried rule belongs.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            name = {
              description = "The name of the association to get from the firewall policy.",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}/getAssociation",
          response = {
            ["$ref"] = "FirewallPolicyAssociation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "locations/global/firewallPolicies/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.firewallPolicies.getIamPolicy",
          parameterOrder = {
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getRule = {
          description = "Gets a rule of the specified priority.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}/getRule",
          httpMethod = "GET",
          id = "compute.firewallPolicies.getRule",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to which the queried rule belongs.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            priority = {
              description = "The priority of the rule to get from the firewall policy.",
              format = "int32",
              location = "query",
              type = "integer",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}/getRule",
          response = {
            ["$ref"] = "FirewallPolicyRule",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a new policy in the specified project using the data included in the request.",
          flatPath = "locations/global/firewallPolicies",
          httpMethod = "POST",
          id = "compute.firewallPolicies.insert",
          parameters = {
            parentId = {
              description = "Parent ID for this request. The ID can be either be \"folders/[FOLDER_ID]\" if the parent is a folder or \"organizations/[ORGANIZATION_ID]\" if the parent is an organization.",
              location = "query",
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies",
          request = {
            ["$ref"] = "FirewallPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists all the policies that have been configured for the specified folder or organization.",
          flatPath = "locations/global/firewallPolicies",
          httpMethod = "GET",
          id = "compute.firewallPolicies.list",
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            parentId = {
              description = "Parent ID for this request.",
              location = "query",
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "locations/global/firewallPolicies",
          response = {
            ["$ref"] = "FirewallPolicyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listAssociations = {
          description = "Lists associations of a specified target, i.e., organization or folder.",
          flatPath = "locations/global/firewallPolicies/listAssociations",
          httpMethod = "GET",
          id = "compute.firewallPolicies.listAssociations",
          parameters = {
            targetResource = {
              description = "The target resource to list associations. It is an organization, or a folder.",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/listAssociations",
          response = {
            ["$ref"] = "FirewallPoliciesListAssociationsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        move = {
          description = "Moves the specified firewall policy.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}/move",
          httpMethod = "POST",
          id = "compute.firewallPolicies.move",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            parentId = {
              description = "The new parent of the firewall policy.",
              location = "query",
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}/move",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        patch = {
          description = "Patches the specified policy with the data included in the request.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}",
          httpMethod = "PATCH",
          id = "compute.firewallPolicies.patch",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}",
          request = {
            ["$ref"] = "FirewallPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        patchRule = {
          description = "Patches a rule of the specified priority.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}/patchRule",
          httpMethod = "POST",
          id = "compute.firewallPolicies.patchRule",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            priority = {
              description = "The priority of the rule to patch.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}/patchRule",
          request = {
            ["$ref"] = "FirewallPolicyRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        removeAssociation = {
          description = "Removes an association for the specified firewall policy.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}/removeAssociation",
          httpMethod = "POST",
          id = "compute.firewallPolicies.removeAssociation",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            name = {
              description = "Name for the attachment that will be removed.",
              location = "query",
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}/removeAssociation",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        removeRule = {
          description = "Deletes a rule of the specified priority.",
          flatPath = "locations/global/firewallPolicies/{firewallPolicy}/removeRule",
          httpMethod = "POST",
          id = "compute.firewallPolicies.removeRule",
          parameterOrder = {
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
            priority = {
              description = "The priority of the rule to remove from the firewall policy.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{firewallPolicy}/removeRule",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "locations/global/firewallPolicies/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.firewallPolicies.setIamPolicy",
          parameterOrder = {
            "resource",
          },
          parameters = {
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "GlobalOrganizationSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "locations/global/firewallPolicies/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.firewallPolicies.testIamPermissions",
          parameterOrder = {
            "resource",
          },
          parameters = {
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "(firewallPolicies/)?[0-9]{0,20}",
              required = true,
              type = "string",
            },
          },
          path = "locations/global/firewallPolicies/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    firewalls = {
      methods = {
        delete = {
          description = "Deletes the specified firewall.",
          flatPath = "projects/{project}/global/firewalls/{firewall}",
          httpMethod = "DELETE",
          id = "compute.firewalls.delete",
          parameterOrder = {
            "project",
            "firewall",
          },
          parameters = {
            firewall = {
              description = "Name of the firewall rule to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewalls/{firewall}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified firewall.",
          flatPath = "projects/{project}/global/firewalls/{firewall}",
          httpMethod = "GET",
          id = "compute.firewalls.get",
          parameterOrder = {
            "project",
            "firewall",
          },
          parameters = {
            firewall = {
              description = "Name of the firewall rule to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/firewalls/{firewall}",
          response = {
            ["$ref"] = "Firewall",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a firewall rule in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/firewalls",
          httpMethod = "POST",
          id = "compute.firewalls.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewalls",
          request = {
            ["$ref"] = "Firewall",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of firewall rules available to the specified project.",
          flatPath = "projects/{project}/global/firewalls",
          httpMethod = "GET",
          id = "compute.firewalls.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/firewalls",
          response = {
            ["$ref"] = "FirewallList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates the specified firewall rule with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/firewalls/{firewall}",
          httpMethod = "PATCH",
          id = "compute.firewalls.patch",
          parameterOrder = {
            "project",
            "firewall",
          },
          parameters = {
            firewall = {
              description = "Name of the firewall rule to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewalls/{firewall}",
          request = {
            ["$ref"] = "Firewall",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates the specified firewall rule with the data included in the request. Note that all fields will be updated if using PUT, even fields that are not specified. To update individual fields, please use PATCH instead.",
          flatPath = "projects/{project}/global/firewalls/{firewall}",
          httpMethod = "PUT",
          id = "compute.firewalls.update",
          parameterOrder = {
            "project",
            "firewall",
          },
          parameters = {
            firewall = {
              description = "Name of the firewall rule to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewalls/{firewall}",
          request = {
            ["$ref"] = "Firewall",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    forwardingRules = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of forwarding rules.",
          flatPath = "projects/{project}/aggregated/forwardingRules",
          httpMethod = "GET",
          id = "compute.forwardingRules.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/forwardingRules",
          response = {
            ["$ref"] = "ForwardingRuleAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified ForwardingRule resource.",
          flatPath = "projects/{project}/regions/{region}/forwardingRules/{forwardingRule}",
          httpMethod = "DELETE",
          id = "compute.forwardingRules.delete",
          parameterOrder = {
            "project",
            "region",
            "forwardingRule",
          },
          parameters = {
            forwardingRule = {
              description = "Name of the ForwardingRule resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/forwardingRules/{forwardingRule}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified ForwardingRule resource.",
          flatPath = "projects/{project}/regions/{region}/forwardingRules/{forwardingRule}",
          httpMethod = "GET",
          id = "compute.forwardingRules.get",
          parameterOrder = {
            "project",
            "region",
            "forwardingRule",
          },
          parameters = {
            forwardingRule = {
              description = "Name of the ForwardingRule resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/forwardingRules/{forwardingRule}",
          response = {
            ["$ref"] = "ForwardingRule",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a ForwardingRule resource in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/forwardingRules",
          httpMethod = "POST",
          id = "compute.forwardingRules.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/forwardingRules",
          request = {
            ["$ref"] = "ForwardingRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of ForwardingRule resources available to the specified project and region.",
          flatPath = "projects/{project}/regions/{region}/forwardingRules",
          httpMethod = "GET",
          id = "compute.forwardingRules.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/forwardingRules",
          response = {
            ["$ref"] = "ForwardingRuleList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates the specified forwarding rule with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules. Currently, you can only patch the network_tier field.",
          flatPath = "projects/{project}/regions/{region}/forwardingRules/{forwardingRule}",
          httpMethod = "PATCH",
          id = "compute.forwardingRules.patch",
          parameterOrder = {
            "project",
            "region",
            "forwardingRule",
          },
          parameters = {
            forwardingRule = {
              description = "Name of the ForwardingRule resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/forwardingRules/{forwardingRule}",
          request = {
            ["$ref"] = "ForwardingRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets the labels on the specified resource. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/regions/{region}/forwardingRules/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.forwardingRules.setLabels",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/forwardingRules/{resource}/setLabels",
          request = {
            ["$ref"] = "RegionSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setTarget = {
          description = "Changes target URL for forwarding rule. The new target should be of the same type as the old target.",
          flatPath = "projects/{project}/regions/{region}/forwardingRules/{forwardingRule}/setTarget",
          httpMethod = "POST",
          id = "compute.forwardingRules.setTarget",
          parameterOrder = {
            "project",
            "region",
            "forwardingRule",
          },
          parameters = {
            forwardingRule = {
              description = "Name of the ForwardingRule resource in which target is to be set.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/forwardingRules/{forwardingRule}/setTarget",
          request = {
            ["$ref"] = "TargetReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    globalAddresses = {
      methods = {
        delete = {
          description = "Deletes the specified address resource.",
          flatPath = "projects/{project}/global/addresses/{address}",
          httpMethod = "DELETE",
          id = "compute.globalAddresses.delete",
          parameterOrder = {
            "project",
            "address",
          },
          parameters = {
            address = {
              description = "Name of the address resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/addresses/{address}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified address resource. Gets a list of available addresses by making a list() request.",
          flatPath = "projects/{project}/global/addresses/{address}",
          httpMethod = "GET",
          id = "compute.globalAddresses.get",
          parameterOrder = {
            "project",
            "address",
          },
          parameters = {
            address = {
              description = "Name of the address resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/addresses/{address}",
          response = {
            ["$ref"] = "Address",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an address resource in the specified project by using the data included in the request.",
          flatPath = "projects/{project}/global/addresses",
          httpMethod = "POST",
          id = "compute.globalAddresses.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/addresses",
          request = {
            ["$ref"] = "Address",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of global addresses.",
          flatPath = "projects/{project}/global/addresses",
          httpMethod = "GET",
          id = "compute.globalAddresses.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/addresses",
          response = {
            ["$ref"] = "AddressList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setLabels = {
          description = "Sets the labels on a GlobalAddress. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/global/addresses/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.globalAddresses.setLabels",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/addresses/{resource}/setLabels",
          request = {
            ["$ref"] = "GlobalSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    globalForwardingRules = {
      methods = {
        delete = {
          description = "Deletes the specified GlobalForwardingRule resource.",
          flatPath = "projects/{project}/global/forwardingRules/{forwardingRule}",
          httpMethod = "DELETE",
          id = "compute.globalForwardingRules.delete",
          parameterOrder = {
            "project",
            "forwardingRule",
          },
          parameters = {
            forwardingRule = {
              description = "Name of the ForwardingRule resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/forwardingRules/{forwardingRule}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified GlobalForwardingRule resource. Gets a list of available forwarding rules by making a list() request.",
          flatPath = "projects/{project}/global/forwardingRules/{forwardingRule}",
          httpMethod = "GET",
          id = "compute.globalForwardingRules.get",
          parameterOrder = {
            "project",
            "forwardingRule",
          },
          parameters = {
            forwardingRule = {
              description = "Name of the ForwardingRule resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/forwardingRules/{forwardingRule}",
          response = {
            ["$ref"] = "ForwardingRule",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a GlobalForwardingRule resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/forwardingRules",
          httpMethod = "POST",
          id = "compute.globalForwardingRules.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/forwardingRules",
          request = {
            ["$ref"] = "ForwardingRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of GlobalForwardingRule resources available to the specified project.",
          flatPath = "projects/{project}/global/forwardingRules",
          httpMethod = "GET",
          id = "compute.globalForwardingRules.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/forwardingRules",
          response = {
            ["$ref"] = "ForwardingRuleList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates the specified forwarding rule with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules. Currently, you can only patch the network_tier field.",
          flatPath = "projects/{project}/global/forwardingRules/{forwardingRule}",
          httpMethod = "PATCH",
          id = "compute.globalForwardingRules.patch",
          parameterOrder = {
            "project",
            "forwardingRule",
          },
          parameters = {
            forwardingRule = {
              description = "Name of the ForwardingRule resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/forwardingRules/{forwardingRule}",
          request = {
            ["$ref"] = "ForwardingRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets the labels on the specified resource. To learn more about labels, read the Labeling resources documentation.",
          flatPath = "projects/{project}/global/forwardingRules/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.globalForwardingRules.setLabels",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/forwardingRules/{resource}/setLabels",
          request = {
            ["$ref"] = "GlobalSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setTarget = {
          description = "Changes target URL for the GlobalForwardingRule resource. The new target should be of the same type as the old target.",
          flatPath = "projects/{project}/global/forwardingRules/{forwardingRule}/setTarget",
          httpMethod = "POST",
          id = "compute.globalForwardingRules.setTarget",
          parameterOrder = {
            "project",
            "forwardingRule",
          },
          parameters = {
            forwardingRule = {
              description = "Name of the ForwardingRule resource in which target is to be set.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/forwardingRules/{forwardingRule}/setTarget",
          request = {
            ["$ref"] = "TargetReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    globalNetworkEndpointGroups = {
      methods = {
        attachNetworkEndpoints = {
          description = "Attach a network endpoint to the specified network endpoint group.",
          flatPath = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}/attachNetworkEndpoints",
          httpMethod = "POST",
          id = "compute.globalNetworkEndpointGroups.attachNetworkEndpoints",
          parameterOrder = {
            "project",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group where you are attaching network endpoints to. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}/attachNetworkEndpoints",
          request = {
            ["$ref"] = "GlobalNetworkEndpointGroupsAttachEndpointsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified network endpoint group.Note that the NEG cannot be deleted if there are backend services referencing it.",
          flatPath = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}",
          httpMethod = "DELETE",
          id = "compute.globalNetworkEndpointGroups.delete",
          parameterOrder = {
            "project",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group to delete. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        detachNetworkEndpoints = {
          description = "Detach the network endpoint from the specified network endpoint group.",
          flatPath = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}/detachNetworkEndpoints",
          httpMethod = "POST",
          id = "compute.globalNetworkEndpointGroups.detachNetworkEndpoints",
          parameterOrder = {
            "project",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group where you are removing network endpoints. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}/detachNetworkEndpoints",
          request = {
            ["$ref"] = "GlobalNetworkEndpointGroupsDetachEndpointsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified network endpoint group. Gets a list of available network endpoint groups by making a list() request.",
          flatPath = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}",
          httpMethod = "GET",
          id = "compute.globalNetworkEndpointGroups.get",
          parameterOrder = {
            "project",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}",
          response = {
            ["$ref"] = "NetworkEndpointGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a network endpoint group in the specified project using the parameters that are included in the request.",
          flatPath = "projects/{project}/global/networkEndpointGroups",
          httpMethod = "POST",
          id = "compute.globalNetworkEndpointGroups.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networkEndpointGroups",
          request = {
            ["$ref"] = "NetworkEndpointGroup",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of network endpoint groups that are located in the specified project.",
          flatPath = "projects/{project}/global/networkEndpointGroups",
          httpMethod = "GET",
          id = "compute.globalNetworkEndpointGroups.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/networkEndpointGroups",
          response = {
            ["$ref"] = "NetworkEndpointGroupList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listNetworkEndpoints = {
          description = "Lists the network endpoints in the specified network endpoint group.",
          flatPath = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}/listNetworkEndpoints",
          httpMethod = "POST",
          id = "compute.globalNetworkEndpointGroups.listNetworkEndpoints",
          parameterOrder = {
            "project",
            "networkEndpointGroup",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            networkEndpointGroup = {
              description = "The name of the network endpoint group from which you want to generate a list of included network endpoints. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/networkEndpointGroups/{networkEndpointGroup}/listNetworkEndpoints",
          response = {
            ["$ref"] = "NetworkEndpointGroupsListNetworkEndpoints",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    globalOperations = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of all operations.",
          flatPath = "projects/{project}/aggregated/operations",
          httpMethod = "GET",
          id = "compute.globalOperations.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/operations",
          response = {
            ["$ref"] = "OperationAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified Operations resource.",
          flatPath = "projects/{project}/global/operations/{operation}",
          httpMethod = "DELETE",
          id = "compute.globalOperations.delete",
          parameterOrder = {
            "project",
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/operations/{operation}",
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Retrieves the specified Operations resource.",
          flatPath = "projects/{project}/global/operations/{operation}",
          httpMethod = "GET",
          id = "compute.globalOperations.get",
          parameterOrder = {
            "project",
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/operations/{operation}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves a list of Operation resources contained within the specified project.",
          flatPath = "projects/{project}/global/operations",
          httpMethod = "GET",
          id = "compute.globalOperations.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/operations",
          response = {
            ["$ref"] = "OperationList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        wait = {
          description = "Waits for the specified Operation resource to return as `DONE` or for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method differs from the `GET` method in that it waits for no more than the default deadline (2 minutes) and then returns the current state of the operation, which might be `DONE` or still in progress. This method is called on a best-effort basis. Specifically: - In uncommon cases, when the server is overloaded, the request might return before the default deadline is reached, or might return after zero seconds. - If the default deadline is reached, there is no guarantee that the operation is actually done when the method returns. Be prepared to retry if the operation is not `DONE`. ",
          flatPath = "projects/{project}/global/operations/{operation}/wait",
          httpMethod = "POST",
          id = "compute.globalOperations.wait",
          parameterOrder = {
            "project",
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/operations/{operation}/wait",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    globalOrganizationOperations = {
      methods = {
        delete = {
          description = "Deletes the specified Operations resource.",
          flatPath = "locations/global/operations/{operation}",
          httpMethod = "DELETE",
          id = "compute.globalOrganizationOperations.delete",
          parameterOrder = {
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            parentId = {
              description = "Parent ID for this request.",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/operations/{operation}",
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Retrieves the specified Operations resource. Gets a list of operations by making a `list()` request.",
          flatPath = "locations/global/operations/{operation}",
          httpMethod = "GET",
          id = "compute.globalOrganizationOperations.get",
          parameterOrder = {
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            parentId = {
              description = "Parent ID for this request.",
              location = "query",
              type = "string",
            },
          },
          path = "locations/global/operations/{operation}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves a list of Operation resources contained within the specified organization.",
          flatPath = "locations/global/operations",
          httpMethod = "GET",
          id = "compute.globalOrganizationOperations.list",
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            parentId = {
              description = "Parent ID for this request.",
              location = "query",
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "locations/global/operations",
          response = {
            ["$ref"] = "OperationList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    globalPublicDelegatedPrefixes = {
      methods = {
        delete = {
          description = "Deletes the specified global PublicDelegatedPrefix.",
          flatPath = "projects/{project}/global/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          httpMethod = "DELETE",
          id = "compute.globalPublicDelegatedPrefixes.delete",
          parameterOrder = {
            "project",
            "publicDelegatedPrefix",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            publicDelegatedPrefix = {
              description = "Name of the PublicDelegatedPrefix resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified global PublicDelegatedPrefix resource.",
          flatPath = "projects/{project}/global/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          httpMethod = "GET",
          id = "compute.globalPublicDelegatedPrefixes.get",
          parameterOrder = {
            "project",
            "publicDelegatedPrefix",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            publicDelegatedPrefix = {
              description = "Name of the PublicDelegatedPrefix resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          response = {
            ["$ref"] = "PublicDelegatedPrefix",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a global PublicDelegatedPrefix in the specified project using the parameters that are included in the request.",
          flatPath = "projects/{project}/global/publicDelegatedPrefixes",
          httpMethod = "POST",
          id = "compute.globalPublicDelegatedPrefixes.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/publicDelegatedPrefixes",
          request = {
            ["$ref"] = "PublicDelegatedPrefix",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists the global PublicDelegatedPrefixes for a project.",
          flatPath = "projects/{project}/global/publicDelegatedPrefixes",
          httpMethod = "GET",
          id = "compute.globalPublicDelegatedPrefixes.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/publicDelegatedPrefixes",
          response = {
            ["$ref"] = "PublicDelegatedPrefixList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified global PublicDelegatedPrefix resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          httpMethod = "PATCH",
          id = "compute.globalPublicDelegatedPrefixes.patch",
          parameterOrder = {
            "project",
            "publicDelegatedPrefix",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            publicDelegatedPrefix = {
              description = "Name of the PublicDelegatedPrefix resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          request = {
            ["$ref"] = "PublicDelegatedPrefix",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    healthChecks = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all HealthCheck resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/healthChecks",
          httpMethod = "GET",
          id = "compute.healthChecks.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/healthChecks",
          response = {
            ["$ref"] = "HealthChecksAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified HealthCheck resource.",
          flatPath = "projects/{project}/global/healthChecks/{healthCheck}",
          httpMethod = "DELETE",
          id = "compute.healthChecks.delete",
          parameterOrder = {
            "project",
            "healthCheck",
          },
          parameters = {
            healthCheck = {
              description = "Name of the HealthCheck resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/healthChecks/{healthCheck}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified HealthCheck resource. Gets a list of available health checks by making a list() request.",
          flatPath = "projects/{project}/global/healthChecks/{healthCheck}",
          httpMethod = "GET",
          id = "compute.healthChecks.get",
          parameterOrder = {
            "project",
            "healthCheck",
          },
          parameters = {
            healthCheck = {
              description = "Name of the HealthCheck resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/healthChecks/{healthCheck}",
          response = {
            ["$ref"] = "HealthCheck",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a HealthCheck resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/healthChecks",
          httpMethod = "POST",
          id = "compute.healthChecks.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/healthChecks",
          request = {
            ["$ref"] = "HealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of HealthCheck resources available to the specified project.",
          flatPath = "projects/{project}/global/healthChecks",
          httpMethod = "GET",
          id = "compute.healthChecks.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/healthChecks",
          response = {
            ["$ref"] = "HealthCheckList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates a HealthCheck resource in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/healthChecks/{healthCheck}",
          httpMethod = "PATCH",
          id = "compute.healthChecks.patch",
          parameterOrder = {
            "project",
            "healthCheck",
          },
          parameters = {
            healthCheck = {
              description = "Name of the HealthCheck resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/healthChecks/{healthCheck}",
          request = {
            ["$ref"] = "HealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates a HealthCheck resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/healthChecks/{healthCheck}",
          httpMethod = "PUT",
          id = "compute.healthChecks.update",
          parameterOrder = {
            "project",
            "healthCheck",
          },
          parameters = {
            healthCheck = {
              description = "Name of the HealthCheck resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/healthChecks/{healthCheck}",
          request = {
            ["$ref"] = "HealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    httpHealthChecks = {
      methods = {
        delete = {
          description = "Deletes the specified HttpHealthCheck resource.",
          flatPath = "projects/{project}/global/httpHealthChecks/{httpHealthCheck}",
          httpMethod = "DELETE",
          id = "compute.httpHealthChecks.delete",
          parameterOrder = {
            "project",
            "httpHealthCheck",
          },
          parameters = {
            httpHealthCheck = {
              description = "Name of the HttpHealthCheck resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/httpHealthChecks/{httpHealthCheck}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified HttpHealthCheck resource. Gets a list of available HTTP health checks by making a list() request.",
          flatPath = "projects/{project}/global/httpHealthChecks/{httpHealthCheck}",
          httpMethod = "GET",
          id = "compute.httpHealthChecks.get",
          parameterOrder = {
            "project",
            "httpHealthCheck",
          },
          parameters = {
            httpHealthCheck = {
              description = "Name of the HttpHealthCheck resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/httpHealthChecks/{httpHealthCheck}",
          response = {
            ["$ref"] = "HttpHealthCheck",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a HttpHealthCheck resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/httpHealthChecks",
          httpMethod = "POST",
          id = "compute.httpHealthChecks.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/httpHealthChecks",
          request = {
            ["$ref"] = "HttpHealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of HttpHealthCheck resources available to the specified project.",
          flatPath = "projects/{project}/global/httpHealthChecks",
          httpMethod = "GET",
          id = "compute.httpHealthChecks.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/httpHealthChecks",
          response = {
            ["$ref"] = "HttpHealthCheckList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates a HttpHealthCheck resource in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/httpHealthChecks/{httpHealthCheck}",
          httpMethod = "PATCH",
          id = "compute.httpHealthChecks.patch",
          parameterOrder = {
            "project",
            "httpHealthCheck",
          },
          parameters = {
            httpHealthCheck = {
              description = "Name of the HttpHealthCheck resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/httpHealthChecks/{httpHealthCheck}",
          request = {
            ["$ref"] = "HttpHealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates a HttpHealthCheck resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/httpHealthChecks/{httpHealthCheck}",
          httpMethod = "PUT",
          id = "compute.httpHealthChecks.update",
          parameterOrder = {
            "project",
            "httpHealthCheck",
          },
          parameters = {
            httpHealthCheck = {
              description = "Name of the HttpHealthCheck resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/httpHealthChecks/{httpHealthCheck}",
          request = {
            ["$ref"] = "HttpHealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    httpsHealthChecks = {
      methods = {
        delete = {
          description = "Deletes the specified HttpsHealthCheck resource.",
          flatPath = "projects/{project}/global/httpsHealthChecks/{httpsHealthCheck}",
          httpMethod = "DELETE",
          id = "compute.httpsHealthChecks.delete",
          parameterOrder = {
            "project",
            "httpsHealthCheck",
          },
          parameters = {
            httpsHealthCheck = {
              description = "Name of the HttpsHealthCheck resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/httpsHealthChecks/{httpsHealthCheck}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified HttpsHealthCheck resource. Gets a list of available HTTPS health checks by making a list() request.",
          flatPath = "projects/{project}/global/httpsHealthChecks/{httpsHealthCheck}",
          httpMethod = "GET",
          id = "compute.httpsHealthChecks.get",
          parameterOrder = {
            "project",
            "httpsHealthCheck",
          },
          parameters = {
            httpsHealthCheck = {
              description = "Name of the HttpsHealthCheck resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/httpsHealthChecks/{httpsHealthCheck}",
          response = {
            ["$ref"] = "HttpsHealthCheck",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a HttpsHealthCheck resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/httpsHealthChecks",
          httpMethod = "POST",
          id = "compute.httpsHealthChecks.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/httpsHealthChecks",
          request = {
            ["$ref"] = "HttpsHealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of HttpsHealthCheck resources available to the specified project.",
          flatPath = "projects/{project}/global/httpsHealthChecks",
          httpMethod = "GET",
          id = "compute.httpsHealthChecks.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/httpsHealthChecks",
          response = {
            ["$ref"] = "HttpsHealthCheckList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates a HttpsHealthCheck resource in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/httpsHealthChecks/{httpsHealthCheck}",
          httpMethod = "PATCH",
          id = "compute.httpsHealthChecks.patch",
          parameterOrder = {
            "project",
            "httpsHealthCheck",
          },
          parameters = {
            httpsHealthCheck = {
              description = "Name of the HttpsHealthCheck resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/httpsHealthChecks/{httpsHealthCheck}",
          request = {
            ["$ref"] = "HttpsHealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates a HttpsHealthCheck resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/httpsHealthChecks/{httpsHealthCheck}",
          httpMethod = "PUT",
          id = "compute.httpsHealthChecks.update",
          parameterOrder = {
            "project",
            "httpsHealthCheck",
          },
          parameters = {
            httpsHealthCheck = {
              description = "Name of the HttpsHealthCheck resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/httpsHealthChecks/{httpsHealthCheck}",
          request = {
            ["$ref"] = "HttpsHealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    imageFamilyViews = {
      methods = {
        get = {
          description = "Returns the latest image that is part of an image family, is not deprecated and is rolled out in the specified zone.",
          flatPath = "projects/{project}/zones/{zone}/imageFamilyViews/{family}",
          httpMethod = "GET",
          id = "compute.imageFamilyViews.get",
          parameterOrder = {
            "project",
            "zone",
            "family",
          },
          parameters = {
            family = {
              description = "Name of the image family to search for.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/imageFamilyViews/{family}",
          response = {
            ["$ref"] = "ImageFamilyView",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    images = {
      methods = {
        delete = {
          description = "Deletes the specified image.",
          flatPath = "projects/{project}/global/images/{image}",
          httpMethod = "DELETE",
          id = "compute.images.delete",
          parameterOrder = {
            "project",
            "image",
          },
          parameters = {
            image = {
              description = "Name of the image resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/images/{image}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        deprecate = {
          description = "Sets the deprecation status of an image. If an empty request body is given, clears the deprecation status instead.",
          flatPath = "projects/{project}/global/images/{image}/deprecate",
          httpMethod = "POST",
          id = "compute.images.deprecate",
          parameterOrder = {
            "project",
            "image",
          },
          parameters = {
            image = {
              description = "Image name.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/images/{image}/deprecate",
          request = {
            ["$ref"] = "DeprecationStatus",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified image. Gets a list of available images by making a list() request.",
          flatPath = "projects/{project}/global/images/{image}",
          httpMethod = "GET",
          id = "compute.images.get",
          parameterOrder = {
            "project",
            "image",
          },
          parameters = {
            image = {
              description = "Name of the image resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/images/{image}",
          response = {
            ["$ref"] = "Image",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getFromFamily = {
          description = "Returns the latest image that is part of an image family and is not deprecated.",
          flatPath = "projects/{project}/global/images/family/{family}",
          httpMethod = "GET",
          id = "compute.images.getFromFamily",
          parameterOrder = {
            "project",
            "family",
          },
          parameters = {
            family = {
              description = "Name of the image family to search for.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/images/family/{family}",
          response = {
            ["$ref"] = "Image",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/global/images/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.images.getIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/images/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an image in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/images",
          httpMethod = "POST",
          id = "compute.images.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            forceCreate = {
              description = "Force image creation if true.",
              location = "query",
              type = "boolean",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/images",
          request = {
            ["$ref"] = "Image",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/devstorage.full_control",
            "https://www.googleapis.com/auth/devstorage.read_only",
            "https://www.googleapis.com/auth/devstorage.read_write",
          },
        },
        list = {
          description = "Retrieves the list of custom images available to the specified project. Custom images are images you create that belong to your project. This method does not get any images that belong to other projects, including publicly-available images, like Debian 8. If you want to get a list of publicly-available images, use this method to make a request to the respective image project, such as debian-cloud or windows-cloud.",
          flatPath = "projects/{project}/global/images",
          httpMethod = "GET",
          id = "compute.images.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/images",
          response = {
            ["$ref"] = "ImageList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified image with the data included in the request. Only the following fields can be modified: family, description, deprecation status.",
          flatPath = "projects/{project}/global/images/{image}",
          httpMethod = "PATCH",
          id = "compute.images.patch",
          parameterOrder = {
            "project",
            "image",
          },
          parameters = {
            image = {
              description = "Name of the image resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/images/{image}",
          request = {
            ["$ref"] = "Image",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/global/images/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.images.setIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/images/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "GlobalSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets the labels on an image. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/global/images/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.images.setLabels",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/images/{resource}/setLabels",
          request = {
            ["$ref"] = "GlobalSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/global/images/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.images.testIamPermissions",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/images/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    instanceGroupManagers = {
      methods = {
        abandonInstances = {
          description = "Flags the specified instances to be removed from the managed instance group. Abandoning an instance does not delete the instance, but it does remove the instance from any target pools that are applied by the managed instance group. This method reduces the targetSize of the managed instance group by the number of instances that you abandon. This operation is marked as DONE when the action is scheduled even if the instances have not yet been removed from the group. You must separately verify the status of the abandoning action with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/abandonInstances",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.abandonInstances",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/abandonInstances",
          request = {
            ["$ref"] = "InstanceGroupManagersAbandonInstancesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        aggregatedList = {
          description = "Retrieves the list of managed instance groups and groups them by zone.",
          flatPath = "projects/{project}/aggregated/instanceGroupManagers",
          httpMethod = "GET",
          id = "compute.instanceGroupManagers.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/instanceGroupManagers",
          response = {
            ["$ref"] = "InstanceGroupManagerAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        applyUpdatesToInstances = {
          description = "Applies changes to selected instances on the managed instance group. This method can be used to apply new overrides and/or new versions.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/applyUpdatesToInstances",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.applyUpdatesToInstances",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group, should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located. Should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/applyUpdatesToInstances",
          request = {
            ["$ref"] = "InstanceGroupManagersApplyUpdatesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        createInstances = {
          description = "Creates instances with per-instance configurations in this managed instance group. Instances are created using the current instance template. The create instances operation is marked DONE if the createInstances request is successful. The underlying actions take additional time. You must separately verify the status of the creating or actions with the listmanagedinstances method.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/createInstances",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.createInstances",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/createInstances",
          request = {
            ["$ref"] = "InstanceGroupManagersCreateInstancesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified managed instance group and all of the instances in that group. Note that the instance group must not belong to a backend service. Read Deleting an instance group for more information.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}",
          httpMethod = "DELETE",
          id = "compute.instanceGroupManagers.delete",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group to delete.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        deleteInstances = {
          description = "Flags the specified instances in the managed instance group for immediate deletion. The instances are also removed from any target pools of which they were a member. This method reduces the targetSize of the managed instance group by the number of instances that you delete. This operation is marked as DONE when the action is scheduled even if the instances are still being deleted. You must separately verify the status of the deleting action with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/deleteInstances",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.deleteInstances",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/deleteInstances",
          request = {
            ["$ref"] = "InstanceGroupManagersDeleteInstancesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        deletePerInstanceConfigs = {
          description = "Deletes selected per-instance configurations for the managed instance group.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/deletePerInstanceConfigs",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.deletePerInstanceConfigs",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/deletePerInstanceConfigs",
          request = {
            ["$ref"] = "InstanceGroupManagersDeletePerInstanceConfigsReq",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns all of the details about the specified managed instance group. Gets a list of available managed instance groups by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}",
          httpMethod = "GET",
          id = "compute.instanceGroupManagers.get",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}",
          response = {
            ["$ref"] = "InstanceGroupManager",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a managed instance group using the information that you specify in the request. After the group is created, instances in the group are created using the specified instance template. This operation is marked as DONE when the group is created even if the instances in the group have not yet been created. You must separately verify the status of the individual instances with the listmanagedinstances method. A managed instance group can have up to 1000 VM instances per group. Please contact Cloud Support if you need an increase in this limit.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.insert",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where you want to create the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers",
          request = {
            ["$ref"] = "InstanceGroupManager",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of managed instance groups that are contained within the specified project and zone.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers",
          httpMethod = "GET",
          id = "compute.instanceGroupManagers.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers",
          response = {
            ["$ref"] = "InstanceGroupManagerList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listErrors = {
          description = "Lists all errors thrown by actions on instances for a given managed instance group. The filter and orderBy query parameters are not supported.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/listErrors",
          httpMethod = "GET",
          id = "compute.instanceGroupManagers.listErrors",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            instanceGroupManager = {
              description = "The name of the managed instance group. It must be a string that meets the requirements in RFC1035, or an unsigned long integer: must match regexp pattern: (?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?)|1-9{0,19}.",
              location = "path",
              required = true,
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/listErrors",
          response = {
            ["$ref"] = "InstanceGroupManagersListErrorsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listManagedInstances = {
          description = "Lists all of the instances in the managed instance group. Each instance in the list has a currentAction, which indicates the action that the managed instance group is performing on the instance. For example, if the group is still creating an instance, the currentAction is CREATING. If a previous action failed, the list displays the errors for that failed action. The orderBy query parameter is not supported. The `pageToken` query parameter is supported only in the alpha and beta API and only if the group's `listManagedInstancesResults` field is set to `PAGINATED`.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/listManagedInstances",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.listManagedInstances",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/listManagedInstances",
          response = {
            ["$ref"] = "InstanceGroupManagersListManagedInstancesResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listPerInstanceConfigs = {
          description = "Lists all of the per-instance configurations defined for the managed instance group. The orderBy query parameter is not supported.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/listPerInstanceConfigs",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.listPerInstanceConfigs",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/listPerInstanceConfigs",
          response = {
            ["$ref"] = "InstanceGroupManagersListPerInstanceConfigsResp",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates a managed instance group using the information that you specify in the request. This operation is marked as DONE when the group is patched even if the instances in the group are still in the process of being patched. You must separately verify the status of the individual instances with the listManagedInstances method. This method supports PATCH semantics and uses the JSON merge patch format and processing rules. If you update your group to specify a new template or instance configuration, it's possible that your intended specification for each VM in the group is different from the current state of that VM. To learn how to apply an updated configuration to the VMs in a MIG, see Updating instances in a MIG.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}",
          httpMethod = "PATCH",
          id = "compute.instanceGroupManagers.patch",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the instance group manager.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where you want to create the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}",
          request = {
            ["$ref"] = "InstanceGroupManager",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        patchPerInstanceConfigs = {
          description = "Inserts or patches per-instance configurations for the managed instance group. perInstanceConfig.name serves as a key used to distinguish whether to perform insert or patch.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/patchPerInstanceConfigs",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.patchPerInstanceConfigs",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/patchPerInstanceConfigs",
          request = {
            ["$ref"] = "InstanceGroupManagersPatchPerInstanceConfigsReq",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        recreateInstances = {
          description = "Flags the specified VM instances in the managed instance group to be immediately recreated. Each instance is recreated using the group's current configuration. This operation is marked as DONE when the flag is set even if the instances have not yet been recreated. You must separately verify the status of each instance by checking its currentAction field; for more information, see Checking the status of managed instances. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/recreateInstances",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.recreateInstances",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/recreateInstances",
          request = {
            ["$ref"] = "InstanceGroupManagersRecreateInstancesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        resize = {
          description = "Resizes the managed instance group. If you increase the size, the group creates new instances using the current instance template. If you decrease the size, the group deletes instances. The resize operation is marked DONE when the resize actions are scheduled even if the group has not yet added or deleted any instances. You must separately verify the status of the creating or deleting actions with the listmanagedinstances method. When resizing down, the instance group arbitrarily chooses the order in which VMs are deleted. The group takes into account some VM attributes when making the selection including: + The status of the VM instance. + The health of the VM instance. + The instance template version the VM is based on. + For regional managed instance groups, the location of the VM instance. This list is subject to change. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/resize",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.resize",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
            "size",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            size = {
              description = "The number of running instances that the managed instance group should maintain at any given time. The group automatically adds or removes instances to maintain the number of instances specified by this parameter.",
              format = "int32",
              location = "query",
              required = true,
              type = "integer",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/resize",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setInstanceTemplate = {
          description = "Specifies the instance template to use when creating new instances in this group. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/setInstanceTemplate",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.setInstanceTemplate",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/setInstanceTemplate",
          request = {
            ["$ref"] = "InstanceGroupManagersSetInstanceTemplateRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setTargetPools = {
          description = "Modifies the target pools to which all instances in this managed instance group are assigned. The target pools automatically apply to all of the instances in the managed instance group. This operation is marked DONE when you make the request even if the instances have not yet been added to their target pools. The change might take some time to apply to all of the instances in the group depending on the size of the group.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/setTargetPools",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.setTargetPools",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/setTargetPools",
          request = {
            ["$ref"] = "InstanceGroupManagersSetTargetPoolsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        updatePerInstanceConfigs = {
          description = "Inserts or updates per-instance configurations for the managed instance group. perInstanceConfig.name serves as a key used to distinguish whether to perform insert or patch.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/updatePerInstanceConfigs",
          httpMethod = "POST",
          id = "compute.instanceGroupManagers.updatePerInstanceConfigs",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the managed instance group is located. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroupManagers/{instanceGroupManager}/updatePerInstanceConfigs",
          request = {
            ["$ref"] = "InstanceGroupManagersUpdatePerInstanceConfigsReq",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    instanceGroups = {
      methods = {
        addInstances = {
          description = "Adds a list of instances to the specified instance group. All of the instances in the instance group must be in the same network/subnetwork. Read Adding instances for more information.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}/addInstances",
          httpMethod = "POST",
          id = "compute.instanceGroups.addInstances",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroup",
          },
          parameters = {
            instanceGroup = {
              description = "The name of the instance group where you are adding instances.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}/addInstances",
          request = {
            ["$ref"] = "InstanceGroupsAddInstancesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        aggregatedList = {
          description = "Retrieves the list of instance groups and sorts them by zone.",
          flatPath = "projects/{project}/aggregated/instanceGroups",
          httpMethod = "GET",
          id = "compute.instanceGroups.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/instanceGroups",
          response = {
            ["$ref"] = "InstanceGroupAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified instance group. The instances in the group are not deleted. Note that instance group must not belong to a backend service. Read Deleting an instance group for more information.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}",
          httpMethod = "DELETE",
          id = "compute.instanceGroups.delete",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroup",
          },
          parameters = {
            instanceGroup = {
              description = "The name of the instance group to delete.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified zonal instance group. Get a list of available zonal instance groups by making a list() request. For managed instance groups, use the instanceGroupManagers or regionInstanceGroupManagers methods instead.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}",
          httpMethod = "GET",
          id = "compute.instanceGroups.get",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroup",
          },
          parameters = {
            instanceGroup = {
              description = "The name of the instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone where the instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}",
          response = {
            ["$ref"] = "InstanceGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an instance group in the specified project using the parameters that are included in the request.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroups",
          httpMethod = "POST",
          id = "compute.instanceGroups.insert",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where you want to create the instance group.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroups",
          request = {
            ["$ref"] = "InstanceGroup",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of zonal instance group resources contained within the specified zone. For managed instance groups, use the instanceGroupManagers or regionInstanceGroupManagers methods instead.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroups",
          httpMethod = "GET",
          id = "compute.instanceGroups.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone where the instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroups",
          response = {
            ["$ref"] = "InstanceGroupList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listInstances = {
          description = "Lists the instances in the specified instance group. The orderBy query parameter is not supported. The filter query parameter is supported, but only for expressions that use `eq` (equal) or `ne` (not equal) operators.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}/listInstances",
          httpMethod = "POST",
          id = "compute.instanceGroups.listInstances",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroup",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            instanceGroup = {
              description = "The name of the instance group from which you want to generate a list of included instances.",
              location = "path",
              required = true,
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone where the instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}/listInstances",
          request = {
            ["$ref"] = "InstanceGroupsListInstancesRequest",
          },
          response = {
            ["$ref"] = "InstanceGroupsListInstances",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        removeInstances = {
          description = "Removes one or more instances from the specified instance group, but does not delete those instances. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration before the VM instance is removed or deleted.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}/removeInstances",
          httpMethod = "POST",
          id = "compute.instanceGroups.removeInstances",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroup",
          },
          parameters = {
            instanceGroup = {
              description = "The name of the instance group where the specified instances will be removed.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}/removeInstances",
          request = {
            ["$ref"] = "InstanceGroupsRemoveInstancesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setNamedPorts = {
          description = "Sets the named ports for the specified instance group.",
          flatPath = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}/setNamedPorts",
          httpMethod = "POST",
          id = "compute.instanceGroups.setNamedPorts",
          parameterOrder = {
            "project",
            "zone",
            "instanceGroup",
          },
          parameters = {
            instanceGroup = {
              description = "The name of the instance group where the named ports are updated.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the instance group is located.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instanceGroups/{instanceGroup}/setNamedPorts",
          request = {
            ["$ref"] = "InstanceGroupsSetNamedPortsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    instanceTemplates = {
      methods = {
        delete = {
          description = "Deletes the specified instance template. Deleting an instance template is permanent and cannot be undone. It is not possible to delete templates that are already in use by a managed instance group.",
          flatPath = "projects/{project}/global/instanceTemplates/{instanceTemplate}",
          httpMethod = "DELETE",
          id = "compute.instanceTemplates.delete",
          parameterOrder = {
            "project",
            "instanceTemplate",
          },
          parameters = {
            instanceTemplate = {
              description = "The name of the instance template to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/instanceTemplates/{instanceTemplate}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified instance template. Gets a list of available instance templates by making a list() request.",
          flatPath = "projects/{project}/global/instanceTemplates/{instanceTemplate}",
          httpMethod = "GET",
          id = "compute.instanceTemplates.get",
          parameterOrder = {
            "project",
            "instanceTemplate",
          },
          parameters = {
            instanceTemplate = {
              description = "The name of the instance template.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/instanceTemplates/{instanceTemplate}",
          response = {
            ["$ref"] = "InstanceTemplate",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/global/instanceTemplates/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.instanceTemplates.getIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/instanceTemplates/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an instance template in the specified project using the data that is included in the request. If you are creating a new template to update an existing instance group, your new instance template must use the same network or, if applicable, the same subnetwork as the original template.",
          flatPath = "projects/{project}/global/instanceTemplates",
          httpMethod = "POST",
          id = "compute.instanceTemplates.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/instanceTemplates",
          request = {
            ["$ref"] = "InstanceTemplate",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of instance templates that are contained within the specified project.",
          flatPath = "projects/{project}/global/instanceTemplates",
          httpMethod = "GET",
          id = "compute.instanceTemplates.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/instanceTemplates",
          response = {
            ["$ref"] = "InstanceTemplateList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/global/instanceTemplates/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.instanceTemplates.setIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/instanceTemplates/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "GlobalSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/global/instanceTemplates/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.instanceTemplates.testIamPermissions",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/instanceTemplates/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    instances = {
      methods = {
        addAccessConfig = {
          description = "Adds an access config to an instance's network interface.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/addAccessConfig",
          httpMethod = "POST",
          id = "compute.instances.addAccessConfig",
          parameterOrder = {
            "project",
            "zone",
            "instance",
            "networkInterface",
          },
          parameters = {
            instance = {
              description = "The instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            networkInterface = {
              description = "The name of the network interface to add to this instance.",
              location = "query",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/addAccessConfig",
          request = {
            ["$ref"] = "AccessConfig",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        addResourcePolicies = {
          description = "Adds existing resource policies to an instance. You can only add one policy right now which will be applied to this instance for scheduling live migrations.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/addResourcePolicies",
          httpMethod = "POST",
          id = "compute.instances.addResourcePolicies",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "The instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/addResourcePolicies",
          request = {
            ["$ref"] = "InstancesAddResourcePoliciesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        aggregatedList = {
          description = "Retrieves an aggregated list of all of the instances in your project across all regions and zones. The performance of this method degrades when a filter is specified on a project that has a very large number of instances.",
          flatPath = "projects/{project}/aggregated/instances",
          httpMethod = "GET",
          id = "compute.instances.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/instances",
          response = {
            ["$ref"] = "InstanceAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        attachDisk = {
          description = "Attaches an existing Disk resource to an instance. You must first create the disk before you can attach it. It is not possible to create and attach a disk at the same time. For more information, read Adding a persistent disk to your instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/attachDisk",
          httpMethod = "POST",
          id = "compute.instances.attachDisk",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            forceAttach = {
              description = "Whether to force attach the regional disk even if it's currently attached to another instance. If you try to force attach a zonal disk to an instance, you will receive an error.",
              location = "query",
              type = "boolean",
            },
            instance = {
              description = "The instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/attachDisk",
          request = {
            ["$ref"] = "AttachedDisk",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        bulkInsert = {
          description = "Creates multiple instances. Count specifies the number of instances to create. For more information, see About bulk creation of VMs.",
          flatPath = "projects/{project}/zones/{zone}/instances/bulkInsert",
          httpMethod = "POST",
          id = "compute.instances.bulkInsert",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/bulkInsert",
          request = {
            ["$ref"] = "BulkInsertInstanceResource",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified Instance resource. For more information, see Deleting an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}",
          httpMethod = "DELETE",
          id = "compute.instances.delete",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        deleteAccessConfig = {
          description = "Deletes an access config from an instance's network interface.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/deleteAccessConfig",
          httpMethod = "POST",
          id = "compute.instances.deleteAccessConfig",
          parameterOrder = {
            "project",
            "zone",
            "instance",
            "accessConfig",
            "networkInterface",
          },
          parameters = {
            accessConfig = {
              description = "The name of the access config to delete.",
              location = "query",
              required = true,
              type = "string",
            },
            instance = {
              description = "The instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            networkInterface = {
              description = "The name of the network interface.",
              location = "query",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/deleteAccessConfig",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        detachDisk = {
          description = "Detaches a disk from an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/detachDisk",
          httpMethod = "POST",
          id = "compute.instances.detachDisk",
          parameterOrder = {
            "project",
            "zone",
            "instance",
            "deviceName",
          },
          parameters = {
            deviceName = {
              description = "The device name of the disk to detach. Make a get() request on the instance to view currently attached disks and device names.",
              location = "query",
              required = true,
              type = "string",
            },
            instance = {
              description = "Instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/detachDisk",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified Instance resource. Gets a list of available instances by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}",
          httpMethod = "GET",
          id = "compute.instances.get",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}",
          response = {
            ["$ref"] = "Instance",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getEffectiveFirewalls = {
          description = "Returns effective firewalls applied to an interface of the instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/getEffectiveFirewalls",
          httpMethod = "GET",
          id = "compute.instances.getEffectiveFirewalls",
          parameterOrder = {
            "project",
            "zone",
            "instance",
            "networkInterface",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            networkInterface = {
              description = "The name of the network interface to get the effective firewalls.",
              location = "query",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/getEffectiveFirewalls",
          response = {
            ["$ref"] = "InstancesGetEffectiveFirewallsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getGuestAttributes = {
          description = "Returns the specified guest attributes entry.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/getGuestAttributes",
          httpMethod = "GET",
          id = "compute.instances.getGuestAttributes",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            queryPath = {
              description = "Specifies the guest attributes path to be queried.",
              location = "query",
              type = "string",
            },
            variableKey = {
              description = "Specifies the key for the guest attributes entry.",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/getGuestAttributes",
          response = {
            ["$ref"] = "GuestAttributes",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/zones/{zone}/instances/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.instances.getIamPolicy",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getScreenshot = {
          description = "Returns the screenshot from the specified instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/screenshot",
          httpMethod = "GET",
          id = "compute.instances.getScreenshot",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/screenshot",
          response = {
            ["$ref"] = "Screenshot",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getSerialPortOutput = {
          description = "Returns the last 1 MB of serial port output from the specified instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/serialPort",
          httpMethod = "GET",
          id = "compute.instances.getSerialPortOutput",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            port = {
              default = "1",
              description = "Specifies which COM or serial port to retrieve data from.",
              format = "int32",
              location = "query",
              maximum = "4",
              minimum = "1",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            start = {
              description = "Specifies the starting byte position of the output to return. To start with the first byte of output to the specified port, omit this field or set it to `0`. If the output for that byte position is available, this field matches the `start` parameter sent with the request. If the amount of serial console output exceeds the size of the buffer (1 MB), the oldest output is discarded and is no longer available. If the requested start position refers to discarded output, the start position is adjusted to the oldest output still available, and the adjusted start position is returned as the `start` property value. You can also provide a negative start position, which translates to the most recent number of bytes written to the serial port. For example, -3 is interpreted as the most recent 3 bytes written to the serial console.",
              format = "int64",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/serialPort",
          response = {
            ["$ref"] = "SerialPortOutput",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getShieldedInstanceIdentity = {
          description = "Returns the Shielded Instance Identity of an instance",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/getShieldedInstanceIdentity",
          httpMethod = "GET",
          id = "compute.instances.getShieldedInstanceIdentity",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name or id of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/getShieldedInstanceIdentity",
          response = {
            ["$ref"] = "ShieldedInstanceIdentity",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an instance resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/zones/{zone}/instances",
          httpMethod = "POST",
          id = "compute.instances.insert",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sourceInstanceTemplate = {
              description = "Specifies instance template to create the instance. This field is optional. It can be a full or partial URL. For example, the following are all valid URLs to an instance template: - https://www.googleapis.com/compute/v1/projects/project /global/instanceTemplates/instanceTemplate - projects/project/global/instanceTemplates/instanceTemplate - global/instanceTemplates/instanceTemplate ",
              location = "query",
              type = "string",
            },
            sourceMachineImage = {
              description = "Specifies the machine image to use to create the instance. This field is optional. It can be a full or partial URL. For example, the following are all valid URLs to a machine image: - https://www.googleapis.com/compute/v1/projects/project/global/global /machineImages/machineImage - projects/project/global/global/machineImages/machineImage - global/machineImages/machineImage ",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances",
          request = {
            ["$ref"] = "Instance",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of instances contained within the specified zone.",
          flatPath = "projects/{project}/zones/{zone}/instances",
          httpMethod = "GET",
          id = "compute.instances.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances",
          response = {
            ["$ref"] = "InstanceList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listReferrers = {
          description = "Retrieves a list of resources that refer to the VM instance specified in the request. For example, if the VM instance is part of a managed or unmanaged instance group, the referrers list includes the instance group. For more information, read Viewing referrers to VM instances.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/referrers",
          httpMethod = "GET",
          id = "compute.instances.listReferrers",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            instance = {
              description = "Name of the target instance scoping this request, or '-' if the request should span over all instances in the container.",
              location = "path",
              pattern = "-|[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/referrers",
          response = {
            ["$ref"] = "InstanceListReferrers",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        removeResourcePolicies = {
          description = "Removes resource policies from an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/removeResourcePolicies",
          httpMethod = "POST",
          id = "compute.instances.removeResourcePolicies",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "The instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/removeResourcePolicies",
          request = {
            ["$ref"] = "InstancesRemoveResourcePoliciesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        reset = {
          description = "Performs a reset on the instance. This is a hard reset. The VM does not do a graceful shutdown. For more information, see Resetting an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/reset",
          httpMethod = "POST",
          id = "compute.instances.reset",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/reset",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        resume = {
          description = "Resumes an instance that was suspended using the instances().suspend method.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/resume",
          httpMethod = "POST",
          id = "compute.instances.resume",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance resource to resume.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/resume",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        sendDiagnosticInterrupt = {
          description = "Sends diagnostic interrupt to the instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/sendDiagnosticInterrupt",
          httpMethod = "POST",
          id = "compute.instances.sendDiagnosticInterrupt",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/sendDiagnosticInterrupt",
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setDeletionProtection = {
          description = "Sets deletion protection on the instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{resource}/setDeletionProtection",
          httpMethod = "POST",
          id = "compute.instances.setDeletionProtection",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            deletionProtection = {
              default = "true",
              description = "Whether the resource should be protected against deletion.",
              location = "query",
              type = "boolean",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{resource}/setDeletionProtection",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setDiskAutoDelete = {
          description = "Sets the auto-delete flag for a disk attached to an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setDiskAutoDelete",
          httpMethod = "POST",
          id = "compute.instances.setDiskAutoDelete",
          parameterOrder = {
            "project",
            "zone",
            "instance",
            "autoDelete",
            "deviceName",
          },
          parameters = {
            autoDelete = {
              description = "Whether to auto-delete the disk when the instance is deleted.",
              location = "query",
              required = true,
              type = "boolean",
            },
            deviceName = {
              description = "The device name of the disk to modify. Make a get() request on the instance to view currently attached disks and device names.",
              location = "query",
              pattern = "\\w[\\w.-]{0,254}",
              required = true,
              type = "string",
            },
            instance = {
              description = "The instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setDiskAutoDelete",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/zones/{zone}/instances/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.instances.setIamPolicy",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "ZoneSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets labels on an instance. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setLabels",
          httpMethod = "POST",
          id = "compute.instances.setLabels",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setLabels",
          request = {
            ["$ref"] = "InstancesSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setMachineResources = {
          description = "Changes the number and/or type of accelerator for a stopped instance to the values specified in the request.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setMachineResources",
          httpMethod = "POST",
          id = "compute.instances.setMachineResources",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setMachineResources",
          request = {
            ["$ref"] = "InstancesSetMachineResourcesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setMachineType = {
          description = "Changes the machine type for a stopped instance to the machine type specified in the request.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setMachineType",
          httpMethod = "POST",
          id = "compute.instances.setMachineType",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setMachineType",
          request = {
            ["$ref"] = "InstancesSetMachineTypeRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setMetadata = {
          description = "Sets metadata for the specified instance to the data included in the request.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setMetadata",
          httpMethod = "POST",
          id = "compute.instances.setMetadata",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setMetadata",
          request = {
            ["$ref"] = "Metadata",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setMinCpuPlatform = {
          description = "Changes the minimum CPU platform that this instance should use. This method can only be called on a stopped instance. For more information, read Specifying a Minimum CPU Platform.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setMinCpuPlatform",
          httpMethod = "POST",
          id = "compute.instances.setMinCpuPlatform",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setMinCpuPlatform",
          request = {
            ["$ref"] = "InstancesSetMinCpuPlatformRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setScheduling = {
          description = "Sets an instance's scheduling options. You can only call this method on a stopped instance, that is, a VM instance that is in a `TERMINATED` state. See Instance Life Cycle for more information on the possible instance states. For more information about setting scheduling options for a VM, see Set VM host maintenance policy.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setScheduling",
          httpMethod = "POST",
          id = "compute.instances.setScheduling",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setScheduling",
          request = {
            ["$ref"] = "Scheduling",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setServiceAccount = {
          description = "Sets the service account on the instance. For more information, read Changing the service account and access scopes for an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setServiceAccount",
          httpMethod = "POST",
          id = "compute.instances.setServiceAccount",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance resource to start.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setServiceAccount",
          request = {
            ["$ref"] = "InstancesSetServiceAccountRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setShieldedInstanceIntegrityPolicy = {
          description = "Sets the Shielded Instance integrity policy for an instance. You can only use this method on a running instance. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setShieldedInstanceIntegrityPolicy",
          httpMethod = "PATCH",
          id = "compute.instances.setShieldedInstanceIntegrityPolicy",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name or id of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setShieldedInstanceIntegrityPolicy",
          request = {
            ["$ref"] = "ShieldedInstanceIntegrityPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setTags = {
          description = "Sets network tags for the specified instance to the data included in the request.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/setTags",
          httpMethod = "POST",
          id = "compute.instances.setTags",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/setTags",
          request = {
            ["$ref"] = "Tags",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        simulateMaintenanceEvent = {
          description = "Simulates a host maintenance event on a VM. For more information, see Simulate a host maintenance event.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/simulateMaintenanceEvent",
          httpMethod = "POST",
          id = "compute.instances.simulateMaintenanceEvent",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/simulateMaintenanceEvent",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        start = {
          description = "Starts an instance that was stopped using the instances().stop method. For more information, see Restart an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/start",
          httpMethod = "POST",
          id = "compute.instances.start",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance resource to start.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/start",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        startWithEncryptionKey = {
          description = "Starts an instance that was stopped using the instances().stop method. For more information, see Restart an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/startWithEncryptionKey",
          httpMethod = "POST",
          id = "compute.instances.startWithEncryptionKey",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance resource to start.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/startWithEncryptionKey",
          request = {
            ["$ref"] = "InstancesStartWithEncryptionKeyRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        stop = {
          description = "Stops a running instance, shutting it down cleanly, and allows you to restart the instance at a later time. Stopped instances do not incur VM usage charges while they are stopped. However, resources that the VM is using, such as persistent disks and static IP addresses, will continue to be charged until they are deleted. For more information, see Stopping an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/stop",
          httpMethod = "POST",
          id = "compute.instances.stop",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            discardLocalSsd = {
              description = "If true, discard the contents of any attached localSSD partitions. Default value is false.",
              location = "query",
              type = "boolean",
            },
            instance = {
              description = "Name of the instance resource to stop.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/stop",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        suspend = {
          description = "This method suspends a running instance, saving its state to persistent storage, and allows you to resume the instance at a later time. Suspended instances have no compute costs (cores or RAM), and incur only storage charges for the saved VM memory and localSSD data. Any charged resources the virtual machine was using, such as persistent disks and static IP addresses, will continue to be charged while the instance is suspended. For more information, see Suspending and resuming an instance.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/suspend",
          httpMethod = "POST",
          id = "compute.instances.suspend",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            discardLocalSsd = {
              description = "If true, discard the contents of any attached localSSD partitions. Default value is false.",
              location = "query",
              type = "boolean",
            },
            instance = {
              description = "Name of the instance resource to suspend.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/suspend",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/zones/{zone}/instances/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.instances.testIamPermissions",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        update = {
          description = "Updates an instance only if the necessary resources are available. This method can update only a specific set of instance properties. See Updating a running instance for a list of updatable instance properties.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}",
          httpMethod = "PUT",
          id = "compute.instances.update",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            minimalAction = {
              description = "Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require.",
              enum = {
                "INVALID",
                "NO_EFFECT",
                "REFRESH",
                "RESTART",
              },
              enumDescriptions = {
                "",
                "No changes can be made to the instance.",
                "The instance will not restart.",
                "The instance will restart.",
              },
              location = "query",
              type = "string",
            },
            mostDisruptiveAllowedAction = {
              description = "Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.",
              enum = {
                "INVALID",
                "NO_EFFECT",
                "REFRESH",
                "RESTART",
              },
              enumDescriptions = {
                "",
                "No changes can be made to the instance.",
                "The instance will not restart.",
                "The instance will restart.",
              },
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}",
          request = {
            ["$ref"] = "Instance",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        updateAccessConfig = {
          description = "Updates the specified access config from an instance's network interface with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/updateAccessConfig",
          httpMethod = "POST",
          id = "compute.instances.updateAccessConfig",
          parameterOrder = {
            "project",
            "zone",
            "instance",
            "networkInterface",
          },
          parameters = {
            instance = {
              description = "The instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            networkInterface = {
              description = "The name of the network interface where the access config is attached.",
              location = "query",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/updateAccessConfig",
          request = {
            ["$ref"] = "AccessConfig",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        updateDisplayDevice = {
          description = "Updates the Display config for a VM instance. You can only use this method on a stopped VM instance. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/updateDisplayDevice",
          httpMethod = "PATCH",
          id = "compute.instances.updateDisplayDevice",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/updateDisplayDevice",
          request = {
            ["$ref"] = "DisplayDevice",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        updateNetworkInterface = {
          description = "Updates an instance's network interface. This method can only update an interface's alias IP range and attached network. See Modifying alias IP ranges for an existing instance for instructions on changing alias IP ranges. See Migrating a VM between networks for instructions on migrating an interface. This method follows PATCH semantics.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/updateNetworkInterface",
          httpMethod = "PATCH",
          id = "compute.instances.updateNetworkInterface",
          parameterOrder = {
            "project",
            "zone",
            "instance",
            "networkInterface",
          },
          parameters = {
            instance = {
              description = "The instance name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            networkInterface = {
              description = "The name of the network interface to update.",
              location = "query",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/updateNetworkInterface",
          request = {
            ["$ref"] = "NetworkInterface",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        updateShieldedInstanceConfig = {
          description = "Updates the Shielded Instance config for an instance. You can only use this method on a stopped instance. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/zones/{zone}/instances/{instance}/updateShieldedInstanceConfig",
          httpMethod = "PATCH",
          id = "compute.instances.updateShieldedInstanceConfig",
          parameterOrder = {
            "project",
            "zone",
            "instance",
          },
          parameters = {
            instance = {
              description = "Name or id of the instance scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/instances/{instance}/updateShieldedInstanceConfig",
          request = {
            ["$ref"] = "ShieldedInstanceConfig",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    interconnectAttachments = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of interconnect attachments.",
          flatPath = "projects/{project}/aggregated/interconnectAttachments",
          httpMethod = "GET",
          id = "compute.interconnectAttachments.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/interconnectAttachments",
          response = {
            ["$ref"] = "InterconnectAttachmentAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified interconnect attachment.",
          flatPath = "projects/{project}/regions/{region}/interconnectAttachments/{interconnectAttachment}",
          httpMethod = "DELETE",
          id = "compute.interconnectAttachments.delete",
          parameterOrder = {
            "project",
            "region",
            "interconnectAttachment",
          },
          parameters = {
            interconnectAttachment = {
              description = "Name of the interconnect attachment to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/interconnectAttachments/{interconnectAttachment}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified interconnect attachment.",
          flatPath = "projects/{project}/regions/{region}/interconnectAttachments/{interconnectAttachment}",
          httpMethod = "GET",
          id = "compute.interconnectAttachments.get",
          parameterOrder = {
            "project",
            "region",
            "interconnectAttachment",
          },
          parameters = {
            interconnectAttachment = {
              description = "Name of the interconnect attachment to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/interconnectAttachments/{interconnectAttachment}",
          response = {
            ["$ref"] = "InterconnectAttachment",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an InterconnectAttachment in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/interconnectAttachments",
          httpMethod = "POST",
          id = "compute.interconnectAttachments.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            validateOnly = {
              description = "If true, the request will not be committed.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/interconnectAttachments",
          request = {
            ["$ref"] = "InterconnectAttachment",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of interconnect attachments contained within the specified region.",
          flatPath = "projects/{project}/regions/{region}/interconnectAttachments",
          httpMethod = "GET",
          id = "compute.interconnectAttachments.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/interconnectAttachments",
          response = {
            ["$ref"] = "InterconnectAttachmentList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates the specified interconnect attachment with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/interconnectAttachments/{interconnectAttachment}",
          httpMethod = "PATCH",
          id = "compute.interconnectAttachments.patch",
          parameterOrder = {
            "project",
            "region",
            "interconnectAttachment",
          },
          parameters = {
            interconnectAttachment = {
              description = "Name of the interconnect attachment to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/interconnectAttachments/{interconnectAttachment}",
          request = {
            ["$ref"] = "InterconnectAttachment",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets the labels on an InterconnectAttachment. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/regions/{region}/interconnectAttachments/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.interconnectAttachments.setLabels",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/interconnectAttachments/{resource}/setLabels",
          request = {
            ["$ref"] = "RegionSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    interconnectLocations = {
      methods = {
        get = {
          description = "Returns the details for the specified interconnect location. Gets a list of available interconnect locations by making a list() request.",
          flatPath = "projects/{project}/global/interconnectLocations/{interconnectLocation}",
          httpMethod = "GET",
          id = "compute.interconnectLocations.get",
          parameterOrder = {
            "project",
            "interconnectLocation",
          },
          parameters = {
            interconnectLocation = {
              description = "Name of the interconnect location to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/interconnectLocations/{interconnectLocation}",
          response = {
            ["$ref"] = "InterconnectLocation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves the list of interconnect locations available to the specified project.",
          flatPath = "projects/{project}/global/interconnectLocations",
          httpMethod = "GET",
          id = "compute.interconnectLocations.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/interconnectLocations",
          response = {
            ["$ref"] = "InterconnectLocationList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    interconnects = {
      methods = {
        delete = {
          description = "Deletes the specified Interconnect.",
          flatPath = "projects/{project}/global/interconnects/{interconnect}",
          httpMethod = "DELETE",
          id = "compute.interconnects.delete",
          parameterOrder = {
            "project",
            "interconnect",
          },
          parameters = {
            interconnect = {
              description = "Name of the interconnect to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/interconnects/{interconnect}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified Interconnect. Get a list of available Interconnects by making a list() request.",
          flatPath = "projects/{project}/global/interconnects/{interconnect}",
          httpMethod = "GET",
          id = "compute.interconnects.get",
          parameterOrder = {
            "project",
            "interconnect",
          },
          parameters = {
            interconnect = {
              description = "Name of the interconnect to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/interconnects/{interconnect}",
          response = {
            ["$ref"] = "Interconnect",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getDiagnostics = {
          description = "Returns the interconnectDiagnostics for the specified Interconnect.",
          flatPath = "projects/{project}/global/interconnects/{interconnect}/getDiagnostics",
          httpMethod = "GET",
          id = "compute.interconnects.getDiagnostics",
          parameterOrder = {
            "project",
            "interconnect",
          },
          parameters = {
            interconnect = {
              description = "Name of the interconnect resource to query.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/interconnects/{interconnect}/getDiagnostics",
          response = {
            ["$ref"] = "InterconnectsGetDiagnosticsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an Interconnect in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/interconnects",
          httpMethod = "POST",
          id = "compute.interconnects.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/interconnects",
          request = {
            ["$ref"] = "Interconnect",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of Interconnects available to the specified project.",
          flatPath = "projects/{project}/global/interconnects",
          httpMethod = "GET",
          id = "compute.interconnects.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/interconnects",
          response = {
            ["$ref"] = "InterconnectList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates the specified Interconnect with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/interconnects/{interconnect}",
          httpMethod = "PATCH",
          id = "compute.interconnects.patch",
          parameterOrder = {
            "project",
            "interconnect",
          },
          parameters = {
            interconnect = {
              description = "Name of the interconnect to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/interconnects/{interconnect}",
          request = {
            ["$ref"] = "Interconnect",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets the labels on an Interconnect. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/global/interconnects/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.interconnects.setLabels",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/interconnects/{resource}/setLabels",
          request = {
            ["$ref"] = "GlobalSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    licenseCodes = {
      methods = {
        get = {
          description = "Return a specified license code. License codes are mirrored across all projects that have permissions to read the License Code. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
          flatPath = "projects/{project}/global/licenseCodes/{licenseCode}",
          httpMethod = "GET",
          id = "compute.licenseCodes.get",
          parameterOrder = {
            "project",
            "licenseCode",
          },
          parameters = {
            licenseCode = {
              description = "Number corresponding to the License code resource to return.",
              location = "path",
              pattern = "[0-9]{0,61}?",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/licenseCodes/{licenseCode}",
          response = {
            ["$ref"] = "LicenseCode",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
          flatPath = "projects/{project}/global/licenseCodes/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.licenseCodes.testIamPermissions",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/licenseCodes/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    licenses = {
      methods = {
        delete = {
          description = "Deletes the specified license. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
          flatPath = "projects/{project}/global/licenses/{license}",
          httpMethod = "DELETE",
          id = "compute.licenses.delete",
          parameterOrder = {
            "project",
            "license",
          },
          parameters = {
            license = {
              description = "Name of the license resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/licenses/{license}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified License resource. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
          flatPath = "projects/{project}/global/licenses/{license}",
          httpMethod = "GET",
          id = "compute.licenses.get",
          parameterOrder = {
            "project",
            "license",
          },
          parameters = {
            license = {
              description = "Name of the License resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/licenses/{license}",
          response = {
            ["$ref"] = "License",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
          flatPath = "projects/{project}/global/licenses/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.licenses.getIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/licenses/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Create a License resource in the specified project. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
          flatPath = "projects/{project}/global/licenses",
          httpMethod = "POST",
          id = "compute.licenses.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/licenses",
          request = {
            ["$ref"] = "License",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/devstorage.full_control",
            "https://www.googleapis.com/auth/devstorage.read_only",
            "https://www.googleapis.com/auth/devstorage.read_write",
          },
        },
        list = {
          description = "Retrieves the list of licenses available in the specified project. This method does not get any licenses that belong to other projects, including licenses attached to publicly-available images, like Debian 9. If you want to get a list of publicly-available licenses, use this method to make a request to the respective image project, such as debian-cloud or windows-cloud. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
          flatPath = "projects/{project}/global/licenses",
          httpMethod = "GET",
          id = "compute.licenses.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/licenses",
          response = {
            ["$ref"] = "LicensesListResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
          flatPath = "projects/{project}/global/licenses/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.licenses.setIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/licenses/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "GlobalSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
          flatPath = "projects/{project}/global/licenses/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.licenses.testIamPermissions",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/licenses/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    machineImages = {
      methods = {
        delete = {
          description = "Deletes the specified machine image. Deleting a machine image is permanent and cannot be undone.",
          flatPath = "projects/{project}/global/machineImages/{machineImage}",
          httpMethod = "DELETE",
          id = "compute.machineImages.delete",
          parameterOrder = {
            "project",
            "machineImage",
          },
          parameters = {
            machineImage = {
              description = "The name of the machine image to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/machineImages/{machineImage}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified machine image. Gets a list of available machine images by making a list() request.",
          flatPath = "projects/{project}/global/machineImages/{machineImage}",
          httpMethod = "GET",
          id = "compute.machineImages.get",
          parameterOrder = {
            "project",
            "machineImage",
          },
          parameters = {
            machineImage = {
              description = "The name of the machine image.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/machineImages/{machineImage}",
          response = {
            ["$ref"] = "MachineImage",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/global/machineImages/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.machineImages.getIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/machineImages/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a machine image in the specified project using the data that is included in the request. If you are creating a new machine image to update an existing instance, your new machine image should use the same network or, if applicable, the same subnetwork as the original instance.",
          flatPath = "projects/{project}/global/machineImages",
          httpMethod = "POST",
          id = "compute.machineImages.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sourceInstance = {
              description = "Required. Source instance that is used to create the machine image from.",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/machineImages",
          request = {
            ["$ref"] = "MachineImage",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of machine images that are contained within the specified project.",
          flatPath = "projects/{project}/global/machineImages",
          httpMethod = "GET",
          id = "compute.machineImages.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/machineImages",
          response = {
            ["$ref"] = "MachineImageList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/global/machineImages/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.machineImages.setIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/machineImages/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "GlobalSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/global/machineImages/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.machineImages.testIamPermissions",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/machineImages/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    machineTypes = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of machine types.",
          flatPath = "projects/{project}/aggregated/machineTypes",
          httpMethod = "GET",
          id = "compute.machineTypes.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/machineTypes",
          response = {
            ["$ref"] = "MachineTypeAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        get = {
          description = "Returns the specified machine type. Gets a list of available machine types by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}/machineTypes/{machineType}",
          httpMethod = "GET",
          id = "compute.machineTypes.get",
          parameterOrder = {
            "project",
            "zone",
            "machineType",
          },
          parameters = {
            machineType = {
              description = "Name of the machine type to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/machineTypes/{machineType}",
          response = {
            ["$ref"] = "MachineType",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves a list of machine types available to the specified project.",
          flatPath = "projects/{project}/zones/{zone}/machineTypes",
          httpMethod = "GET",
          id = "compute.machineTypes.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/machineTypes",
          response = {
            ["$ref"] = "MachineTypeList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    networkAttachments = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all NetworkAttachment resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/networkAttachments",
          httpMethod = "GET",
          id = "compute.networkAttachments.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/networkAttachments",
          response = {
            ["$ref"] = "NetworkAttachmentAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified NetworkAttachment in the given scope",
          flatPath = "projects/{project}/regions/{region}/networkAttachments/{networkAttachment}",
          httpMethod = "DELETE",
          id = "compute.networkAttachments.delete",
          parameterOrder = {
            "project",
            "region",
            "networkAttachment",
          },
          parameters = {
            networkAttachment = {
              description = "Name of the NetworkAttachment resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). end_interface: MixerMutationRequestBuilder",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkAttachments/{networkAttachment}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified NetworkAttachment resource in the given scope.",
          flatPath = "projects/{project}/regions/{region}/networkAttachments/{networkAttachment}",
          httpMethod = "GET",
          id = "compute.networkAttachments.get",
          parameterOrder = {
            "project",
            "region",
            "networkAttachment",
          },
          parameters = {
            networkAttachment = {
              description = "Name of the NetworkAttachment resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkAttachments/{networkAttachment}",
          response = {
            ["$ref"] = "NetworkAttachment",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/regions/{region}/networkAttachments/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.networkAttachments.getIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkAttachments/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a NetworkAttachment in the specified project in the given scope using the parameters that are included in the request.",
          flatPath = "projects/{project}/regions/{region}/networkAttachments",
          httpMethod = "POST",
          id = "compute.networkAttachments.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). end_interface: MixerMutationRequestBuilder",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkAttachments",
          request = {
            ["$ref"] = "NetworkAttachment",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists the NetworkAttachments for a project in the given scope.",
          flatPath = "projects/{project}/regions/{region}/networkAttachments",
          httpMethod = "GET",
          id = "compute.networkAttachments.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/networkAttachments",
          response = {
            ["$ref"] = "NetworkAttachmentList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/regions/{region}/networkAttachments/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.networkAttachments.setIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkAttachments/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "RegionSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/regions/{region}/networkAttachments/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.networkAttachments.testIamPermissions",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkAttachments/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    networkEdgeSecurityServices = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all NetworkEdgeSecurityService resources available to the specified project.",
          flatPath = "projects/{project}/aggregated/networkEdgeSecurityServices",
          httpMethod = "GET",
          id = "compute.networkEdgeSecurityServices.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/networkEdgeSecurityServices",
          response = {
            ["$ref"] = "NetworkEdgeSecurityServiceAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified service.",
          flatPath = "projects/{project}/regions/{region}/networkEdgeSecurityServices/{networkEdgeSecurityService}",
          httpMethod = "DELETE",
          id = "compute.networkEdgeSecurityServices.delete",
          parameterOrder = {
            "project",
            "region",
            "networkEdgeSecurityService",
          },
          parameters = {
            networkEdgeSecurityService = {
              description = "Name of the network edge security service to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkEdgeSecurityServices/{networkEdgeSecurityService}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Gets a specified NetworkEdgeSecurityService.",
          flatPath = "projects/{project}/regions/{region}/networkEdgeSecurityServices/{networkEdgeSecurityService}",
          httpMethod = "GET",
          id = "compute.networkEdgeSecurityServices.get",
          parameterOrder = {
            "project",
            "region",
            "networkEdgeSecurityService",
          },
          parameters = {
            networkEdgeSecurityService = {
              description = "Name of the network edge security service to get.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkEdgeSecurityServices/{networkEdgeSecurityService}",
          response = {
            ["$ref"] = "NetworkEdgeSecurityService",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a new service in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/networkEdgeSecurityServices",
          httpMethod = "POST",
          id = "compute.networkEdgeSecurityServices.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            validateOnly = {
              description = "If true, the request will not be committed.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/networkEdgeSecurityServices",
          request = {
            ["$ref"] = "NetworkEdgeSecurityService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        patch = {
          description = "Patches the specified policy with the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/networkEdgeSecurityServices/{networkEdgeSecurityService}",
          httpMethod = "PATCH",
          id = "compute.networkEdgeSecurityServices.patch",
          parameterOrder = {
            "project",
            "region",
            "networkEdgeSecurityService",
          },
          parameters = {
            networkEdgeSecurityService = {
              description = "Name of the network edge security service to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            paths = {
              location = "query",
              repeated = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            updateMask = {
              description = "Indicates fields to be updated as part of this request.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkEdgeSecurityServices/{networkEdgeSecurityService}",
          request = {
            ["$ref"] = "NetworkEdgeSecurityService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    networkEndpointGroups = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of network endpoint groups and sorts them by zone.",
          flatPath = "projects/{project}/aggregated/networkEndpointGroups",
          httpMethod = "GET",
          id = "compute.networkEndpointGroups.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/networkEndpointGroups",
          response = {
            ["$ref"] = "NetworkEndpointGroupAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        attachNetworkEndpoints = {
          description = "Attach a list of network endpoints to the specified network endpoint group.",
          flatPath = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}/attachNetworkEndpoints",
          httpMethod = "POST",
          id = "compute.networkEndpointGroups.attachNetworkEndpoints",
          parameterOrder = {
            "project",
            "zone",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group where you are attaching network endpoints to. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the network endpoint group is located. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}/attachNetworkEndpoints",
          request = {
            ["$ref"] = "NetworkEndpointGroupsAttachEndpointsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified network endpoint group. The network endpoints in the NEG and the VM instances they belong to are not terminated when the NEG is deleted. Note that the NEG cannot be deleted if there are backend services referencing it.",
          flatPath = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}",
          httpMethod = "DELETE",
          id = "compute.networkEndpointGroups.delete",
          parameterOrder = {
            "project",
            "zone",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group to delete. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the network endpoint group is located. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        detachNetworkEndpoints = {
          description = "Detach a list of network endpoints from the specified network endpoint group.",
          flatPath = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}/detachNetworkEndpoints",
          httpMethod = "POST",
          id = "compute.networkEndpointGroups.detachNetworkEndpoints",
          parameterOrder = {
            "project",
            "zone",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group where you are removing network endpoints. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where the network endpoint group is located. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}/detachNetworkEndpoints",
          request = {
            ["$ref"] = "NetworkEndpointGroupsDetachEndpointsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified network endpoint group. Gets a list of available network endpoint groups by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}",
          httpMethod = "GET",
          id = "compute.networkEndpointGroups.get",
          parameterOrder = {
            "project",
            "zone",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone where the network endpoint group is located. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}",
          response = {
            ["$ref"] = "NetworkEndpointGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a network endpoint group in the specified project using the parameters that are included in the request.",
          flatPath = "projects/{project}/zones/{zone}/networkEndpointGroups",
          httpMethod = "POST",
          id = "compute.networkEndpointGroups.insert",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone where you want to create the network endpoint group. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/networkEndpointGroups",
          request = {
            ["$ref"] = "NetworkEndpointGroup",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of network endpoint groups that are located in the specified project and zone.",
          flatPath = "projects/{project}/zones/{zone}/networkEndpointGroups",
          httpMethod = "GET",
          id = "compute.networkEndpointGroups.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone where the network endpoint group is located. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/networkEndpointGroups",
          response = {
            ["$ref"] = "NetworkEndpointGroupList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listNetworkEndpoints = {
          description = "Lists the network endpoints in the specified network endpoint group.",
          flatPath = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}/listNetworkEndpoints",
          httpMethod = "POST",
          id = "compute.networkEndpointGroups.listNetworkEndpoints",
          parameterOrder = {
            "project",
            "zone",
            "networkEndpointGroup",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            networkEndpointGroup = {
              description = "The name of the network endpoint group from which you want to generate a list of included network endpoints. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone where the network endpoint group is located. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/networkEndpointGroups/{networkEndpointGroup}/listNetworkEndpoints",
          request = {
            ["$ref"] = "NetworkEndpointGroupsListEndpointsRequest",
          },
          response = {
            ["$ref"] = "NetworkEndpointGroupsListNetworkEndpoints",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/zones/{zone}/networkEndpointGroups/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.networkEndpointGroups.testIamPermissions",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/networkEndpointGroups/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    networkFirewallPolicies = {
      methods = {
        addAssociation = {
          description = "Inserts an association for the specified firewall policy.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}/addAssociation",
          httpMethod = "POST",
          id = "compute.networkFirewallPolicies.addAssociation",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            replaceExistingAssociation = {
              description = "Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.",
              location = "query",
              type = "boolean",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}/addAssociation",
          request = {
            ["$ref"] = "FirewallPolicyAssociation",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        addRule = {
          description = "Inserts a rule into a firewall policy.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}/addRule",
          httpMethod = "POST",
          id = "compute.networkFirewallPolicies.addRule",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            maxPriority = {
              description = "When rule.priority is not specified, auto choose a unused priority between minPriority and maxPriority>. This field is exclusive with rule.priority.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            minPriority = {
              description = "When rule.priority is not specified, auto choose a unused priority between minPriority and maxPriority>. This field is exclusive with rule.priority.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}/addRule",
          request = {
            ["$ref"] = "FirewallPolicyRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        cloneRules = {
          description = "Copies rules to the specified firewall policy.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}/cloneRules",
          httpMethod = "POST",
          id = "compute.networkFirewallPolicies.cloneRules",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sourceFirewallPolicy = {
              description = "The firewall policy from which to copy rules.",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}/cloneRules",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified policy.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}",
          httpMethod = "DELETE",
          id = "compute.networkFirewallPolicies.delete",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified network firewall policy.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}",
          httpMethod = "GET",
          id = "compute.networkFirewallPolicies.get",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to get.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}",
          response = {
            ["$ref"] = "FirewallPolicy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getAssociation = {
          description = "Gets an association with the specified name.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}/getAssociation",
          httpMethod = "GET",
          id = "compute.networkFirewallPolicies.getAssociation",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to which the queried association belongs.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            name = {
              description = "The name of the association to get from the firewall policy.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}/getAssociation",
          response = {
            ["$ref"] = "FirewallPolicyAssociation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/global/firewallPolicies/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.networkFirewallPolicies.getIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getRule = {
          description = "Gets a rule of the specified priority.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}/getRule",
          httpMethod = "GET",
          id = "compute.networkFirewallPolicies.getRule",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to which the queried rule belongs.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            priority = {
              description = "The priority of the rule to get from the firewall policy.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}/getRule",
          response = {
            ["$ref"] = "FirewallPolicyRule",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a new policy in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/firewallPolicies",
          httpMethod = "POST",
          id = "compute.networkFirewallPolicies.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies",
          request = {
            ["$ref"] = "FirewallPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists all the policies that have been configured for the specified project.",
          flatPath = "projects/{project}/global/firewallPolicies",
          httpMethod = "GET",
          id = "compute.networkFirewallPolicies.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/firewallPolicies",
          response = {
            ["$ref"] = "FirewallPolicyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified policy with the data included in the request.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}",
          httpMethod = "PATCH",
          id = "compute.networkFirewallPolicies.patch",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}",
          request = {
            ["$ref"] = "FirewallPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        patchRule = {
          description = "Patches a rule of the specified priority.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}/patchRule",
          httpMethod = "POST",
          id = "compute.networkFirewallPolicies.patchRule",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            priority = {
              description = "The priority of the rule to patch.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}/patchRule",
          request = {
            ["$ref"] = "FirewallPolicyRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        removeAssociation = {
          description = "Removes an association for the specified firewall policy.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}/removeAssociation",
          httpMethod = "POST",
          id = "compute.networkFirewallPolicies.removeAssociation",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            name = {
              description = "Name for the attachment that will be removed.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}/removeAssociation",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        removeRule = {
          description = "Deletes a rule of the specified priority.",
          flatPath = "projects/{project}/global/firewallPolicies/{firewallPolicy}/removeRule",
          httpMethod = "POST",
          id = "compute.networkFirewallPolicies.removeRule",
          parameterOrder = {
            "project",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            priority = {
              description = "The priority of the rule to remove from the firewall policy.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{firewallPolicy}/removeRule",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/global/firewallPolicies/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.networkFirewallPolicies.setIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "GlobalSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/global/firewallPolicies/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.networkFirewallPolicies.testIamPermissions",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/firewallPolicies/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    networks = {
      methods = {
        addPeering = {
          description = "Adds a peering to the specified network.",
          flatPath = "projects/{project}/global/networks/{network}/addPeering",
          httpMethod = "POST",
          id = "compute.networks.addPeering",
          parameterOrder = {
            "project",
            "network",
          },
          parameters = {
            network = {
              description = "Name of the network resource to add peering to.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networks/{network}/addPeering",
          request = {
            ["$ref"] = "NetworksAddPeeringRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified network.",
          flatPath = "projects/{project}/global/networks/{network}",
          httpMethod = "DELETE",
          id = "compute.networks.delete",
          parameterOrder = {
            "project",
            "network",
          },
          parameters = {
            network = {
              description = "Name of the network to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networks/{network}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified network. Gets a list of available networks by making a list() request.",
          flatPath = "projects/{project}/global/networks/{network}",
          httpMethod = "GET",
          id = "compute.networks.get",
          parameterOrder = {
            "project",
            "network",
          },
          parameters = {
            network = {
              description = "Name of the network to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/networks/{network}",
          response = {
            ["$ref"] = "Network",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getEffectiveFirewalls = {
          description = "Returns the effective firewalls on a given network.",
          flatPath = "projects/{project}/global/networks/{network}/getEffectiveFirewalls",
          httpMethod = "GET",
          id = "compute.networks.getEffectiveFirewalls",
          parameterOrder = {
            "project",
            "network",
          },
          parameters = {
            network = {
              description = "Name of the network for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/networks/{network}/getEffectiveFirewalls",
          response = {
            ["$ref"] = "NetworksGetEffectiveFirewallsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a network in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/networks",
          httpMethod = "POST",
          id = "compute.networks.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networks",
          request = {
            ["$ref"] = "Network",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of networks available to the specified project.",
          flatPath = "projects/{project}/global/networks",
          httpMethod = "GET",
          id = "compute.networks.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/networks",
          response = {
            ["$ref"] = "NetworkList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listPeeringRoutes = {
          description = "Lists the peering routes exchanged over peering connection.",
          flatPath = "projects/{project}/global/networks/{network}/listPeeringRoutes",
          httpMethod = "GET",
          id = "compute.networks.listPeeringRoutes",
          parameterOrder = {
            "project",
            "network",
          },
          parameters = {
            direction = {
              description = "The direction of the exchanged routes.",
              enum = {
                "INCOMING",
                "OUTGOING",
              },
              enumDescriptions = {
                "For routes exported from peer network.",
                "For routes exported from local network.",
              },
              location = "query",
              type = "string",
            },
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            network = {
              description = "Name of the network for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            peeringName = {
              description = "The response will show routes exchanged over the given peering connection.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The region of the request. The response will include all subnet routes, static routes and dynamic routes in the region.",
              location = "query",
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/networks/{network}/listPeeringRoutes",
          response = {
            ["$ref"] = "ExchangedPeeringRoutesList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified network with the data included in the request. Only the following fields can be modified: routingConfig.routingMode.",
          flatPath = "projects/{project}/global/networks/{network}",
          httpMethod = "PATCH",
          id = "compute.networks.patch",
          parameterOrder = {
            "project",
            "network",
          },
          parameters = {
            network = {
              description = "Name of the network to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networks/{network}",
          request = {
            ["$ref"] = "Network",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        removePeering = {
          description = "Removes a peering from the specified network.",
          flatPath = "projects/{project}/global/networks/{network}/removePeering",
          httpMethod = "POST",
          id = "compute.networks.removePeering",
          parameterOrder = {
            "project",
            "network",
          },
          parameters = {
            network = {
              description = "Name of the network resource to remove peering from.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networks/{network}/removePeering",
          request = {
            ["$ref"] = "NetworksRemovePeeringRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        switchToCustomMode = {
          description = "Switches the network mode from auto subnet mode to custom subnet mode.",
          flatPath = "projects/{project}/global/networks/{network}/switchToCustomMode",
          httpMethod = "POST",
          id = "compute.networks.switchToCustomMode",
          parameterOrder = {
            "project",
            "network",
          },
          parameters = {
            network = {
              description = "Name of the network to be updated.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networks/{network}/switchToCustomMode",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        updatePeering = {
          description = "Updates the specified network peering with the data included in the request. You can only modify the NetworkPeering.export_custom_routes field and the NetworkPeering.import_custom_routes field.",
          flatPath = "projects/{project}/global/networks/{network}/updatePeering",
          httpMethod = "PATCH",
          id = "compute.networks.updatePeering",
          parameterOrder = {
            "project",
            "network",
          },
          parameters = {
            network = {
              description = "Name of the network resource which the updated peering is belonging to.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/networks/{network}/updatePeering",
          request = {
            ["$ref"] = "NetworksUpdatePeeringRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    nodeGroups = {
      methods = {
        addNodes = {
          description = "Adds specified number of nodes to the node group.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}/addNodes",
          httpMethod = "POST",
          id = "compute.nodeGroups.addNodes",
          parameterOrder = {
            "project",
            "zone",
            "nodeGroup",
          },
          parameters = {
            nodeGroup = {
              description = "Name of the NodeGroup resource.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}/addNodes",
          request = {
            ["$ref"] = "NodeGroupsAddNodesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        aggregatedList = {
          description = "Retrieves an aggregated list of node groups. Note: use nodeGroups.listNodes for more details about each group.",
          flatPath = "projects/{project}/aggregated/nodeGroups",
          httpMethod = "GET",
          id = "compute.nodeGroups.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/nodeGroups",
          response = {
            ["$ref"] = "NodeGroupAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified NodeGroup resource.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}",
          httpMethod = "DELETE",
          id = "compute.nodeGroups.delete",
          parameterOrder = {
            "project",
            "zone",
            "nodeGroup",
          },
          parameters = {
            nodeGroup = {
              description = "Name of the NodeGroup resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        deleteNodes = {
          description = "Deletes specified nodes from the node group.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}/deleteNodes",
          httpMethod = "POST",
          id = "compute.nodeGroups.deleteNodes",
          parameterOrder = {
            "project",
            "zone",
            "nodeGroup",
          },
          parameters = {
            nodeGroup = {
              description = "Name of the NodeGroup resource whose nodes will be deleted.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}/deleteNodes",
          request = {
            ["$ref"] = "NodeGroupsDeleteNodesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified NodeGroup. Get a list of available NodeGroups by making a list() request. Note: the \"nodes\" field should not be used. Use nodeGroups.listNodes instead.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}",
          httpMethod = "GET",
          id = "compute.nodeGroups.get",
          parameterOrder = {
            "project",
            "zone",
            "nodeGroup",
          },
          parameters = {
            nodeGroup = {
              description = "Name of the node group to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}",
          response = {
            ["$ref"] = "NodeGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.nodeGroups.getIamPolicy",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a NodeGroup resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups",
          httpMethod = "POST",
          id = "compute.nodeGroups.insert",
          parameterOrder = {
            "project",
            "zone",
            "initialNodeCount",
          },
          parameters = {
            initialNodeCount = {
              description = "Initial count of nodes in the node group.",
              format = "int32",
              location = "query",
              required = true,
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups",
          request = {
            ["$ref"] = "NodeGroup",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of node groups available to the specified project. Note: use nodeGroups.listNodes for more details about each group.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups",
          httpMethod = "GET",
          id = "compute.nodeGroups.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups",
          response = {
            ["$ref"] = "NodeGroupList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listNodes = {
          description = "Lists nodes in the node group.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}/listNodes",
          httpMethod = "POST",
          id = "compute.nodeGroups.listNodes",
          parameterOrder = {
            "project",
            "zone",
            "nodeGroup",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            nodeGroup = {
              description = "Name of the NodeGroup resource whose nodes you want to list.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}/listNodes",
          response = {
            ["$ref"] = "NodeGroupsListNodes",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates the specified node group.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}",
          httpMethod = "PATCH",
          id = "compute.nodeGroups.patch",
          parameterOrder = {
            "project",
            "zone",
            "nodeGroup",
          },
          parameters = {
            nodeGroup = {
              description = "Name of the NodeGroup resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}",
          request = {
            ["$ref"] = "NodeGroup",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.nodeGroups.setIamPolicy",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "ZoneSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setNodeTemplate = {
          description = "Updates the node template of the node group.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}/setNodeTemplate",
          httpMethod = "POST",
          id = "compute.nodeGroups.setNodeTemplate",
          parameterOrder = {
            "project",
            "zone",
            "nodeGroup",
          },
          parameters = {
            nodeGroup = {
              description = "Name of the NodeGroup resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{nodeGroup}/setNodeTemplate",
          request = {
            ["$ref"] = "NodeGroupsSetNodeTemplateRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/zones/{zone}/nodeGroups/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.nodeGroups.testIamPermissions",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeGroups/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    nodeTemplates = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of node templates.",
          flatPath = "projects/{project}/aggregated/nodeTemplates",
          httpMethod = "GET",
          id = "compute.nodeTemplates.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/nodeTemplates",
          response = {
            ["$ref"] = "NodeTemplateAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified NodeTemplate resource.",
          flatPath = "projects/{project}/regions/{region}/nodeTemplates/{nodeTemplate}",
          httpMethod = "DELETE",
          id = "compute.nodeTemplates.delete",
          parameterOrder = {
            "project",
            "region",
            "nodeTemplate",
          },
          parameters = {
            nodeTemplate = {
              description = "Name of the NodeTemplate resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/nodeTemplates/{nodeTemplate}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified node template. Gets a list of available node templates by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/nodeTemplates/{nodeTemplate}",
          httpMethod = "GET",
          id = "compute.nodeTemplates.get",
          parameterOrder = {
            "project",
            "region",
            "nodeTemplate",
          },
          parameters = {
            nodeTemplate = {
              description = "Name of the node template to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/nodeTemplates/{nodeTemplate}",
          response = {
            ["$ref"] = "NodeTemplate",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/regions/{region}/nodeTemplates/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.nodeTemplates.getIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/nodeTemplates/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a NodeTemplate resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/nodeTemplates",
          httpMethod = "POST",
          id = "compute.nodeTemplates.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/nodeTemplates",
          request = {
            ["$ref"] = "NodeTemplate",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of node templates available to the specified project.",
          flatPath = "projects/{project}/regions/{region}/nodeTemplates",
          httpMethod = "GET",
          id = "compute.nodeTemplates.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/nodeTemplates",
          response = {
            ["$ref"] = "NodeTemplateList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/regions/{region}/nodeTemplates/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.nodeTemplates.setIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/nodeTemplates/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "RegionSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/regions/{region}/nodeTemplates/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.nodeTemplates.testIamPermissions",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/nodeTemplates/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    nodeTypes = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of node types.",
          flatPath = "projects/{project}/aggregated/nodeTypes",
          httpMethod = "GET",
          id = "compute.nodeTypes.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/nodeTypes",
          response = {
            ["$ref"] = "NodeTypeAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        get = {
          description = "Returns the specified node type. Gets a list of available node types by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}/nodeTypes/{nodeType}",
          httpMethod = "GET",
          id = "compute.nodeTypes.get",
          parameterOrder = {
            "project",
            "zone",
            "nodeType",
          },
          parameters = {
            nodeType = {
              description = "Name of the node type to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeTypes/{nodeType}",
          response = {
            ["$ref"] = "NodeType",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves a list of node types available to the specified project.",
          flatPath = "projects/{project}/zones/{zone}/nodeTypes",
          httpMethod = "GET",
          id = "compute.nodeTypes.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/nodeTypes",
          response = {
            ["$ref"] = "NodeTypeList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    packetMirrorings = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of packetMirrorings.",
          flatPath = "projects/{project}/aggregated/packetMirrorings",
          httpMethod = "GET",
          id = "compute.packetMirrorings.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/packetMirrorings",
          response = {
            ["$ref"] = "PacketMirroringAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified PacketMirroring resource.",
          flatPath = "projects/{project}/regions/{region}/packetMirrorings/{packetMirroring}",
          httpMethod = "DELETE",
          id = "compute.packetMirrorings.delete",
          parameterOrder = {
            "project",
            "region",
            "packetMirroring",
          },
          parameters = {
            packetMirroring = {
              description = "Name of the PacketMirroring resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/packetMirrorings/{packetMirroring}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified PacketMirroring resource.",
          flatPath = "projects/{project}/regions/{region}/packetMirrorings/{packetMirroring}",
          httpMethod = "GET",
          id = "compute.packetMirrorings.get",
          parameterOrder = {
            "project",
            "region",
            "packetMirroring",
          },
          parameters = {
            packetMirroring = {
              description = "Name of the PacketMirroring resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/packetMirrorings/{packetMirroring}",
          response = {
            ["$ref"] = "PacketMirroring",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a PacketMirroring resource in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/packetMirrorings",
          httpMethod = "POST",
          id = "compute.packetMirrorings.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/packetMirrorings",
          request = {
            ["$ref"] = "PacketMirroring",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of PacketMirroring resources available to the specified project and region.",
          flatPath = "projects/{project}/regions/{region}/packetMirrorings",
          httpMethod = "GET",
          id = "compute.packetMirrorings.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/packetMirrorings",
          response = {
            ["$ref"] = "PacketMirroringList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified PacketMirroring resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/packetMirrorings/{packetMirroring}",
          httpMethod = "PATCH",
          id = "compute.packetMirrorings.patch",
          parameterOrder = {
            "project",
            "region",
            "packetMirroring",
          },
          parameters = {
            packetMirroring = {
              description = "Name of the PacketMirroring resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/packetMirrorings/{packetMirroring}",
          request = {
            ["$ref"] = "PacketMirroring",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/regions/{region}/packetMirrorings/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.packetMirrorings.testIamPermissions",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/packetMirrorings/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    projects = {
      methods = {
        disableXpnHost = {
          description = "Disable this project as a shared VPC host project.",
          flatPath = "projects/{project}/disableXpnHost",
          httpMethod = "POST",
          id = "compute.projects.disableXpnHost",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/disableXpnHost",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        disableXpnResource = {
          description = "Disable a service resource (also known as service project) associated with this host project.",
          flatPath = "projects/{project}/disableXpnResource",
          httpMethod = "POST",
          id = "compute.projects.disableXpnResource",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/disableXpnResource",
          request = {
            ["$ref"] = "ProjectsDisableXpnResourceRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        enableXpnHost = {
          description = "Enable this project as a shared VPC host project.",
          flatPath = "projects/{project}/enableXpnHost",
          httpMethod = "POST",
          id = "compute.projects.enableXpnHost",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/enableXpnHost",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        enableXpnResource = {
          description = "Enable service resource (a.k.a service project) for a host project, so that subnets in the host project can be used by instances in the service project.",
          flatPath = "projects/{project}/enableXpnResource",
          httpMethod = "POST",
          id = "compute.projects.enableXpnResource",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/enableXpnResource",
          request = {
            ["$ref"] = "ProjectsEnableXpnResourceRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified Project resource. To decrease latency for this method, you can optionally omit any unneeded information from the response by using a field mask. This practice is especially recommended for unused quota information (the `quotas` field). To exclude one or more fields, set your request's `fields` query parameter to only include the fields you need. For example, to only include the `id` and `selfLink` fields, add the query parameter `?fields=id,selfLink` to your request.",
          flatPath = "projects/{project}",
          httpMethod = "GET",
          id = "compute.projects.get",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}",
          response = {
            ["$ref"] = "Project",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getXpnHost = {
          description = "Gets the shared VPC host project that this project links to. May be empty if no link exists.",
          flatPath = "projects/{project}/getXpnHost",
          httpMethod = "GET",
          id = "compute.projects.getXpnHost",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/getXpnHost",
          response = {
            ["$ref"] = "Project",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        getXpnResources = {
          description = "Gets service resources (a.k.a service project) associated with this host project.",
          flatPath = "projects/{project}/getXpnResources",
          httpMethod = "GET",
          id = "compute.projects.getXpnResources",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/getXpnResources",
          response = {
            ["$ref"] = "ProjectsGetXpnResources",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        listXpnHosts = {
          description = "Lists all shared VPC host projects visible to the user in an organization.",
          flatPath = "projects/{project}/listXpnHosts",
          httpMethod = "POST",
          id = "compute.projects.listXpnHosts",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/listXpnHosts",
          request = {
            ["$ref"] = "ProjectsListXpnHostsRequest",
          },
          response = {
            ["$ref"] = "XpnHostList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        moveDisk = {
          description = "Moves a persistent disk from one zone to another.",
          flatPath = "projects/{project}/moveDisk",
          httpMethod = "POST",
          id = "compute.projects.moveDisk",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/moveDisk",
          request = {
            ["$ref"] = "DiskMoveRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        moveInstance = {
          description = "Moves an instance and its attached persistent disks from one zone to another. *Note*: Moving VMs or disks by using this method might cause unexpected behavior. For more information, see the [known issue](/compute/docs/troubleshooting/known-issues#moving_vms_or_disks_using_the_moveinstance_api_or_the_causes_unexpected_behavior).",
          flatPath = "projects/{project}/moveInstance",
          httpMethod = "POST",
          id = "compute.projects.moveInstance",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/moveInstance",
          request = {
            ["$ref"] = "InstanceMoveRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setCommonInstanceMetadata = {
          description = "Sets metadata common to all instances within the specified project using the data included in the request.",
          flatPath = "projects/{project}/setCommonInstanceMetadata",
          httpMethod = "POST",
          id = "compute.projects.setCommonInstanceMetadata",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/setCommonInstanceMetadata",
          request = {
            ["$ref"] = "Metadata",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setDefaultNetworkTier = {
          description = "Sets the default network tier of the project. The default network tier is used when an address/forwardingRule/instance is created without specifying the network tier field.",
          flatPath = "projects/{project}/setDefaultNetworkTier",
          httpMethod = "POST",
          id = "compute.projects.setDefaultNetworkTier",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/setDefaultNetworkTier",
          request = {
            ["$ref"] = "ProjectsSetDefaultNetworkTierRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setUsageExportBucket = {
          description = "Enables the usage export feature and sets the usage export bucket where reports are stored. If you provide an empty request body using this method, the usage export feature will be disabled.",
          flatPath = "projects/{project}/setUsageExportBucket",
          httpMethod = "POST",
          id = "compute.projects.setUsageExportBucket",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/setUsageExportBucket",
          request = {
            ["$ref"] = "UsageExportLocation",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/devstorage.full_control",
            "https://www.googleapis.com/auth/devstorage.read_only",
            "https://www.googleapis.com/auth/devstorage.read_write",
          },
        },
      },
    },
    publicAdvertisedPrefixes = {
      methods = {
        delete = {
          description = "Deletes the specified PublicAdvertisedPrefix",
          flatPath = "projects/{project}/global/publicAdvertisedPrefixes/{publicAdvertisedPrefix}",
          httpMethod = "DELETE",
          id = "compute.publicAdvertisedPrefixes.delete",
          parameterOrder = {
            "project",
            "publicAdvertisedPrefix",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            publicAdvertisedPrefix = {
              description = "Name of the PublicAdvertisedPrefix resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/publicAdvertisedPrefixes/{publicAdvertisedPrefix}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified PublicAdvertisedPrefix resource.",
          flatPath = "projects/{project}/global/publicAdvertisedPrefixes/{publicAdvertisedPrefix}",
          httpMethod = "GET",
          id = "compute.publicAdvertisedPrefixes.get",
          parameterOrder = {
            "project",
            "publicAdvertisedPrefix",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            publicAdvertisedPrefix = {
              description = "Name of the PublicAdvertisedPrefix resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/publicAdvertisedPrefixes/{publicAdvertisedPrefix}",
          response = {
            ["$ref"] = "PublicAdvertisedPrefix",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a PublicAdvertisedPrefix in the specified project using the parameters that are included in the request.",
          flatPath = "projects/{project}/global/publicAdvertisedPrefixes",
          httpMethod = "POST",
          id = "compute.publicAdvertisedPrefixes.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/publicAdvertisedPrefixes",
          request = {
            ["$ref"] = "PublicAdvertisedPrefix",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists the PublicAdvertisedPrefixes for a project.",
          flatPath = "projects/{project}/global/publicAdvertisedPrefixes",
          httpMethod = "GET",
          id = "compute.publicAdvertisedPrefixes.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/publicAdvertisedPrefixes",
          response = {
            ["$ref"] = "PublicAdvertisedPrefixList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified Router resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/publicAdvertisedPrefixes/{publicAdvertisedPrefix}",
          httpMethod = "PATCH",
          id = "compute.publicAdvertisedPrefixes.patch",
          parameterOrder = {
            "project",
            "publicAdvertisedPrefix",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            publicAdvertisedPrefix = {
              description = "Name of the PublicAdvertisedPrefix resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/publicAdvertisedPrefixes/{publicAdvertisedPrefix}",
          request = {
            ["$ref"] = "PublicAdvertisedPrefix",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    publicDelegatedPrefixes = {
      methods = {
        aggregatedList = {
          description = "Lists all PublicDelegatedPrefix resources owned by the specific project across all scopes.",
          flatPath = "projects/{project}/aggregated/publicDelegatedPrefixes",
          httpMethod = "GET",
          id = "compute.publicDelegatedPrefixes.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/publicDelegatedPrefixes",
          response = {
            ["$ref"] = "PublicDelegatedPrefixAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified PublicDelegatedPrefix in the given region.",
          flatPath = "projects/{project}/regions/{region}/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          httpMethod = "DELETE",
          id = "compute.publicDelegatedPrefixes.delete",
          parameterOrder = {
            "project",
            "region",
            "publicDelegatedPrefix",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            publicDelegatedPrefix = {
              description = "Name of the PublicDelegatedPrefix resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified PublicDelegatedPrefix resource in the given region.",
          flatPath = "projects/{project}/regions/{region}/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          httpMethod = "GET",
          id = "compute.publicDelegatedPrefixes.get",
          parameterOrder = {
            "project",
            "region",
            "publicDelegatedPrefix",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            publicDelegatedPrefix = {
              description = "Name of the PublicDelegatedPrefix resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          response = {
            ["$ref"] = "PublicDelegatedPrefix",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a PublicDelegatedPrefix in the specified project in the given region using the parameters that are included in the request.",
          flatPath = "projects/{project}/regions/{region}/publicDelegatedPrefixes",
          httpMethod = "POST",
          id = "compute.publicDelegatedPrefixes.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/publicDelegatedPrefixes",
          request = {
            ["$ref"] = "PublicDelegatedPrefix",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists the PublicDelegatedPrefixes for a project in the given region.",
          flatPath = "projects/{project}/regions/{region}/publicDelegatedPrefixes",
          httpMethod = "GET",
          id = "compute.publicDelegatedPrefixes.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/publicDelegatedPrefixes",
          response = {
            ["$ref"] = "PublicDelegatedPrefixList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified PublicDelegatedPrefix resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          httpMethod = "PATCH",
          id = "compute.publicDelegatedPrefixes.patch",
          parameterOrder = {
            "project",
            "region",
            "publicDelegatedPrefix",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            publicDelegatedPrefix = {
              description = "Name of the PublicDelegatedPrefix resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/publicDelegatedPrefixes/{publicDelegatedPrefix}",
          request = {
            ["$ref"] = "PublicDelegatedPrefix",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionAutoscalers = {
      methods = {
        delete = {
          description = "Deletes the specified autoscaler.",
          flatPath = "projects/{project}/regions/{region}/autoscalers/{autoscaler}",
          httpMethod = "DELETE",
          id = "compute.regionAutoscalers.delete",
          parameterOrder = {
            "project",
            "region",
            "autoscaler",
          },
          parameters = {
            autoscaler = {
              description = "Name of the autoscaler to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/autoscalers/{autoscaler}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified autoscaler.",
          flatPath = "projects/{project}/regions/{region}/autoscalers/{autoscaler}",
          httpMethod = "GET",
          id = "compute.regionAutoscalers.get",
          parameterOrder = {
            "project",
            "region",
            "autoscaler",
          },
          parameters = {
            autoscaler = {
              description = "Name of the autoscaler to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/autoscalers/{autoscaler}",
          response = {
            ["$ref"] = "Autoscaler",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates an autoscaler in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/autoscalers",
          httpMethod = "POST",
          id = "compute.regionAutoscalers.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/autoscalers",
          request = {
            ["$ref"] = "Autoscaler",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of autoscalers contained within the specified region.",
          flatPath = "projects/{project}/regions/{region}/autoscalers",
          httpMethod = "GET",
          id = "compute.regionAutoscalers.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/autoscalers",
          response = {
            ["$ref"] = "RegionAutoscalerList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates an autoscaler in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/autoscalers",
          httpMethod = "PATCH",
          id = "compute.regionAutoscalers.patch",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            autoscaler = {
              description = "Name of the autoscaler to patch.",
              location = "query",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/autoscalers",
          request = {
            ["$ref"] = "Autoscaler",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates an autoscaler in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/autoscalers",
          httpMethod = "PUT",
          id = "compute.regionAutoscalers.update",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            autoscaler = {
              description = "Name of the autoscaler to update.",
              location = "query",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/autoscalers",
          request = {
            ["$ref"] = "Autoscaler",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionBackendServices = {
      methods = {
        delete = {
          description = "Deletes the specified regional BackendService resource.",
          flatPath = "projects/{project}/regions/{region}/backendServices/{backendService}",
          httpMethod = "DELETE",
          id = "compute.regionBackendServices.delete",
          parameterOrder = {
            "project",
            "region",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/backendServices/{backendService}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified regional BackendService resource.",
          flatPath = "projects/{project}/regions/{region}/backendServices/{backendService}",
          httpMethod = "GET",
          id = "compute.regionBackendServices.get",
          parameterOrder = {
            "project",
            "region",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/backendServices/{backendService}",
          response = {
            ["$ref"] = "BackendService",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getHealth = {
          description = "Gets the most recent health check results for this regional BackendService.",
          flatPath = "projects/{project}/regions/{region}/backendServices/{backendService}/getHealth",
          httpMethod = "POST",
          id = "compute.regionBackendServices.getHealth",
          parameterOrder = {
            "project",
            "region",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource for which to get health.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/backendServices/{backendService}/getHealth",
          request = {
            ["$ref"] = "ResourceGroupReference",
          },
          response = {
            ["$ref"] = "BackendServiceGroupHealth",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/regions/{region}/backendServices/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.regionBackendServices.getIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/backendServices/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a regional BackendService resource in the specified project using the data included in the request. For more information, see Backend services overview.",
          flatPath = "projects/{project}/regions/{region}/backendServices",
          httpMethod = "POST",
          id = "compute.regionBackendServices.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/backendServices",
          request = {
            ["$ref"] = "BackendService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of regional BackendService resources available to the specified project in the given region.",
          flatPath = "projects/{project}/regions/{region}/backendServices",
          httpMethod = "GET",
          id = "compute.regionBackendServices.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/backendServices",
          response = {
            ["$ref"] = "BackendServiceList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates the specified regional BackendService resource with the data included in the request. For more information, see Understanding backend services This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/backendServices/{backendService}",
          httpMethod = "PATCH",
          id = "compute.regionBackendServices.patch",
          parameterOrder = {
            "project",
            "region",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/backendServices/{backendService}",
          request = {
            ["$ref"] = "BackendService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/regions/{region}/backendServices/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.regionBackendServices.setIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/backendServices/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "RegionSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates the specified regional BackendService resource with the data included in the request. For more information, see Backend services overview .",
          flatPath = "projects/{project}/regions/{region}/backendServices/{backendService}",
          httpMethod = "PUT",
          id = "compute.regionBackendServices.update",
          parameterOrder = {
            "project",
            "region",
            "backendService",
          },
          parameters = {
            backendService = {
              description = "Name of the BackendService resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/backendServices/{backendService}",
          request = {
            ["$ref"] = "BackendService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionCommitments = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of commitments by region.",
          flatPath = "projects/{project}/aggregated/commitments",
          httpMethod = "GET",
          id = "compute.regionCommitments.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/commitments",
          response = {
            ["$ref"] = "CommitmentAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        get = {
          description = "Returns the specified commitment resource. Gets a list of available commitments by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/commitments/{commitment}",
          httpMethod = "GET",
          id = "compute.regionCommitments.get",
          parameterOrder = {
            "project",
            "region",
            "commitment",
          },
          parameters = {
            commitment = {
              description = "Name of the commitment to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/commitments/{commitment}",
          response = {
            ["$ref"] = "Commitment",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a commitment in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/commitments",
          httpMethod = "POST",
          id = "compute.regionCommitments.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/commitments",
          request = {
            ["$ref"] = "Commitment",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of commitments contained within the specified region.",
          flatPath = "projects/{project}/regions/{region}/commitments",
          httpMethod = "GET",
          id = "compute.regionCommitments.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/commitments",
          response = {
            ["$ref"] = "CommitmentList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        update = {
          description = "Updates the specified commitment with the data included in the request. Update is performed only on selected fields included as part of update-mask. Only the following fields can be modified: auto_renew.",
          flatPath = "projects/{project}/regions/{region}/commitments/{commitment}",
          httpMethod = "PATCH",
          id = "compute.regionCommitments.update",
          parameterOrder = {
            "project",
            "region",
            "commitment",
          },
          parameters = {
            commitment = {
              description = "Name of the commitment for which auto renew is being updated.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            paths = {
              location = "query",
              repeated = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            updateMask = {
              description = "update_mask indicates fields to be updated as part of this request.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/commitments/{commitment}",
          request = {
            ["$ref"] = "Commitment",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionDiskTypes = {
      methods = {
        get = {
          description = "Returns the specified regional disk type. Gets a list of available disk types by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/diskTypes/{diskType}",
          httpMethod = "GET",
          id = "compute.regionDiskTypes.get",
          parameterOrder = {
            "project",
            "region",
            "diskType",
          },
          parameters = {
            diskType = {
              description = "Name of the disk type to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/diskTypes/{diskType}",
          response = {
            ["$ref"] = "DiskType",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves a list of regional disk types available to the specified project.",
          flatPath = "projects/{project}/regions/{region}/diskTypes",
          httpMethod = "GET",
          id = "compute.regionDiskTypes.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/diskTypes",
          response = {
            ["$ref"] = "RegionDiskTypeList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    regionDisks = {
      methods = {
        addResourcePolicies = {
          description = "Adds existing resource policies to a regional disk. You can only add one policy which will be applied to this disk for scheduling snapshot creation.",
          flatPath = "projects/{project}/regions/{region}/disks/{disk}/addResourcePolicies",
          httpMethod = "POST",
          id = "compute.regionDisks.addResourcePolicies",
          parameterOrder = {
            "project",
            "region",
            "disk",
          },
          parameters = {
            disk = {
              description = "The disk name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{disk}/addResourcePolicies",
          request = {
            ["$ref"] = "RegionDisksAddResourcePoliciesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        createSnapshot = {
          description = "Creates a snapshot of a specified persistent disk. For regular snapshot creation, consider using snapshots.insert instead, as that method supports more features, such as creating snapshots in a project different from the source disk project.",
          flatPath = "projects/{project}/regions/{region}/disks/{disk}/createSnapshot",
          httpMethod = "POST",
          id = "compute.regionDisks.createSnapshot",
          parameterOrder = {
            "project",
            "region",
            "disk",
          },
          parameters = {
            disk = {
              description = "Name of the regional persistent disk to snapshot.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{disk}/createSnapshot",
          request = {
            ["$ref"] = "Snapshot",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified regional persistent disk. Deleting a regional disk removes all the replicas of its data permanently and is irreversible. However, deleting a disk does not delete any snapshots previously made from the disk. You must separately delete snapshots.",
          flatPath = "projects/{project}/regions/{region}/disks/{disk}",
          httpMethod = "DELETE",
          id = "compute.regionDisks.delete",
          parameterOrder = {
            "project",
            "region",
            "disk",
          },
          parameters = {
            disk = {
              description = "Name of the regional persistent disk to delete.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{disk}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns a specified regional persistent disk.",
          flatPath = "projects/{project}/regions/{region}/disks/{disk}",
          httpMethod = "GET",
          id = "compute.regionDisks.get",
          parameterOrder = {
            "project",
            "region",
            "disk",
          },
          parameters = {
            disk = {
              description = "Name of the regional persistent disk to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{disk}",
          response = {
            ["$ref"] = "Disk",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/regions/{region}/disks/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.regionDisks.getIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a persistent regional disk in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/disks",
          httpMethod = "POST",
          id = "compute.regionDisks.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sourceImage = {
              description = "Source image to restore onto a disk. This field is optional.",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks",
          request = {
            ["$ref"] = "Disk",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of persistent disks contained within the specified region.",
          flatPath = "projects/{project}/regions/{region}/disks",
          httpMethod = "GET",
          id = "compute.regionDisks.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/disks",
          response = {
            ["$ref"] = "DiskList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        removeResourcePolicies = {
          description = "Removes resource policies from a regional disk.",
          flatPath = "projects/{project}/regions/{region}/disks/{disk}/removeResourcePolicies",
          httpMethod = "POST",
          id = "compute.regionDisks.removeResourcePolicies",
          parameterOrder = {
            "project",
            "region",
            "disk",
          },
          parameters = {
            disk = {
              description = "The disk name for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{disk}/removeResourcePolicies",
          request = {
            ["$ref"] = "RegionDisksRemoveResourcePoliciesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        resize = {
          description = "Resizes the specified regional persistent disk.",
          flatPath = "projects/{project}/regions/{region}/disks/{disk}/resize",
          httpMethod = "POST",
          id = "compute.regionDisks.resize",
          parameterOrder = {
            "project",
            "region",
            "disk",
          },
          parameters = {
            disk = {
              description = "Name of the regional persistent disk.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "The project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{disk}/resize",
          request = {
            ["$ref"] = "RegionDisksResizeRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/regions/{region}/disks/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.regionDisks.setIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "RegionSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets the labels on the target regional disk.",
          flatPath = "projects/{project}/regions/{region}/disks/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.regionDisks.setLabels",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{resource}/setLabels",
          request = {
            ["$ref"] = "RegionSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/regions/{region}/disks/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.regionDisks.testIamPermissions",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/disks/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    regionHealthCheckServices = {
      methods = {
        delete = {
          description = "Deletes the specified regional HealthCheckService.",
          flatPath = "projects/{project}/regions/{region}/healthCheckServices/{healthCheckService}",
          httpMethod = "DELETE",
          id = "compute.regionHealthCheckServices.delete",
          parameterOrder = {
            "project",
            "region",
            "healthCheckService",
          },
          parameters = {
            healthCheckService = {
              description = "Name of the HealthCheckService to delete. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/healthCheckServices/{healthCheckService}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified regional HealthCheckService resource.",
          flatPath = "projects/{project}/regions/{region}/healthCheckServices/{healthCheckService}",
          httpMethod = "GET",
          id = "compute.regionHealthCheckServices.get",
          parameterOrder = {
            "project",
            "region",
            "healthCheckService",
          },
          parameters = {
            healthCheckService = {
              description = "Name of the HealthCheckService to update. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/healthCheckServices/{healthCheckService}",
          response = {
            ["$ref"] = "HealthCheckService",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a regional HealthCheckService resource in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/healthCheckServices",
          httpMethod = "POST",
          id = "compute.regionHealthCheckServices.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/healthCheckServices",
          request = {
            ["$ref"] = "HealthCheckService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists all the HealthCheckService resources that have been configured for the specified project in the given region.",
          flatPath = "projects/{project}/regions/{region}/healthCheckServices",
          httpMethod = "GET",
          id = "compute.regionHealthCheckServices.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/healthCheckServices",
          response = {
            ["$ref"] = "HealthCheckServicesList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates the specified regional HealthCheckService resource with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/healthCheckServices/{healthCheckService}",
          httpMethod = "PATCH",
          id = "compute.regionHealthCheckServices.patch",
          parameterOrder = {
            "project",
            "region",
            "healthCheckService",
          },
          parameters = {
            healthCheckService = {
              description = "Name of the HealthCheckService to update. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/healthCheckServices/{healthCheckService}",
          request = {
            ["$ref"] = "HealthCheckService",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionHealthChecks = {
      methods = {
        delete = {
          description = "Deletes the specified HealthCheck resource.",
          flatPath = "projects/{project}/regions/{region}/healthChecks/{healthCheck}",
          httpMethod = "DELETE",
          id = "compute.regionHealthChecks.delete",
          parameterOrder = {
            "project",
            "region",
            "healthCheck",
          },
          parameters = {
            healthCheck = {
              description = "Name of the HealthCheck resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/healthChecks/{healthCheck}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified HealthCheck resource. Gets a list of available health checks by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/healthChecks/{healthCheck}",
          httpMethod = "GET",
          id = "compute.regionHealthChecks.get",
          parameterOrder = {
            "project",
            "region",
            "healthCheck",
          },
          parameters = {
            healthCheck = {
              description = "Name of the HealthCheck resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/healthChecks/{healthCheck}",
          response = {
            ["$ref"] = "HealthCheck",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a HealthCheck resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/healthChecks",
          httpMethod = "POST",
          id = "compute.regionHealthChecks.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/healthChecks",
          request = {
            ["$ref"] = "HealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of HealthCheck resources available to the specified project.",
          flatPath = "projects/{project}/regions/{region}/healthChecks",
          httpMethod = "GET",
          id = "compute.regionHealthChecks.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/healthChecks",
          response = {
            ["$ref"] = "HealthCheckList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates a HealthCheck resource in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/healthChecks/{healthCheck}",
          httpMethod = "PATCH",
          id = "compute.regionHealthChecks.patch",
          parameterOrder = {
            "project",
            "region",
            "healthCheck",
          },
          parameters = {
            healthCheck = {
              description = "Name of the HealthCheck resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/healthChecks/{healthCheck}",
          request = {
            ["$ref"] = "HealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates a HealthCheck resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/healthChecks/{healthCheck}",
          httpMethod = "PUT",
          id = "compute.regionHealthChecks.update",
          parameterOrder = {
            "project",
            "region",
            "healthCheck",
          },
          parameters = {
            healthCheck = {
              description = "Name of the HealthCheck resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/healthChecks/{healthCheck}",
          request = {
            ["$ref"] = "HealthCheck",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionInstanceGroupManagers = {
      methods = {
        abandonInstances = {
          description = "Flags the specified instances to be immediately removed from the managed instance group. Abandoning an instance does not delete the instance, but it does remove the instance from any target pools that are applied by the managed instance group. This method reduces the targetSize of the managed instance group by the number of instances that you abandon. This operation is marked as DONE when the action is scheduled even if the instances have not yet been removed from the group. You must separately verify the status of the abandoning action with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/abandonInstances",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.abandonInstances",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "Name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/abandonInstances",
          request = {
            ["$ref"] = "RegionInstanceGroupManagersAbandonInstancesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        applyUpdatesToInstances = {
          description = "Apply updates to selected instances the managed instance group.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/applyUpdatesToInstances",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.applyUpdatesToInstances",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group, should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request, should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/applyUpdatesToInstances",
          request = {
            ["$ref"] = "RegionInstanceGroupManagersApplyUpdatesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        createInstances = {
          description = "Creates instances with per-instance configurations in this regional managed instance group. Instances are created using the current instance template. The create instances operation is marked DONE if the createInstances request is successful. The underlying actions take additional time. You must separately verify the status of the creating or actions with the listmanagedinstances method.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/createInstances",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.createInstances",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region where the managed instance group is located. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/createInstances",
          request = {
            ["$ref"] = "RegionInstanceGroupManagersCreateInstancesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified managed instance group and all of the instances in that group.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}",
          httpMethod = "DELETE",
          id = "compute.regionInstanceGroupManagers.delete",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "Name of the managed instance group to delete.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        deleteInstances = {
          description = "Flags the specified instances in the managed instance group to be immediately deleted. The instances are also removed from any target pools of which they were a member. This method reduces the targetSize of the managed instance group by the number of instances that you delete. The deleteInstances operation is marked DONE if the deleteInstances request is successful. The underlying actions take additional time. You must separately verify the status of the deleting action with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/deleteInstances",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.deleteInstances",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "Name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/deleteInstances",
          request = {
            ["$ref"] = "RegionInstanceGroupManagersDeleteInstancesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        deletePerInstanceConfigs = {
          description = "Deletes selected per-instance configurations for the managed instance group.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/deletePerInstanceConfigs",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.deletePerInstanceConfigs",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request, should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/deletePerInstanceConfigs",
          request = {
            ["$ref"] = "RegionInstanceGroupManagerDeleteInstanceConfigReq",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns all of the details about the specified managed instance group.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}",
          httpMethod = "GET",
          id = "compute.regionInstanceGroupManagers.get",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "Name of the managed instance group to return.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}",
          response = {
            ["$ref"] = "InstanceGroupManager",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a managed instance group using the information that you specify in the request. After the group is created, instances in the group are created using the specified instance template. This operation is marked as DONE when the group is created even if the instances in the group have not yet been created. You must separately verify the status of the individual instances with the listmanagedinstances method. A regional managed instance group can contain up to 2000 instances.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers",
          request = {
            ["$ref"] = "InstanceGroupManager",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of managed instance groups that are contained within the specified region.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers",
          httpMethod = "GET",
          id = "compute.regionInstanceGroupManagers.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers",
          response = {
            ["$ref"] = "RegionInstanceGroupManagerList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listErrors = {
          description = "Lists all errors thrown by actions on instances for a given regional managed instance group. The filter and orderBy query parameters are not supported.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/listErrors",
          httpMethod = "GET",
          id = "compute.regionInstanceGroupManagers.listErrors",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            instanceGroupManager = {
              description = "The name of the managed instance group. It must be a string that meets the requirements in RFC1035, or an unsigned long integer: must match regexp pattern: (?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?)|1-9{0,19}.",
              location = "path",
              required = true,
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request. This should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/listErrors",
          response = {
            ["$ref"] = "RegionInstanceGroupManagersListErrorsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listManagedInstances = {
          description = "Lists the instances in the managed instance group and instances that are scheduled to be created. The list includes any current actions that the group has scheduled for its instances. The orderBy query parameter is not supported. The `pageToken` query parameter is supported only in the alpha and beta API and only if the group's `listManagedInstancesResults` field is set to `PAGINATED`.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/listManagedInstances",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.listManagedInstances",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/listManagedInstances",
          response = {
            ["$ref"] = "RegionInstanceGroupManagersListInstancesResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listPerInstanceConfigs = {
          description = "Lists all of the per-instance configurations defined for the managed instance group. The orderBy query parameter is not supported.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/listPerInstanceConfigs",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.listPerInstanceConfigs",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request, should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/listPerInstanceConfigs",
          response = {
            ["$ref"] = "RegionInstanceGroupManagersListInstanceConfigsResp",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Updates a managed instance group using the information that you specify in the request. This operation is marked as DONE when the group is patched even if the instances in the group are still in the process of being patched. You must separately verify the status of the individual instances with the listmanagedinstances method. This method supports PATCH semantics and uses the JSON merge patch format and processing rules. If you update your group to specify a new template or instance configuration, it's possible that your intended specification for each VM in the group is different from the current state of that VM. To learn how to apply an updated configuration to the VMs in a MIG, see Updating instances in a MIG.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}",
          httpMethod = "PATCH",
          id = "compute.regionInstanceGroupManagers.patch",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the instance group manager.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}",
          request = {
            ["$ref"] = "InstanceGroupManager",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        patchPerInstanceConfigs = {
          description = "Inserts or patches per-instance configurations for the managed instance group. perInstanceConfig.name serves as a key used to distinguish whether to perform insert or patch.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/patchPerInstanceConfigs",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.patchPerInstanceConfigs",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request, should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/patchPerInstanceConfigs",
          request = {
            ["$ref"] = "RegionInstanceGroupManagerPatchInstanceConfigReq",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        recreateInstances = {
          description = "Flags the specified VM instances in the managed instance group to be immediately recreated. Each instance is recreated using the group's current configuration. This operation is marked as DONE when the flag is set even if the instances have not yet been recreated. You must separately verify the status of each instance by checking its currentAction field; for more information, see Checking the status of managed instances. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/recreateInstances",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.recreateInstances",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "Name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/recreateInstances",
          request = {
            ["$ref"] = "RegionInstanceGroupManagersRecreateRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        resize = {
          description = "Changes the intended size of the managed instance group. If you increase the size, the group creates new instances using the current instance template. If you decrease the size, the group deletes one or more instances. The resize operation is marked DONE if the resize request is successful. The underlying actions take additional time. You must separately verify the status of the creating or deleting actions with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/resize",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.resize",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
            "size",
          },
          parameters = {
            instanceGroupManager = {
              description = "Name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            size = {
              description = "Number of instances that should exist in this instance group manager.",
              format = "int32",
              location = "query",
              minimum = "0",
              required = true,
              type = "integer",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/resize",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setInstanceTemplate = {
          description = "Sets the instance template to use when creating new instances or recreating instances in this group. Existing instances are not affected.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/setInstanceTemplate",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.setInstanceTemplate",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/setInstanceTemplate",
          request = {
            ["$ref"] = "RegionInstanceGroupManagersSetTemplateRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setTargetPools = {
          description = "Modifies the target pools to which all new instances in this group are assigned. Existing instances in the group are not affected.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/setTargetPools",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.setTargetPools",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "Name of the managed instance group.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/setTargetPools",
          request = {
            ["$ref"] = "RegionInstanceGroupManagersSetTargetPoolsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        updatePerInstanceConfigs = {
          description = "Inserts or updates per-instance configurations for the managed instance group. perInstanceConfig.name serves as a key used to distinguish whether to perform insert or patch.",
          flatPath = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/updatePerInstanceConfigs",
          httpMethod = "POST",
          id = "compute.regionInstanceGroupManagers.updatePerInstanceConfigs",
          parameterOrder = {
            "project",
            "region",
            "instanceGroupManager",
          },
          parameters = {
            instanceGroupManager = {
              description = "The name of the managed instance group. It should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request, should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroupManagers/{instanceGroupManager}/updatePerInstanceConfigs",
          request = {
            ["$ref"] = "RegionInstanceGroupManagerUpdateInstanceConfigReq",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionInstanceGroups = {
      methods = {
        get = {
          description = "Returns the specified instance group resource.",
          flatPath = "projects/{project}/regions/{region}/instanceGroups/{instanceGroup}",
          httpMethod = "GET",
          id = "compute.regionInstanceGroups.get",
          parameterOrder = {
            "project",
            "region",
            "instanceGroup",
          },
          parameters = {
            instanceGroup = {
              description = "Name of the instance group resource to return.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroups/{instanceGroup}",
          response = {
            ["$ref"] = "InstanceGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves the list of instance group resources contained within the specified region.",
          flatPath = "projects/{project}/regions/{region}/instanceGroups",
          httpMethod = "GET",
          id = "compute.regionInstanceGroups.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroups",
          response = {
            ["$ref"] = "RegionInstanceGroupList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listInstances = {
          description = "Lists the instances in the specified instance group and displays information about the named ports. Depending on the specified options, this method can list all instances or only the instances that are running. The orderBy query parameter is not supported.",
          flatPath = "projects/{project}/regions/{region}/instanceGroups/{instanceGroup}/listInstances",
          httpMethod = "POST",
          id = "compute.regionInstanceGroups.listInstances",
          parameterOrder = {
            "project",
            "region",
            "instanceGroup",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            instanceGroup = {
              description = "Name of the regional instance group for which we want to list the instances.",
              location = "path",
              required = true,
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroups/{instanceGroup}/listInstances",
          request = {
            ["$ref"] = "RegionInstanceGroupsListInstancesRequest",
          },
          response = {
            ["$ref"] = "RegionInstanceGroupsListInstances",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setNamedPorts = {
          description = "Sets the named ports for the specified regional instance group.",
          flatPath = "projects/{project}/regions/{region}/instanceGroups/{instanceGroup}/setNamedPorts",
          httpMethod = "POST",
          id = "compute.regionInstanceGroups.setNamedPorts",
          parameterOrder = {
            "project",
            "region",
            "instanceGroup",
          },
          parameters = {
            instanceGroup = {
              description = "The name of the regional instance group where the named ports are updated.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instanceGroups/{instanceGroup}/setNamedPorts",
          request = {
            ["$ref"] = "RegionInstanceGroupsSetNamedPortsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionInstances = {
      methods = {
        bulkInsert = {
          description = "Creates multiple instances in a given region. Count specifies the number of instances to create.",
          flatPath = "projects/{project}/regions/{region}/instances/bulkInsert",
          httpMethod = "POST",
          id = "compute.regionInstances.bulkInsert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/instances/bulkInsert",
          request = {
            ["$ref"] = "BulkInsertInstanceResource",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionNetworkEndpointGroups = {
      methods = {
        delete = {
          description = "Deletes the specified network endpoint group. Note that the NEG cannot be deleted if it is configured as a backend of a backend service.",
          flatPath = "projects/{project}/regions/{region}/networkEndpointGroups/{networkEndpointGroup}",
          httpMethod = "DELETE",
          id = "compute.regionNetworkEndpointGroups.delete",
          parameterOrder = {
            "project",
            "region",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group to delete. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region where the network endpoint group is located. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkEndpointGroups/{networkEndpointGroup}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified network endpoint group. Gets a list of available network endpoint groups by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/networkEndpointGroups/{networkEndpointGroup}",
          httpMethod = "GET",
          id = "compute.regionNetworkEndpointGroups.get",
          parameterOrder = {
            "project",
            "region",
            "networkEndpointGroup",
          },
          parameters = {
            networkEndpointGroup = {
              description = "The name of the network endpoint group. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region where the network endpoint group is located. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkEndpointGroups/{networkEndpointGroup}",
          response = {
            ["$ref"] = "NetworkEndpointGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a network endpoint group in the specified project using the parameters that are included in the request.",
          flatPath = "projects/{project}/regions/{region}/networkEndpointGroups",
          httpMethod = "POST",
          id = "compute.regionNetworkEndpointGroups.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region where you want to create the network endpoint group. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/networkEndpointGroups",
          request = {
            ["$ref"] = "NetworkEndpointGroup",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of regional network endpoint groups available to the specified project in the given region.",
          flatPath = "projects/{project}/regions/{region}/networkEndpointGroups",
          httpMethod = "GET",
          id = "compute.regionNetworkEndpointGroups.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region where the network endpoint group is located. It should comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/networkEndpointGroups",
          response = {
            ["$ref"] = "NetworkEndpointGroupList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    regionNetworkFirewallPolicies = {
      methods = {
        addAssociation = {
          description = "Inserts an association for the specified network firewall policy.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/addAssociation",
          httpMethod = "POST",
          id = "compute.regionNetworkFirewallPolicies.addAssociation",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            replaceExistingAssociation = {
              description = "Indicates whether or not to replace it if an association already exists. This is false by default, in which case an error will be returned if an association already exists.",
              location = "query",
              type = "boolean",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/addAssociation",
          request = {
            ["$ref"] = "FirewallPolicyAssociation",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        addRule = {
          description = "Inserts a rule into a network firewall policy.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/addRule",
          httpMethod = "POST",
          id = "compute.regionNetworkFirewallPolicies.addRule",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            maxPriority = {
              description = "When rule.priority is not specified, auto choose a unused priority between minPriority and maxPriority>. This field is exclusive with rule.priority.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            minPriority = {
              description = "When rule.priority is not specified, auto choose a unused priority between minPriority and maxPriority>. This field is exclusive with rule.priority.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/addRule",
          request = {
            ["$ref"] = "FirewallPolicyRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        cloneRules = {
          description = "Copies rules to the specified network firewall policy.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/cloneRules",
          httpMethod = "POST",
          id = "compute.regionNetworkFirewallPolicies.cloneRules",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sourceFirewallPolicy = {
              description = "The firewall policy from which to copy rules.",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/cloneRules",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        delete = {
          description = "Deletes the specified network firewall policy.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}",
          httpMethod = "DELETE",
          id = "compute.regionNetworkFirewallPolicies.delete",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified network firewall policy.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}",
          httpMethod = "GET",
          id = "compute.regionNetworkFirewallPolicies.get",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to get.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}",
          response = {
            ["$ref"] = "FirewallPolicy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getAssociation = {
          description = "Gets an association with the specified name.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/getAssociation",
          httpMethod = "GET",
          id = "compute.regionNetworkFirewallPolicies.getAssociation",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to which the queried association belongs.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            name = {
              description = "The name of the association to get from the firewall policy.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/getAssociation",
          response = {
            ["$ref"] = "FirewallPolicyAssociation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getEffectiveFirewalls = {
          description = "Returns the effective firewalls on a given network.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/getEffectiveFirewalls",
          httpMethod = "GET",
          id = "compute.regionNetworkFirewallPolicies.getEffectiveFirewalls",
          parameterOrder = {
            "project",
            "region",
            "network",
          },
          parameters = {
            network = {
              description = "Network reference",
              location = "query",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/getEffectiveFirewalls",
          response = {
            ["$ref"] = "RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.regionNetworkFirewallPolicies.getIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getRule = {
          description = "Gets a rule of the specified priority.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/getRule",
          httpMethod = "GET",
          id = "compute.regionNetworkFirewallPolicies.getRule",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to which the queried rule belongs.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            priority = {
              description = "The priority of the rule to get from the firewall policy.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/getRule",
          response = {
            ["$ref"] = "FirewallPolicyRule",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a new network firewall policy in the specified project and region.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies",
          httpMethod = "POST",
          id = "compute.regionNetworkFirewallPolicies.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies",
          request = {
            ["$ref"] = "FirewallPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists all the network firewall policies that have been configured for the specified project in the given region.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies",
          httpMethod = "GET",
          id = "compute.regionNetworkFirewallPolicies.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies",
          response = {
            ["$ref"] = "FirewallPolicyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified network firewall policy.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}",
          httpMethod = "PATCH",
          id = "compute.regionNetworkFirewallPolicies.patch",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}",
          request = {
            ["$ref"] = "FirewallPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        patchRule = {
          description = "Patches a rule of the specified priority.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/patchRule",
          httpMethod = "POST",
          id = "compute.regionNetworkFirewallPolicies.patchRule",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            priority = {
              description = "The priority of the rule to patch.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/patchRule",
          request = {
            ["$ref"] = "FirewallPolicyRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        removeAssociation = {
          description = "Removes an association for the specified network firewall policy.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/removeAssociation",
          httpMethod = "POST",
          id = "compute.regionNetworkFirewallPolicies.removeAssociation",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            name = {
              description = "Name for the association that will be removed.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/removeAssociation",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        removeRule = {
          description = "Deletes a rule of the specified priority.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/removeRule",
          httpMethod = "POST",
          id = "compute.regionNetworkFirewallPolicies.removeRule",
          parameterOrder = {
            "project",
            "region",
            "firewallPolicy",
          },
          parameters = {
            firewallPolicy = {
              description = "Name of the firewall policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            priority = {
              description = "The priority of the rule to remove from the firewall policy.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{firewallPolicy}/removeRule",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.regionNetworkFirewallPolicies.setIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "RegionSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/regions/{region}/firewallPolicies/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.regionNetworkFirewallPolicies.testIamPermissions",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/firewallPolicies/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    regionNotificationEndpoints = {
      methods = {
        delete = {
          description = "Deletes the specified NotificationEndpoint in the given region",
          flatPath = "projects/{project}/regions/{region}/notificationEndpoints/{notificationEndpoint}",
          httpMethod = "DELETE",
          id = "compute.regionNotificationEndpoints.delete",
          parameterOrder = {
            "project",
            "region",
            "notificationEndpoint",
          },
          parameters = {
            notificationEndpoint = {
              description = "Name of the NotificationEndpoint resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/notificationEndpoints/{notificationEndpoint}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified NotificationEndpoint resource in the given region.",
          flatPath = "projects/{project}/regions/{region}/notificationEndpoints/{notificationEndpoint}",
          httpMethod = "GET",
          id = "compute.regionNotificationEndpoints.get",
          parameterOrder = {
            "project",
            "region",
            "notificationEndpoint",
          },
          parameters = {
            notificationEndpoint = {
              description = "Name of the NotificationEndpoint resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/notificationEndpoints/{notificationEndpoint}",
          response = {
            ["$ref"] = "NotificationEndpoint",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Create a NotificationEndpoint in the specified project in the given region using the parameters that are included in the request.",
          flatPath = "projects/{project}/regions/{region}/notificationEndpoints",
          httpMethod = "POST",
          id = "compute.regionNotificationEndpoints.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/notificationEndpoints",
          request = {
            ["$ref"] = "NotificationEndpoint",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists the NotificationEndpoints for a project in the given region.",
          flatPath = "projects/{project}/regions/{region}/notificationEndpoints",
          httpMethod = "GET",
          id = "compute.regionNotificationEndpoints.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/notificationEndpoints",
          response = {
            ["$ref"] = "NotificationEndpointList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    regionOperations = {
      methods = {
        delete = {
          description = "Deletes the specified region-specific Operations resource.",
          flatPath = "projects/{project}/regions/{region}/operations/{operation}",
          httpMethod = "DELETE",
          id = "compute.regionOperations.delete",
          parameterOrder = {
            "project",
            "region",
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/operations/{operation}",
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Retrieves the specified region-specific Operations resource.",
          flatPath = "projects/{project}/regions/{region}/operations/{operation}",
          httpMethod = "GET",
          id = "compute.regionOperations.get",
          parameterOrder = {
            "project",
            "region",
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/operations/{operation}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves a list of Operation resources contained within the specified region.",
          flatPath = "projects/{project}/regions/{region}/operations",
          httpMethod = "GET",
          id = "compute.regionOperations.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/operations",
          response = {
            ["$ref"] = "OperationList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        wait = {
          description = "Waits for the specified Operation resource to return as `DONE` or for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method differs from the `GET` method in that it waits for no more than the default deadline (2 minutes) and then returns the current state of the operation, which might be `DONE` or still in progress. This method is called on a best-effort basis. Specifically: - In uncommon cases, when the server is overloaded, the request might return before the default deadline is reached, or might return after zero seconds. - If the default deadline is reached, there is no guarantee that the operation is actually done when the method returns. Be prepared to retry if the operation is not `DONE`. ",
          flatPath = "projects/{project}/regions/{region}/operations/{operation}/wait",
          httpMethod = "POST",
          id = "compute.regionOperations.wait",
          parameterOrder = {
            "project",
            "region",
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/operations/{operation}/wait",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    regionSecurityPolicies = {
      methods = {
        delete = {
          description = "Deletes the specified policy.",
          flatPath = "projects/{project}/regions/{region}/securityPolicies/{securityPolicy}",
          httpMethod = "DELETE",
          id = "compute.regionSecurityPolicies.delete",
          parameterOrder = {
            "project",
            "region",
            "securityPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/securityPolicies/{securityPolicy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "List all of the ordered rules present in a single specified policy.",
          flatPath = "projects/{project}/regions/{region}/securityPolicies/{securityPolicy}",
          httpMethod = "GET",
          id = "compute.regionSecurityPolicies.get",
          parameterOrder = {
            "project",
            "region",
            "securityPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to get.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/securityPolicies/{securityPolicy}",
          response = {
            ["$ref"] = "SecurityPolicy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a new policy in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/securityPolicies",
          httpMethod = "POST",
          id = "compute.regionSecurityPolicies.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            validateOnly = {
              description = "If true, the request will not be committed.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/securityPolicies",
          request = {
            ["$ref"] = "SecurityPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "List all the policies that have been configured for the specified project and region.",
          flatPath = "projects/{project}/regions/{region}/securityPolicies",
          httpMethod = "GET",
          id = "compute.regionSecurityPolicies.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/securityPolicies",
          response = {
            ["$ref"] = "SecurityPolicyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified policy with the data included in the request. To clear fields in the rule, leave the fields empty and specify them in the updateMask. This cannot be used to be update the rules in the policy. Please use the per rule methods like addRule, patchRule, and removeRule instead.",
          flatPath = "projects/{project}/regions/{region}/securityPolicies/{securityPolicy}",
          httpMethod = "PATCH",
          id = "compute.regionSecurityPolicies.patch",
          parameterOrder = {
            "project",
            "region",
            "securityPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/securityPolicies/{securityPolicy}",
          request = {
            ["$ref"] = "SecurityPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionSslCertificates = {
      methods = {
        delete = {
          description = "Deletes the specified SslCertificate resource in the region.",
          flatPath = "projects/{project}/regions/{region}/sslCertificates/{sslCertificate}",
          httpMethod = "DELETE",
          id = "compute.regionSslCertificates.delete",
          parameterOrder = {
            "project",
            "region",
            "sslCertificate",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sslCertificate = {
              description = "Name of the SslCertificate resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/sslCertificates/{sslCertificate}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified SslCertificate resource in the specified region. Get a list of available SSL certificates by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/sslCertificates/{sslCertificate}",
          httpMethod = "GET",
          id = "compute.regionSslCertificates.get",
          parameterOrder = {
            "project",
            "region",
            "sslCertificate",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            sslCertificate = {
              description = "Name of the SslCertificate resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/sslCertificates/{sslCertificate}",
          response = {
            ["$ref"] = "SslCertificate",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a SslCertificate resource in the specified project and region using the data included in the request",
          flatPath = "projects/{project}/regions/{region}/sslCertificates",
          httpMethod = "POST",
          id = "compute.regionSslCertificates.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/sslCertificates",
          request = {
            ["$ref"] = "SslCertificate",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of SslCertificate resources available to the specified project in the specified region.",
          flatPath = "projects/{project}/regions/{region}/sslCertificates",
          httpMethod = "GET",
          id = "compute.regionSslCertificates.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/sslCertificates",
          response = {
            ["$ref"] = "SslCertificateList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    regionSslPolicies = {
      methods = {
        delete = {
          description = "Deletes the specified SSL policy. The SSL policy resource can be deleted only if it is not in use by any TargetHttpsProxy or TargetSslProxy resources.",
          flatPath = "projects/{project}/regions/{region}/sslPolicies/{sslPolicy}",
          httpMethod = "DELETE",
          id = "compute.regionSslPolicies.delete",
          parameterOrder = {
            "project",
            "region",
            "sslPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sslPolicy = {
              description = "Name of the SSL policy to delete. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/sslPolicies/{sslPolicy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Lists all of the ordered rules present in a single specified policy.",
          flatPath = "projects/{project}/regions/{region}/sslPolicies/{sslPolicy}",
          httpMethod = "GET",
          id = "compute.regionSslPolicies.get",
          parameterOrder = {
            "project",
            "region",
            "sslPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            sslPolicy = {
              description = "Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/sslPolicies/{sslPolicy}",
          response = {
            ["$ref"] = "SslPolicy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a new policy in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/sslPolicies",
          httpMethod = "POST",
          id = "compute.regionSslPolicies.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/sslPolicies",
          request = {
            ["$ref"] = "SslPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists all the SSL policies that have been configured for the specified project and region.",
          flatPath = "projects/{project}/regions/{region}/sslPolicies",
          httpMethod = "GET",
          id = "compute.regionSslPolicies.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/sslPolicies",
          response = {
            ["$ref"] = "SslPoliciesList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listAvailableFeatures = {
          description = "Lists all features that can be specified in the SSL policy when using custom profile.",
          flatPath = "projects/{project}/regions/{region}/sslPolicies/listAvailableFeatures",
          httpMethod = "GET",
          id = "compute.regionSslPolicies.listAvailableFeatures",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/sslPolicies/listAvailableFeatures",
          response = {
            ["$ref"] = "SslPoliciesListAvailableFeaturesResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified SSL policy with the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/sslPolicies/{sslPolicy}",
          httpMethod = "PATCH",
          id = "compute.regionSslPolicies.patch",
          parameterOrder = {
            "project",
            "region",
            "sslPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sslPolicy = {
              description = "Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/sslPolicies/{sslPolicy}",
          request = {
            ["$ref"] = "SslPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionTargetHttpProxies = {
      methods = {
        delete = {
          description = "Deletes the specified TargetHttpProxy resource.",
          flatPath = "projects/{project}/regions/{region}/targetHttpProxies/{targetHttpProxy}",
          httpMethod = "DELETE",
          id = "compute.regionTargetHttpProxies.delete",
          parameterOrder = {
            "project",
            "region",
            "targetHttpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpProxy = {
              description = "Name of the TargetHttpProxy resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpProxies/{targetHttpProxy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified TargetHttpProxy resource in the specified region. Gets a list of available target HTTP proxies by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/targetHttpProxies/{targetHttpProxy}",
          httpMethod = "GET",
          id = "compute.regionTargetHttpProxies.get",
          parameterOrder = {
            "project",
            "region",
            "targetHttpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            targetHttpProxy = {
              description = "Name of the TargetHttpProxy resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpProxies/{targetHttpProxy}",
          response = {
            ["$ref"] = "TargetHttpProxy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a TargetHttpProxy resource in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/targetHttpProxies",
          httpMethod = "POST",
          id = "compute.regionTargetHttpProxies.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpProxies",
          request = {
            ["$ref"] = "TargetHttpProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of TargetHttpProxy resources available to the specified project in the specified region.",
          flatPath = "projects/{project}/regions/{region}/targetHttpProxies",
          httpMethod = "GET",
          id = "compute.regionTargetHttpProxies.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpProxies",
          response = {
            ["$ref"] = "TargetHttpProxyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setUrlMap = {
          description = "Changes the URL map for TargetHttpProxy.",
          flatPath = "projects/{project}/regions/{region}/targetHttpProxies/{targetHttpProxy}/setUrlMap",
          httpMethod = "POST",
          id = "compute.regionTargetHttpProxies.setUrlMap",
          parameterOrder = {
            "project",
            "region",
            "targetHttpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpProxy = {
              description = "Name of the TargetHttpProxy to set a URL map for.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpProxies/{targetHttpProxy}/setUrlMap",
          request = {
            ["$ref"] = "UrlMapReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionTargetHttpsProxies = {
      methods = {
        delete = {
          description = "Deletes the specified TargetHttpsProxy resource.",
          flatPath = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}",
          httpMethod = "DELETE",
          id = "compute.regionTargetHttpsProxies.delete",
          parameterOrder = {
            "project",
            "region",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified TargetHttpsProxy resource in the specified region. Gets a list of available target HTTP proxies by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}",
          httpMethod = "GET",
          id = "compute.regionTargetHttpsProxies.get",
          parameterOrder = {
            "project",
            "region",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}",
          response = {
            ["$ref"] = "TargetHttpsProxy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a TargetHttpsProxy resource in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/targetHttpsProxies",
          httpMethod = "POST",
          id = "compute.regionTargetHttpsProxies.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpsProxies",
          request = {
            ["$ref"] = "TargetHttpsProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of TargetHttpsProxy resources available to the specified project in the specified region.",
          flatPath = "projects/{project}/regions/{region}/targetHttpsProxies",
          httpMethod = "GET",
          id = "compute.regionTargetHttpsProxies.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpsProxies",
          response = {
            ["$ref"] = "TargetHttpsProxyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified regional TargetHttpsProxy resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}",
          httpMethod = "PATCH",
          id = "compute.regionTargetHttpsProxies.patch",
          parameterOrder = {
            "project",
            "region",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}",
          request = {
            ["$ref"] = "TargetHttpsProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setSslCertificates = {
          description = "Replaces SslCertificates for TargetHttpsProxy.",
          flatPath = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}/setSslCertificates",
          httpMethod = "POST",
          id = "compute.regionTargetHttpsProxies.setSslCertificates",
          parameterOrder = {
            "project",
            "region",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource to set an SslCertificates resource for.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}/setSslCertificates",
          request = {
            ["$ref"] = "RegionTargetHttpsProxiesSetSslCertificatesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setUrlMap = {
          description = "Changes the URL map for TargetHttpsProxy.",
          flatPath = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}/setUrlMap",
          httpMethod = "POST",
          id = "compute.regionTargetHttpsProxies.setUrlMap",
          parameterOrder = {
            "project",
            "region",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy to set a URL map for.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetHttpsProxies/{targetHttpsProxy}/setUrlMap",
          request = {
            ["$ref"] = "UrlMapReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regionTargetTcpProxies = {
      methods = {
        delete = {
          description = "Deletes the specified TargetTcpProxy resource.",
          flatPath = "projects/{project}/regions/{region}/targetTcpProxies/{targetTcpProxy}",
          httpMethod = "DELETE",
          id = "compute.regionTargetTcpProxies.delete",
          parameterOrder = {
            "project",
            "region",
            "targetTcpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetTcpProxy = {
              description = "Name of the TargetTcpProxy resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetTcpProxies/{targetTcpProxy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified TargetTcpProxy resource.",
          flatPath = "projects/{project}/regions/{region}/targetTcpProxies/{targetTcpProxy}",
          httpMethod = "GET",
          id = "compute.regionTargetTcpProxies.get",
          parameterOrder = {
            "project",
            "region",
            "targetTcpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            targetTcpProxy = {
              description = "Name of the TargetTcpProxy resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetTcpProxies/{targetTcpProxy}",
          response = {
            ["$ref"] = "TargetTcpProxy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a TargetTcpProxy resource in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/targetTcpProxies",
          httpMethod = "POST",
          id = "compute.regionTargetTcpProxies.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetTcpProxies",
          request = {
            ["$ref"] = "TargetTcpProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of TargetTcpProxy resources available to the specified project in a given region.",
          flatPath = "projects/{project}/regions/{region}/targetTcpProxies",
          httpMethod = "GET",
          id = "compute.regionTargetTcpProxies.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/targetTcpProxies",
          response = {
            ["$ref"] = "TargetTcpProxyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    regionUrlMaps = {
      methods = {
        delete = {
          description = "Deletes the specified UrlMap resource.",
          flatPath = "projects/{project}/regions/{region}/urlMaps/{urlMap}",
          httpMethod = "DELETE",
          id = "compute.regionUrlMaps.delete",
          parameterOrder = {
            "project",
            "region",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.",
              location = "query",
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/urlMaps/{urlMap}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified UrlMap resource. Gets a list of available URL maps by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/urlMaps/{urlMap}",
          httpMethod = "GET",
          id = "compute.regionUrlMaps.get",
          parameterOrder = {
            "project",
            "region",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/urlMaps/{urlMap}",
          response = {
            ["$ref"] = "UrlMap",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a UrlMap resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/urlMaps",
          httpMethod = "POST",
          id = "compute.regionUrlMaps.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/urlMaps",
          request = {
            ["$ref"] = "UrlMap",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of UrlMap resources available to the specified project in the specified region.",
          flatPath = "projects/{project}/regions/{region}/urlMaps",
          httpMethod = "GET",
          id = "compute.regionUrlMaps.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/urlMaps",
          response = {
            ["$ref"] = "UrlMapList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified UrlMap resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/urlMaps/{urlMap}",
          httpMethod = "PATCH",
          id = "compute.regionUrlMaps.patch",
          parameterOrder = {
            "project",
            "region",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.",
              location = "query",
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/urlMaps/{urlMap}",
          request = {
            ["$ref"] = "UrlMap",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates the specified UrlMap resource with the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/urlMaps/{urlMap}",
          httpMethod = "PUT",
          id = "compute.regionUrlMaps.update",
          parameterOrder = {
            "project",
            "region",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.",
              location = "query",
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/urlMaps/{urlMap}",
          request = {
            ["$ref"] = "UrlMap",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        validate = {
          description = "Runs static validation for the UrlMap. In particular, the tests of the provided UrlMap will be run. Calling this method does NOT create the UrlMap.",
          flatPath = "projects/{project}/regions/{region}/urlMaps/{urlMap}/validate",
          httpMethod = "POST",
          id = "compute.regionUrlMaps.validate",
          parameterOrder = {
            "project",
            "region",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to be validated as.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/urlMaps/{urlMap}/validate",
          request = {
            ["$ref"] = "RegionUrlMapsValidateRequest",
          },
          response = {
            ["$ref"] = "UrlMapsValidateResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    regions = {
      methods = {
        get = {
          description = "Returns the specified Region resource. Gets a list of available regions by making a list() request. To decrease latency for this method, you can optionally omit any unneeded information from the response by using a field mask. This practice is especially recommended for unused quota information (the `quotas` field). To exclude one or more fields, set your request's `fields` query parameter to only include the fields you need. For example, to only include the `id` and `selfLink` fields, add the query parameter `?fields=id,selfLink` to your request.",
          flatPath = "projects/{project}/regions/{region}",
          httpMethod = "GET",
          id = "compute.regions.get",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}",
          response = {
            ["$ref"] = "Region",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves the list of region resources available to the specified project. To decrease latency for this method, you can optionally omit any unneeded information from the response by using a field mask. This practice is especially recommended for unused quota information (the `items.quotas` field). To exclude one or more fields, set your request's `fields` query parameter to only include the fields you need. For example, to only include the `id` and `selfLink` fields, add the query parameter `?fields=id,selfLink` to your request.",
          flatPath = "projects/{project}/regions",
          httpMethod = "GET",
          id = "compute.regions.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions",
          response = {
            ["$ref"] = "RegionList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    reservations = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of reservations.",
          flatPath = "projects/{project}/aggregated/reservations",
          httpMethod = "GET",
          id = "compute.reservations.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/reservations",
          response = {
            ["$ref"] = "ReservationAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified reservation.",
          flatPath = "projects/{project}/zones/{zone}/reservations/{reservation}",
          httpMethod = "DELETE",
          id = "compute.reservations.delete",
          parameterOrder = {
            "project",
            "zone",
            "reservation",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            reservation = {
              description = "Name of the reservation to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/reservations/{reservation}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Retrieves information about the specified reservation.",
          flatPath = "projects/{project}/zones/{zone}/reservations/{reservation}",
          httpMethod = "GET",
          id = "compute.reservations.get",
          parameterOrder = {
            "project",
            "zone",
            "reservation",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            reservation = {
              description = "Name of the reservation to retrieve.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/reservations/{reservation}",
          response = {
            ["$ref"] = "Reservation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/zones/{zone}/reservations/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.reservations.getIamPolicy",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/reservations/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a new reservation. For more information, read Reserving zonal resources.",
          flatPath = "projects/{project}/zones/{zone}/reservations",
          httpMethod = "POST",
          id = "compute.reservations.insert",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/reservations",
          request = {
            ["$ref"] = "Reservation",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "A list of all the reservations that have been configured for the specified project in specified zone.",
          flatPath = "projects/{project}/zones/{zone}/reservations",
          httpMethod = "GET",
          id = "compute.reservations.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/reservations",
          response = {
            ["$ref"] = "ReservationList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        resize = {
          description = "Resizes the reservation (applicable to standalone reservations only). For more information, read Modifying reservations.",
          flatPath = "projects/{project}/zones/{zone}/reservations/{reservation}/resize",
          httpMethod = "POST",
          id = "compute.reservations.resize",
          parameterOrder = {
            "project",
            "zone",
            "reservation",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            reservation = {
              description = "Name of the reservation to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/reservations/{reservation}/resize",
          request = {
            ["$ref"] = "ReservationsResizeRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/zones/{zone}/reservations/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.reservations.setIamPolicy",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/reservations/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "ZoneSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/zones/{zone}/reservations/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.reservations.testIamPermissions",
          parameterOrder = {
            "project",
            "zone",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "The name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/reservations/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        update = {
          description = "Update share settings of the reservation.",
          flatPath = "projects/{project}/zones/{zone}/reservations/{reservation}",
          httpMethod = "PATCH",
          id = "compute.reservations.update",
          parameterOrder = {
            "project",
            "zone",
            "reservation",
          },
          parameters = {
            paths = {
              location = "query",
              repeated = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            reservation = {
              description = "Name of the reservation to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            updateMask = {
              description = "Update_mask indicates fields to be updated as part of this request.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/reservations/{reservation}",
          request = {
            ["$ref"] = "Reservation",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    resourcePolicies = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of resource policies.",
          flatPath = "projects/{project}/aggregated/resourcePolicies",
          httpMethod = "GET",
          id = "compute.resourcePolicies.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/resourcePolicies",
          response = {
            ["$ref"] = "ResourcePolicyAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified resource policy.",
          flatPath = "projects/{project}/regions/{region}/resourcePolicies/{resourcePolicy}",
          httpMethod = "DELETE",
          id = "compute.resourcePolicies.delete",
          parameterOrder = {
            "project",
            "region",
            "resourcePolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resourcePolicy = {
              description = "Name of the resource policy to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/resourcePolicies/{resourcePolicy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Retrieves all information of the specified resource policy.",
          flatPath = "projects/{project}/regions/{region}/resourcePolicies/{resourcePolicy}",
          httpMethod = "GET",
          id = "compute.resourcePolicies.get",
          parameterOrder = {
            "project",
            "region",
            "resourcePolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resourcePolicy = {
              description = "Name of the resource policy to retrieve.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/resourcePolicies/{resourcePolicy}",
          response = {
            ["$ref"] = "ResourcePolicy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/regions/{region}/resourcePolicies/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.resourcePolicies.getIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/resourcePolicies/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a new resource policy.",
          flatPath = "projects/{project}/regions/{region}/resourcePolicies",
          httpMethod = "POST",
          id = "compute.resourcePolicies.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/resourcePolicies",
          request = {
            ["$ref"] = "ResourcePolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "A list all the resource policies that have been configured for the specified project in specified region.",
          flatPath = "projects/{project}/regions/{region}/resourcePolicies",
          httpMethod = "GET",
          id = "compute.resourcePolicies.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/resourcePolicies",
          response = {
            ["$ref"] = "ResourcePolicyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/regions/{region}/resourcePolicies/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.resourcePolicies.setIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/resourcePolicies/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "RegionSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/regions/{region}/resourcePolicies/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.resourcePolicies.testIamPermissions",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/resourcePolicies/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    routers = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of routers.",
          flatPath = "projects/{project}/aggregated/routers",
          httpMethod = "GET",
          id = "compute.routers.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/routers",
          response = {
            ["$ref"] = "RouterAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified Router resource.",
          flatPath = "projects/{project}/regions/{region}/routers/{router}",
          httpMethod = "DELETE",
          id = "compute.routers.delete",
          parameterOrder = {
            "project",
            "region",
            "router",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            router = {
              description = "Name of the Router resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/routers/{router}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified Router resource. Gets a list of available routers by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/routers/{router}",
          httpMethod = "GET",
          id = "compute.routers.get",
          parameterOrder = {
            "project",
            "region",
            "router",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            router = {
              description = "Name of the Router resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/routers/{router}",
          response = {
            ["$ref"] = "Router",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getNatMappingInfo = {
          description = "Retrieves runtime Nat mapping information of VM endpoints.",
          flatPath = "projects/{project}/regions/{region}/routers/{router}/getNatMappingInfo",
          httpMethod = "GET",
          id = "compute.routers.getNatMappingInfo",
          parameterOrder = {
            "project",
            "region",
            "router",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            router = {
              description = "Name of the Router resource to query for Nat Mapping information of VM endpoints.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/routers/{router}/getNatMappingInfo",
          response = {
            ["$ref"] = "VmEndpointNatMappingsList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getRouterStatus = {
          description = "Retrieves runtime information of the specified router.",
          flatPath = "projects/{project}/regions/{region}/routers/{router}/getRouterStatus",
          httpMethod = "GET",
          id = "compute.routers.getRouterStatus",
          parameterOrder = {
            "project",
            "region",
            "router",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            router = {
              description = "Name of the Router resource to query.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/routers/{router}/getRouterStatus",
          response = {
            ["$ref"] = "RouterStatusResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a Router resource in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/routers",
          httpMethod = "POST",
          id = "compute.routers.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/routers",
          request = {
            ["$ref"] = "Router",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of Router resources available to the specified project.",
          flatPath = "projects/{project}/regions/{region}/routers",
          httpMethod = "GET",
          id = "compute.routers.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/routers",
          response = {
            ["$ref"] = "RouterList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified Router resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/routers/{router}",
          httpMethod = "PATCH",
          id = "compute.routers.patch",
          parameterOrder = {
            "project",
            "region",
            "router",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            router = {
              description = "Name of the Router resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/routers/{router}",
          request = {
            ["$ref"] = "Router",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        preview = {
          description = "Preview fields auto-generated during router create and update operations. Calling this method does NOT create or update the router.",
          flatPath = "projects/{project}/regions/{region}/routers/{router}/preview",
          httpMethod = "POST",
          id = "compute.routers.preview",
          parameterOrder = {
            "project",
            "region",
            "router",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            router = {
              description = "Name of the Router resource to query.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/routers/{router}/preview",
          request = {
            ["$ref"] = "Router",
          },
          response = {
            ["$ref"] = "RoutersPreviewResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        update = {
          description = "Updates the specified Router resource with the data included in the request. This method conforms to PUT semantics, which requests that the state of the target resource be created or replaced with the state defined by the representation enclosed in the request message payload.",
          flatPath = "projects/{project}/regions/{region}/routers/{router}",
          httpMethod = "PUT",
          id = "compute.routers.update",
          parameterOrder = {
            "project",
            "region",
            "router",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            router = {
              description = "Name of the Router resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/routers/{router}",
          request = {
            ["$ref"] = "Router",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    routes = {
      methods = {
        delete = {
          description = "Deletes the specified Route resource.",
          flatPath = "projects/{project}/global/routes/{route}",
          httpMethod = "DELETE",
          id = "compute.routes.delete",
          parameterOrder = {
            "project",
            "route",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            route = {
              description = "Name of the Route resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/routes/{route}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified Route resource. Gets a list of available routes by making a list() request.",
          flatPath = "projects/{project}/global/routes/{route}",
          httpMethod = "GET",
          id = "compute.routes.get",
          parameterOrder = {
            "project",
            "route",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            route = {
              description = "Name of the Route resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/routes/{route}",
          response = {
            ["$ref"] = "Route",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a Route resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/routes",
          httpMethod = "POST",
          id = "compute.routes.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/routes",
          request = {
            ["$ref"] = "Route",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of Route resources available to the specified project.",
          flatPath = "projects/{project}/global/routes",
          httpMethod = "GET",
          id = "compute.routes.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/routes",
          response = {
            ["$ref"] = "RouteList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    securityPolicies = {
      methods = {
        addRule = {
          description = "Inserts a rule into a security policy.",
          flatPath = "projects/{project}/global/securityPolicies/{securityPolicy}/addRule",
          httpMethod = "POST",
          id = "compute.securityPolicies.addRule",
          parameterOrder = {
            "project",
            "securityPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            validateOnly = {
              description = "If true, the request will not be committed.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/securityPolicies/{securityPolicy}/addRule",
          request = {
            ["$ref"] = "SecurityPolicyRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        aggregatedList = {
          description = "Retrieves the list of all SecurityPolicy resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/securityPolicies",
          httpMethod = "GET",
          id = "compute.securityPolicies.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/securityPolicies",
          response = {
            ["$ref"] = "SecurityPoliciesAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified policy.",
          flatPath = "projects/{project}/global/securityPolicies/{securityPolicy}",
          httpMethod = "DELETE",
          id = "compute.securityPolicies.delete",
          parameterOrder = {
            "project",
            "securityPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/securityPolicies/{securityPolicy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "List all of the ordered rules present in a single specified policy.",
          flatPath = "projects/{project}/global/securityPolicies/{securityPolicy}",
          httpMethod = "GET",
          id = "compute.securityPolicies.get",
          parameterOrder = {
            "project",
            "securityPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to get.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/securityPolicies/{securityPolicy}",
          response = {
            ["$ref"] = "SecurityPolicy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getRule = {
          description = "Gets a rule at the specified priority.",
          flatPath = "projects/{project}/global/securityPolicies/{securityPolicy}/getRule",
          httpMethod = "GET",
          id = "compute.securityPolicies.getRule",
          parameterOrder = {
            "project",
            "securityPolicy",
          },
          parameters = {
            priority = {
              description = "The priority of the rule to get from the security policy.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to which the queried rule belongs.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/securityPolicies/{securityPolicy}/getRule",
          response = {
            ["$ref"] = "SecurityPolicyRule",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a new policy in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/securityPolicies",
          httpMethod = "POST",
          id = "compute.securityPolicies.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            validateOnly = {
              description = "If true, the request will not be committed.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/securityPolicies",
          request = {
            ["$ref"] = "SecurityPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "List all the policies that have been configured for the specified project.",
          flatPath = "projects/{project}/global/securityPolicies",
          httpMethod = "GET",
          id = "compute.securityPolicies.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/securityPolicies",
          response = {
            ["$ref"] = "SecurityPolicyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listPreconfiguredExpressionSets = {
          description = "Gets the current list of preconfigured Web Application Firewall (WAF) expressions.",
          flatPath = "projects/{project}/global/securityPolicies/listPreconfiguredExpressionSets",
          httpMethod = "GET",
          id = "compute.securityPolicies.listPreconfiguredExpressionSets",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/securityPolicies/listPreconfiguredExpressionSets",
          response = {
            ["$ref"] = "SecurityPoliciesListPreconfiguredExpressionSetsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified policy with the data included in the request. To clear fields in the rule, leave the fields empty and specify them in the updateMask. This cannot be used to be update the rules in the policy. Please use the per rule methods like addRule, patchRule, and removeRule instead.",
          flatPath = "projects/{project}/global/securityPolicies/{securityPolicy}",
          httpMethod = "PATCH",
          id = "compute.securityPolicies.patch",
          parameterOrder = {
            "project",
            "securityPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/securityPolicies/{securityPolicy}",
          request = {
            ["$ref"] = "SecurityPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        patchRule = {
          description = "Patches a rule at the specified priority.",
          flatPath = "projects/{project}/global/securityPolicies/{securityPolicy}/patchRule",
          httpMethod = "POST",
          id = "compute.securityPolicies.patchRule",
          parameterOrder = {
            "project",
            "securityPolicy",
          },
          parameters = {
            priority = {
              description = "The priority of the rule to patch.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            validateOnly = {
              description = "If true, the request will not be committed.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/securityPolicies/{securityPolicy}/patchRule",
          request = {
            ["$ref"] = "SecurityPolicyRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        removeRule = {
          description = "Deletes a rule at the specified priority.",
          flatPath = "projects/{project}/global/securityPolicies/{securityPolicy}/removeRule",
          httpMethod = "POST",
          id = "compute.securityPolicies.removeRule",
          parameterOrder = {
            "project",
            "securityPolicy",
          },
          parameters = {
            priority = {
              description = "The priority of the rule to remove from the security policy.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            securityPolicy = {
              description = "Name of the security policy to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/securityPolicies/{securityPolicy}/removeRule",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets the labels on a security policy. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/global/securityPolicies/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.securityPolicies.setLabels",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/securityPolicies/{resource}/setLabels",
          request = {
            ["$ref"] = "GlobalSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    serviceAttachments = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all ServiceAttachment resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/serviceAttachments",
          httpMethod = "GET",
          id = "compute.serviceAttachments.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/serviceAttachments",
          response = {
            ["$ref"] = "ServiceAttachmentAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified ServiceAttachment in the given scope",
          flatPath = "projects/{project}/regions/{region}/serviceAttachments/{serviceAttachment}",
          httpMethod = "DELETE",
          id = "compute.serviceAttachments.delete",
          parameterOrder = {
            "project",
            "region",
            "serviceAttachment",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            serviceAttachment = {
              description = "Name of the ServiceAttachment resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/serviceAttachments/{serviceAttachment}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified ServiceAttachment resource in the given scope.",
          flatPath = "projects/{project}/regions/{region}/serviceAttachments/{serviceAttachment}",
          httpMethod = "GET",
          id = "compute.serviceAttachments.get",
          parameterOrder = {
            "project",
            "region",
            "serviceAttachment",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            serviceAttachment = {
              description = "Name of the ServiceAttachment resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/serviceAttachments/{serviceAttachment}",
          response = {
            ["$ref"] = "ServiceAttachment",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/regions/{region}/serviceAttachments/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.serviceAttachments.getIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/serviceAttachments/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a ServiceAttachment in the specified project in the given scope using the parameters that are included in the request.",
          flatPath = "projects/{project}/regions/{region}/serviceAttachments",
          httpMethod = "POST",
          id = "compute.serviceAttachments.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/serviceAttachments",
          request = {
            ["$ref"] = "ServiceAttachment",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists the ServiceAttachments for a project in the given scope.",
          flatPath = "projects/{project}/regions/{region}/serviceAttachments",
          httpMethod = "GET",
          id = "compute.serviceAttachments.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region of this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/serviceAttachments",
          response = {
            ["$ref"] = "ServiceAttachmentList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified ServiceAttachment resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/regions/{region}/serviceAttachments/{serviceAttachment}",
          httpMethod = "PATCH",
          id = "compute.serviceAttachments.patch",
          parameterOrder = {
            "project",
            "region",
            "serviceAttachment",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The region scoping this request and should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            serviceAttachment = {
              description = "The resource id of the ServiceAttachment to patch. It should conform to RFC1035 resource name or be a string form on an unsigned long number.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/serviceAttachments/{serviceAttachment}",
          request = {
            ["$ref"] = "ServiceAttachment",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/regions/{region}/serviceAttachments/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.serviceAttachments.setIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/serviceAttachments/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "RegionSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/regions/{region}/serviceAttachments/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.serviceAttachments.testIamPermissions",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/serviceAttachments/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    snapshots = {
      methods = {
        delete = {
          description = "Deletes the specified Snapshot resource. Keep in mind that deleting a single snapshot might not necessarily delete all the data on that snapshot. If any data on the snapshot that is marked for deletion is needed for subsequent snapshots, the data will be moved to the next corresponding snapshot. For more information, see Deleting snapshots.",
          flatPath = "projects/{project}/global/snapshots/{snapshot}",
          httpMethod = "DELETE",
          id = "compute.snapshots.delete",
          parameterOrder = {
            "project",
            "snapshot",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            snapshot = {
              description = "Name of the Snapshot resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/snapshots/{snapshot}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified Snapshot resource. Gets a list of available snapshots by making a list() request.",
          flatPath = "projects/{project}/global/snapshots/{snapshot}",
          httpMethod = "GET",
          id = "compute.snapshots.get",
          parameterOrder = {
            "project",
            "snapshot",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            snapshot = {
              description = "Name of the Snapshot resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/snapshots/{snapshot}",
          response = {
            ["$ref"] = "Snapshot",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/global/snapshots/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.snapshots.getIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/snapshots/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a snapshot in the specified project using the data included in the request. For regular snapshot creation, consider using this method instead of disks.createSnapshot, as this method supports more features, such as creating snapshots in a project different from the source disk project.",
          flatPath = "projects/{project}/global/snapshots",
          httpMethod = "POST",
          id = "compute.snapshots.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/snapshots",
          request = {
            ["$ref"] = "Snapshot",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of Snapshot resources contained within the specified project.",
          flatPath = "projects/{project}/global/snapshots",
          httpMethod = "GET",
          id = "compute.snapshots.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/snapshots",
          response = {
            ["$ref"] = "SnapshotList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/global/snapshots/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.snapshots.setIamPolicy",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/snapshots/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "GlobalSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setLabels = {
          description = "Sets the labels on a snapshot. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/global/snapshots/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.snapshots.setLabels",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/snapshots/{resource}/setLabels",
          request = {
            ["$ref"] = "GlobalSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/global/snapshots/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.snapshots.testIamPermissions",
          parameterOrder = {
            "project",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9_]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/snapshots/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    sslCertificates = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all SslCertificate resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/sslCertificates",
          httpMethod = "GET",
          id = "compute.sslCertificates.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/sslCertificates",
          response = {
            ["$ref"] = "SslCertificateAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified SslCertificate resource.",
          flatPath = "projects/{project}/global/sslCertificates/{sslCertificate}",
          httpMethod = "DELETE",
          id = "compute.sslCertificates.delete",
          parameterOrder = {
            "project",
            "sslCertificate",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sslCertificate = {
              description = "Name of the SslCertificate resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/sslCertificates/{sslCertificate}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified SslCertificate resource. Gets a list of available SSL certificates by making a list() request.",
          flatPath = "projects/{project}/global/sslCertificates/{sslCertificate}",
          httpMethod = "GET",
          id = "compute.sslCertificates.get",
          parameterOrder = {
            "project",
            "sslCertificate",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            sslCertificate = {
              description = "Name of the SslCertificate resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/sslCertificates/{sslCertificate}",
          response = {
            ["$ref"] = "SslCertificate",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a SslCertificate resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/sslCertificates",
          httpMethod = "POST",
          id = "compute.sslCertificates.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/sslCertificates",
          request = {
            ["$ref"] = "SslCertificate",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of SslCertificate resources available to the specified project.",
          flatPath = "projects/{project}/global/sslCertificates",
          httpMethod = "GET",
          id = "compute.sslCertificates.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/sslCertificates",
          response = {
            ["$ref"] = "SslCertificateList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    sslPolicies = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all SslPolicy resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/sslPolicies",
          httpMethod = "GET",
          id = "compute.sslPolicies.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/sslPolicies",
          response = {
            ["$ref"] = "SslPoliciesAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified SSL policy. The SSL policy resource can be deleted only if it is not in use by any TargetHttpsProxy or TargetSslProxy resources.",
          flatPath = "projects/{project}/global/sslPolicies/{sslPolicy}",
          httpMethod = "DELETE",
          id = "compute.sslPolicies.delete",
          parameterOrder = {
            "project",
            "sslPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sslPolicy = {
              description = "Name of the SSL policy to delete. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/sslPolicies/{sslPolicy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Lists all of the ordered rules present in a single specified policy.",
          flatPath = "projects/{project}/global/sslPolicies/{sslPolicy}",
          httpMethod = "GET",
          id = "compute.sslPolicies.get",
          parameterOrder = {
            "project",
            "sslPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            sslPolicy = {
              description = "Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/sslPolicies/{sslPolicy}",
          response = {
            ["$ref"] = "SslPolicy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Returns the specified SSL policy resource. Gets a list of available SSL policies by making a list() request.",
          flatPath = "projects/{project}/global/sslPolicies",
          httpMethod = "POST",
          id = "compute.sslPolicies.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/sslPolicies",
          request = {
            ["$ref"] = "SslPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists all the SSL policies that have been configured for the specified project.",
          flatPath = "projects/{project}/global/sslPolicies",
          httpMethod = "GET",
          id = "compute.sslPolicies.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/sslPolicies",
          response = {
            ["$ref"] = "SslPoliciesList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listAvailableFeatures = {
          description = "Lists all features that can be specified in the SSL policy when using custom profile.",
          flatPath = "projects/{project}/global/sslPolicies/listAvailableFeatures",
          httpMethod = "GET",
          id = "compute.sslPolicies.listAvailableFeatures",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/sslPolicies/listAvailableFeatures",
          response = {
            ["$ref"] = "SslPoliciesListAvailableFeaturesResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified SSL policy with the data included in the request.",
          flatPath = "projects/{project}/global/sslPolicies/{sslPolicy}",
          httpMethod = "PATCH",
          id = "compute.sslPolicies.patch",
          parameterOrder = {
            "project",
            "sslPolicy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            sslPolicy = {
              description = "Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/sslPolicies/{sslPolicy}",
          request = {
            ["$ref"] = "SslPolicy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    subnetworks = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of subnetworks.",
          flatPath = "projects/{project}/aggregated/subnetworks",
          httpMethod = "GET",
          id = "compute.subnetworks.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/subnetworks",
          response = {
            ["$ref"] = "SubnetworkAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified subnetwork.",
          flatPath = "projects/{project}/regions/{region}/subnetworks/{subnetwork}",
          httpMethod = "DELETE",
          id = "compute.subnetworks.delete",
          parameterOrder = {
            "project",
            "region",
            "subnetwork",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            subnetwork = {
              description = "Name of the Subnetwork resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks/{subnetwork}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        expandIpCidrRange = {
          description = "Expands the IP CIDR range of the subnetwork to a specified value.",
          flatPath = "projects/{project}/regions/{region}/subnetworks/{subnetwork}/expandIpCidrRange",
          httpMethod = "POST",
          id = "compute.subnetworks.expandIpCidrRange",
          parameterOrder = {
            "project",
            "region",
            "subnetwork",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            subnetwork = {
              description = "Name of the Subnetwork resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks/{subnetwork}/expandIpCidrRange",
          request = {
            ["$ref"] = "SubnetworksExpandIpCidrRangeRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified subnetwork. Gets a list of available subnetworks list() request.",
          flatPath = "projects/{project}/regions/{region}/subnetworks/{subnetwork}",
          httpMethod = "GET",
          id = "compute.subnetworks.get",
          parameterOrder = {
            "project",
            "region",
            "subnetwork",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            subnetwork = {
              description = "Name of the Subnetwork resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks/{subnetwork}",
          response = {
            ["$ref"] = "Subnetwork",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getIamPolicy = {
          description = "Gets the access control policy for a resource. May be empty if no such policy or resource exists.",
          flatPath = "projects/{project}/regions/{region}/subnetworks/{resource}/getIamPolicy",
          httpMethod = "GET",
          id = "compute.subnetworks.getIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            optionsRequestedPolicyVersion = {
              description = "Requested IAM Policy version.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks/{resource}/getIamPolicy",
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a subnetwork in the specified project using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/subnetworks",
          httpMethod = "POST",
          id = "compute.subnetworks.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks",
          request = {
            ["$ref"] = "Subnetwork",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of subnetworks available to the specified project.",
          flatPath = "projects/{project}/regions/{region}/subnetworks",
          httpMethod = "GET",
          id = "compute.subnetworks.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks",
          response = {
            ["$ref"] = "SubnetworkList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        listUsable = {
          description = "Retrieves an aggregated list of all usable subnetworks in the project.",
          flatPath = "projects/{project}/aggregated/subnetworks/listUsable",
          httpMethod = "GET",
          id = "compute.subnetworks.listUsable",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/subnetworks/listUsable",
          response = {
            ["$ref"] = "UsableSubnetworksAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified subnetwork with the data included in the request. Only certain fields can be updated with a patch request as indicated in the field descriptions. You must specify the current fingerprint of the subnetwork resource being patched.",
          flatPath = "projects/{project}/regions/{region}/subnetworks/{subnetwork}",
          httpMethod = "PATCH",
          id = "compute.subnetworks.patch",
          parameterOrder = {
            "project",
            "region",
            "subnetwork",
          },
          parameters = {
            drainTimeoutSeconds = {
              description = "The drain timeout specifies the upper bound in seconds on the amount of time allowed to drain connections from the current ACTIVE subnetwork to the current BACKUP subnetwork. The drain timeout is only applicable when the following conditions are true: - the subnetwork being patched has purpose = INTERNAL_HTTPS_LOAD_BALANCER - the subnetwork being patched has role = BACKUP - the patch request is setting the role to ACTIVE. Note that after this patch operation the roles of the ACTIVE and BACKUP subnetworks will be swapped.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            subnetwork = {
              description = "Name of the Subnetwork resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks/{subnetwork}",
          request = {
            ["$ref"] = "Subnetwork",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setIamPolicy = {
          description = "Sets the access control policy on the specified resource. Replaces any existing policy.",
          flatPath = "projects/{project}/regions/{region}/subnetworks/{resource}/setIamPolicy",
          httpMethod = "POST",
          id = "compute.subnetworks.setIamPolicy",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks/{resource}/setIamPolicy",
          request = {
            ["$ref"] = "RegionSetPolicyRequest",
          },
          response = {
            ["$ref"] = "Policy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setPrivateIpGoogleAccess = {
          description = "Set whether VMs in this subnet can access Google services without assigning external IP addresses through Private Google Access.",
          flatPath = "projects/{project}/regions/{region}/subnetworks/{subnetwork}/setPrivateIpGoogleAccess",
          httpMethod = "POST",
          id = "compute.subnetworks.setPrivateIpGoogleAccess",
          parameterOrder = {
            "project",
            "region",
            "subnetwork",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            subnetwork = {
              description = "Name of the Subnetwork resource.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks/{subnetwork}/setPrivateIpGoogleAccess",
          request = {
            ["$ref"] = "SubnetworksSetPrivateIpGoogleAccessRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/regions/{region}/subnetworks/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.subnetworks.testIamPermissions",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/subnetworks/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    targetGrpcProxies = {
      methods = {
        delete = {
          description = "Deletes the specified TargetGrpcProxy in the given scope",
          flatPath = "projects/{project}/global/targetGrpcProxies/{targetGrpcProxy}",
          httpMethod = "DELETE",
          id = "compute.targetGrpcProxies.delete",
          parameterOrder = {
            "project",
            "targetGrpcProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetGrpcProxy = {
              description = "Name of the TargetGrpcProxy resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetGrpcProxies/{targetGrpcProxy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified TargetGrpcProxy resource in the given scope.",
          flatPath = "projects/{project}/global/targetGrpcProxies/{targetGrpcProxy}",
          httpMethod = "GET",
          id = "compute.targetGrpcProxies.get",
          parameterOrder = {
            "project",
            "targetGrpcProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            targetGrpcProxy = {
              description = "Name of the TargetGrpcProxy resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetGrpcProxies/{targetGrpcProxy}",
          response = {
            ["$ref"] = "TargetGrpcProxy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a TargetGrpcProxy in the specified project in the given scope using the parameters that are included in the request.",
          flatPath = "projects/{project}/global/targetGrpcProxies",
          httpMethod = "POST",
          id = "compute.targetGrpcProxies.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/targetGrpcProxies",
          request = {
            ["$ref"] = "TargetGrpcProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Lists the TargetGrpcProxies for a project in the given scope.",
          flatPath = "projects/{project}/global/targetGrpcProxies",
          httpMethod = "GET",
          id = "compute.targetGrpcProxies.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/targetGrpcProxies",
          response = {
            ["$ref"] = "TargetGrpcProxyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified TargetGrpcProxy resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/targetGrpcProxies/{targetGrpcProxy}",
          httpMethod = "PATCH",
          id = "compute.targetGrpcProxies.patch",
          parameterOrder = {
            "project",
            "targetGrpcProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetGrpcProxy = {
              description = "Name of the TargetGrpcProxy resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetGrpcProxies/{targetGrpcProxy}",
          request = {
            ["$ref"] = "TargetGrpcProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    targetHttpProxies = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all TargetHttpProxy resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/targetHttpProxies",
          httpMethod = "GET",
          id = "compute.targetHttpProxies.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/targetHttpProxies",
          response = {
            ["$ref"] = "TargetHttpProxyAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified TargetHttpProxy resource.",
          flatPath = "projects/{project}/global/targetHttpProxies/{targetHttpProxy}",
          httpMethod = "DELETE",
          id = "compute.targetHttpProxies.delete",
          parameterOrder = {
            "project",
            "targetHttpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpProxy = {
              description = "Name of the TargetHttpProxy resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpProxies/{targetHttpProxy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified TargetHttpProxy resource. Gets a list of available target HTTP proxies by making a list() request.",
          flatPath = "projects/{project}/global/targetHttpProxies/{targetHttpProxy}",
          httpMethod = "GET",
          id = "compute.targetHttpProxies.get",
          parameterOrder = {
            "project",
            "targetHttpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            targetHttpProxy = {
              description = "Name of the TargetHttpProxy resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpProxies/{targetHttpProxy}",
          response = {
            ["$ref"] = "TargetHttpProxy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a TargetHttpProxy resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/targetHttpProxies",
          httpMethod = "POST",
          id = "compute.targetHttpProxies.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpProxies",
          request = {
            ["$ref"] = "TargetHttpProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of TargetHttpProxy resources available to the specified project.",
          flatPath = "projects/{project}/global/targetHttpProxies",
          httpMethod = "GET",
          id = "compute.targetHttpProxies.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/targetHttpProxies",
          response = {
            ["$ref"] = "TargetHttpProxyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified TargetHttpProxy resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/targetHttpProxies/{targetHttpProxy}",
          httpMethod = "PATCH",
          id = "compute.targetHttpProxies.patch",
          parameterOrder = {
            "project",
            "targetHttpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpProxy = {
              description = "Name of the TargetHttpProxy resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpProxies/{targetHttpProxy}",
          request = {
            ["$ref"] = "TargetHttpProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setUrlMap = {
          description = "Changes the URL map for TargetHttpProxy.",
          flatPath = "projects/{project}/targetHttpProxies/{targetHttpProxy}/setUrlMap",
          httpMethod = "POST",
          id = "compute.targetHttpProxies.setUrlMap",
          parameterOrder = {
            "project",
            "targetHttpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpProxy = {
              description = "Name of the TargetHttpProxy to set a URL map for.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/targetHttpProxies/{targetHttpProxy}/setUrlMap",
          request = {
            ["$ref"] = "UrlMapReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    targetHttpsProxies = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all TargetHttpsProxy resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/targetHttpsProxies",
          httpMethod = "GET",
          id = "compute.targetHttpsProxies.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/targetHttpsProxies",
          response = {
            ["$ref"] = "TargetHttpsProxyAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified TargetHttpsProxy resource.",
          flatPath = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}",
          httpMethod = "DELETE",
          id = "compute.targetHttpsProxies.delete",
          parameterOrder = {
            "project",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified TargetHttpsProxy resource. Gets a list of available target HTTPS proxies by making a list() request.",
          flatPath = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}",
          httpMethod = "GET",
          id = "compute.targetHttpsProxies.get",
          parameterOrder = {
            "project",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}",
          response = {
            ["$ref"] = "TargetHttpsProxy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a TargetHttpsProxy resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/targetHttpsProxies",
          httpMethod = "POST",
          id = "compute.targetHttpsProxies.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpsProxies",
          request = {
            ["$ref"] = "TargetHttpsProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of TargetHttpsProxy resources available to the specified project.",
          flatPath = "projects/{project}/global/targetHttpsProxies",
          httpMethod = "GET",
          id = "compute.targetHttpsProxies.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/targetHttpsProxies",
          response = {
            ["$ref"] = "TargetHttpsProxyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified TargetHttpsProxy resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}",
          httpMethod = "PATCH",
          id = "compute.targetHttpsProxies.patch",
          parameterOrder = {
            "project",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}",
          request = {
            ["$ref"] = "TargetHttpsProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setCertificateMap = {
          description = "Changes the Certificate Map for TargetHttpsProxy.",
          flatPath = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}/setCertificateMap",
          httpMethod = "POST",
          id = "compute.targetHttpsProxies.setCertificateMap",
          parameterOrder = {
            "project",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource whose CertificateMap is to be set. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}/setCertificateMap",
          request = {
            ["$ref"] = "TargetHttpsProxiesSetCertificateMapRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setQuicOverride = {
          description = "Sets the QUIC override policy for TargetHttpsProxy.",
          flatPath = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}/setQuicOverride",
          httpMethod = "POST",
          id = "compute.targetHttpsProxies.setQuicOverride",
          parameterOrder = {
            "project",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource to set the QUIC override policy for. The name should conform to RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}/setQuicOverride",
          request = {
            ["$ref"] = "TargetHttpsProxiesSetQuicOverrideRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setSslCertificates = {
          description = "Replaces SslCertificates for TargetHttpsProxy.",
          flatPath = "projects/{project}/targetHttpsProxies/{targetHttpsProxy}/setSslCertificates",
          httpMethod = "POST",
          id = "compute.targetHttpsProxies.setSslCertificates",
          parameterOrder = {
            "project",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource to set an SslCertificates resource for.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/targetHttpsProxies/{targetHttpsProxy}/setSslCertificates",
          request = {
            ["$ref"] = "TargetHttpsProxiesSetSslCertificatesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setSslPolicy = {
          description = "Sets the SSL policy for TargetHttpsProxy. The SSL policy specifies the server-side support for SSL features. This affects connections between clients and the HTTPS proxy load balancer. They do not affect the connection between the load balancer and the backends.",
          flatPath = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}/setSslPolicy",
          httpMethod = "POST",
          id = "compute.targetHttpsProxies.setSslPolicy",
          parameterOrder = {
            "project",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource whose SSL policy is to be set. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetHttpsProxies/{targetHttpsProxy}/setSslPolicy",
          request = {
            ["$ref"] = "SslPolicyReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setUrlMap = {
          description = "Changes the URL map for TargetHttpsProxy.",
          flatPath = "projects/{project}/targetHttpsProxies/{targetHttpsProxy}/setUrlMap",
          httpMethod = "POST",
          id = "compute.targetHttpsProxies.setUrlMap",
          parameterOrder = {
            "project",
            "targetHttpsProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetHttpsProxy = {
              description = "Name of the TargetHttpsProxy resource whose URL map is to be set.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/targetHttpsProxies/{targetHttpsProxy}/setUrlMap",
          request = {
            ["$ref"] = "UrlMapReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    targetInstances = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of target instances.",
          flatPath = "projects/{project}/aggregated/targetInstances",
          httpMethod = "GET",
          id = "compute.targetInstances.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/targetInstances",
          response = {
            ["$ref"] = "TargetInstanceAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified TargetInstance resource.",
          flatPath = "projects/{project}/zones/{zone}/targetInstances/{targetInstance}",
          httpMethod = "DELETE",
          id = "compute.targetInstances.delete",
          parameterOrder = {
            "project",
            "zone",
            "targetInstance",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetInstance = {
              description = "Name of the TargetInstance resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/targetInstances/{targetInstance}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified TargetInstance resource. Gets a list of available target instances by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}/targetInstances/{targetInstance}",
          httpMethod = "GET",
          id = "compute.targetInstances.get",
          parameterOrder = {
            "project",
            "zone",
            "targetInstance",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            targetInstance = {
              description = "Name of the TargetInstance resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/targetInstances/{targetInstance}",
          response = {
            ["$ref"] = "TargetInstance",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a TargetInstance resource in the specified project and zone using the data included in the request.",
          flatPath = "projects/{project}/zones/{zone}/targetInstances",
          httpMethod = "POST",
          id = "compute.targetInstances.insert",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            zone = {
              description = "Name of the zone scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/targetInstances",
          request = {
            ["$ref"] = "TargetInstance",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of TargetInstance resources available to the specified project and zone.",
          flatPath = "projects/{project}/zones/{zone}/targetInstances",
          httpMethod = "GET",
          id = "compute.targetInstances.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "Name of the zone scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/targetInstances",
          response = {
            ["$ref"] = "TargetInstanceList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    targetPools = {
      methods = {
        addHealthCheck = {
          description = "Adds health check URLs to a target pool.",
          flatPath = "projects/{project}/regions/{region}/targetPools/{targetPool}/addHealthCheck",
          httpMethod = "POST",
          id = "compute.targetPools.addHealthCheck",
          parameterOrder = {
            "project",
            "region",
            "targetPool",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetPool = {
              description = "Name of the target pool to add a health check to.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools/{targetPool}/addHealthCheck",
          request = {
            ["$ref"] = "TargetPoolsAddHealthCheckRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        addInstance = {
          description = "Adds an instance to a target pool.",
          flatPath = "projects/{project}/regions/{region}/targetPools/{targetPool}/addInstance",
          httpMethod = "POST",
          id = "compute.targetPools.addInstance",
          parameterOrder = {
            "project",
            "region",
            "targetPool",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetPool = {
              description = "Name of the TargetPool resource to add instances to.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools/{targetPool}/addInstance",
          request = {
            ["$ref"] = "TargetPoolsAddInstanceRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        aggregatedList = {
          description = "Retrieves an aggregated list of target pools.",
          flatPath = "projects/{project}/aggregated/targetPools",
          httpMethod = "GET",
          id = "compute.targetPools.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/targetPools",
          response = {
            ["$ref"] = "TargetPoolAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified target pool.",
          flatPath = "projects/{project}/regions/{region}/targetPools/{targetPool}",
          httpMethod = "DELETE",
          id = "compute.targetPools.delete",
          parameterOrder = {
            "project",
            "region",
            "targetPool",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetPool = {
              description = "Name of the TargetPool resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools/{targetPool}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified target pool. Gets a list of available target pools by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/targetPools/{targetPool}",
          httpMethod = "GET",
          id = "compute.targetPools.get",
          parameterOrder = {
            "project",
            "region",
            "targetPool",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            targetPool = {
              description = "Name of the TargetPool resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools/{targetPool}",
          response = {
            ["$ref"] = "TargetPool",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getHealth = {
          description = "Gets the most recent health check results for each IP for the instance that is referenced by the given target pool.",
          flatPath = "projects/{project}/regions/{region}/targetPools/{targetPool}/getHealth",
          httpMethod = "POST",
          id = "compute.targetPools.getHealth",
          parameterOrder = {
            "project",
            "region",
            "targetPool",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            targetPool = {
              description = "Name of the TargetPool resource to which the queried instance belongs.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools/{targetPool}/getHealth",
          request = {
            ["$ref"] = "InstanceReference",
          },
          response = {
            ["$ref"] = "TargetPoolInstanceHealth",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a target pool in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/targetPools",
          httpMethod = "POST",
          id = "compute.targetPools.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools",
          request = {
            ["$ref"] = "TargetPool",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of target pools available to the specified project and region.",
          flatPath = "projects/{project}/regions/{region}/targetPools",
          httpMethod = "GET",
          id = "compute.targetPools.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools",
          response = {
            ["$ref"] = "TargetPoolList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        removeHealthCheck = {
          description = "Removes health check URL from a target pool.",
          flatPath = "projects/{project}/regions/{region}/targetPools/{targetPool}/removeHealthCheck",
          httpMethod = "POST",
          id = "compute.targetPools.removeHealthCheck",
          parameterOrder = {
            "project",
            "region",
            "targetPool",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetPool = {
              description = "Name of the target pool to remove health checks from.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools/{targetPool}/removeHealthCheck",
          request = {
            ["$ref"] = "TargetPoolsRemoveHealthCheckRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        removeInstance = {
          description = "Removes instance URL from a target pool.",
          flatPath = "projects/{project}/regions/{region}/targetPools/{targetPool}/removeInstance",
          httpMethod = "POST",
          id = "compute.targetPools.removeInstance",
          parameterOrder = {
            "project",
            "region",
            "targetPool",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetPool = {
              description = "Name of the TargetPool resource to remove instances from.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools/{targetPool}/removeInstance",
          request = {
            ["$ref"] = "TargetPoolsRemoveInstanceRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setBackup = {
          description = "Changes a backup target pool's configurations.",
          flatPath = "projects/{project}/regions/{region}/targetPools/{targetPool}/setBackup",
          httpMethod = "POST",
          id = "compute.targetPools.setBackup",
          parameterOrder = {
            "project",
            "region",
            "targetPool",
          },
          parameters = {
            failoverRatio = {
              description = "New failoverRatio value for the target pool.",
              format = "float",
              location = "query",
              type = "number",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetPool = {
              description = "Name of the TargetPool resource to set a backup pool for.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetPools/{targetPool}/setBackup",
          request = {
            ["$ref"] = "TargetReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    targetSslProxies = {
      methods = {
        delete = {
          description = "Deletes the specified TargetSslProxy resource.",
          flatPath = "projects/{project}/global/targetSslProxies/{targetSslProxy}",
          httpMethod = "DELETE",
          id = "compute.targetSslProxies.delete",
          parameterOrder = {
            "project",
            "targetSslProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetSslProxy = {
              description = "Name of the TargetSslProxy resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetSslProxies/{targetSslProxy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified TargetSslProxy resource. Gets a list of available target SSL proxies by making a list() request.",
          flatPath = "projects/{project}/global/targetSslProxies/{targetSslProxy}",
          httpMethod = "GET",
          id = "compute.targetSslProxies.get",
          parameterOrder = {
            "project",
            "targetSslProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            targetSslProxy = {
              description = "Name of the TargetSslProxy resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetSslProxies/{targetSslProxy}",
          response = {
            ["$ref"] = "TargetSslProxy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a TargetSslProxy resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/targetSslProxies",
          httpMethod = "POST",
          id = "compute.targetSslProxies.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/targetSslProxies",
          request = {
            ["$ref"] = "TargetSslProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of TargetSslProxy resources available to the specified project.",
          flatPath = "projects/{project}/global/targetSslProxies",
          httpMethod = "GET",
          id = "compute.targetSslProxies.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/targetSslProxies",
          response = {
            ["$ref"] = "TargetSslProxyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setBackendService = {
          description = "Changes the BackendService for TargetSslProxy.",
          flatPath = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setBackendService",
          httpMethod = "POST",
          id = "compute.targetSslProxies.setBackendService",
          parameterOrder = {
            "project",
            "targetSslProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetSslProxy = {
              description = "Name of the TargetSslProxy resource whose BackendService resource is to be set.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setBackendService",
          request = {
            ["$ref"] = "TargetSslProxiesSetBackendServiceRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setCertificateMap = {
          description = "Changes the Certificate Map for TargetSslProxy.",
          flatPath = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setCertificateMap",
          httpMethod = "POST",
          id = "compute.targetSslProxies.setCertificateMap",
          parameterOrder = {
            "project",
            "targetSslProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetSslProxy = {
              description = "Name of the TargetSslProxy resource whose CertificateMap is to be set. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setCertificateMap",
          request = {
            ["$ref"] = "TargetSslProxiesSetCertificateMapRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setProxyHeader = {
          description = "Changes the ProxyHeaderType for TargetSslProxy.",
          flatPath = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setProxyHeader",
          httpMethod = "POST",
          id = "compute.targetSslProxies.setProxyHeader",
          parameterOrder = {
            "project",
            "targetSslProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetSslProxy = {
              description = "Name of the TargetSslProxy resource whose ProxyHeader is to be set.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setProxyHeader",
          request = {
            ["$ref"] = "TargetSslProxiesSetProxyHeaderRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setSslCertificates = {
          description = "Changes SslCertificates for TargetSslProxy.",
          flatPath = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setSslCertificates",
          httpMethod = "POST",
          id = "compute.targetSslProxies.setSslCertificates",
          parameterOrder = {
            "project",
            "targetSslProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetSslProxy = {
              description = "Name of the TargetSslProxy resource whose SslCertificate resource is to be set.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setSslCertificates",
          request = {
            ["$ref"] = "TargetSslProxiesSetSslCertificatesRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setSslPolicy = {
          description = "Sets the SSL policy for TargetSslProxy. The SSL policy specifies the server-side support for SSL features. This affects connections between clients and the SSL proxy load balancer. They do not affect the connection between the load balancer and the backends.",
          flatPath = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setSslPolicy",
          httpMethod = "POST",
          id = "compute.targetSslProxies.setSslPolicy",
          parameterOrder = {
            "project",
            "targetSslProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetSslProxy = {
              description = "Name of the TargetSslProxy resource whose SSL policy is to be set. The name must be 1-63 characters long, and comply with RFC1035.",
              location = "path",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetSslProxies/{targetSslProxy}/setSslPolicy",
          request = {
            ["$ref"] = "SslPolicyReference",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    targetTcpProxies = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all TargetTcpProxy resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/targetTcpProxies",
          httpMethod = "GET",
          id = "compute.targetTcpProxies.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/targetTcpProxies",
          response = {
            ["$ref"] = "TargetTcpProxyAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified TargetTcpProxy resource.",
          flatPath = "projects/{project}/global/targetTcpProxies/{targetTcpProxy}",
          httpMethod = "DELETE",
          id = "compute.targetTcpProxies.delete",
          parameterOrder = {
            "project",
            "targetTcpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetTcpProxy = {
              description = "Name of the TargetTcpProxy resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetTcpProxies/{targetTcpProxy}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified TargetTcpProxy resource. Gets a list of available target TCP proxies by making a list() request.",
          flatPath = "projects/{project}/global/targetTcpProxies/{targetTcpProxy}",
          httpMethod = "GET",
          id = "compute.targetTcpProxies.get",
          parameterOrder = {
            "project",
            "targetTcpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            targetTcpProxy = {
              description = "Name of the TargetTcpProxy resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetTcpProxies/{targetTcpProxy}",
          response = {
            ["$ref"] = "TargetTcpProxy",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a TargetTcpProxy resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/targetTcpProxies",
          httpMethod = "POST",
          id = "compute.targetTcpProxies.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/targetTcpProxies",
          request = {
            ["$ref"] = "TargetTcpProxy",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of TargetTcpProxy resources available to the specified project.",
          flatPath = "projects/{project}/global/targetTcpProxies",
          httpMethod = "GET",
          id = "compute.targetTcpProxies.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/targetTcpProxies",
          response = {
            ["$ref"] = "TargetTcpProxyList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setBackendService = {
          description = "Changes the BackendService for TargetTcpProxy.",
          flatPath = "projects/{project}/global/targetTcpProxies/{targetTcpProxy}/setBackendService",
          httpMethod = "POST",
          id = "compute.targetTcpProxies.setBackendService",
          parameterOrder = {
            "project",
            "targetTcpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetTcpProxy = {
              description = "Name of the TargetTcpProxy resource whose BackendService resource is to be set.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetTcpProxies/{targetTcpProxy}/setBackendService",
          request = {
            ["$ref"] = "TargetTcpProxiesSetBackendServiceRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        setProxyHeader = {
          description = "Changes the ProxyHeaderType for TargetTcpProxy.",
          flatPath = "projects/{project}/global/targetTcpProxies/{targetTcpProxy}/setProxyHeader",
          httpMethod = "POST",
          id = "compute.targetTcpProxies.setProxyHeader",
          parameterOrder = {
            "project",
            "targetTcpProxy",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetTcpProxy = {
              description = "Name of the TargetTcpProxy resource whose ProxyHeader is to be set.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/targetTcpProxies/{targetTcpProxy}/setProxyHeader",
          request = {
            ["$ref"] = "TargetTcpProxiesSetProxyHeaderRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    targetVpnGateways = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of target VPN gateways.",
          flatPath = "projects/{project}/aggregated/targetVpnGateways",
          httpMethod = "GET",
          id = "compute.targetVpnGateways.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/targetVpnGateways",
          response = {
            ["$ref"] = "TargetVpnGatewayAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified target VPN gateway.",
          flatPath = "projects/{project}/regions/{region}/targetVpnGateways/{targetVpnGateway}",
          httpMethod = "DELETE",
          id = "compute.targetVpnGateways.delete",
          parameterOrder = {
            "project",
            "region",
            "targetVpnGateway",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            targetVpnGateway = {
              description = "Name of the target VPN gateway to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetVpnGateways/{targetVpnGateway}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified target VPN gateway. Gets a list of available target VPN gateways by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/targetVpnGateways/{targetVpnGateway}",
          httpMethod = "GET",
          id = "compute.targetVpnGateways.get",
          parameterOrder = {
            "project",
            "region",
            "targetVpnGateway",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            targetVpnGateway = {
              description = "Name of the target VPN gateway to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetVpnGateways/{targetVpnGateway}",
          response = {
            ["$ref"] = "TargetVpnGateway",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a target VPN gateway in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/targetVpnGateways",
          httpMethod = "POST",
          id = "compute.targetVpnGateways.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetVpnGateways",
          request = {
            ["$ref"] = "TargetVpnGateway",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of target VPN gateways available to the specified project and region.",
          flatPath = "projects/{project}/regions/{region}/targetVpnGateways",
          httpMethod = "GET",
          id = "compute.targetVpnGateways.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/targetVpnGateways",
          response = {
            ["$ref"] = "TargetVpnGatewayList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setLabels = {
          description = "Sets the labels on a TargetVpnGateway. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/regions/{region}/targetVpnGateways/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.targetVpnGateways.setLabels",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/targetVpnGateways/{resource}/setLabels",
          request = {
            ["$ref"] = "RegionSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    urlMaps = {
      methods = {
        aggregatedList = {
          description = "Retrieves the list of all UrlMap resources, regional and global, available to the specified project.",
          flatPath = "projects/{project}/aggregated/urlMaps",
          httpMethod = "GET",
          id = "compute.urlMaps.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Name of the project scoping this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/urlMaps",
          response = {
            ["$ref"] = "UrlMapsAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified UrlMap resource.",
          flatPath = "projects/{project}/global/urlMaps/{urlMap}",
          httpMethod = "DELETE",
          id = "compute.urlMaps.delete",
          parameterOrder = {
            "project",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/urlMaps/{urlMap}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified UrlMap resource. Gets a list of available URL maps by making a list() request.",
          flatPath = "projects/{project}/global/urlMaps/{urlMap}",
          httpMethod = "GET",
          id = "compute.urlMaps.get",
          parameterOrder = {
            "project",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/urlMaps/{urlMap}",
          response = {
            ["$ref"] = "UrlMap",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a UrlMap resource in the specified project using the data included in the request.",
          flatPath = "projects/{project}/global/urlMaps",
          httpMethod = "POST",
          id = "compute.urlMaps.insert",
          parameterOrder = {
            "project",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/global/urlMaps",
          request = {
            ["$ref"] = "UrlMap",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        invalidateCache = {
          description = "Initiates a cache invalidation operation, invalidating the specified path, scoped to the specified UrlMap. For more information, see [Invalidating cached content](/cdn/docs/invalidating-cached-content).",
          flatPath = "projects/{project}/global/urlMaps/{urlMap}/invalidateCache",
          httpMethod = "POST",
          id = "compute.urlMaps.invalidateCache",
          parameterOrder = {
            "project",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap scoping this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/urlMaps/{urlMap}/invalidateCache",
          request = {
            ["$ref"] = "CacheInvalidationRule",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves the list of UrlMap resources available to the specified project.",
          flatPath = "projects/{project}/global/urlMaps",
          httpMethod = "GET",
          id = "compute.urlMaps.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/global/urlMaps",
          response = {
            ["$ref"] = "UrlMapList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        patch = {
          description = "Patches the specified UrlMap resource with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.",
          flatPath = "projects/{project}/global/urlMaps/{urlMap}",
          httpMethod = "PATCH",
          id = "compute.urlMaps.patch",
          parameterOrder = {
            "project",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to patch.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/urlMaps/{urlMap}",
          request = {
            ["$ref"] = "UrlMap",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        update = {
          description = "Updates the specified UrlMap resource with the data included in the request.",
          flatPath = "projects/{project}/global/urlMaps/{urlMap}",
          httpMethod = "PUT",
          id = "compute.urlMaps.update",
          parameterOrder = {
            "project",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to update.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/urlMaps/{urlMap}",
          request = {
            ["$ref"] = "UrlMap",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        validate = {
          description = "Runs static validation for the UrlMap. In particular, the tests of the provided UrlMap will be run. Calling this method does NOT create the UrlMap.",
          flatPath = "projects/{project}/global/urlMaps/{urlMap}/validate",
          httpMethod = "POST",
          id = "compute.urlMaps.validate",
          parameterOrder = {
            "project",
            "urlMap",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            urlMap = {
              description = "Name of the UrlMap resource to be validated as.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/global/urlMaps/{urlMap}/validate",
          request = {
            ["$ref"] = "UrlMapsValidateRequest",
          },
          response = {
            ["$ref"] = "UrlMapsValidateResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    vpnGateways = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of VPN gateways.",
          flatPath = "projects/{project}/aggregated/vpnGateways",
          httpMethod = "GET",
          id = "compute.vpnGateways.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/vpnGateways",
          response = {
            ["$ref"] = "VpnGatewayAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified VPN gateway.",
          flatPath = "projects/{project}/regions/{region}/vpnGateways/{vpnGateway}",
          httpMethod = "DELETE",
          id = "compute.vpnGateways.delete",
          parameterOrder = {
            "project",
            "region",
            "vpnGateway",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            vpnGateway = {
              description = "Name of the VPN gateway to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnGateways/{vpnGateway}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified VPN gateway. Gets a list of available VPN gateways by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/vpnGateways/{vpnGateway}",
          httpMethod = "GET",
          id = "compute.vpnGateways.get",
          parameterOrder = {
            "project",
            "region",
            "vpnGateway",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            vpnGateway = {
              description = "Name of the VPN gateway to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnGateways/{vpnGateway}",
          response = {
            ["$ref"] = "VpnGateway",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        getStatus = {
          description = "Returns the status for the specified VPN gateway.",
          flatPath = "projects/{project}/regions/{region}/vpnGateways/{vpnGateway}/getStatus",
          httpMethod = "GET",
          id = "compute.vpnGateways.getStatus",
          parameterOrder = {
            "project",
            "region",
            "vpnGateway",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            vpnGateway = {
              description = "Name of the VPN gateway to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnGateways/{vpnGateway}/getStatus",
          response = {
            ["$ref"] = "VpnGatewaysGetStatusResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a VPN gateway in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/vpnGateways",
          httpMethod = "POST",
          id = "compute.vpnGateways.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnGateways",
          request = {
            ["$ref"] = "VpnGateway",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of VPN gateways available to the specified project and region.",
          flatPath = "projects/{project}/regions/{region}/vpnGateways",
          httpMethod = "GET",
          id = "compute.vpnGateways.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/vpnGateways",
          response = {
            ["$ref"] = "VpnGatewayList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setLabels = {
          description = "Sets the labels on a VpnGateway. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/regions/{region}/vpnGateways/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.vpnGateways.setLabels",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnGateways/{resource}/setLabels",
          request = {
            ["$ref"] = "RegionSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        testIamPermissions = {
          description = "Returns permissions that a caller has on the specified resource.",
          flatPath = "projects/{project}/regions/{region}/vpnGateways/{resource}/testIamPermissions",
          httpMethod = "POST",
          id = "compute.vpnGateways.testIamPermissions",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnGateways/{resource}/testIamPermissions",
          request = {
            ["$ref"] = "TestPermissionsRequest",
          },
          response = {
            ["$ref"] = "TestPermissionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    vpnTunnels = {
      methods = {
        aggregatedList = {
          description = "Retrieves an aggregated list of VPN tunnels.",
          flatPath = "projects/{project}/aggregated/vpnTunnels",
          httpMethod = "GET",
          id = "compute.vpnTunnels.aggregatedList",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            includeAllScopes = {
              description = "Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.",
              location = "query",
              type = "boolean",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/aggregated/vpnTunnels",
          response = {
            ["$ref"] = "VpnTunnelAggregatedList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        delete = {
          description = "Deletes the specified VpnTunnel resource.",
          flatPath = "projects/{project}/regions/{region}/vpnTunnels/{vpnTunnel}",
          httpMethod = "DELETE",
          id = "compute.vpnTunnels.delete",
          parameterOrder = {
            "project",
            "region",
            "vpnTunnel",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            vpnTunnel = {
              description = "Name of the VpnTunnel resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnTunnels/{vpnTunnel}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Returns the specified VpnTunnel resource. Gets a list of available VPN tunnels by making a list() request.",
          flatPath = "projects/{project}/regions/{region}/vpnTunnels/{vpnTunnel}",
          httpMethod = "GET",
          id = "compute.vpnTunnels.get",
          parameterOrder = {
            "project",
            "region",
            "vpnTunnel",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            vpnTunnel = {
              description = "Name of the VpnTunnel resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnTunnels/{vpnTunnel}",
          response = {
            ["$ref"] = "VpnTunnel",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        insert = {
          description = "Creates a VpnTunnel resource in the specified project and region using the data included in the request.",
          flatPath = "projects/{project}/regions/{region}/vpnTunnels",
          httpMethod = "POST",
          id = "compute.vpnTunnels.insert",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnTunnels",
          request = {
            ["$ref"] = "VpnTunnel",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        list = {
          description = "Retrieves a list of VpnTunnel resources contained in the specified project and region.",
          flatPath = "projects/{project}/regions/{region}/vpnTunnels",
          httpMethod = "GET",
          id = "compute.vpnTunnels.list",
          parameterOrder = {
            "project",
            "region",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "Name of the region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/regions/{region}/vpnTunnels",
          response = {
            ["$ref"] = "VpnTunnelList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        setLabels = {
          description = "Sets the labels on a VpnTunnel. To learn more about labels, read the Labeling Resources documentation.",
          flatPath = "projects/{project}/regions/{region}/vpnTunnels/{resource}/setLabels",
          httpMethod = "POST",
          id = "compute.vpnTunnels.setLabels",
          parameterOrder = {
            "project",
            "region",
            "resource",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            region = {
              description = "The region for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
            requestId = {
              description = "An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).",
              location = "query",
              type = "string",
            },
            resource = {
              description = "Name or id of the resource for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/regions/{region}/vpnTunnels/{resource}/setLabels",
          request = {
            ["$ref"] = "RegionSetLabelsRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
      },
    },
    zoneOperations = {
      methods = {
        delete = {
          description = "Deletes the specified zone-specific Operations resource.",
          flatPath = "projects/{project}/zones/{zone}/operations/{operation}",
          httpMethod = "DELETE",
          id = "compute.zoneOperations.delete",
          parameterOrder = {
            "project",
            "zone",
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to delete.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/operations/{operation}",
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
          },
        },
        get = {
          description = "Retrieves the specified zone-specific Operations resource.",
          flatPath = "projects/{project}/zones/{zone}/operations/{operation}",
          httpMethod = "GET",
          id = "compute.zoneOperations.get",
          parameterOrder = {
            "project",
            "zone",
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/operations/{operation}",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves a list of Operation resources contained within the specified zone.",
          flatPath = "projects/{project}/zones/{zone}/operations",
          httpMethod = "GET",
          id = "compute.zoneOperations.list",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
            zone = {
              description = "Name of the zone for request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/operations",
          response = {
            ["$ref"] = "OperationList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        wait = {
          description = "Waits for the specified Operation resource to return as `DONE` or for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method waits for no more than the 2 minutes and then returns the current state of the operation, which might be `DONE` or still in progress. This method is called on a best-effort basis. Specifically: - In uncommon cases, when the server is overloaded, the request might return before the default deadline is reached, or might return after zero seconds. - If the default deadline is reached, there is no guarantee that the operation is actually done when the method returns. Be prepared to retry if the operation is not `DONE`. ",
          flatPath = "projects/{project}/zones/{zone}/operations/{operation}/wait",
          httpMethod = "POST",
          id = "compute.zoneOperations.wait",
          parameterOrder = {
            "project",
            "zone",
            "operation",
          },
          parameters = {
            operation = {
              description = "Name of the Operations resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone for this request.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}/operations/{operation}/wait",
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
    zones = {
      methods = {
        get = {
          description = "Returns the specified Zone resource. Gets a list of available zones by making a list() request.",
          flatPath = "projects/{project}/zones/{zone}",
          httpMethod = "GET",
          id = "compute.zones.get",
          parameterOrder = {
            "project",
            "zone",
          },
          parameters = {
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            zone = {
              description = "Name of the zone resource to return.",
              location = "path",
              pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?|[1-9][0-9]{0,19}",
              required = true,
              type = "string",
            },
          },
          path = "projects/{project}/zones/{zone}",
          response = {
            ["$ref"] = "Zone",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
        list = {
          description = "Retrieves the list of Zone resources available to the specified project.",
          flatPath = "projects/{project}/zones",
          httpMethod = "GET",
          id = "compute.zones.list",
          parameterOrder = {
            "project",
          },
          parameters = {
            filter = {
              description = "A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:` operator can be used with string fields to match substrings. For non-string fields it is equivalent to the `=` operator. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = \"Intel Skylake\") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = \"Intel Skylake\") OR (cpuPlatform = \"Intel Broadwell\") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq \"double quoted literal\"` `(fieldname1 eq literal) (fieldname2 ne \"literal\")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name \"instance\", you would use `name ne .*instance`.",
              location = "query",
              type = "string",
            },
            maxResults = {
              default = "500",
              description = "The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)",
              format = "uint32",
              location = "query",
              minimum = "0",
              type = "integer",
            },
            orderBy = {
              description = "Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy=\"creationTimestamp desc\"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.",
              location = "query",
              type = "string",
            },
            pageToken = {
              description = "Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.",
              location = "query",
              type = "string",
            },
            project = {
              description = "Project ID for this request.",
              location = "path",
              pattern = "(?:(?:[-a-z0-9]{1,63}\\.)*(?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?):)?(?:[0-9]{1,19}|(?:[a-z0-9](?:[-a-z0-9]{0,61}[a-z0-9])?))",
              required = true,
              type = "string",
            },
            returnPartialSuccess = {
              description = "Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.",
              location = "query",
              type = "boolean",
            },
          },
          path = "projects/{project}/zones",
          response = {
            ["$ref"] = "ZoneList",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/compute",
            "https://www.googleapis.com/auth/compute.readonly",
          },
        },
      },
    },
  },
  revision = "20221224",
  rootUrl = "https://compute.googleapis.com/",
  schemas = {
    AcceleratorConfig = {
      description = "A specification of the type and number of accelerator cards attached to the instance.",
      id = "AcceleratorConfig",
      properties = {
        acceleratorCount = {
          description = "The number of the guest accelerator cards exposed to this instance.",
          format = "int32",
          type = "integer",
        },
        acceleratorType = {
          description = "Full or partial URL of the accelerator type resource to attach to this instance. For example: projects/my-project/zones/us-central1-c/acceleratorTypes/nvidia-tesla-p100 If you are creating an instance template, specify only the accelerator name. See GPUs on Compute Engine for a full list of accelerator types.",
          type = "string",
        },
      },
      type = "object",
    },
    AcceleratorType = {
      description = "Represents an Accelerator Type resource. Google Cloud Platform provides graphics processing units (accelerators) that you can add to VM instances to improve or accelerate performance when working with intensive workloads. For more information, read GPUs on Compute Engine.",
      id = "AcceleratorType",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        deprecated = {
          ["$ref"] = "DeprecationStatus",
          description = "[Output Only] The deprecation status associated with this accelerator type.",
        },
        description = {
          description = "[Output Only] An optional textual description of the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#acceleratorType",
          description = "[Output Only] The type of the resource. Always compute#acceleratorType for accelerator types.",
          type = "string",
        },
        maximumCardsPerInstance = {
          description = "[Output Only] Maximum number of accelerator cards allowed per instance.",
          format = "int32",
          type = "integer",
        },
        name = {
          description = "[Output Only] Name of the resource.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined, fully qualified URL for this resource.",
          type = "string",
        },
        zone = {
          description = "[Output Only] The name of the zone where the accelerator type resides, such as us-central1-a. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
      },
      type = "object",
    },
    AcceleratorTypeAggregatedList = {
      id = "AcceleratorTypeAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "AcceleratorTypesScopedList",
            description = "[Output Only] Name of the scope containing this set of accelerator types.",
          },
          description = "A list of AcceleratorTypesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#acceleratorTypeAggregatedList",
          description = "[Output Only] Type of resource. Always compute#acceleratorTypeAggregatedList for aggregated lists of accelerator types.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    AcceleratorTypeList = {
      description = "Contains a list of accelerator types.",
      id = "AcceleratorTypeList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of AcceleratorType resources.",
          items = {
            ["$ref"] = "AcceleratorType",
          },
          type = "array",
        },
        kind = {
          default = "compute#acceleratorTypeList",
          description = "[Output Only] Type of resource. Always compute#acceleratorTypeList for lists of accelerator types.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    AcceleratorTypesScopedList = {
      id = "AcceleratorTypesScopedList",
      properties = {
        acceleratorTypes = {
          description = "[Output Only] A list of accelerator types contained in this scope.",
          items = {
            ["$ref"] = "AcceleratorType",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] An informational warning that appears when the accelerator types list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    AccessConfig = {
      description = "An access configuration attached to an instance's network interface. Only one access config per instance is supported.",
      id = "AccessConfig",
      properties = {
        externalIpv6 = {
          description = "The first IPv6 address of the external IPv6 range associated with this instance, prefix length is stored in externalIpv6PrefixLength in ipv6AccessConfig. The field is output only, an IPv6 address from a subnetwork associated with the instance will be allocated dynamically.",
          type = "string",
        },
        externalIpv6PrefixLength = {
          description = "The prefix length of the external IPv6 range.",
          format = "int32",
          type = "integer",
        },
        kind = {
          default = "compute#accessConfig",
          description = "[Output Only] Type of the resource. Always compute#accessConfig for access configs.",
          type = "string",
        },
        name = {
          description = "The name of this access configuration. The default and recommended name is External NAT, but you can use any arbitrary string, such as My external IP or Network Access.",
          type = "string",
        },
        natIP = {
          description = "An external IP address associated with this instance. Specify an unused static external IP address available to the project or leave this field undefined to use an IP from a shared ephemeral IP address pool. If you specify a static external IP address, it must live in the same region as the zone of the instance.",
          type = "string",
        },
        networkTier = {
          description = "This signifies the networking tier used for configuring this access configuration and can only take the following values: PREMIUM, STANDARD. If an AccessConfig is specified without a valid external IP address, an ephemeral IP will be created with this networkTier. If an AccessConfig with a valid external IP address is specified, it must match that of the networkTier associated with the Address resource owning that IP.",
          enum = {
            "FIXED_STANDARD",
            "PREMIUM",
            "STANDARD",
            "STANDARD_OVERRIDES_FIXED_STANDARD",
          },
          enumDescriptions = {
            "Public internet quality with fixed bandwidth.",
            "High quality, Google-grade network tier, support for all networking products.",
            "Public internet quality, only limited support for other networking products.",
            "(Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.",
          },
          type = "string",
        },
        publicPtrDomainName = {
          description = "The DNS domain name for the public PTR record. You can set this field only if the `setPublicPtr` field is enabled in accessConfig. If this field is unspecified in ipv6AccessConfig, a default PTR record will be createc for first IP in associated external IPv6 range.",
          type = "string",
        },
        setPublicPtr = {
          description = "Specifies whether a public DNS 'PTR' record should be created to map the external IP address of the instance to a DNS domain name. This field is not used in ipv6AccessConfig. A default PTR record will be created if the VM has external IPv6 range associated.",
          type = "boolean",
        },
        type = {
          default = "ONE_TO_ONE_NAT",
          description = "The type of configuration. The default and only option is ONE_TO_ONE_NAT.",
          enum = {
            "DIRECT_IPV6",
            "ONE_TO_ONE_NAT",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Address = {
      description = "Represents an IP Address resource. Google Compute Engine has two IP Address resources: * [Global (external and internal)](https://cloud.google.com/compute/docs/reference/rest/v1/globalAddresses) * [Regional (external and internal)](https://cloud.google.com/compute/docs/reference/rest/v1/addresses) For more information, see Reserving a static external IP address.",
      id = "Address",
      properties = {
        address = {
          description = "The static IP address represented by this resource.",
          type = "string",
        },
        addressType = {
          description = "The type of address to reserve, either INTERNAL or EXTERNAL. If unspecified, defaults to EXTERNAL.",
          enum = {
            "EXTERNAL",
            "INTERNAL",
            "UNSPECIFIED_TYPE",
          },
          enumDescriptions = {
            "A publicly visible external IP address.",
            "A private network IP address, for use with an Instance or Internal Load Balancer forwarding rule.",
            "",
          },
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this field when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        ipVersion = {
          description = "The IP version that will be used by this address. Valid options are IPV4 or IPV6. This can only be specified for a global address.",
          enum = {
            "IPV4",
            "IPV6",
            "UNSPECIFIED_VERSION",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        ipv6EndpointType = {
          description = "The endpoint type of this address, which should be VM or NETLB. This is used for deciding which type of endpoint this address can be used after the external IPv6 address reservation.",
          enum = {
            "NETLB",
            "VM",
          },
          enumDescriptions = {
            "Reserved IPv6 address can be used on network load balancer.",
            "Reserved IPv6 address can be used on VM.",
          },
          type = "string",
        },
        kind = {
          default = "compute#address",
          description = "[Output Only] Type of the resource. Always compute#address for addresses.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.addresses.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          description = "The URL of the network in which to reserve the address. This field can only be used with INTERNAL type with the VPC_PEERING purpose.",
          type = "string",
        },
        networkTier = {
          description = "This signifies the networking tier used for configuring this address and can only take the following values: PREMIUM or STANDARD. Internal IP addresses are always Premium Tier; global external IP addresses are always Premium Tier; regional external IP addresses can be either Standard or Premium Tier. If this field is not specified, it is assumed to be PREMIUM.",
          enum = {
            "FIXED_STANDARD",
            "PREMIUM",
            "STANDARD",
            "STANDARD_OVERRIDES_FIXED_STANDARD",
          },
          enumDescriptions = {
            "Public internet quality with fixed bandwidth.",
            "High quality, Google-grade network tier, support for all networking products.",
            "Public internet quality, only limited support for other networking products.",
            "(Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.",
          },
          type = "string",
        },
        prefixLength = {
          description = "The prefix length if the resource represents an IP range.",
          format = "int32",
          type = "integer",
        },
        purpose = {
          description = "The purpose of this resource, which can be one of the following values: - GCE_ENDPOINT for addresses that are used by VM instances, alias IP ranges, load balancers, and similar resources. - DNS_RESOLVER for a DNS resolver address in a subnetwork for a Cloud DNS inbound forwarder IP addresses (regional internal IP address in a subnet of a VPC network) - VPC_PEERING for global internal IP addresses used for private services access allocated ranges. - NAT_AUTO for the regional external IP addresses used by Cloud NAT when allocating addresses using automatic NAT IP address allocation. - IPSEC_INTERCONNECT for addresses created from a private IP range that are reserved for a VLAN attachment in an *HA VPN over Cloud Interconnect* configuration. These addresses are regional resources. - `SHARED_LOADBALANCER_VIP` for an internal IP address that is assigned to multiple internal forwarding rules. - `PRIVATE_SERVICE_CONNECT` for a private network address that is used to configure Private Service Connect. Only global internal addresses can use this purpose. ",
          enum = {
            "DNS_RESOLVER",
            "GCE_ENDPOINT",
            "IPSEC_INTERCONNECT",
            "NAT_AUTO",
            "PRIVATE_SERVICE_CONNECT",
            "SERVERLESS",
            "SHARED_LOADBALANCER_VIP",
            "VPC_PEERING",
          },
          enumDescriptions = {
            "DNS resolver address in the subnetwork.",
            "VM internal/alias IP, Internal LB service IP, etc.",
            "A regional internal IP address range reserved for the VLAN attachment that is used in HA VPN over Cloud Interconnect. This regional internal IP address range must not overlap with any IP address range of subnet/route in the VPC network and its peering networks. After the VLAN attachment is created with the reserved IP address range, when creating a new VPN gateway, its interface IP address is allocated from the associated VLAN attachment’s IP address range.",
            "External IP automatically reserved for Cloud NAT.",
            "A private network IP address that can be used to configure Private Service Connect. This purpose can be specified only for GLOBAL addresses of Type INTERNAL",
            "A regional internal IP address range reserved for Serverless.",
            "A private network IP address that can be shared by multiple Internal Load Balancer forwarding rules.",
            "IP range for peer networks.",
          },
          type = "string",
        },
        region = {
          description = "[Output Only] The URL of the region where a regional address resides. For regional addresses, you must specify the region as a path parameter in the HTTP request URL. *This field is not applicable to global addresses.*",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of the address, which can be one of RESERVING, RESERVED, or IN_USE. An address that is RESERVING is currently in the process of being reserved. A RESERVED address is currently reserved and available to use. An IN_USE address is currently being used by another resource and is not available.",
          enum = {
            "IN_USE",
            "RESERVED",
            "RESERVING",
          },
          enumDescriptions = {
            "Address is being used by another resource and is not available.",
            "Address is reserved and available to use.",
            "Address is being reserved.",
          },
          type = "string",
        },
        subnetwork = {
          description = "The URL of the subnetwork in which to reserve the address. If an IP address is specified, it must be within the subnetwork's IP range. This field can only be used with INTERNAL type with a GCE_ENDPOINT or DNS_RESOLVER purpose.",
          type = "string",
        },
        users = {
          description = "[Output Only] The URLs of the resources that are using this address.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    AddressAggregatedList = {
      id = "AddressAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "AddressesScopedList",
            description = "[Output Only] Name of the scope containing this set of addresses.",
          },
          description = "A list of AddressesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#addressAggregatedList",
          description = "[Output Only] Type of resource. Always compute#addressAggregatedList for aggregated lists of addresses.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    AddressList = {
      description = "Contains a list of addresses.",
      id = "AddressList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Address resources.",
          items = {
            ["$ref"] = "Address",
          },
          type = "array",
        },
        kind = {
          default = "compute#addressList",
          description = "[Output Only] Type of resource. Always compute#addressList for lists of addresses.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    AddressesScopedList = {
      id = "AddressesScopedList",
      properties = {
        addresses = {
          description = "[Output Only] A list of addresses contained in this scope.",
          items = {
            ["$ref"] = "Address",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of addresses when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    AdvancedMachineFeatures = {
      description = "Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of an Image (e.g., whether or not the OS in the Image supports nested virtualization being enabled or disabled).",
      id = "AdvancedMachineFeatures",
      properties = {
        enableNestedVirtualization = {
          description = "Whether to enable nested virtualization or not (default is false).",
          type = "boolean",
        },
        enableUefiNetworking = {
          description = "Whether to enable UEFI networking for instance creation.",
          type = "boolean",
        },
        threadsPerCore = {
          description = "The number of threads per physical core. To disable simultaneous multithreading (SMT) set this to 1. If unset, the maximum number of threads supported per core by the underlying processor is assumed.",
          format = "int32",
          type = "integer",
        },
        visibleCoreCount = {
          description = "The number of physical cores to expose to an instance. Multiply by the number of threads per core to compute the total number of virtual CPUs to expose to the instance. If unset, the number of cores is inferred from the instance's nominal CPU count and the underlying platform's SMT width.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    AliasIpRange = {
      description = "An alias IP range attached to an instance's network interface.",
      id = "AliasIpRange",
      properties = {
        ipCidrRange = {
          description = "The IP alias ranges to allocate for this interface. This IP CIDR range must belong to the specified subnetwork and cannot contain IP addresses reserved by system or used by other network interfaces. This range may be a single IP address (such as 10.2.3.4), a netmask (such as /24) or a CIDR-formatted string (such as 10.1.2.0/24).",
          type = "string",
        },
        subnetworkRangeName = {
          description = "The name of a subnetwork secondary IP range from which to allocate an IP alias range. If not specified, the primary range of the subnetwork is used.",
          type = "string",
        },
      },
      type = "object",
    },
    AllocationResourceStatus = {
      id = "AllocationResourceStatus",
      properties = {
        specificSkuAllocation = {
          ["$ref"] = "AllocationResourceStatusSpecificSKUAllocation",
        },
      },
      type = "object",
    },
    AllocationResourceStatusSpecificSKUAllocation = {
      id = "AllocationResourceStatusSpecificSKUAllocation",
      properties = {
        sourceInstanceTemplateId = {
          type = "string",
        },
      },
      type = "object",
    },
    AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk = {
      id = "AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk",
      properties = {
        diskSizeGb = {
          description = "Specifies the size of the disk in base-2 GB.",
          format = "int64",
          type = "string",
        },
        interface = {
          description = "Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default is SCSI. For performance characteristics of SCSI over NVMe, see Local SSD performance.",
          enum = {
            "NVME",
            "SCSI",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    AllocationSpecificSKUAllocationReservedInstanceProperties = {
      description = "Properties of the SKU instances being reserved. Next ID: 9",
      id = "AllocationSpecificSKUAllocationReservedInstanceProperties",
      properties = {
        guestAccelerators = {
          description = "Specifies accelerator type and count.",
          items = {
            ["$ref"] = "AcceleratorConfig",
          },
          type = "array",
        },
        localSsds = {
          description = "Specifies amount of local ssd to reserve with each instance. The type of disk is local-ssd.",
          items = {
            ["$ref"] = "AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk",
          },
          type = "array",
        },
        locationHint = {
          description = "An opaque location hint used to place the allocation close to other resources. This field is for use by internal tools that use the public API.",
          type = "string",
        },
        machineType = {
          description = "Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory. This also includes specifying custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern.",
          type = "string",
        },
        minCpuPlatform = {
          description = "Minimum cpu platform the reservation.",
          type = "string",
        },
      },
      type = "object",
    },
    AllocationSpecificSKUReservation = {
      description = "This reservation type allows to pre allocate specific instance configuration. Next ID: 6",
      id = "AllocationSpecificSKUReservation",
      properties = {
        assuredCount = {
          description = "[Output Only] Indicates how many instances are actually usable currently.",
          format = "int64",
          type = "string",
        },
        count = {
          description = "Specifies the number of resources that are allocated.",
          format = "int64",
          type = "string",
        },
        inUseCount = {
          description = "[Output Only] Indicates how many instances are in use.",
          format = "int64",
          type = "string",
        },
        instanceProperties = {
          ["$ref"] = "AllocationSpecificSKUAllocationReservedInstanceProperties",
          description = "The instance properties for the reservation.",
        },
        sourceInstanceTemplate = {
          description = "Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field. This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template: - https://www.googleapis.com/compute/v1/projects/project /global/instanceTemplates/instanceTemplate - projects/project/global/instanceTemplates/instanceTemplate - global/instanceTemplates/instanceTemplate ",
          type = "string",
        },
      },
      type = "object",
    },
    AttachedDisk = {
      description = "An instance-attached disk resource.",
      id = "AttachedDisk",
      properties = {
        architecture = {
          description = "[Output Only] The architecture of the attached disk. Valid values are ARM64 or X86_64.",
          enum = {
            "ARCHITECTURE_UNSPECIFIED",
            "ARM64",
            "X86_64",
          },
          enumDescriptions = {
            "Default value indicating Architecture is not set.",
            "Machines with architecture ARM64",
            "Machines with architecture X86_64",
          },
          type = "string",
        },
        autoDelete = {
          description = "Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).",
          type = "boolean",
        },
        boot = {
          description = "Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.",
          type = "boolean",
        },
        deviceName = {
          description = "Specifies a unique device name of your choice that is reflected into the /dev/disk/by-id/google-* tree of a Linux operating system running within the instance. This name can be used to reference the device for mounting, resizing, and so on, from within the instance. If not specified, the server chooses a default device name to apply to this disk, in the form persistent-disk-x, where x is a number assigned by Google Compute Engine. This field is only applicable for persistent disks.",
          type = "string",
        },
        diskEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "Encrypts or decrypts a disk using a customer-supplied encryption key. If you are creating a new disk, this field encrypts the new disk using an encryption key that you provide. If you are attaching an existing disk that is already encrypted, this field decrypts the disk using the customer-supplied encryption key. If you encrypt a disk using a customer-supplied key, you must provide the same key again when you attempt to use this resource at a later time. For example, you must provide the key when you create a snapshot or an image from the disk or when you attach the disk to a virtual machine instance. If you do not provide an encryption key, then the disk will be encrypted using an automatically generated key and you do not need to provide a key to use the disk later. Instance templates do not store customer-supplied encryption keys, so you cannot use your own keys to encrypt disks in a managed instance group.",
        },
        diskSizeGb = {
          description = "The size of the disk in GB.",
          format = "int64",
          type = "string",
        },
        forceAttach = {
          description = "[Input Only] Whether to force attach the regional disk even if it's currently attached to another instance. If you try to force attach a zonal disk to an instance, you will receive an error.",
          type = "boolean",
        },
        guestOsFeatures = {
          description = "A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.",
          items = {
            ["$ref"] = "GuestOsFeature",
          },
          type = "array",
        },
        index = {
          description = "[Output Only] A zero-based index to this disk, where 0 is reserved for the boot disk. If you have many disks attached to an instance, each disk would have a unique index number.",
          format = "int32",
          type = "integer",
        },
        initializeParams = {
          ["$ref"] = "AttachedDiskInitializeParams",
          description = "[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.",
        },
        interface = {
          description = "Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. For most machine types, the default is SCSI. Local SSDs can use either NVME or SCSI. In certain configurations, persistent disks can use NVMe. For more information, see About persistent disks.",
          enum = {
            "NVME",
            "SCSI",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        kind = {
          default = "compute#attachedDisk",
          description = "[Output Only] Type of the resource. Always compute#attachedDisk for attached disks.",
          type = "string",
        },
        licenses = {
          description = "[Output Only] Any valid publicly visible licenses.",
          items = {
            type = "string",
          },
          type = "array",
        },
        mode = {
          description = "The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode.",
          enum = {
            "READ_ONLY",
            "READ_WRITE",
          },
          enumDescriptions = {
            "Attaches this disk in read-only mode. Multiple virtual machines can use a disk in read-only mode at a time.",
            "*[Default]* Attaches this disk in read-write mode. Only one virtual machine at a time can be attached to a disk in read-write mode.",
          },
          type = "string",
        },
        shieldedInstanceInitialState = {
          ["$ref"] = "InitialStateConfig",
          description = "[Output Only] shielded vm initial state stored on disk",
        },
        source = {
          description = "Specifies a valid partial or full URL to an existing Persistent Disk resource. When creating a new instance, one of initializeParams.sourceImage or initializeParams.sourceSnapshot or disks.source is required except for local SSD. If desired, you can also attach existing non-root persistent disks using this property. This field is only applicable for persistent disks. Note that for InstanceTemplate, specify the disk name for zonal disk, and the URL for regional disk.",
          type = "string",
        },
        type = {
          description = "Specifies the type of the disk, either SCRATCH or PERSISTENT. If not specified, the default is PERSISTENT.",
          enum = {
            "PERSISTENT",
            "SCRATCH",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    AttachedDiskInitializeParams = {
      description = "[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This field is persisted and returned for instanceTemplate and not returned in the context of instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.",
      id = "AttachedDiskInitializeParams",
      properties = {
        architecture = {
          description = "The architecture of the attached disk. Valid values are arm64 or x86_64.",
          enum = {
            "ARCHITECTURE_UNSPECIFIED",
            "ARM64",
            "X86_64",
          },
          enumDescriptions = {
            "Default value indicating Architecture is not set.",
            "Machines with architecture ARM64",
            "Machines with architecture X86_64",
          },
          type = "string",
        },
        description = {
          description = "An optional description. Provide this property when creating the disk.",
          type = "string",
        },
        diskName = {
          description = "Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created.",
          type = "string",
        },
        diskSizeGb = {
          description = "Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB.",
          format = "int64",
          type = "string",
        },
        diskType = {
          description = "Specifies the disk type to use to create the instance. If not specified, the default is pd-standard, specified using the full URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone /diskTypes/pd-standard For a full list of acceptable values, see Persistent disk types. If you specify this field when creating a VM, you can provide either the full or partial URL. For example, the following values are valid: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /diskTypes/diskType - projects/project/zones/zone/diskTypes/diskType - zones/zone/diskTypes/diskType If you specify this field when creating or updating an instance template or all-instances configuration, specify the type of the disk, not the URL. For example: pd-standard.",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels to apply to this disk. These can be later modified by the disks.setLabels method. This field is only applicable for persistent disks.",
          type = "object",
        },
        licenses = {
          description = "A list of publicly visible licenses. Reserved for Google's use.",
          items = {
            type = "string",
          },
          type = "array",
        },
        onUpdateAction = {
          description = "Specifies which action to take on instance update with this disk. Default is to use the existing disk.",
          enum = {
            "RECREATE_DISK",
            "RECREATE_DISK_IF_SOURCE_CHANGED",
            "USE_EXISTING_DISK",
          },
          enumDescriptions = {
            "Always recreate the disk.",
            "Recreate the disk if source (image, snapshot) of this disk is different from source of existing disk.",
            "Use the existing disk, this is the default behaviour.",
          },
          type = "string",
        },
        provisionedIops = {
          description = "Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see the Extreme persistent disk documentation.",
          format = "int64",
          type = "string",
        },
        resourceManagerTags = {
          additionalProperties = {
            type = "string",
          },
          description = "Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys must be in the format `tagKeys/{tag_key_id}`, and values are in the format `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.",
          type = "object",
        },
        resourcePolicies = {
          description = "Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sourceImage = {
          description = "The source image to create this disk. When creating a new instance, one of initializeParams.sourceImage or initializeParams.sourceSnapshot or disks.source is required except for local SSD. To create a disk with one of the public operating system images, specify the image by its family name. For example, specify family/debian-9 to use the latest Debian 9 image: projects/debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my-custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family If the source image is deleted later, this field will not be set.",
          type = "string",
        },
        sourceImageEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. InstanceTemplate and InstancePropertiesPatch do not store customer-supplied encryption keys, so you cannot create disks for instances in a managed instance group if the source images are encrypted with your own keys.",
        },
        sourceSnapshot = {
          description = "The source snapshot to create this disk. When creating a new instance, one of initializeParams.sourceSnapshot or initializeParams.sourceImage or disks.source is required except for local SSD. To create a disk with a snapshot that you created, specify the snapshot name in the following format: global/snapshots/my-backup If the source snapshot is deleted later, this field will not be set.",
          type = "string",
        },
        sourceSnapshotEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The customer-supplied encryption key of the source snapshot.",
        },
      },
      type = "object",
    },
    AuditConfig = {
      description = "Specifies the audit configuration for a service. The configuration determines which permission types are logged, and what identities, if any, are exempted from logging. An AuditConfig must have one or more AuditLogConfigs. If there are AuditConfigs for both `allServices` and a specific service, the union of the two AuditConfigs is used for that service: the log_types specified in each AuditConfig are enabled, and the exempted_members in each AuditLogConfig are exempted. Example Policy with multiple AuditConfigs: { \"audit_configs\": [ { \"service\": \"allServices\", \"audit_log_configs\": [ { \"log_type\": \"DATA_READ\", \"exempted_members\": [ \"user:jose@example.com\" ] }, { \"log_type\": \"DATA_WRITE\" }, { \"log_type\": \"ADMIN_READ\" } ] }, { \"service\": \"sampleservice.googleapis.com\", \"audit_log_configs\": [ { \"log_type\": \"DATA_READ\" }, { \"log_type\": \"DATA_WRITE\", \"exempted_members\": [ \"user:aliya@example.com\" ] } ] } ] } For sampleservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ logging. It also exempts jose@example.com from DATA_READ logging, and aliya@example.com from DATA_WRITE logging.",
      id = "AuditConfig",
      properties = {
        auditLogConfigs = {
          description = "The configuration for logging of each type of permission.",
          items = {
            ["$ref"] = "AuditLogConfig",
          },
          type = "array",
        },
        exemptedMembers = {
          description = "This is deprecated and has no effect. Do not use.",
          items = {
            type = "string",
          },
          type = "array",
        },
        service = {
          description = "Specifies a service that will be enabled for audit logging. For example, `storage.googleapis.com`, `cloudsql.googleapis.com`. `allServices` is a special value that covers all services.",
          type = "string",
        },
      },
      type = "object",
    },
    AuditLogConfig = {
      description = "Provides the configuration for logging a type of permissions. Example: { \"audit_log_configs\": [ { \"log_type\": \"DATA_READ\", \"exempted_members\": [ \"user:jose@example.com\" ] }, { \"log_type\": \"DATA_WRITE\" } ] } This enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting jose@example.com from DATA_READ logging.",
      id = "AuditLogConfig",
      properties = {
        exemptedMembers = {
          description = "Specifies the identities that do not cause logging for this type of permission. Follows the same format of Binding.members.",
          items = {
            type = "string",
          },
          type = "array",
        },
        ignoreChildExemptions = {
          description = "This is deprecated and has no effect. Do not use.",
          type = "boolean",
        },
        logType = {
          description = "The log type that this config enables.",
          enum = {
            "ADMIN_READ",
            "DATA_READ",
            "DATA_WRITE",
            "LOG_TYPE_UNSPECIFIED",
          },
          enumDescriptions = {
            "Admin reads. Example: CloudIAM getIamPolicy",
            "Data reads. Example: CloudSQL Users list",
            "Data writes. Example: CloudSQL Users create",
            "Default case. Should never be this.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    AuthorizationLoggingOptions = {
      description = "This is deprecated and has no effect. Do not use.",
      id = "AuthorizationLoggingOptions",
      properties = {
        permissionType = {
          description = "This is deprecated and has no effect. Do not use.",
          enum = {
            "ADMIN_READ",
            "ADMIN_WRITE",
            "DATA_READ",
            "DATA_WRITE",
            "PERMISSION_TYPE_UNSPECIFIED",
          },
          enumDescriptions = {
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Autoscaler = {
      description = "Represents an Autoscaler resource. Google Compute Engine has two Autoscaler resources: * [Zonal](/compute/docs/reference/rest/v1/autoscalers) * [Regional](/compute/docs/reference/rest/v1/regionAutoscalers) Use autoscalers to automatically add or delete instances from a managed instance group according to your defined autoscaling policy. For more information, read Autoscaling Groups of Instances. For zonal managed instance groups resource, use the autoscaler resource. For regional managed instance groups, use the regionAutoscalers resource.",
      id = "Autoscaler",
      properties = {
        autoscalingPolicy = {
          ["$ref"] = "AutoscalingPolicy",
          description = "The configuration parameters for the autoscaling algorithm. You can define one or more signals for an autoscaler: cpuUtilization, customMetricUtilizations, and loadBalancingUtilization. If none of these are specified, the default will be to autoscale based on cpuUtilization to 0.6 or 60%.",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#autoscaler",
          description = "[Output Only] Type of the resource. Always compute#autoscaler for autoscalers.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.autoscalers.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        recommendedSize = {
          description = "[Output Only] Target recommended MIG size (number of instances) computed by autoscaler. Autoscaler calculates the recommended MIG size even when the autoscaling policy mode is different from ON. This field is empty when autoscaler is not connected to an existing managed instance group or autoscaler did not generate its prediction.",
          format = "int32",
          type = "integer",
        },
        region = {
          description = "[Output Only] URL of the region where the instance group resides (for autoscalers living in regional scope).",
          type = "string",
        },
        scalingScheduleStatus = {
          additionalProperties = {
            ["$ref"] = "ScalingScheduleStatus",
          },
          description = "[Output Only] Status information of existing scaling schedules.",
          type = "object",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of the autoscaler configuration. Current set of possible values: - PENDING: Autoscaler backend hasn't read new/updated configuration. - DELETING: Configuration is being deleted. - ACTIVE: Configuration is acknowledged to be effective. Some warnings might be present in the statusDetails field. - ERROR: Configuration has errors. Actionable for users. Details are present in the statusDetails field. New values might be added in the future.",
          enum = {
            "ACTIVE",
            "DELETING",
            "ERROR",
            "PENDING",
          },
          enumDescriptions = {
            "Configuration is acknowledged to be effective",
            "Configuration is being deleted",
            "Configuration has errors. Actionable for users.",
            "Autoscaler backend hasn't read new/updated configuration",
          },
          type = "string",
        },
        statusDetails = {
          description = "[Output Only] Human-readable details about the current state of the autoscaler. Read the documentation for Commonly returned status messages for examples of status messages you might encounter.",
          items = {
            ["$ref"] = "AutoscalerStatusDetails",
          },
          type = "array",
        },
        target = {
          description = "URL of the managed instance group that this autoscaler will scale. This field is required when creating an autoscaler.",
          type = "string",
        },
        zone = {
          description = "[Output Only] URL of the zone where the instance group resides (for autoscalers living in zonal scope).",
          type = "string",
        },
      },
      type = "object",
    },
    AutoscalerAggregatedList = {
      id = "AutoscalerAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "AutoscalersScopedList",
            description = "[Output Only] Name of the scope containing this set of autoscalers.",
          },
          description = "A list of AutoscalersScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#autoscalerAggregatedList",
          description = "[Output Only] Type of resource. Always compute#autoscalerAggregatedList for aggregated lists of autoscalers.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    AutoscalerList = {
      description = "Contains a list of Autoscaler resources.",
      id = "AutoscalerList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Autoscaler resources.",
          items = {
            ["$ref"] = "Autoscaler",
          },
          type = "array",
        },
        kind = {
          default = "compute#autoscalerList",
          description = "[Output Only] Type of resource. Always compute#autoscalerList for lists of autoscalers.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    AutoscalerStatusDetails = {
      id = "AutoscalerStatusDetails",
      properties = {
        message = {
          description = "The status message.",
          type = "string",
        },
        type = {
          description = "The type of error, warning, or notice returned. Current set of possible values: - ALL_INSTANCES_UNHEALTHY (WARNING): All instances in the instance group are unhealthy (not in RUNNING state). - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service attached to the instance group. - CAPPED_AT_MAX_NUM_REPLICAS (WARNING): Autoscaler recommends a size greater than maxNumReplicas. - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric samples are not exported often enough to be a credible base for autoscaling. - CUSTOM_METRIC_INVALID (ERROR): The custom metric that was specified does not exist or does not have the necessary labels. - MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas. This means the autoscaler cannot add or remove instances from the instance group. - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The autoscaler did not receive any data from the custom metric configured for autoscaling. - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The autoscaler is configured to scale based on a load balancing signal but the instance group has not received any requests from the load balancer. - MODE_OFF (WARNING): Autoscaling is turned off. The number of instances in the group won't change automatically. The autoscaling configuration is preserved. - MODE_ONLY_UP (WARNING): Autoscaling is in the \"Autoscale only out\" mode. The autoscaler can add instances but not remove any. - MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group cannot be autoscaled because it has more than one backend service attached to it. - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is insufficient quota for the necessary resources, such as CPU or number of instances. - REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional autoscalers: there is a resource stockout in the chosen region. - SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not exist. - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR): Autoscaling does not work with an HTTP/S load balancer that has been configured for maxRate. - ZONE_RESOURCE_STOCKOUT (ERROR): For zonal autoscalers: there is a resource stockout in the chosen zone. For regional autoscalers: in at least one of the zones you're using there is a resource stockout. New values might be added in the future. Some of the values might not be available in all API versions.",
          enum = {
            "ALL_INSTANCES_UNHEALTHY",
            "BACKEND_SERVICE_DOES_NOT_EXIST",
            "CAPPED_AT_MAX_NUM_REPLICAS",
            "CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE",
            "CUSTOM_METRIC_INVALID",
            "MIN_EQUALS_MAX",
            "MISSING_CUSTOM_METRIC_DATA_POINTS",
            "MISSING_LOAD_BALANCING_DATA_POINTS",
            "MODE_OFF",
            "MODE_ONLY_SCALE_OUT",
            "MODE_ONLY_UP",
            "MORE_THAN_ONE_BACKEND_SERVICE",
            "NOT_ENOUGH_QUOTA_AVAILABLE",
            "REGION_RESOURCE_STOCKOUT",
            "SCALING_TARGET_DOES_NOT_EXIST",
            "SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX",
            "SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN",
            "UNKNOWN",
            "UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION",
            "ZONE_RESOURCE_STOCKOUT",
          },
          enumDescriptions = {
            "All instances in the instance group are unhealthy (not in RUNNING state).",
            "There is no backend service attached to the instance group.",
            "Autoscaler recommends a size greater than maxNumReplicas.",
            "The custom metric samples are not exported often enough to be a credible base for autoscaling.",
            "The custom metric that was specified does not exist or does not have the necessary labels.",
            "The minNumReplicas is equal to maxNumReplicas. This means the autoscaler cannot add or remove instances from the instance group.",
            "The autoscaler did not receive any data from the custom metric configured for autoscaling.",
            "The autoscaler is configured to scale based on a load balancing signal but the instance group has not received any requests from the load balancer.",
            "Autoscaling is turned off. The number of instances in the group won't change automatically. The autoscaling configuration is preserved.",
            "Autoscaling is in the \"Autoscale only scale out\" mode. Instances in the group will be only added.",
            "Autoscaling is in the \"Autoscale only out\" mode. Instances in the group will be only added.",
            "The instance group cannot be autoscaled because it has more than one backend service attached to it.",
            "There is insufficient quota for the necessary resources, such as CPU or number of instances.",
            "Showed only for regional autoscalers: there is a resource stockout in the chosen region.",
            "The target to be scaled does not exist.",
            "For some scaling schedules minRequiredReplicas is greater than maxNumReplicas. Autoscaler always recommends at most maxNumReplicas instances.",
            "For some scaling schedules minRequiredReplicas is less than minNumReplicas. Autoscaler always recommends at least minNumReplicas instances.",
            "",
            "Autoscaling does not work with an HTTP/S load balancer that has been configured for maxRate.",
            "For zonal autoscalers: there is a resource stockout in the chosen zone. For regional autoscalers: in at least one of the zones you're using there is a resource stockout.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    AutoscalersScopedList = {
      id = "AutoscalersScopedList",
      properties = {
        autoscalers = {
          description = "[Output Only] A list of autoscalers contained in this scope.",
          items = {
            ["$ref"] = "Autoscaler",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of autoscalers when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    AutoscalingPolicy = {
      description = "Cloud Autoscaler policy.",
      id = "AutoscalingPolicy",
      properties = {
        coolDownPeriodSec = {
          description = "The number of seconds that the autoscaler waits before it starts collecting information from a new instance. This prevents the autoscaler from collecting information when the instance is initializing, during which the collected usage would not be reliable. The default time autoscaler waits is 60 seconds. Virtual machine initialization times might vary because of numerous factors. We recommend that you test how long an instance may take to initialize. To do this, create an instance and time the startup process.",
          format = "int32",
          type = "integer",
        },
        cpuUtilization = {
          ["$ref"] = "AutoscalingPolicyCpuUtilization",
          description = "Defines the CPU utilization policy that allows the autoscaler to scale based on the average CPU utilization of a managed instance group.",
        },
        customMetricUtilizations = {
          description = "Configuration parameters of autoscaling based on a custom metric.",
          items = {
            ["$ref"] = "AutoscalingPolicyCustomMetricUtilization",
          },
          type = "array",
        },
        loadBalancingUtilization = {
          ["$ref"] = "AutoscalingPolicyLoadBalancingUtilization",
          description = "Configuration parameters of autoscaling based on load balancer.",
        },
        maxNumReplicas = {
          description = "The maximum number of instances that the autoscaler can scale out to. This is required when creating or updating an autoscaler. The maximum number of replicas must not be lower than minimal number of replicas.",
          format = "int32",
          type = "integer",
        },
        minNumReplicas = {
          description = "The minimum number of replicas that the autoscaler can scale in to. This cannot be less than 0. If not provided, autoscaler chooses a default value depending on maximum number of instances allowed.",
          format = "int32",
          type = "integer",
        },
        mode = {
          description = "Defines operating mode for this policy.",
          enum = {
            "OFF",
            "ON",
            "ONLY_SCALE_OUT",
            "ONLY_UP",
          },
          enumDescriptions = {
            "Do not automatically scale the MIG in or out. The recommended_size field contains the size of MIG that would be set if the actuation mode was enabled.",
            "Automatically scale the MIG in and out according to the policy.",
            "Automatically create VMs according to the policy, but do not scale the MIG in.",
            "Automatically create VMs according to the policy, but do not scale the MIG in.",
          },
          type = "string",
        },
        scaleInControl = {
          ["$ref"] = "AutoscalingPolicyScaleInControl",
        },
        scalingSchedules = {
          additionalProperties = {
            ["$ref"] = "AutoscalingPolicyScalingSchedule",
          },
          description = "Scaling schedules defined for an autoscaler. Multiple schedules can be set on an autoscaler, and they can overlap. During overlapping periods the greatest min_required_replicas of all scaling schedules is applied. Up to 128 scaling schedules are allowed.",
          type = "object",
        },
      },
      type = "object",
    },
    AutoscalingPolicyCpuUtilization = {
      description = "CPU utilization policy.",
      id = "AutoscalingPolicyCpuUtilization",
      properties = {
        predictiveMethod = {
          description = "Indicates whether predictive autoscaling based on CPU metric is enabled. Valid values are: * NONE (default). No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics. * OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by monitoring daily and weekly load patterns and scaling out ahead of anticipated demand.",
          enum = {
            "NONE",
            "OPTIMIZE_AVAILABILITY",
          },
          enumDescriptions = {
            "No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics",
            "Predictive autoscaling improves availability by monitoring daily and weekly load patterns and scaling out ahead of anticipated demand.",
          },
          type = "string",
        },
        utilizationTarget = {
          description = "The target CPU utilization that the autoscaler maintains. Must be a float value in the range (0, 1]. If not specified, the default is 0.6. If the CPU level is below the target utilization, the autoscaler scales in the number of instances until it reaches the minimum number of instances you specified or until the average CPU of your instances reaches the target utilization. If the average CPU is above the target utilization, the autoscaler scales out until it reaches the maximum number of instances you specified or until the average utilization reaches the target utilization.",
          format = "double",
          type = "number",
        },
      },
      type = "object",
    },
    AutoscalingPolicyCustomMetricUtilization = {
      description = "Custom utilization metric policy.",
      id = "AutoscalingPolicyCustomMetricUtilization",
      properties = {
        filter = {
          description = "A filter string, compatible with a Stackdriver Monitoring filter string for TimeSeries.list API call. This filter is used to select a specific TimeSeries for the purpose of autoscaling and to determine whether the metric is exporting per-instance or per-group data. For the filter to be valid for autoscaling purposes, the following rules apply: - You can only use the AND operator for joining selectors. - You can only use direct equality comparison operator (=) without any functions for each selector. - You can specify the metric in both the filter string and in the metric field. However, if specified in both places, the metric must be identical. - The monitored resource type determines what kind of values are expected for the metric. If it is a gce_instance, the autoscaler expects the metric to include a separate TimeSeries for each instance in a group. In such a case, you cannot filter on resource labels. If the resource type is any other value, the autoscaler expects this metric to contain values that apply to the entire autoscaled instance group and resource label filtering can be performed to point autoscaler at the correct TimeSeries to scale upon. This is called a *per-group metric* for the purpose of autoscaling. If not specified, the type defaults to gce_instance. Try to provide a filter that is selective enough to pick just one TimeSeries for the autoscaled group or for each of the instances (if you are using gce_instance resource type). If multiple TimeSeries are returned upon the query execution, the autoscaler will sum their respective values to obtain its scaling value.",
          type = "string",
        },
        metric = {
          description = "The identifier (type) of the Stackdriver Monitoring metric. The metric cannot have negative values. The metric must have a value type of INT64 or DOUBLE.",
          type = "string",
        },
        singleInstanceAssignment = {
          description = "If scaling is based on a per-group metric value that represents the total amount of work to be done or resource usage, set this value to an amount assigned for a single instance of the scaled group. Autoscaler keeps the number of instances proportional to the value of this metric. The metric itself does not change value due to group resizing. A good metric to use with the target is for example pubsub.googleapis.com/subscription/num_undelivered_messages or a custom metric exporting the total number of requests coming to your instances. A bad example would be a metric exporting an average or median latency, since this value can't include a chunk assignable to a single instance, it could be better used with utilization_target instead.",
          format = "double",
          type = "number",
        },
        utilizationTarget = {
          description = "The target value of the metric that autoscaler maintains. This must be a positive value. A utilization metric scales number of virtual machines handling requests to increase or decrease proportionally to the metric. For example, a good metric to use as a utilization_target is https://www.googleapis.com/compute/v1/instance/network/received_bytes_count. The autoscaler works to keep this value constant for each of the instances.",
          format = "double",
          type = "number",
        },
        utilizationTargetType = {
          description = "Defines how target utilization value is expressed for a Stackdriver Monitoring metric. Either GAUGE, DELTA_PER_SECOND, or DELTA_PER_MINUTE.",
          enum = {
            "DELTA_PER_MINUTE",
            "DELTA_PER_SECOND",
            "GAUGE",
          },
          enumDescriptions = {
            "Sets the utilization target value for a cumulative or delta metric, expressed as the rate of growth per minute.",
            "Sets the utilization target value for a cumulative or delta metric, expressed as the rate of growth per second.",
            "Sets the utilization target value for a gauge metric. The autoscaler will collect the average utilization of the virtual machines from the last couple of minutes, and compare the value to the utilization target value to perform autoscaling.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    AutoscalingPolicyLoadBalancingUtilization = {
      description = "Configuration parameters of autoscaling based on load balancing.",
      id = "AutoscalingPolicyLoadBalancingUtilization",
      properties = {
        utilizationTarget = {
          description = "Fraction of backend capacity utilization (set in HTTP(S) load balancing configuration) that the autoscaler maintains. Must be a positive float value. If not defined, the default is 0.8.",
          format = "double",
          type = "number",
        },
      },
      type = "object",
    },
    AutoscalingPolicyScaleInControl = {
      description = "Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below.",
      id = "AutoscalingPolicyScaleInControl",
      properties = {
        maxScaledInReplicas = {
          ["$ref"] = "FixedOrPercent",
          description = "Maximum allowed number (or %) of VMs that can be deducted from the peak recommendation during the window autoscaler looks at when computing recommendations. Possibly all these VMs can be deleted at once so user service needs to be prepared to lose that many VMs in one step.",
        },
        timeWindowSec = {
          description = "How far back autoscaling looks when computing recommendations to include directives regarding slower scale in, as described above.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    AutoscalingPolicyScalingSchedule = {
      description = "Scaling based on user-defined schedule. The message describes a single scaling schedule. A scaling schedule changes the minimum number of VM instances an autoscaler can recommend, which can trigger scaling out.",
      id = "AutoscalingPolicyScalingSchedule",
      properties = {
        description = {
          description = "A description of a scaling schedule.",
          type = "string",
        },
        disabled = {
          description = "A boolean value that specifies whether a scaling schedule can influence autoscaler recommendations. If set to true, then a scaling schedule has no effect. This field is optional, and its value is false by default.",
          type = "boolean",
        },
        durationSec = {
          description = "The duration of time intervals, in seconds, for which this scaling schedule is to run. The minimum allowed value is 300. This field is required.",
          format = "int32",
          type = "integer",
        },
        minRequiredReplicas = {
          description = "The minimum number of VM instances that the autoscaler will recommend in time intervals starting according to schedule. This field is required.",
          format = "int32",
          type = "integer",
        },
        schedule = {
          description = "The start timestamps of time intervals when this scaling schedule is to provide a scaling signal. This field uses the extended cron format (with an optional year field). The expression can describe a single timestamp if the optional year is set, in which case the scaling schedule runs once. The schedule is interpreted with respect to time_zone. This field is required. Note: These timestamps only describe when autoscaler starts providing the scaling signal. The VMs need additional time to become serving.",
          type = "string",
        },
        timeZone = {
          description = "The time zone to use when interpreting the schedule. The value of this field must be a time zone name from the tz database: http://en.wikipedia.org/wiki/Tz_database. This field is assigned a default value of “UTC” if left empty.",
          type = "string",
        },
      },
      type = "object",
    },
    Backend = {
      description = "Message containing information of one individual backend.",
      id = "Backend",
      properties = {
        balancingMode = {
          description = "Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected.",
          enum = {
            "CONNECTION",
            "RATE",
            "UTILIZATION",
          },
          enumDescriptions = {
            "Balance based on the number of simultaneous connections.",
            "Balance based on requests per second (RPS).",
            "Balance based on the backend utilization.",
          },
          type = "string",
        },
        capacityScaler = {
          description = "A multiplier applied to the backend's target capacity of its balancing mode. The default value is 1, which means the group serves up to 100% of its configured capacity (depending on balancingMode). A setting of 0 means the group is completely drained, offering 0% of its available capacity. The valid ranges are 0.0 and [0.1,1.0]. You cannot configure a setting larger than 0 and smaller than 0.1. You cannot configure a setting of 0 when there is only one backend attached to the backend service. Not available with backends that don't support using a balancingMode. This includes backends such as global internet NEGs, regional serverless NEGs, and PSC NEGs.",
          format = "float",
          type = "number",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        failover = {
          description = "This field designates whether this is a failover backend. More than one failover backend can be configured for a given BackendService.",
          type = "boolean",
        },
        group = {
          description = "The fully-qualified URL of an instance group or network endpoint group (NEG) resource. To determine what types of backends a load balancer supports, see the [Backend services overview](https://cloud.google.com/load-balancing/docs/backend-service#backends). You must use the *fully-qualified* URL (starting with https://www.googleapis.com/) to specify the instance group or NEG. Partial URLs are not supported.",
          type = "string",
        },
        maxConnections = {
          description = "Defines a target maximum number of simultaneous connections. For usage guidelines, see Connection balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is RATE.",
          format = "int32",
          type = "integer",
        },
        maxConnectionsPerEndpoint = {
          description = "Defines a target maximum number of simultaneous connections. For usage guidelines, see Connection balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is RATE.",
          format = "int32",
          type = "integer",
        },
        maxConnectionsPerInstance = {
          description = "Defines a target maximum number of simultaneous connections. For usage guidelines, see Connection balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is RATE.",
          format = "int32",
          type = "integer",
        },
        maxRate = {
          description = "Defines a maximum number of HTTP requests per second (RPS). For usage guidelines, see Rate balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is CONNECTION.",
          format = "int32",
          type = "integer",
        },
        maxRatePerEndpoint = {
          description = "Defines a maximum target for requests per second (RPS). For usage guidelines, see Rate balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is CONNECTION.",
          format = "float",
          type = "number",
        },
        maxRatePerInstance = {
          description = "Defines a maximum target for requests per second (RPS). For usage guidelines, see Rate balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is CONNECTION.",
          format = "float",
          type = "number",
        },
        maxUtilization = {
          description = "Optional parameter to define a target capacity for the UTILIZATION balancing mode. The valid range is [0.0, 1.0]. For usage guidelines, see Utilization balancing mode.",
          format = "float",
          type = "number",
        },
      },
      type = "object",
    },
    BackendBucket = {
      description = "Represents a Cloud Storage Bucket resource. This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, read Backend Buckets.",
      id = "BackendBucket",
      properties = {
        bucketName = {
          description = "Cloud Storage bucket name.",
          type = "string",
        },
        cdnPolicy = {
          ["$ref"] = "BackendBucketCdnPolicy",
          description = "Cloud CDN configuration for this BackendBucket.",
        },
        compressionMode = {
          description = "Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header.",
          enum = {
            "AUTOMATIC",
            "DISABLED",
          },
          enumDescriptions = {
            "Automatically uses the best compression based on the Accept-Encoding header sent by the client.",
            "Disables compression. Existing compressed responses cached by Cloud CDN will not be served to clients.",
          },
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        customResponseHeaders = {
          description = "Headers that the HTTP/S load balancer should add to proxied responses.",
          items = {
            type = "string",
          },
          type = "array",
        },
        description = {
          description = "An optional textual description of the resource; provided by the client when the resource is created.",
          type = "string",
        },
        edgeSecurityPolicy = {
          description = "[Output Only] The resource URL for the edge security policy associated with this backend bucket.",
          type = "string",
        },
        enableCdn = {
          description = "If true, enable Cloud CDN for this BackendBucket.",
          type = "boolean",
        },
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#backendBucket",
          description = "Type of the resource.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
      },
      type = "object",
    },
    BackendBucketCdnPolicy = {
      description = "Message containing Cloud CDN configuration for a backend bucket.",
      id = "BackendBucketCdnPolicy",
      properties = {
        bypassCacheOnRequestHeaders = {
          description = "Bypass the cache when the specified request headers are matched - e.g. Pragma or Authorization headers. Up to 5 headers can be specified. The cache is bypassed for all cdnPolicy.cacheMode settings.",
          items = {
            ["$ref"] = "BackendBucketCdnPolicyBypassCacheOnRequestHeader",
          },
          type = "array",
        },
        cacheKeyPolicy = {
          ["$ref"] = "BackendBucketCdnPolicyCacheKeyPolicy",
          description = "The CacheKeyPolicy for this CdnPolicy.",
        },
        cacheMode = {
          description = "Specifies the cache setting for all responses from this backend. The possible values are: USE_ORIGIN_HEADERS Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at Google's edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server. FORCE_CACHE_ALL Cache all content, ignoring any \"private\", \"no-store\" or \"no-cache\" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content. CACHE_ALL_STATIC Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.",
          enum = {
            "CACHE_ALL_STATIC",
            "FORCE_CACHE_ALL",
            "INVALID_CACHE_MODE",
            "USE_ORIGIN_HEADERS",
          },
          enumDescriptions = {
            "Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.",
            "Cache all content, ignoring any \"private\", \"no-store\" or \"no-cache\" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content.",
            "",
            "Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at Google's edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server.",
          },
          type = "string",
        },
        clientTtl = {
          description = "Specifies a separate client (e.g. browser client) maximum TTL. This is used to clamp the max-age (or Expires) value sent to the client. With FORCE_CACHE_ALL, the lesser of client_ttl and default_ttl is used for the response max-age directive, along with a \"public\" directive. For cacheable content in CACHE_ALL_STATIC mode, client_ttl clamps the max-age from the origin (if specified), or else sets the response max-age directive to the lesser of the client_ttl and default_ttl, and also ensures a \"public\" cache-control directive is present. If a client TTL is not specified, a default value (1 hour) will be used. The maximum allowed value is 31,622,400s (1 year).",
          format = "int32",
          type = "integer",
        },
        defaultTtl = {
          description = "Specifies the default TTL for cached content served by this origin for responses that do not have an existing valid TTL (max-age or s-max-age). Setting a TTL of \"0\" means \"always revalidate\". The value of defaultTTL cannot be set to a value greater than that of maxTTL, but can be equal. When the cacheMode is set to FORCE_CACHE_ALL, the defaultTTL will overwrite the TTL set in all responses. The maximum allowed value is 31,622,400s (1 year), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.",
          format = "int32",
          type = "integer",
        },
        maxTtl = {
          description = "Specifies the maximum allowed TTL for cached content served by this origin. Cache directives that attempt to set a max-age or s-maxage higher than this, or an Expires header more than maxTTL seconds in the future will be capped at the value of maxTTL, as if it were the value of an s-maxage Cache-Control directive. Headers sent to the client will not be modified. Setting a TTL of \"0\" means \"always revalidate\". The maximum allowed value is 31,622,400s (1 year), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.",
          format = "int32",
          type = "integer",
        },
        negativeCaching = {
          description = "Negative caching allows per-status code TTLs to be set, in order to apply fine-grained caching for common errors or redirects. This can reduce the load on your origin and improve end-user experience by reducing response latency. When the cache mode is set to CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, negative caching applies to responses with the specified response code that lack any Cache-Control, Expires, or Pragma: no-cache directives. When the cache mode is set to FORCE_CACHE_ALL, negative caching applies to all responses with the specified response code, and override any caching headers. By default, Cloud CDN will apply the following default TTLs to these status codes: HTTP 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m HTTP 404 (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s HTTP 405 (Method Not Found), 421 (Misdirected Request), 501 (Not Implemented): 60s. These defaults can be overridden in negative_caching_policy.",
          type = "boolean",
        },
        negativeCachingPolicy = {
          description = "Sets a cache TTL for the specified HTTP status code. negative_caching must be enabled to configure negative_caching_policy. Omitting the policy and leaving negative_caching enabled will use Cloud CDN's default cache TTLs. Note that when specifying an explicit negative_caching_policy, you should take care to specify a cache TTL for all response codes that you wish to cache. Cloud CDN will not apply any default negative caching when a policy exists.",
          items = {
            ["$ref"] = "BackendBucketCdnPolicyNegativeCachingPolicy",
          },
          type = "array",
        },
        requestCoalescing = {
          description = "If true then Cloud CDN will combine multiple concurrent cache fill requests into a small number of requests to the origin.",
          type = "boolean",
        },
        serveWhileStale = {
          description = "Serve existing content from the cache (if available) when revalidating content with the origin, or when an error is encountered when refreshing the cache. This setting defines the default \"max-stale\" duration for any cached responses that do not specify a max-stale directive. Stale responses that exceed the TTL configured here will not be served. The default limit (max-stale) is 86400s (1 day), which will allow stale content to be served up to this limit beyond the max-age (or s-max-age) of a cached response. The maximum allowed value is 604800 (1 week). Set this to zero (0) to disable serve-while-stale.",
          format = "int32",
          type = "integer",
        },
        signedUrlCacheMaxAgeSec = {
          description = "Maximum number of seconds the response to a signed URL request will be considered fresh. After this time period, the response will be revalidated before being served. Defaults to 1hr (3600s). When serving responses to signed URL requests, Cloud CDN will internally behave as though all responses from this backend had a \"Cache-Control: public, max-age=[TTL]\" header, regardless of any existing Cache-Control header. The actual headers served in responses will not be altered.",
          format = "int64",
          type = "string",
        },
        signedUrlKeyNames = {
          description = "[Output Only] Names of the keys for signing request URLs.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BackendBucketCdnPolicyBypassCacheOnRequestHeader = {
      description = "Bypass the cache when the specified request headers are present, e.g. Pragma or Authorization headers. Values are case insensitive. The presence of such a header overrides the cache_mode setting.",
      id = "BackendBucketCdnPolicyBypassCacheOnRequestHeader",
      properties = {
        headerName = {
          description = "The header field name to match on when bypassing cache. Values are case-insensitive.",
          type = "string",
        },
      },
      type = "object",
    },
    BackendBucketCdnPolicyCacheKeyPolicy = {
      description = "Message containing what to include in the cache key for a request for Cloud CDN.",
      id = "BackendBucketCdnPolicyCacheKeyPolicy",
      properties = {
        includeHttpHeaders = {
          description = "Allows HTTP request headers (by name) to be used in the cache key.",
          items = {
            type = "string",
          },
          type = "array",
        },
        queryStringWhitelist = {
          description = "Names of query string parameters to include in cache keys. Default parameters are always included. '&' and '=' will be percent encoded and not treated as delimiters.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BackendBucketCdnPolicyNegativeCachingPolicy = {
      description = "Specify CDN TTLs for response error codes.",
      id = "BackendBucketCdnPolicyNegativeCachingPolicy",
      properties = {
        code = {
          description = "The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 are can be specified as values, and you cannot specify a status code more than once.",
          format = "int32",
          type = "integer",
        },
        ttl = {
          description = "The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    BackendBucketList = {
      description = "Contains a list of BackendBucket resources.",
      id = "BackendBucketList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of BackendBucket resources.",
          items = {
            ["$ref"] = "BackendBucket",
          },
          type = "array",
        },
        kind = {
          default = "compute#backendBucketList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    BackendService = {
      description = "Represents a Backend Service resource. A backend service defines how Google Cloud load balancers distribute traffic. The backend service configuration contains a set of values, such as the protocol used to connect to backends, various distribution and session settings, health checks, and timeouts. These settings provide fine-grained control over how your load balancer behaves. Most of the settings have default values that allow for easy configuration if you need to get started quickly. Backend services in Google Compute Engine can be either regionally or globally scoped. * [Global](https://cloud.google.com/compute/docs/reference/rest/v1/backendServices) * [Regional](https://cloud.google.com/compute/docs/reference/rest/v1/regionBackendServices) For more information, see Backend Services.",
      id = "BackendService",
      properties = {
        affinityCookieTtlSec = {
          description = "Lifetime of cookies in seconds. This setting is applicable to external and internal HTTP(S) load balancers and Traffic Director and requires GENERATED_COOKIE or HTTP_COOKIE session affinity. If set to 0, the cookie is non-persistent and lasts only until the end of the browser session (or equivalent). The maximum allowed value is two weeks (1,209,600). Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          format = "int32",
          type = "integer",
        },
        backends = {
          description = "The list of backends that serve this BackendService.",
          items = {
            ["$ref"] = "Backend",
          },
          type = "array",
        },
        cdnPolicy = {
          ["$ref"] = "BackendServiceCdnPolicy",
          description = "Cloud CDN configuration for this BackendService. Only available for specified load balancer types.",
        },
        circuitBreakers = {
          ["$ref"] = "CircuitBreakers",
        },
        compressionMode = {
          description = "Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header.",
          enum = {
            "AUTOMATIC",
            "DISABLED",
          },
          enumDescriptions = {
            "Automatically uses the best compression based on the Accept-Encoding header sent by the client.",
            "Disables compression. Existing compressed responses cached by Cloud CDN will not be served to clients.",
          },
          type = "string",
        },
        connectionDraining = {
          ["$ref"] = "ConnectionDraining",
        },
        connectionTrackingPolicy = {
          ["$ref"] = "BackendServiceConnectionTrackingPolicy",
          description = "Connection Tracking configuration for this BackendService. Connection tracking policy settings are only available for Network Load Balancing and Internal TCP/UDP Load Balancing.",
        },
        consistentHash = {
          ["$ref"] = "ConsistentHashLoadBalancerSettings",
          description = "Consistent Hash-based load balancing can be used to provide soft session affinity based on HTTP headers, cookies or other properties. This load balancing policy is applicable only for HTTP connections. The affinity to a particular destination host will be lost when one or more hosts are added/removed from the destination service. This field specifies parameters that control consistent hashing. This field is only applicable when localityLbPolicy is set to MAGLEV or RING_HASH. This field is applicable to either: - A regional backend service with the service_protocol set to HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to INTERNAL_MANAGED. - A global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED. ",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        customRequestHeaders = {
          description = "Headers that the load balancer adds to proxied requests. See [Creating custom headers](https://cloud.google.com/load-balancing/docs/custom-headers).",
          items = {
            type = "string",
          },
          type = "array",
        },
        customResponseHeaders = {
          description = "Headers that the load balancer adds to proxied responses. See [Creating custom headers](https://cloud.google.com/load-balancing/docs/custom-headers).",
          items = {
            type = "string",
          },
          type = "array",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        edgeSecurityPolicy = {
          description = "[Output Only] The resource URL for the edge security policy associated with this backend service.",
          type = "string",
        },
        enableCDN = {
          description = "If true, enables Cloud CDN for the backend service of an external HTTP(S) load balancer.",
          type = "boolean",
        },
        failoverPolicy = {
          ["$ref"] = "BackendServiceFailoverPolicy",
          description = "Requires at least one backend instance group to be defined as a backup (failover) backend. For load balancers that have configurable failover: [Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal/failover-overview) and [external TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-failover-overview).",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a BackendService. An up-to-date fingerprint must be provided in order to update the BackendService, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a BackendService.",
          format = "byte",
          type = "string",
        },
        healthChecks = {
          description = "The list of URLs to the healthChecks, httpHealthChecks (legacy), or httpsHealthChecks (legacy) resource for health checking this backend service. Not all backend services support legacy health checks. See Load balancer guide. Currently, at most one health check can be specified for each backend service. Backend services with instance group or zonal NEG backends must have a health check. Backend services with internet or serverless NEG backends must not have a health check.",
          items = {
            type = "string",
          },
          type = "array",
        },
        iap = {
          ["$ref"] = "BackendServiceIAP",
          description = "The configurations for Identity-Aware Proxy on this resource. Not available for Internal TCP/UDP Load Balancing and Network Load Balancing.",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#backendService",
          description = "[Output Only] Type of resource. Always compute#backendService for backend services.",
          type = "string",
        },
        loadBalancingScheme = {
          description = "Specifies the load balancer type. A backend service created for one type of load balancer cannot be used with another. For more information, refer to Choosing a load balancer.",
          enum = {
            "EXTERNAL",
            "EXTERNAL_MANAGED",
            "INTERNAL",
            "INTERNAL_MANAGED",
            "INTERNAL_SELF_MANAGED",
            "INVALID_LOAD_BALANCING_SCHEME",
          },
          enumDescriptions = {
            "Signifies that this will be used for external HTTP(S), SSL Proxy, TCP Proxy, or Network Load Balancing",
            "Signifies that this will be used for External Managed HTTP(S) Load Balancing.",
            "Signifies that this will be used for Internal TCP/UDP Load Balancing.",
            "Signifies that this will be used for Internal HTTP(S) Load Balancing.",
            "Signifies that this will be used by Traffic Director.",
            "",
          },
          type = "string",
        },
        localityLbPolicies = {
          description = "A list of locality load balancing policies to be used in order of preference. Either the policy or the customPolicy field should be set. Overrides any value set in the localityLbPolicy field. localityLbPolicies is only supported when the BackendService is referenced by a URL Map that is referenced by a target gRPC proxy that has the validateForProxyless field set to true.",
          items = {
            ["$ref"] = "BackendServiceLocalityLoadBalancingPolicyConfig",
          },
          type = "array",
        },
        localityLbPolicy = {
          description = "The load balancing algorithm used within the scope of the locality. The possible values are: - ROUND_ROBIN: This is a simple policy in which each healthy backend is selected in round robin order. This is the default. - LEAST_REQUEST: An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests. - RING_HASH: The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests. - RANDOM: The load balancer selects a random healthy host. - ORIGINAL_DESTINATION: Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer. - MAGLEV: used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, see https://ai.google/research/pubs/pub44824 This field is applicable to either: - A regional backend service with the service_protocol set to HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to INTERNAL_MANAGED. - A global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED. If sessionAffinity is not NONE, and this field is not set to MAGLEV or RING_HASH, session affinity settings will not take effect. Only ROUND_ROBIN and RING_HASH are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          enum = {
            "INVALID_LB_POLICY",
            "LEAST_REQUEST",
            "MAGLEV",
            "ORIGINAL_DESTINATION",
            "RANDOM",
            "RING_HASH",
            "ROUND_ROBIN",
          },
          enumDescriptions = {
            "",
            "An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests.",
            "This algorithm implements consistent hashing to backends. Maglev can be used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, see https://ai.google/research/pubs/pub44824",
            "Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer.",
            "The load balancer selects a random healthy host.",
            "The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests.",
            "This is a simple policy in which each healthy backend is selected in round robin order. This is the default.",
          },
          type = "string",
        },
        logConfig = {
          ["$ref"] = "BackendServiceLogConfig",
          description = "This field denotes the logging options for the load balancer traffic served by this backend service. If logging is enabled, logs will be exported to Stackdriver.",
        },
        maxStreamDuration = {
          ["$ref"] = "Duration",
          description = "Specifies the default maximum duration (timeout) for streams to this service. Duration is computed from the beginning of the stream until the response has been completely processed, including all retries. A stream that does not complete in this duration is closed. If not specified, there will be no timeout limit, i.e. the maximum duration is infinite. This value can be overridden in the PathMatcher configuration of the UrlMap that references this backend service. This field is only allowed when the loadBalancingScheme of the backend service is INTERNAL_SELF_MANAGED.",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          description = "The URL of the network to which this backend service belongs. This field can only be specified when the load balancing scheme is set to INTERNAL.",
          type = "string",
        },
        outlierDetection = {
          ["$ref"] = "OutlierDetection",
          description = "Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service. If not set, this feature is considered disabled. This field is applicable to either: - A regional backend service with the service_protocol set to HTTP, HTTPS, HTTP2, or GRPC, and load_balancing_scheme set to INTERNAL_MANAGED. - A global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED. ",
        },
        port = {
          description = "Deprecated in favor of portName. The TCP port to connect on the backend. The default value is 80. For Internal TCP/UDP Load Balancing and Network Load Balancing, omit port.",
          format = "int32",
          type = "integer",
        },
        portName = {
          description = "A named port on a backend instance group representing the port for communication to the backend VMs in that group. The named port must be [defined on each backend instance group](https://cloud.google.com/load-balancing/docs/backend-service#named_ports). This parameter has no meaning if the backends are NEGs. For Internal TCP/UDP Load Balancing and Network Load Balancing, omit port_name.",
          type = "string",
        },
        protocol = {
          description = "The protocol this BackendService uses to communicate with backends. Possible values are HTTP, HTTPS, HTTP2, TCP, SSL, UDP or GRPC. depending on the chosen load balancer or Traffic Director configuration. Refer to the documentation for the load balancers or for Traffic Director for more information. Must be set to GRPC when the backend service is referenced by a URL map that is bound to target gRPC proxy.",
          enum = {
            "GRPC",
            "HTTP",
            "HTTP2",
            "HTTPS",
            "SSL",
            "TCP",
            "UDP",
            "UNSPECIFIED",
          },
          enumDescriptions = {
            "gRPC (available for Traffic Director).",
            "",
            "HTTP/2 with SSL.",
            "",
            "TCP proxying with SSL.",
            "TCP proxying or TCP pass-through.",
            "UDP.",
            "If a Backend Service has UNSPECIFIED as its protocol, it can be used with any L3/L4 Forwarding Rules.",
          },
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the regional backend service resides. This field is not applicable to global backend services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        securityPolicy = {
          description = "[Output Only] The resource URL for the security policy associated with this backend service.",
          type = "string",
        },
        securitySettings = {
          ["$ref"] = "SecuritySettings",
          description = "This field specifies the security settings that apply to this backend service. This field is applicable to a global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED.",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        serviceBindings = {
          description = "URLs of networkservices.ServiceBinding resources. Can only be set if load balancing scheme is INTERNAL_SELF_MANAGED. If set, lists of backends and health checks must be both empty.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sessionAffinity = {
          description = "Type of session affinity to use. The default is NONE. Only NONE and HEADER_FIELD are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. For more details, see: [Session Affinity](https://cloud.google.com/load-balancing/docs/backend-service#session_affinity).",
          enum = {
            "CLIENT_IP",
            "CLIENT_IP_NO_DESTINATION",
            "CLIENT_IP_PORT_PROTO",
            "CLIENT_IP_PROTO",
            "GENERATED_COOKIE",
            "HEADER_FIELD",
            "HTTP_COOKIE",
            "NONE",
          },
          enumDescriptions = {
            "2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy.",
            "1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing.",
            "5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing.",
            "3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing.",
            "Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing.",
            "The hash is based on a user specified header field.",
            "The hash is based on a user provided cookie.",
            "No session affinity. Connections from the same client IP may go to any instance in the pool.",
          },
          type = "string",
        },
        subsetting = {
          ["$ref"] = "Subsetting",
        },
        timeoutSec = {
          description = "The backend service timeout has a different meaning depending on the type of load balancer. For more information see, Backend service settings. The default is 30 seconds. The full range of timeout values allowed goes from 1 through 2,147,483,647 seconds. This value can be overridden in the PathMatcher configuration of the UrlMap that references this backend service. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Instead, use maxStreamDuration.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    BackendServiceAggregatedList = {
      description = "Contains a list of BackendServicesScopedList.",
      id = "BackendServiceAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "BackendServicesScopedList",
            description = "Name of the scope containing this set of BackendServices.",
          },
          description = "A list of BackendServicesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#backendServiceAggregatedList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    BackendServiceCdnPolicy = {
      description = "Message containing Cloud CDN configuration for a backend service.",
      id = "BackendServiceCdnPolicy",
      properties = {
        bypassCacheOnRequestHeaders = {
          description = "Bypass the cache when the specified request headers are matched - e.g. Pragma or Authorization headers. Up to 5 headers can be specified. The cache is bypassed for all cdnPolicy.cacheMode settings.",
          items = {
            ["$ref"] = "BackendServiceCdnPolicyBypassCacheOnRequestHeader",
          },
          type = "array",
        },
        cacheKeyPolicy = {
          ["$ref"] = "CacheKeyPolicy",
          description = "The CacheKeyPolicy for this CdnPolicy.",
        },
        cacheMode = {
          description = "Specifies the cache setting for all responses from this backend. The possible values are: USE_ORIGIN_HEADERS Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at Google's edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server. FORCE_CACHE_ALL Cache all content, ignoring any \"private\", \"no-store\" or \"no-cache\" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content. CACHE_ALL_STATIC Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.",
          enum = {
            "CACHE_ALL_STATIC",
            "FORCE_CACHE_ALL",
            "INVALID_CACHE_MODE",
            "USE_ORIGIN_HEADERS",
          },
          enumDescriptions = {
            "Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.",
            "Cache all content, ignoring any \"private\", \"no-store\" or \"no-cache\" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content.",
            "",
            "Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at Google's edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server.",
          },
          type = "string",
        },
        clientTtl = {
          description = "Specifies a separate client (e.g. browser client) maximum TTL. This is used to clamp the max-age (or Expires) value sent to the client. With FORCE_CACHE_ALL, the lesser of client_ttl and default_ttl is used for the response max-age directive, along with a \"public\" directive. For cacheable content in CACHE_ALL_STATIC mode, client_ttl clamps the max-age from the origin (if specified), or else sets the response max-age directive to the lesser of the client_ttl and default_ttl, and also ensures a \"public\" cache-control directive is present. If a client TTL is not specified, a default value (1 hour) will be used. The maximum allowed value is 31,622,400s (1 year).",
          format = "int32",
          type = "integer",
        },
        defaultTtl = {
          description = "Specifies the default TTL for cached content served by this origin for responses that do not have an existing valid TTL (max-age or s-max-age). Setting a TTL of \"0\" means \"always revalidate\". The value of defaultTTL cannot be set to a value greater than that of maxTTL, but can be equal. When the cacheMode is set to FORCE_CACHE_ALL, the defaultTTL will overwrite the TTL set in all responses. The maximum allowed value is 31,622,400s (1 year), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.",
          format = "int32",
          type = "integer",
        },
        maxTtl = {
          description = "Specifies the maximum allowed TTL for cached content served by this origin. Cache directives that attempt to set a max-age or s-maxage higher than this, or an Expires header more than maxTTL seconds in the future will be capped at the value of maxTTL, as if it were the value of an s-maxage Cache-Control directive. Headers sent to the client will not be modified. Setting a TTL of \"0\" means \"always revalidate\". The maximum allowed value is 31,622,400s (1 year), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.",
          format = "int32",
          type = "integer",
        },
        negativeCaching = {
          description = "Negative caching allows per-status code TTLs to be set, in order to apply fine-grained caching for common errors or redirects. This can reduce the load on your origin and improve end-user experience by reducing response latency. When the cache mode is set to CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, negative caching applies to responses with the specified response code that lack any Cache-Control, Expires, or Pragma: no-cache directives. When the cache mode is set to FORCE_CACHE_ALL, negative caching applies to all responses with the specified response code, and override any caching headers. By default, Cloud CDN will apply the following default TTLs to these status codes: HTTP 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m HTTP 404 (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s HTTP 405 (Method Not Found), 421 (Misdirected Request), 501 (Not Implemented): 60s. These defaults can be overridden in negative_caching_policy.",
          type = "boolean",
        },
        negativeCachingPolicy = {
          description = "Sets a cache TTL for the specified HTTP status code. negative_caching must be enabled to configure negative_caching_policy. Omitting the policy and leaving negative_caching enabled will use Cloud CDN's default cache TTLs. Note that when specifying an explicit negative_caching_policy, you should take care to specify a cache TTL for all response codes that you wish to cache. Cloud CDN will not apply any default negative caching when a policy exists.",
          items = {
            ["$ref"] = "BackendServiceCdnPolicyNegativeCachingPolicy",
          },
          type = "array",
        },
        requestCoalescing = {
          description = "If true then Cloud CDN will combine multiple concurrent cache fill requests into a small number of requests to the origin.",
          type = "boolean",
        },
        serveWhileStale = {
          description = "Serve existing content from the cache (if available) when revalidating content with the origin, or when an error is encountered when refreshing the cache. This setting defines the default \"max-stale\" duration for any cached responses that do not specify a max-stale directive. Stale responses that exceed the TTL configured here will not be served. The default limit (max-stale) is 86400s (1 day), which will allow stale content to be served up to this limit beyond the max-age (or s-max-age) of a cached response. The maximum allowed value is 604800 (1 week). Set this to zero (0) to disable serve-while-stale.",
          format = "int32",
          type = "integer",
        },
        signedUrlCacheMaxAgeSec = {
          description = "Maximum number of seconds the response to a signed URL request will be considered fresh. After this time period, the response will be revalidated before being served. Defaults to 1hr (3600s). When serving responses to signed URL requests, Cloud CDN will internally behave as though all responses from this backend had a \"Cache-Control: public, max-age=[TTL]\" header, regardless of any existing Cache-Control header. The actual headers served in responses will not be altered.",
          format = "int64",
          type = "string",
        },
        signedUrlKeyNames = {
          description = "[Output Only] Names of the keys for signing request URLs.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BackendServiceCdnPolicyBypassCacheOnRequestHeader = {
      description = "Bypass the cache when the specified request headers are present, e.g. Pragma or Authorization headers. Values are case insensitive. The presence of such a header overrides the cache_mode setting.",
      id = "BackendServiceCdnPolicyBypassCacheOnRequestHeader",
      properties = {
        headerName = {
          description = "The header field name to match on when bypassing cache. Values are case-insensitive.",
          type = "string",
        },
      },
      type = "object",
    },
    BackendServiceCdnPolicyNegativeCachingPolicy = {
      description = "Specify CDN TTLs for response error codes.",
      id = "BackendServiceCdnPolicyNegativeCachingPolicy",
      properties = {
        code = {
          description = "The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 are can be specified as values, and you cannot specify a status code more than once.",
          format = "int32",
          type = "integer",
        },
        ttl = {
          description = "The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    BackendServiceConnectionTrackingPolicy = {
      description = "Connection Tracking configuration for this BackendService.",
      id = "BackendServiceConnectionTrackingPolicy",
      properties = {
        connectionPersistenceOnUnhealthyBackends = {
          description = "Specifies connection persistence when backends are unhealthy. The default value is DEFAULT_FOR_PROTOCOL. If set to DEFAULT_FOR_PROTOCOL, the existing connections persist on unhealthy backends only for connection-oriented protocols (TCP and SCTP) and only if the Tracking Mode is PER_CONNECTION (default tracking mode) or the Session Affinity is configured for 5-tuple. They do not persist for UDP. If set to NEVER_PERSIST, after a backend becomes unhealthy, the existing connections on the unhealthy backend are never persisted on the unhealthy backend. They are always diverted to newly selected healthy backends (unless all backends are unhealthy). If set to ALWAYS_PERSIST, existing connections always persist on unhealthy backends regardless of protocol and session affinity. It is generally not recommended to use this mode overriding the default. For more details, see [Connection Persistence for Network Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence) and [Connection Persistence for Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence).",
          enum = {
            "ALWAYS_PERSIST",
            "DEFAULT_FOR_PROTOCOL",
            "NEVER_PERSIST",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        enableStrongAffinity = {
          description = "Enable Strong Session Affinity for Network Load Balancing. This option is not available publicly.",
          type = "boolean",
        },
        idleTimeoutSec = {
          description = "Specifies how long to keep a Connection Tracking entry while there is no matching traffic (in seconds). For Internal TCP/UDP Load Balancing: - The minimum (default) is 10 minutes and the maximum is 16 hours. - It can be set only if Connection Tracking is less than 5-tuple (i.e. Session Affinity is CLIENT_IP_NO_DESTINATION, CLIENT_IP or CLIENT_IP_PROTO, and Tracking Mode is PER_SESSION). For Network Load Balancer the default is 60 seconds. This option is not available publicly.",
          format = "int32",
          type = "integer",
        },
        trackingMode = {
          description = "Specifies the key used for connection tracking. There are two options: - PER_CONNECTION: This is the default mode. The Connection Tracking is performed as per the Connection Key (default Hash Method) for the specific protocol. - PER_SESSION: The Connection Tracking is performed as per the configured Session Affinity. It matches the configured Session Affinity. For more details, see [Tracking Mode for Network Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode) and [Tracking Mode for Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode).",
          enum = {
            "INVALID_TRACKING_MODE",
            "PER_CONNECTION",
            "PER_SESSION",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    BackendServiceFailoverPolicy = {
      description = "For load balancers that have configurable failover: [Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal/failover-overview) and [external TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-failover-overview). On failover or failback, this field indicates whether connection draining will be honored. Google Cloud has a fixed connection draining timeout of 10 minutes. A setting of true terminates existing TCP connections to the active pool during failover and failback, immediately draining traffic. A setting of false allows existing TCP connections to persist, even on VMs no longer in the active pool, for up to the duration of the connection draining timeout (10 minutes).",
      id = "BackendServiceFailoverPolicy",
      properties = {
        disableConnectionDrainOnFailover = {
          description = "This can be set to true only if the protocol is TCP. The default is false.",
          type = "boolean",
        },
        dropTrafficIfUnhealthy = {
          description = "If set to true, connections to the load balancer are dropped when all primary and all backup backend VMs are unhealthy.If set to false, connections are distributed among all primary VMs when all primary and all backup backend VMs are unhealthy. For load balancers that have configurable failover: [Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal/failover-overview) and [external TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-failover-overview). The default is false.",
          type = "boolean",
        },
        failoverRatio = {
          description = "The value of the field must be in the range [0, 1]. If the value is 0, the load balancer performs a failover when the number of healthy primary VMs equals zero. For all other values, the load balancer performs a failover when the total number of healthy primary VMs is less than this ratio. For load balancers that have configurable failover: [Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal/failover-overview) and [external TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-failover-overview).",
          format = "float",
          type = "number",
        },
      },
      type = "object",
    },
    BackendServiceGroupHealth = {
      id = "BackendServiceGroupHealth",
      properties = {
        annotations = {
          additionalProperties = {
            type = "string",
          },
          description = "Metadata defined as annotations on the network endpoint group.",
          type = "object",
        },
        healthStatus = {
          description = "Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.",
          items = {
            ["$ref"] = "HealthStatus",
          },
          type = "array",
        },
        kind = {
          default = "compute#backendServiceGroupHealth",
          description = "[Output Only] Type of resource. Always compute#backendServiceGroupHealth for the health of backend services.",
          type = "string",
        },
      },
      type = "object",
    },
    BackendServiceIAP = {
      description = "Identity-Aware Proxy",
      id = "BackendServiceIAP",
      properties = {
        enabled = {
          description = "Whether the serving infrastructure will authenticate and authorize all incoming requests. If true, the oauth2ClientId and oauth2ClientSecret fields must be non-empty.",
          type = "boolean",
        },
        oauth2ClientId = {
          description = "OAuth2 client ID to use for the authentication flow.",
          type = "string",
        },
        oauth2ClientSecret = {
          description = "OAuth2 client secret to use for the authentication flow. For security reasons, this value cannot be retrieved via the API. Instead, the SHA-256 hash of the value is returned in the oauth2ClientSecretSha256 field. @InputOnly",
          type = "string",
        },
        oauth2ClientSecretSha256 = {
          description = "[Output Only] SHA256 hash value for the field oauth2_client_secret above.",
          type = "string",
        },
      },
      type = "object",
    },
    BackendServiceList = {
      description = "Contains a list of BackendService resources.",
      id = "BackendServiceList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of BackendService resources.",
          items = {
            ["$ref"] = "BackendService",
          },
          type = "array",
        },
        kind = {
          default = "compute#backendServiceList",
          description = "[Output Only] Type of resource. Always compute#backendServiceList for lists of backend services.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    BackendServiceLocalityLoadBalancingPolicyConfig = {
      description = "Container for either a built-in LB policy supported by gRPC or Envoy or a custom one implemented by the end user.",
      id = "BackendServiceLocalityLoadBalancingPolicyConfig",
      properties = {
        customPolicy = {
          ["$ref"] = "BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy",
        },
        policy = {
          ["$ref"] = "BackendServiceLocalityLoadBalancingPolicyConfigPolicy",
        },
      },
      type = "object",
    },
    BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy = {
      description = "The configuration for a custom policy implemented by the user and deployed with the client.",
      id = "BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy",
      properties = {
        data = {
          description = "An optional, arbitrary JSON object with configuration data, understood by a locally installed custom policy implementation.",
          type = "string",
        },
        name = {
          description = "Identifies the custom policy. The value should match the type the custom implementation is registered with on the gRPC clients. It should follow protocol buffer message naming conventions and include the full path (e.g. myorg.CustomLbPolicy). The maximum length is 256 characters. Note that specifying the same custom policy more than once for a backend is not a valid configuration and will be rejected.",
          type = "string",
        },
      },
      type = "object",
    },
    BackendServiceLocalityLoadBalancingPolicyConfigPolicy = {
      description = "The configuration for a built-in load balancing policy.",
      id = "BackendServiceLocalityLoadBalancingPolicyConfigPolicy",
      properties = {
        name = {
          description = "The name of a locality load balancer policy to be used. The value should be one of the predefined ones as supported by localityLbPolicy, although at the moment only ROUND_ROBIN is supported. This field should only be populated when the customPolicy field is not used. Note that specifying the same policy more than once for a backend is not a valid configuration and will be rejected.",
          enum = {
            "INVALID_LB_POLICY",
            "LEAST_REQUEST",
            "MAGLEV",
            "ORIGINAL_DESTINATION",
            "RANDOM",
            "RING_HASH",
            "ROUND_ROBIN",
          },
          enumDescriptions = {
            "",
            "An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests.",
            "This algorithm implements consistent hashing to backends. Maglev can be used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, see https://ai.google/research/pubs/pub44824",
            "Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer.",
            "The load balancer selects a random healthy host.",
            "The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests.",
            "This is a simple policy in which each healthy backend is selected in round robin order. This is the default.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    BackendServiceLogConfig = {
      description = "The available logging options for the load balancer traffic served by this backend service.",
      id = "BackendServiceLogConfig",
      properties = {
        enable = {
          description = "Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false.",
          type = "boolean",
        },
        sampleRate = {
          description = "This field can only be specified if logging is enabled for this backend service. The value of the field must be in [0, 1]. This configures the sampling rate of requests to the load balancer where 1.0 means all logged requests are reported and 0.0 means no logged requests are reported. The default value is 1.0.",
          format = "float",
          type = "number",
        },
      },
      type = "object",
    },
    BackendServiceReference = {
      id = "BackendServiceReference",
      properties = {
        backendService = {
          type = "string",
        },
      },
      type = "object",
    },
    BackendServicesScopedList = {
      id = "BackendServicesScopedList",
      properties = {
        backendServices = {
          description = "A list of BackendServices contained in this scope.",
          items = {
            ["$ref"] = "BackendService",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of backend services when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    BfdPacket = {
      id = "BfdPacket",
      properties = {
        authenticationPresent = {
          description = "The Authentication Present bit of the BFD packet. This is specified in section 4.1 of RFC5880",
          type = "boolean",
        },
        controlPlaneIndependent = {
          description = "The Control Plane Independent bit of the BFD packet. This is specified in section 4.1 of RFC5880",
          type = "boolean",
        },
        demand = {
          description = "The demand bit of the BFD packet. This is specified in section 4.1 of RFC5880",
          type = "boolean",
        },
        diagnostic = {
          description = "The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 of RFC5880",
          enum = {
            "ADMINISTRATIVELY_DOWN",
            "CONCATENATED_PATH_DOWN",
            "CONTROL_DETECTION_TIME_EXPIRED",
            "DIAGNOSTIC_UNSPECIFIED",
            "ECHO_FUNCTION_FAILED",
            "FORWARDING_PLANE_RESET",
            "NEIGHBOR_SIGNALED_SESSION_DOWN",
            "NO_DIAGNOSTIC",
            "PATH_DOWN",
            "REVERSE_CONCATENATED_PATH_DOWN",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        final = {
          description = "The Final bit of the BFD packet. This is specified in section 4.1 of RFC5880",
          type = "boolean",
        },
        length = {
          description = "The length of the BFD Control packet in bytes. This is specified in section 4.1 of RFC5880",
          format = "uint32",
          type = "integer",
        },
        minEchoRxIntervalMs = {
          description = "The Required Min Echo RX Interval value in the BFD packet. This is specified in section 4.1 of RFC5880",
          format = "uint32",
          type = "integer",
        },
        minRxIntervalMs = {
          description = "The Required Min RX Interval value in the BFD packet. This is specified in section 4.1 of RFC5880",
          format = "uint32",
          type = "integer",
        },
        minTxIntervalMs = {
          description = "The Desired Min TX Interval value in the BFD packet. This is specified in section 4.1 of RFC5880",
          format = "uint32",
          type = "integer",
        },
        multiplier = {
          description = "The detection time multiplier of the BFD packet. This is specified in section 4.1 of RFC5880",
          format = "uint32",
          type = "integer",
        },
        multipoint = {
          description = "The multipoint bit of the BFD packet. This is specified in section 4.1 of RFC5880",
          type = "boolean",
        },
        myDiscriminator = {
          description = "The My Discriminator value in the BFD packet. This is specified in section 4.1 of RFC5880",
          format = "uint32",
          type = "integer",
        },
        poll = {
          description = "The Poll bit of the BFD packet. This is specified in section 4.1 of RFC5880",
          type = "boolean",
        },
        state = {
          description = "The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 of RFC5880",
          enum = {
            "ADMIN_DOWN",
            "DOWN",
            "INIT",
            "STATE_UNSPECIFIED",
            "UP",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        version = {
          description = "The version number of the BFD protocol, as specified in section 4.1 of RFC5880.",
          format = "uint32",
          type = "integer",
        },
        yourDiscriminator = {
          description = "The Your Discriminator value in the BFD packet. This is specified in section 4.1 of RFC5880",
          format = "uint32",
          type = "integer",
        },
      },
      type = "object",
    },
    BfdStatus = {
      description = "Next free: 15",
      id = "BfdStatus",
      properties = {
        bfdSessionInitializationMode = {
          description = "The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer.",
          enum = {
            "ACTIVE",
            "DISABLED",
            "PASSIVE",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        configUpdateTimestampMicros = {
          description = "Unix timestamp of the most recent config update.",
          format = "int64",
          type = "string",
        },
        controlPacketCounts = {
          ["$ref"] = "BfdStatusPacketCounts",
          description = "Control packet counts for the current BFD session.",
        },
        controlPacketIntervals = {
          description = "Inter-packet time interval statistics for control packets.",
          items = {
            ["$ref"] = "PacketIntervals",
          },
          type = "array",
        },
        localDiagnostic = {
          description = "The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 of RFC5880",
          enum = {
            "ADMINISTRATIVELY_DOWN",
            "CONCATENATED_PATH_DOWN",
            "CONTROL_DETECTION_TIME_EXPIRED",
            "DIAGNOSTIC_UNSPECIFIED",
            "ECHO_FUNCTION_FAILED",
            "FORWARDING_PLANE_RESET",
            "NEIGHBOR_SIGNALED_SESSION_DOWN",
            "NO_DIAGNOSTIC",
            "PATH_DOWN",
            "REVERSE_CONCATENATED_PATH_DOWN",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        localState = {
          description = "The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 of RFC5880",
          enum = {
            "ADMIN_DOWN",
            "DOWN",
            "INIT",
            "STATE_UNSPECIFIED",
            "UP",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        negotiatedLocalControlTxIntervalMs = {
          description = "Negotiated transmit interval for control packets.",
          format = "uint32",
          type = "integer",
        },
        rxPacket = {
          ["$ref"] = "BfdPacket",
          description = "The most recent Rx control packet for this BFD session.",
        },
        txPacket = {
          ["$ref"] = "BfdPacket",
          description = "The most recent Tx control packet for this BFD session.",
        },
        uptimeMs = {
          description = "Session uptime in milliseconds. Value will be 0 if session is not up.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    BfdStatusPacketCounts = {
      id = "BfdStatusPacketCounts",
      properties = {
        numRx = {
          description = "Number of packets received since the beginning of the current BFD session.",
          format = "uint32",
          type = "integer",
        },
        numRxRejected = {
          description = "Number of packets received that were rejected because of errors since the beginning of the current BFD session.",
          format = "uint32",
          type = "integer",
        },
        numRxSuccessful = {
          description = "Number of packets received that were successfully processed since the beginning of the current BFD session.",
          format = "uint32",
          type = "integer",
        },
        numTx = {
          description = "Number of packets transmitted since the beginning of the current BFD session.",
          format = "uint32",
          type = "integer",
        },
      },
      type = "object",
    },
    Binding = {
      description = "Associates `members`, or principals, with a `role`.",
      id = "Binding",
      properties = {
        bindingId = {
          description = "This is deprecated and has no effect. Do not use.",
          type = "string",
        },
        condition = {
          ["$ref"] = "Expr",
          description = "The condition that is associated with this binding. If the condition evaluates to `true`, then this binding applies to the current request. If the condition evaluates to `false`, then this binding does not apply to the current request. However, a different role binding might grant the same role to one or more of the principals in this binding. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).",
        },
        members = {
          description = "Specifies the principals requesting access for a Google Cloud resource. `members` can have the following values: * `allUsers`: A special identifier that represents anyone who is on the internet; with or without a Google account. * `allAuthenticatedUsers`: A special identifier that represents anyone who is authenticated with a Google account or a service account. Does not include identities that come from external identity providers (IdPs) through identity federation. * `user:{emailid}`: An email address that represents a specific Google account. For example, `alice@example.com` . * `serviceAccount:{emailid}`: An email address that represents a Google service account. For example, `my-other-app@appspot.gserviceaccount.com`. * `serviceAccount:{projectid}.svc.id.goog[{namespace}/{kubernetes-sa}]`: An identifier for a [Kubernetes service account](https://cloud.google.com/kubernetes-engine/docs/how-to/kubernetes-service-accounts). For example, `my-project.svc.id.goog[my-namespace/my-kubernetes-sa]`. * `group:{emailid}`: An email address that represents a Google group. For example, `admins@example.com`. * `deleted:user:{emailid}?uid={uniqueid}`: An email address (plus unique identifier) representing a user that has been recently deleted. For example, `alice@example.com?uid=123456789012345678901`. If the user is recovered, this value reverts to `user:{emailid}` and the recovered user retains the role in the binding. * `deleted:serviceAccount:{emailid}?uid={uniqueid}`: An email address (plus unique identifier) representing a service account that has been recently deleted. For example, `my-other-app@appspot.gserviceaccount.com?uid=123456789012345678901`. If the service account is undeleted, this value reverts to `serviceAccount:{emailid}` and the undeleted service account retains the role in the binding. * `deleted:group:{emailid}?uid={uniqueid}`: An email address (plus unique identifier) representing a Google group that has been recently deleted. For example, `admins@example.com?uid=123456789012345678901`. If the group is recovered, this value reverts to `group:{emailid}` and the recovered group retains the role in the binding. * `domain:{domain}`: The G Suite domain (primary) that represents all the users of that domain. For example, `google.com` or `example.com`. ",
          items = {
            type = "string",
          },
          type = "array",
        },
        role = {
          description = "Role that is assigned to the list of `members`, or principals. For example, `roles/viewer`, `roles/editor`, or `roles/owner`.",
          type = "string",
        },
      },
      type = "object",
    },
    BulkInsertInstanceResource = {
      description = "A transient resource used in compute.instances.bulkInsert and compute.regionInstances.bulkInsert . This resource is not persisted anywhere, it is used only for processing the requests.",
      id = "BulkInsertInstanceResource",
      properties = {
        count = {
          description = "The maximum number of instances to create.",
          format = "int64",
          type = "string",
        },
        instanceProperties = {
          ["$ref"] = "InstanceProperties",
          description = "The instance properties defining the VM instances to be created. Required if sourceInstanceTemplate is not provided.",
        },
        locationPolicy = {
          ["$ref"] = "LocationPolicy",
          description = "Policy for chosing target zone. For more information, see Create VMs in bulk .",
        },
        minCount = {
          description = "The minimum number of instances to create. If no min_count is specified then count is used as the default value. If min_count instances cannot be created, then no instances will be created and instances already created will be deleted.",
          format = "int64",
          type = "string",
        },
        namePattern = {
          description = "The string pattern used for the names of the VMs. Either name_pattern or per_instance_properties must be set. The pattern must contain one continuous sequence of placeholder hash characters (#) with each character corresponding to one digit of the generated instance name. Example: a name_pattern of inst-#### generates instance names such as inst-0001 and inst-0002. If existing instances in the same project and zone have names that match the name pattern then the generated instance numbers start after the biggest existing number. For example, if there exists an instance with name inst-0050, then instance names generated using the pattern inst-#### begin with inst-0051. The name pattern placeholder #...# can contain up to 18 characters.",
          type = "string",
        },
        perInstanceProperties = {
          additionalProperties = {
            ["$ref"] = "BulkInsertInstanceResourcePerInstanceProperties",
          },
          description = "Per-instance properties to be set on individual instances. Keys of this map specify requested instance names. Can be empty if name_pattern is used.",
          type = "object",
        },
        sourceInstanceTemplate = {
          description = "Specifies the instance template from which to create instances. You may combine sourceInstanceTemplate with instanceProperties to override specific values from an existing instance template. Bulk API follows the semantics of JSON Merge Patch described by RFC 7396. It can be a full or partial URL. For example, the following are all valid URLs to an instance template: - https://www.googleapis.com/compute/v1/projects/project /global/instanceTemplates/instanceTemplate - projects/project/global/instanceTemplates/instanceTemplate - global/instanceTemplates/instanceTemplate This field is optional.",
          type = "string",
        },
      },
      type = "object",
    },
    BulkInsertInstanceResourcePerInstanceProperties = {
      description = "Per-instance properties to be set on individual instances. To be extended in the future.",
      id = "BulkInsertInstanceResourcePerInstanceProperties",
      properties = {
        name = {
          description = "This field is only temporary. It will be removed. Do not use it.",
          type = "string",
        },
      },
      type = "object",
    },
    CacheInvalidationRule = {
      id = "CacheInvalidationRule",
      properties = {
        host = {
          description = "If set, this invalidation rule will only apply to requests with a Host header matching host.",
          type = "string",
        },
        path = {
          type = "string",
        },
      },
      type = "object",
    },
    CacheKeyPolicy = {
      description = "Message containing what to include in the cache key for a request for Cloud CDN.",
      id = "CacheKeyPolicy",
      properties = {
        includeHost = {
          description = "If true, requests to different hosts will be cached separately.",
          type = "boolean",
        },
        includeHttpHeaders = {
          description = "Allows HTTP request headers (by name) to be used in the cache key.",
          items = {
            type = "string",
          },
          type = "array",
        },
        includeNamedCookies = {
          description = "Allows HTTP cookies (by name) to be used in the cache key. The name=value pair will be used in the cache key Cloud CDN generates.",
          items = {
            type = "string",
          },
          type = "array",
        },
        includeProtocol = {
          description = "If true, http and https requests will be cached separately.",
          type = "boolean",
        },
        includeQueryString = {
          description = "If true, include query string parameters in the cache key according to query_string_whitelist and query_string_blacklist. If neither is set, the entire query string will be included. If false, the query string will be excluded from the cache key entirely.",
          type = "boolean",
        },
        queryStringBlacklist = {
          description = "Names of query string parameters to exclude in cache keys. All other parameters will be included. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters.",
          items = {
            type = "string",
          },
          type = "array",
        },
        queryStringWhitelist = {
          description = "Names of query string parameters to include in cache keys. All other parameters will be excluded. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    CircuitBreakers = {
      description = "Settings controlling the volume of requests, connections and retries to this backend service.",
      id = "CircuitBreakers",
      properties = {
        maxConnections = {
          description = "The maximum number of connections to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          format = "int32",
          type = "integer",
        },
        maxPendingRequests = {
          description = "The maximum number of pending requests allowed to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          format = "int32",
          type = "integer",
        },
        maxRequests = {
          description = "The maximum number of parallel requests that allowed to the backend service. If not specified, there is no limit.",
          format = "int32",
          type = "integer",
        },
        maxRequestsPerConnection = {
          description = "Maximum requests for a single connection to the backend service. This parameter is respected by both the HTTP/1.1 and HTTP/2 implementations. If not specified, there is no limit. Setting this parameter to 1 will effectively disable keep alive. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          format = "int32",
          type = "integer",
        },
        maxRetries = {
          description = "The maximum number of parallel retries allowed to the backend cluster. If not specified, the default is 1. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    Commitment = {
      description = "Represents a regional Commitment resource. Creating a commitment resource means that you are purchasing a committed use contract with an explicit start and end time. You can create commitments based on vCPUs and memory usage and receive discounted rates. For full details, read Signing Up for Committed Use Discounts.",
      id = "Commitment",
      properties = {
        autoRenew = {
          description = "Specifies whether to enable automatic renewal for the commitment. The default value is false if not specified. The field can be updated until the day of the commitment expiration at 12:00am PST. If the field is set to true, the commitment will be automatically renewed for either one or three years according to the terms of the existing commitment.",
          type = "boolean",
        },
        category = {
          description = "The category of the commitment. Category MACHINE specifies commitments composed of machine resources such as VCPU or MEMORY, listed in resources. Category LICENSE specifies commitments composed of software licenses, listed in licenseResources. Note that only MACHINE commitments should have a Type specified.",
          enum = {
            "CATEGORY_UNSPECIFIED",
            "LICENSE",
            "MACHINE",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        endTimestamp = {
          description = "[Output Only] Commitment end time in RFC3339 text format.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#commitment",
          description = "[Output Only] Type of the resource. Always compute#commitment for commitments.",
          type = "string",
        },
        licenseResource = {
          ["$ref"] = "LicenseResourceCommitment",
          description = "The license specification required as part of a license commitment.",
        },
        mergeSourceCommitments = {
          description = "List of source commitments to be merged into a new commitment.",
          items = {
            type = "string",
          },
          type = "array",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        plan = {
          description = "The plan for this commitment, which determines duration and discount rate. The currently supported plans are TWELVE_MONTH (1 year), and THIRTY_SIX_MONTH (3 years).",
          enum = {
            "INVALID",
            "THIRTY_SIX_MONTH",
            "TWELVE_MONTH",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where this commitment may be used.",
          type = "string",
        },
        reservations = {
          description = "List of reservations in this commitment.",
          items = {
            ["$ref"] = "Reservation",
          },
          type = "array",
        },
        resources = {
          description = "A list of commitment amounts for particular resources. Note that VCPU and MEMORY resource commitments must occur together.",
          items = {
            ["$ref"] = "ResourceCommitment",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        splitSourceCommitment = {
          description = "Source commitment to be splitted into a new commitment.",
          type = "string",
        },
        startTimestamp = {
          description = "[Output Only] Commitment start time in RFC3339 text format.",
          type = "string",
        },
        status = {
          description = "[Output Only] Status of the commitment with regards to eventual expiration (each commitment has an end date defined). One of the following values: NOT_YET_ACTIVE, ACTIVE, EXPIRED.",
          enum = {
            "ACTIVE",
            "CANCELLED",
            "CREATING",
            "EXPIRED",
            "NOT_YET_ACTIVE",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        statusMessage = {
          description = "[Output Only] An optional, human-readable explanation of the status.",
          type = "string",
        },
        type = {
          description = "The type of commitment, which affects the discount rate and the eligible resources. Type MEMORY_OPTIMIZED specifies a commitment that will only apply to memory optimized machines. Type ACCELERATOR_OPTIMIZED specifies a commitment that will only apply to accelerator optimized machines.",
          enum = {
            "ACCELERATOR_OPTIMIZED",
            "COMPUTE_OPTIMIZED",
            "COMPUTE_OPTIMIZED_C2D",
            "GENERAL_PURPOSE",
            "GENERAL_PURPOSE_E2",
            "GENERAL_PURPOSE_N2",
            "GENERAL_PURPOSE_N2D",
            "GENERAL_PURPOSE_T2D",
            "MEMORY_OPTIMIZED",
            "MEMORY_OPTIMIZED_M3",
            "TYPE_UNSPECIFIED",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    CommitmentAggregatedList = {
      id = "CommitmentAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "CommitmentsScopedList",
            description = "[Output Only] Name of the scope containing this set of commitments.",
          },
          description = "A list of CommitmentsScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#commitmentAggregatedList",
          description = "[Output Only] Type of resource. Always compute#commitmentAggregatedList for aggregated lists of commitments.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    CommitmentList = {
      description = "Contains a list of Commitment resources.",
      id = "CommitmentList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Commitment resources.",
          items = {
            ["$ref"] = "Commitment",
          },
          type = "array",
        },
        kind = {
          default = "compute#commitmentList",
          description = "[Output Only] Type of resource. Always compute#commitmentList for lists of commitments.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    CommitmentsScopedList = {
      id = "CommitmentsScopedList",
      properties = {
        commitments = {
          description = "[Output Only] A list of commitments contained in this scope.",
          items = {
            ["$ref"] = "Commitment",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of commitments when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    Condition = {
      description = "This is deprecated and has no effect. Do not use.",
      id = "Condition",
      properties = {
        iam = {
          description = "This is deprecated and has no effect. Do not use.",
          enum = {
            "APPROVER",
            "ATTRIBUTION",
            "AUTHORITY",
            "CREDENTIALS_TYPE",
            "CREDS_ASSERTION",
            "JUSTIFICATION_TYPE",
            "NO_ATTR",
            "SECURITY_REALM",
          },
          enumDescriptions = {
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
          },
          type = "string",
        },
        op = {
          description = "This is deprecated and has no effect. Do not use.",
          enum = {
            "DISCHARGED",
            "EQUALS",
            "IN",
            "NOT_EQUALS",
            "NOT_IN",
            "NO_OP",
          },
          enumDescriptions = {
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
          },
          type = "string",
        },
        svc = {
          description = "This is deprecated and has no effect. Do not use.",
          type = "string",
        },
        sys = {
          description = "This is deprecated and has no effect. Do not use.",
          enum = {
            "IP",
            "NAME",
            "NO_ATTR",
            "REGION",
            "SERVICE",
          },
          enumDescriptions = {
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
          },
          type = "string",
        },
        values = {
          description = "This is deprecated and has no effect. Do not use.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ConfidentialInstanceConfig = {
      description = "A set of Confidential Instance options.",
      id = "ConfidentialInstanceConfig",
      properties = {
        enableConfidentialCompute = {
          description = "Defines whether the instance should have confidential compute enabled.",
          type = "boolean",
        },
      },
      type = "object",
    },
    ConnectionDraining = {
      description = "Message containing connection draining configuration.",
      id = "ConnectionDraining",
      properties = {
        drainingTimeoutSec = {
          description = "Configures a duration timeout for existing requests on a removed backend instance. For supported load balancers and protocols, as described in Enabling connection draining.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    ConsistentHashLoadBalancerSettings = {
      description = "This message defines settings for a consistent hash style load balancer.",
      id = "ConsistentHashLoadBalancerSettings",
      properties = {
        httpCookie = {
          ["$ref"] = "ConsistentHashLoadBalancerSettingsHttpCookie",
          description = "Hash is based on HTTP Cookie. This field describes a HTTP cookie that will be used as the hash key for the consistent hash load balancer. If the cookie is not present, it will be generated. This field is applicable if the sessionAffinity is set to HTTP_COOKIE. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
        },
        httpHeaderName = {
          description = "The hash based on the value of the specified header field. This field is applicable if the sessionAffinity is set to HEADER_FIELD.",
          type = "string",
        },
        minimumRingSize = {
          description = "The minimum number of virtual nodes to use for the hash ring. Defaults to 1024. Larger ring sizes result in more granular load distributions. If the number of hosts in the load balancing pool is larger than the ring size, each host will be assigned a single virtual node.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    ConsistentHashLoadBalancerSettingsHttpCookie = {
      description = "The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.",
      id = "ConsistentHashLoadBalancerSettingsHttpCookie",
      properties = {
        name = {
          description = "Name of the cookie.",
          type = "string",
        },
        path = {
          description = "Path to set for the cookie.",
          type = "string",
        },
        ttl = {
          ["$ref"] = "Duration",
          description = "Lifetime of the cookie.",
        },
      },
      type = "object",
    },
    CorsPolicy = {
      description = "The specification for allowing client-side cross-origin requests. For more information about the W3C recommendation for cross-origin resource sharing (CORS), see Fetch API Living Standard.",
      id = "CorsPolicy",
      properties = {
        allowCredentials = {
          description = "In response to a preflight request, setting this to true indicates that the actual request can include user credentials. This field translates to the Access-Control-Allow-Credentials header. Default is false.",
          type = "boolean",
        },
        allowHeaders = {
          description = "Specifies the content for the Access-Control-Allow-Headers header.",
          items = {
            type = "string",
          },
          type = "array",
        },
        allowMethods = {
          description = "Specifies the content for the Access-Control-Allow-Methods header.",
          items = {
            type = "string",
          },
          type = "array",
        },
        allowOriginRegexes = {
          description = "Specifies a regular expression that matches allowed origins. For more information about the regular expression syntax, see Syntax. An origin is allowed if it matches either an item in allowOrigins or an item in allowOriginRegexes. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED.",
          items = {
            type = "string",
          },
          type = "array",
        },
        allowOrigins = {
          description = "Specifies the list of origins that is allowed to do CORS requests. An origin is allowed if it matches either an item in allowOrigins or an item in allowOriginRegexes.",
          items = {
            type = "string",
          },
          type = "array",
        },
        disabled = {
          description = "If true, the setting specifies the CORS policy is disabled. The default value of false, which indicates that the CORS policy is in effect.",
          type = "boolean",
        },
        exposeHeaders = {
          description = "Specifies the content for the Access-Control-Expose-Headers header.",
          items = {
            type = "string",
          },
          type = "array",
        },
        maxAge = {
          description = "Specifies how long results of a preflight request can be cached in seconds. This field translates to the Access-Control-Max-Age header.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    CustomerEncryptionKey = {
      id = "CustomerEncryptionKey",
      properties = {
        kmsKeyName = {
          description = "The name of the encryption key that is stored in Google Cloud KMS. For example: \"kmsKeyName\": \"projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key ",
          type = "string",
        },
        kmsKeyServiceAccount = {
          description = "The service account being used for the encryption request for the given KMS key. If absent, the Compute Engine default service account is used. For example: \"kmsKeyServiceAccount\": \"name@project_id.iam.gserviceaccount.com/ ",
          type = "string",
        },
        rawKey = {
          description = "Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey. For example: \"rawKey\": \"SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0=\" ",
          type = "string",
        },
        rsaEncryptedKey = {
          description = "Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey. For example: \"rsaEncryptedKey\": \"ieCx/NcW06PcT7Ep1X6LUTc/hLvUDYyzSZPPVCVPTVEohpeHASqC8uw5TzyO9U+Fka9JFH z0mBibXUInrC/jEk014kCK/NPjYgEMOyssZ4ZINPKxlUh2zn1bV+MCaTICrdmuSBTWlUUiFoD D6PYznLwh8ZNdaheCeZ8ewEXgFQ8V+sDroLaN3Xs3MDTXQEMMoNUXMCZEIpg9Vtp9x2oe==\" The key must meet the following requirements before you can provide it to Compute Engine: 1. The key is wrapped using a RSA public key certificate provided by Google. 2. After being wrapped, the key must be encoded in RFC 4648 base64 encoding. Gets the RSA public key certificate provided by Google at: https://cloud-certs.storage.googleapis.com/google-cloud-csek-ingress.pem ",
          type = "string",
        },
        sha256 = {
          description = "[Output only] The RFC 4648 base64 encoded SHA-256 hash of the customer-supplied encryption key that protects this resource.",
          type = "string",
        },
      },
      type = "object",
    },
    CustomerEncryptionKeyProtectedDisk = {
      id = "CustomerEncryptionKeyProtectedDisk",
      properties = {
        diskEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "Decrypts data associated with the disk with a customer-supplied encryption key.",
        },
        source = {
          description = "Specifies a valid partial or full URL to an existing Persistent Disk resource. This field is only applicable for persistent disks. For example: \"source\": \"/compute/v1/projects/project_id/zones/zone/disks/ disk_name ",
          type = "string",
        },
      },
      type = "object",
    },
    DeprecationStatus = {
      description = "Deprecation status for a public resource.",
      id = "DeprecationStatus",
      properties = {
        deleted = {
          description = "An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED. This is only informational and the status will not change unless the client explicitly changes it.",
          type = "string",
        },
        deprecated = {
          description = "An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED. This is only informational and the status will not change unless the client explicitly changes it.",
          type = "string",
        },
        obsolete = {
          description = "An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE. This is only informational and the status will not change unless the client explicitly changes it.",
          type = "string",
        },
        replacement = {
          description = "The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource.",
          type = "string",
        },
        state = {
          description = "The deprecation state of this resource. This can be ACTIVE, DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can use ACTIVE. Operations which create a new resource using a DEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE or DELETED resources will be rejected and result in an error.",
          enum = {
            "ACTIVE",
            "DELETED",
            "DEPRECATED",
            "OBSOLETE",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Disk = {
      description = "Represents a Persistent Disk resource. Google Compute Engine has two Disk resources: * [Zonal](/compute/docs/reference/rest/v1/disks) * [Regional](/compute/docs/reference/rest/v1/regionDisks) Persistent disks are required for running your VM instances. Create both boot and non-boot (data) persistent disks. For more information, read Persistent Disks. For more storage options, read Storage options. The disks resource represents a zonal persistent disk. For more information, read Zonal persistent disks. The regionDisks resource represents a regional persistent disk. For more information, read Regional resources.",
      id = "Disk",
      properties = {
        architecture = {
          description = "The architecture of the disk. Valid values are ARM64 or X86_64.",
          enum = {
            "ARCHITECTURE_UNSPECIFIED",
            "ARM64",
            "X86_64",
          },
          enumDescriptions = {
            "Default value indicating Architecture is not set.",
            "Machines with architecture ARM64",
            "Machines with architecture X86_64",
          },
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        diskEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "Encrypts the disk using a customer-supplied encryption key or a customer-managed encryption key. Encryption keys do not protect access to metadata of the disk. After you encrypt a disk with a customer-supplied key, you must provide the same key if you use the disk later. For example, to create a disk snapshot, to create a disk image, to create a machine image, or to attach the disk to a virtual machine. After you encrypt a disk with a customer-managed key, the diskEncryptionKey.kmsKeyName is set to a key *version* name once the disk is created. The disk is encrypted with this version of the key. In the response, diskEncryptionKey.kmsKeyName appears in the following format: \"diskEncryptionKey.kmsKeyName\": \"projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key /cryptoKeysVersions/version If you do not provide an encryption key when creating the disk, then the disk is encrypted using an automatically generated key and you don't need to provide a key to use the disk later.",
        },
        guestOsFeatures = {
          description = "A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.",
          items = {
            ["$ref"] = "GuestOsFeature",
          },
          type = "array",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#disk",
          description = "[Output Only] Type of the resource. Always compute#disk for disks.",
          type = "string",
        },
        labelFingerprint = {
          description = "A fingerprint for the labels being applied to this disk, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a disk.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels to apply to this disk. These can be later modified by the setLabels method.",
          type = "object",
        },
        lastAttachTimestamp = {
          description = "[Output Only] Last attach timestamp in RFC3339 text format.",
          type = "string",
        },
        lastDetachTimestamp = {
          description = "[Output Only] Last detach timestamp in RFC3339 text format.",
          type = "string",
        },
        licenseCodes = {
          description = "Integer license codes indicating which licenses are attached to this disk.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        licenses = {
          description = "A list of publicly visible licenses. Reserved for Google's use.",
          items = {
            type = "string",
          },
          type = "array",
        },
        locationHint = {
          description = "An opaque location hint used to place the disk close to other resources. This field is for use by internal tools that use the public API.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.disks.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        options = {
          description = "Internal use only.",
          type = "string",
        },
        params = {
          ["$ref"] = "DiskParams",
          description = "Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.",
        },
        physicalBlockSizeBytes = {
          description = "Physical block size of the persistent disk, in bytes. If not present in a request, a default value is used. The currently supported size is 4096, other sizes may be added in the future. If an unsupported value is requested, the error message will list the supported values for the caller's project.",
          format = "int64",
          type = "string",
        },
        provisionedIops = {
          description = "Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see the Extreme persistent disk documentation.",
          format = "int64",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the disk resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        replicaZones = {
          description = "URLs of the zones where the disk should be replicated to. Only applicable for regional resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        resourcePolicies = {
          description = "Resource policies applied to this disk for automatic snapshot creations.",
          items = {
            type = "string",
          },
          type = "array",
        },
        satisfiesPzs = {
          description = "[Output Only] Reserved for future use.",
          type = "boolean",
        },
        selfLink = {
          description = "[Output Only] Server-defined fully-qualified URL for this resource.",
          type = "string",
        },
        sizeGb = {
          description = "Size, in GB, of the persistent disk. You can specify this field when creating a persistent disk using the sourceImage, sourceSnapshot, or sourceDisk parameter, or specify it alone to create an empty persistent disk. If you specify this field along with a source, the value of sizeGb must not be less than the size of the source. Acceptable values are 1 to 65536, inclusive.",
          format = "int64",
          type = "string",
        },
        sourceDisk = {
          description = "The source disk used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - https://www.googleapis.com/compute/v1/projects/project/regions/region /disks/disk - projects/project/zones/zone/disks/disk - projects/project/regions/region/disks/disk - zones/zone/disks/disk - regions/region/disks/disk ",
          type = "string",
        },
        sourceDiskId = {
          description = "[Output Only] The unique ID of the disk used to create this disk. This value identifies the exact disk that was used to create this persistent disk. For example, if you created the persistent disk from a disk that was later deleted and recreated under the same name, the source disk ID would identify the exact version of the disk that was used.",
          type = "string",
        },
        sourceImage = {
          description = "The source image used to create this disk. If the source image is deleted, this field will not be set. To create a disk with one of the public operating system images, specify the image by its family name. For example, specify family/debian-9 to use the latest Debian 9 image: projects/debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my-custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family ",
          type = "string",
        },
        sourceImageEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key.",
        },
        sourceImageId = {
          description = "[Output Only] The ID value of the image used to create this disk. This value identifies the exact image that was used to create this persistent disk. For example, if you created the persistent disk from an image that was later deleted and recreated under the same name, the source image ID would identify the exact version of the image that was used.",
          type = "string",
        },
        sourceSnapshot = {
          description = "The source snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project /global/snapshots/snapshot - projects/project/global/snapshots/snapshot - global/snapshots/snapshot ",
          type = "string",
        },
        sourceSnapshotEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The customer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key.",
        },
        sourceSnapshotId = {
          description = "[Output Only] The unique ID of the snapshot used to create this disk. This value identifies the exact snapshot that was used to create this persistent disk. For example, if you created the persistent disk from a snapshot that was later deleted and recreated under the same name, the source snapshot ID would identify the exact version of the snapshot that was used.",
          type = "string",
        },
        sourceStorageObject = {
          description = "The full Google Cloud Storage URI where the disk image is stored. This file must be a gzip-compressed tarball whose name ends in .tar.gz or virtual machine disk whose name ends in vmdk. Valid URIs may start with gs:// or https://storage.googleapis.com/. This flag is not optimized for creating multiple disks from a source storage object. To create many disks from a source storage object, use gcloud compute images import instead.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of disk creation. - CREATING: Disk is provisioning. - RESTORING: Source data is being copied into the disk. - FAILED: Disk creation failed. - READY: Disk is ready for use. - DELETING: Disk is deleting. ",
          enum = {
            "CREATING",
            "DELETING",
            "FAILED",
            "READY",
            "RESTORING",
          },
          enumDescriptions = {
            "Disk is provisioning",
            "Disk is deleting.",
            "Disk creation failed.",
            "Disk is ready for use.",
            "Source data is being copied into the disk.",
          },
          type = "string",
        },
        type = {
          description = "URL of the disk type resource describing which disk type to use to create the disk. Provide this when creating the disk. For example: projects/project /zones/zone/diskTypes/pd-ssd . See Persistent disk types.",
          type = "string",
        },
        users = {
          description = "[Output Only] Links to the users of the disk (attached instances) in form: projects/project/zones/zone/instances/instance",
          items = {
            type = "string",
          },
          type = "array",
        },
        zone = {
          description = "[Output Only] URL of the zone where the disk resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
      },
      type = "object",
    },
    DiskAggregatedList = {
      id = "DiskAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "DisksScopedList",
            description = "[Output Only] Name of the scope containing this set of disks.",
          },
          description = "A list of DisksScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#diskAggregatedList",
          description = "[Output Only] Type of resource. Always compute#diskAggregatedList for aggregated lists of persistent disks.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    DiskInstantiationConfig = {
      description = "A specification of the desired way to instantiate a disk in the instance template when its created from a source instance.",
      id = "DiskInstantiationConfig",
      properties = {
        autoDelete = {
          description = "Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).",
          type = "boolean",
        },
        customImage = {
          description = "The custom source image to be used to restore this disk when instantiating this instance template.",
          type = "string",
        },
        deviceName = {
          description = "Specifies the device name of the disk to which the configurations apply to.",
          type = "string",
        },
        instantiateFrom = {
          description = "Specifies whether to include the disk and what image to use. Possible values are: - source-image: to use the same image that was used to create the source instance's corresponding disk. Applicable to the boot disk and additional read-write disks. - source-image-family: to use the same image family that was used to create the source instance's corresponding disk. Applicable to the boot disk and additional read-write disks. - custom-image: to use a user-provided image url for disk creation. Applicable to the boot disk and additional read-write disks. - attach-read-only: to attach a read-only disk. Applicable to read-only disks. - do-not-include: to exclude a disk from the template. Applicable to additional read-write disks, local SSDs, and read-only disks. ",
          enum = {
            "ATTACH_READ_ONLY",
            "BLANK",
            "CUSTOM_IMAGE",
            "DEFAULT",
            "DO_NOT_INCLUDE",
            "SOURCE_IMAGE",
            "SOURCE_IMAGE_FAMILY",
          },
          enumDescriptions = {
            "Attach the existing disk in read-only mode. The request will fail if the disk was attached in read-write mode on the source instance. Applicable to: read-only disks.",
            "Create a blank disk. The disk will be created unformatted. Applicable to: additional read-write disks, local SSDs.",
            "Use the custom image specified in the custom_image field. Applicable to: boot disk, additional read-write disks.",
            "Use the default instantiation option for the corresponding type of disk. For boot disk and any other R/W disks, new custom images will be created from each disk. For read-only disks, they will be attached in read-only mode. Local SSD disks will be created as blank volumes.",
            "Do not include the disk in the instance template. Applicable to: additional read-write disks, local SSDs, read-only disks.",
            "Use the same source image used for creation of the source instance's corresponding disk. The request will fail if the source VM's disk was created from a snapshot. Applicable to: boot disk, additional read-write disks.",
            "Use the same source image family used for creation of the source instance's corresponding disk. The request will fail if the source image of the source disk does not belong to any image family. Applicable to: boot disk, additional read-write disks.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    DiskList = {
      description = "A list of Disk resources.",
      id = "DiskList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Disk resources.",
          items = {
            ["$ref"] = "Disk",
          },
          type = "array",
        },
        kind = {
          default = "compute#diskList",
          description = "[Output Only] Type of resource. Always compute#diskList for lists of disks.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    DiskMoveRequest = {
      id = "DiskMoveRequest",
      properties = {
        destinationZone = {
          description = "The URL of the destination zone to move the disk. This can be a full or partial URL. For example, the following are all valid URLs to a zone: - https://www.googleapis.com/compute/v1/projects/project/zones/zone - projects/project/zones/zone - zones/zone ",
          type = "string",
        },
        targetDisk = {
          description = "The URL of the target disk to move. This can be a full or partial URL. For example, the following are all valid URLs to a disk: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/disks/disk ",
          type = "string",
        },
      },
      type = "object",
    },
    DiskParams = {
      description = "Additional disk params.",
      id = "DiskParams",
      properties = {
        resourceManagerTags = {
          additionalProperties = {
            type = "string",
          },
          description = "Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys must be in the format `tagKeys/{tag_key_id}`, and values are in the format `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.",
          type = "object",
        },
      },
      type = "object",
    },
    DiskType = {
      description = "Represents a Disk Type resource. Google Compute Engine has two Disk Type resources: * [Regional](/compute/docs/reference/rest/v1/regionDiskTypes) * [Zonal](/compute/docs/reference/rest/v1/diskTypes) You can choose from a variety of disk types based on your needs. For more information, read Storage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, read Zonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.",
      id = "DiskType",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        defaultDiskSizeGb = {
          description = "[Output Only] Server-defined default disk size in GB.",
          format = "int64",
          type = "string",
        },
        deprecated = {
          ["$ref"] = "DeprecationStatus",
          description = "[Output Only] The deprecation status associated with this disk type.",
        },
        description = {
          description = "[Output Only] An optional description of this resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#diskType",
          description = "[Output Only] Type of the resource. Always compute#diskType for disk types.",
          type = "string",
        },
        name = {
          description = "[Output Only] Name of the resource.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the disk type resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        validDiskSize = {
          description = "[Output Only] An optional textual description of the valid disk size, such as \"10GB-10TB\".",
          type = "string",
        },
        zone = {
          description = "[Output Only] URL of the zone where the disk type resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
      },
      type = "object",
    },
    DiskTypeAggregatedList = {
      id = "DiskTypeAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "DiskTypesScopedList",
            description = "[Output Only] Name of the scope containing this set of disk types.",
          },
          description = "A list of DiskTypesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#diskTypeAggregatedList",
          description = "[Output Only] Type of resource. Always compute#diskTypeAggregatedList.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    DiskTypeList = {
      description = "Contains a list of disk types.",
      id = "DiskTypeList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of DiskType resources.",
          items = {
            ["$ref"] = "DiskType",
          },
          type = "array",
        },
        kind = {
          default = "compute#diskTypeList",
          description = "[Output Only] Type of resource. Always compute#diskTypeList for disk types.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    DiskTypesScopedList = {
      id = "DiskTypesScopedList",
      properties = {
        diskTypes = {
          description = "[Output Only] A list of disk types contained in this scope.",
          items = {
            ["$ref"] = "DiskType",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of disk types when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    DisksAddResourcePoliciesRequest = {
      id = "DisksAddResourcePoliciesRequest",
      properties = {
        resourcePolicies = {
          description = "Full or relative path to the resource policy to be added to this disk. You can only specify one resource policy.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    DisksRemoveResourcePoliciesRequest = {
      id = "DisksRemoveResourcePoliciesRequest",
      properties = {
        resourcePolicies = {
          description = "Resource policies to be removed from this disk.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    DisksResizeRequest = {
      id = "DisksResizeRequest",
      properties = {
        sizeGb = {
          description = "The new size of the persistent disk, which is specified in GB.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    DisksScopedList = {
      id = "DisksScopedList",
      properties = {
        disks = {
          description = "[Output Only] A list of disks contained in this scope.",
          items = {
            ["$ref"] = "Disk",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of disks when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    DisplayDevice = {
      description = "A set of Display Device options",
      id = "DisplayDevice",
      properties = {
        enableDisplay = {
          description = "Defines whether the instance has Display enabled.",
          type = "boolean",
        },
      },
      type = "object",
    },
    DistributionPolicy = {
      id = "DistributionPolicy",
      properties = {
        targetShape = {
          description = "The distribution shape to which the group converges either proactively or on resize events (depending on the value set in updatePolicy.instanceRedistributionType).",
          enum = {
            "ANY",
            "BALANCED",
            "EVEN",
          },
          enumDescriptions = {
            "The group picks zones for creating VM instances to fulfill the requested number of VMs within present resource constraints and to maximize utilization of unused zonal reservations. Recommended for batch workloads that do not require high availability.",
            "The group prioritizes acquisition of resources, scheduling VMs in zones where resources are available while distributing VMs as evenly as possible across selected zones to minimize the impact of zonal failure. Recommended for highly available serving workloads.",
            "The group schedules VM instance creation and deletion to achieve and maintain an even number of managed instances across the selected zones. The distribution is even when the number of managed instances does not differ by more than 1 between any two zones. Recommended for highly available serving workloads.",
          },
          type = "string",
        },
        zones = {
          description = "Zones where the regional managed instance group will create and manage its instances.",
          items = {
            ["$ref"] = "DistributionPolicyZoneConfiguration",
          },
          type = "array",
        },
      },
      type = "object",
    },
    DistributionPolicyZoneConfiguration = {
      id = "DistributionPolicyZoneConfiguration",
      properties = {
        zone = {
          annotations = {
            required = {
              "compute.regionInstanceGroupManagers.insert",
            },
          },
          description = "The URL of the zone. The zone must exist in the region where the managed instance group is located.",
          type = "string",
        },
      },
      type = "object",
    },
    Duration = {
      description = "A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like \"day\" or \"month\". Range is approximately 10,000 years.",
      id = "Duration",
      properties = {
        nanos = {
          description = "Span of time that's a fraction of a second at nanosecond resolution. Durations less than one second are represented with a 0 `seconds` field and a positive `nanos` field. Must be from 0 to 999,999,999 inclusive.",
          format = "int32",
          type = "integer",
        },
        seconds = {
          description = "Span of time at a resolution of a second. Must be from 0 to 315,576,000,000 inclusive. Note: these bounds are computed from: 60 sec/min * 60 min/hr * 24 hr/day * 365.25 days/year * 10000 years",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    ErrorInfo = {
      description = "Describes the cause of the error with structured details. Example of an error when contacting the \"pubsub.googleapis.com\" API when it is not enabled: { \"reason\": \"API_DISABLED\" \"domain\": \"googleapis.com\" \"metadata\": { \"resource\": \"projects/123\", \"service\": \"pubsub.googleapis.com\" } } This response indicates that the pubsub.googleapis.com API is not enabled. Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock: { \"reason\": \"STOCKOUT\" \"domain\": \"spanner.googleapis.com\", \"metadata\": { \"availableRegions\": \"us-central1,us-east2\" } }",
      id = "ErrorInfo",
      properties = {
        domain = {
          description = "The logical grouping to which the \"reason\" belongs. The error domain is typically the registered service name of the tool or product that generates the error. Example: \"pubsub.googleapis.com\". If the error is generated by some common infrastructure, the error domain must be a globally unique value that identifies the infrastructure. For Google API infrastructure, the error domain is \"googleapis.com\".",
          type = "string",
        },
        metadatas = {
          additionalProperties = {
            type = "string",
          },
          description = "Additional structured details about this error. Keys should match /[a-zA-Z0-9-_]/ and be limited to 64 characters in length. When identifying the current value of an exceeded limit, the units should be contained in the key, not the value. For example, rather than {\"instanceLimit\": \"100/request\"}, should be returned as, {\"instanceLimitPerRequest\": \"100\"}, if the client exceeds the number of instances that can be created in a single (batch) request.",
          type = "object",
        },
        reason = {
          description = "The reason of the error. This is a constant value that identifies the proximate cause of the error. Error reasons are unique within a particular domain of errors. This should be at most 63 characters and match a regular expression of `A-Z+[A-Z0-9]`, which represents UPPER_SNAKE_CASE.",
          type = "string",
        },
      },
      type = "object",
    },
    ExchangedPeeringRoute = {
      id = "ExchangedPeeringRoute",
      properties = {
        destRange = {
          description = "The destination range of the route.",
          type = "string",
        },
        imported = {
          description = "True if the peering route has been imported from a peer. The actual import happens if the field networkPeering.importCustomRoutes is true for this network, and networkPeering.exportCustomRoutes is true for the peer network, and the import does not result in a route conflict.",
          type = "boolean",
        },
        nextHopRegion = {
          description = "The region of peering route next hop, only applies to dynamic routes.",
          type = "string",
        },
        priority = {
          description = "The priority of the peering route.",
          format = "uint32",
          type = "integer",
        },
        type = {
          description = "The type of the peering route.",
          enum = {
            "DYNAMIC_PEERING_ROUTE",
            "STATIC_PEERING_ROUTE",
            "SUBNET_PEERING_ROUTE",
          },
          enumDescriptions = {
            "For routes exported from local network.",
            "The peering route.",
            "The peering route corresponding to subnetwork range.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ExchangedPeeringRoutesList = {
      id = "ExchangedPeeringRoutesList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of ExchangedPeeringRoute resources.",
          items = {
            ["$ref"] = "ExchangedPeeringRoute",
          },
          type = "array",
        },
        kind = {
          default = "compute#exchangedPeeringRoutesList",
          description = "[Output Only] Type of resource. Always compute#exchangedPeeringRoutesList for exchanged peering routes lists.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    Expr = {
      description = "Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: \"Summary size limit\" description: \"Determines if a summary is less than 100 chars\" expression: \"document.summary.size() < 100\" Example (Equality): title: \"Requestor is owner\" description: \"Determines if requestor is the document owner\" expression: \"document.owner == request.auth.claims.email\" Example (Logic): title: \"Public documents\" description: \"Determine whether the document should be publicly visible\" expression: \"document.type != 'private' && document.type != 'internal'\" Example (Data Manipulation): title: \"Notification string\" description: \"Create a notification string with a timestamp.\" expression: \"'New message received at ' + string(document.create_time)\" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.",
      id = "Expr",
      properties = {
        description = {
          description = "Optional. Description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI.",
          type = "string",
        },
        expression = {
          description = "Textual representation of an expression in Common Expression Language syntax.",
          type = "string",
        },
        location = {
          description = "Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file.",
          type = "string",
        },
        title = {
          description = "Optional. Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.",
          type = "string",
        },
      },
      type = "object",
    },
    ExternalVpnGateway = {
      description = "Represents an external VPN gateway. External VPN gateway is the on-premises VPN gateway(s) or another cloud provider's VPN gateway that connects to your Google Cloud VPN gateway. To create a highly available VPN from Google Cloud Platform to your VPN gateway or another cloud provider's VPN gateway, you must create a external VPN gateway resource with information about the other gateway. For more information about using external VPN gateways, see Creating an HA VPN gateway and tunnel pair to a peer VPN.",
      id = "ExternalVpnGateway",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        interfaces = {
          description = "A list of interfaces for this external VPN gateway. If your peer-side gateway is an on-premises gateway and non-AWS cloud providers' gateway, at most two interfaces can be provided for an external VPN gateway. If your peer side is an AWS virtual private gateway, four interfaces should be provided for an external VPN gateway.",
          items = {
            ["$ref"] = "ExternalVpnGatewayInterface",
          },
          type = "array",
        },
        kind = {
          default = "compute#externalVpnGateway",
          description = "[Output Only] Type of the resource. Always compute#externalVpnGateway for externalVpnGateways.",
          type = "string",
        },
        labelFingerprint = {
          description = "A fingerprint for the labels being applied to this ExternalVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an ExternalVpnGateway.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.",
          type = "object",
        },
        name = {
          annotations = {
            required = {
              "compute.externalVpnGateways.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        redundancyType = {
          description = "Indicates the user-supplied redundancy type of this external VPN gateway.",
          enum = {
            "FOUR_IPS_REDUNDANCY",
            "SINGLE_IP_INTERNALLY_REDUNDANT",
            "TWO_IPS_REDUNDANCY",
          },
          enumDescriptions = {
            "The external VPN gateway has four public IP addresses; at the time of writing this API, the AWS virtual private gateway is an example which has four public IP addresses for high availability connections; there should be two VPN connections in the AWS virtual private gateway , each AWS VPN connection has two public IP addresses; please make sure to put two public IP addresses from one AWS VPN connection into interfaces 0 and 1 of this external VPN gateway, and put the other two public IP addresses from another AWS VPN connection into interfaces 2 and 3 of this external VPN gateway. When displaying highly available configuration status for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN gateway, Google will always detect whether interfaces 0 and 1 are connected on one interface of HA Cloud VPN gateway, and detect whether interfaces 2 and 3 are connected to another interface of the HA Cloud VPN gateway.",
            "The external VPN gateway has only one public IP address which internally provide redundancy or failover.",
            "The external VPN gateway has two public IP addresses which are redundant with each other, the following two types of setup on your on-premises side would have this type of redundancy: (1) Two separate on-premises gateways, each with one public IP address, the two on-premises gateways are redundant with each other. (2) A single on-premise gateway with two public IP addresses that are redundant with eatch other.",
          },
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
      },
      type = "object",
    },
    ExternalVpnGatewayInterface = {
      description = "The interface for the external VPN gateway.",
      id = "ExternalVpnGatewayInterface",
      properties = {
        id = {
          description = "The numeric ID of this interface. The allowed input values for this id for different redundancy types of external VPN gateway: - SINGLE_IP_INTERNALLY_REDUNDANT - 0 - TWO_IPS_REDUNDANCY - 0, 1 - FOUR_IPS_REDUNDANCY - 0, 1, 2, 3 ",
          format = "uint32",
          type = "integer",
        },
        ipAddress = {
          description = "IP address of the interface in the external VPN gateway. Only IPv4 is supported. This IP address can be either from your on-premise gateway or another Cloud provider's VPN gateway, it cannot be an IP address from Google Compute Engine.",
          type = "string",
        },
      },
      type = "object",
    },
    ExternalVpnGatewayList = {
      description = "Response to the list request, and contains a list of externalVpnGateways.",
      id = "ExternalVpnGatewayList",
      properties = {
        etag = {
          type = "string",
        },
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of ExternalVpnGateway resources.",
          items = {
            ["$ref"] = "ExternalVpnGateway",
          },
          type = "array",
        },
        kind = {
          default = "compute#externalVpnGatewayList",
          description = "[Output Only] Type of resource. Always compute#externalVpnGatewayList for lists of externalVpnGateways.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    FileContentBuffer = {
      id = "FileContentBuffer",
      properties = {
        content = {
          description = "The raw content in the secure keys file.",
          format = "byte",
          type = "string",
        },
        fileType = {
          description = "The file type of source file.",
          enum = {
            "BIN",
            "UNDEFINED",
            "X509",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Firewall = {
      description = "Represents a Firewall Rule resource. Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, read Firewall rules.",
      id = "Firewall",
      properties = {
        allowed = {
          description = "The list of ALLOW rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a permitted connection.",
          items = {
            properties = {
              IPProtocol = {
                description = "The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp, icmp, esp, ah, ipip, sctp) or the IP protocol number.",
                type = "string",
              },
              ports = {
                description = "An optional list of ports to which this rule applies. This field is only applicable for the UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: [\"22\"], [\"80\",\"443\"], and [\"12345-12349\"].",
                items = {
                  type = "string",
                },
                type = "array",
              },
            },
            type = "object",
          },
          type = "array",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        denied = {
          description = "The list of DENY rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a denied connection.",
          items = {
            properties = {
              IPProtocol = {
                description = "The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp, icmp, esp, ah, ipip, sctp) or the IP protocol number.",
                type = "string",
              },
              ports = {
                description = "An optional list of ports to which this rule applies. This field is only applicable for the UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: [\"22\"], [\"80\",\"443\"], and [\"12345-12349\"].",
                items = {
                  type = "string",
                },
                type = "array",
              },
            },
            type = "object",
          },
          type = "array",
        },
        description = {
          description = "An optional description of this resource. Provide this field when you create the resource.",
          type = "string",
        },
        destinationRanges = {
          description = "If destination ranges are specified, the firewall rule applies only to traffic that has destination IP address in these ranges. These ranges must be expressed in CIDR format. Both IPv4 and IPv6 are supported.",
          items = {
            type = "string",
          },
          type = "array",
        },
        direction = {
          description = "Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.",
          enum = {
            "EGRESS",
            "INGRESS",
          },
          enumDescriptions = {
            "Indicates that firewall should apply to outgoing traffic.",
            "Indicates that firewall should apply to incoming traffic.",
          },
          type = "string",
        },
        disabled = {
          description = "Denotes whether the firewall rule is disabled. When set to true, the firewall rule is not enforced and the network behaves as if it did not exist. If this is unspecified, the firewall rule will be enabled.",
          type = "boolean",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#firewall",
          description = "[Output Only] Type of the resource. Always compute#firewall for firewall rules.",
          type = "string",
        },
        logConfig = {
          ["$ref"] = "FirewallLogConfig",
          description = "This field denotes the logging options for a particular firewall rule. If logging is enabled, logs will be exported to Cloud Logging.",
        },
        name = {
          annotations = {
            required = {
              "compute.firewalls.insert",
              "compute.firewalls.patch",
            },
          },
          description = "Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          description = "URL of the network resource for this firewall rule. If not specified when creating a firewall rule, the default network is used: global/networks/default If you choose to specify this field, you can specify the network as a full or partial URL. For example, the following are all valid URLs: - https://www.googleapis.com/compute/v1/projects/myproject/global/networks/my-network - projects/myproject/global/networks/my-network - global/networks/default ",
          type = "string",
        },
        priority = {
          description = "Priority for this rule. This is an integer between `0` and `65535`, both inclusive. The default value is `1000`. Relative priorities determine which rule takes effect if multiple rules apply. Lower values indicate higher priority. For example, a rule with priority `0` has higher precedence than a rule with priority `1`. DENY rules take precedence over ALLOW rules if they have equal priority. Note that VPC networks have implied rules with a priority of `65535`. To avoid conflicts with the implied rules, use a priority number less than `65535`.",
          format = "int32",
          type = "integer",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        sourceRanges = {
          description = "If source ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed in CIDR format. One or both of sourceRanges and sourceTags may be set. If both fields are set, the rule applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in the sourceTags field. The connection does not need to match both fields for the rule to apply. Both IPv4 and IPv6 are supported.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sourceServiceAccounts = {
          description = "If source service accounts are specified, the firewall rules apply only to traffic originating from an instance with a service account in this list. Source service accounts cannot be used to control traffic to an instance's external IP address because service accounts are associated with an instance, not an IP address. sourceRanges can be set at the same time as sourceServiceAccounts. If both are set, the firewall applies to traffic that has a source IP address within the sourceRanges OR a source IP that belongs to an instance with service account listed in sourceServiceAccount. The connection does not need to match both fields for the firewall to apply. sourceServiceAccounts cannot be used at the same time as sourceTags or targetTags.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sourceTags = {
          description = "If source tags are specified, the firewall rule applies only to traffic with source IPs that match the primary network interfaces of VM instances that have the tag and are in the same VPC network. Source tags cannot be used to control traffic to an instance's external IP address, it only applies to traffic between instances in the same virtual network. Because tags are associated with instances, not IP addresses. One or both of sourceRanges and sourceTags may be set. If both fields are set, the firewall applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in the sourceTags field. The connection does not need to match both fields for the firewall to apply.",
          items = {
            type = "string",
          },
          type = "array",
        },
        targetServiceAccounts = {
          description = "A list of service accounts indicating sets of instances located in the network that may make network connections as specified in allowed[]. targetServiceAccounts cannot be used at the same time as targetTags or sourceTags. If neither targetServiceAccounts nor targetTags are specified, the firewall rule applies to all instances on the specified network.",
          items = {
            type = "string",
          },
          type = "array",
        },
        targetTags = {
          description = "A list of tags that controls which instances the firewall rule applies to. If targetTags are specified, then the firewall rule applies only to instances in the VPC network that have one of those tags. If no targetTags are specified, the firewall rule applies to all instances on the specified network.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    FirewallList = {
      description = "Contains a list of firewalls.",
      id = "FirewallList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Firewall resources.",
          items = {
            ["$ref"] = "Firewall",
          },
          type = "array",
        },
        kind = {
          default = "compute#firewallList",
          description = "[Output Only] Type of resource. Always compute#firewallList for lists of firewalls.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    FirewallLogConfig = {
      description = "The available logging options for a firewall rule.",
      id = "FirewallLogConfig",
      properties = {
        enable = {
          description = "This field denotes whether to enable logging for a particular firewall rule.",
          type = "boolean",
        },
        metadata = {
          description = "This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs.",
          enum = {
            "EXCLUDE_ALL_METADATA",
            "INCLUDE_ALL_METADATA",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    FirewallPoliciesListAssociationsResponse = {
      id = "FirewallPoliciesListAssociationsResponse",
      properties = {
        associations = {
          description = "A list of associations.",
          items = {
            ["$ref"] = "FirewallPolicyAssociation",
          },
          type = "array",
        },
        kind = {
          default = "compute#firewallPoliciesListAssociationsResponse",
          description = "[Output Only] Type of firewallPolicy associations. Always compute#FirewallPoliciesListAssociations for lists of firewallPolicy associations.",
          type = "string",
        },
      },
      type = "object",
    },
    FirewallPolicy = {
      description = "Represents a Firewall Policy resource.",
      id = "FirewallPolicy",
      properties = {
        associations = {
          description = "A list of associations that belong to this firewall policy.",
          items = {
            ["$ref"] = "FirewallPolicyAssociation",
          },
          type = "array",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        displayName = {
          description = "Deprecated, please use short name instead. User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        fingerprint = {
          description = "Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make get() request to the firewall policy.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#firewallPolicy",
          description = "[Output only] Type of the resource. Always compute#firewallPolicyfor firewall policies",
          type = "string",
        },
        name = {
          description = "Name of the resource. For Organization Firewall Policies it's a [Output Only] numeric ID allocated by Google Cloud which uniquely identifies the Organization Firewall Policy.",
          type = "string",
        },
        parent = {
          description = "[Output Only] The parent of the firewall policy. This field is not applicable to network firewall policies.",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the regional firewall policy resides. This field is not applicable to global firewall policies. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        ruleTupleCount = {
          description = "[Output Only] Total count of all firewall policy rule tuples. A firewall policy can not exceed a set number of tuples.",
          format = "int32",
          type = "integer",
        },
        rules = {
          description = "A list of rules that belong to this policy. There must always be a default rule (rule with priority 2147483647 and match \"*\"). If no rules are provided when creating a firewall policy, a default rule with action \"allow\" will be added.",
          items = {
            ["$ref"] = "FirewallPolicyRule",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        selfLinkWithId = {
          description = "[Output Only] Server-defined URL for this resource with the resource id.",
          type = "string",
        },
        shortName = {
          description = "User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
      },
      type = "object",
    },
    FirewallPolicyAssociation = {
      id = "FirewallPolicyAssociation",
      properties = {
        attachmentTarget = {
          description = "The target that the firewall policy is attached to.",
          type = "string",
        },
        displayName = {
          description = "[Output Only] Deprecated, please use short name instead. The display name of the firewall policy of the association.",
          type = "string",
        },
        firewallPolicyId = {
          description = "[Output Only] The firewall policy ID of the association.",
          type = "string",
        },
        name = {
          description = "The name for an association.",
          type = "string",
        },
        shortName = {
          description = "[Output Only] The short name of the firewall policy of the association.",
          type = "string",
        },
      },
      type = "object",
    },
    FirewallPolicyList = {
      id = "FirewallPolicyList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of FirewallPolicy resources.",
          items = {
            ["$ref"] = "FirewallPolicy",
          },
          type = "array",
        },
        kind = {
          default = "compute#firewallPolicyList",
          description = "[Output Only] Type of resource. Always compute#firewallPolicyList for listsof FirewallPolicies",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    FirewallPolicyRule = {
      description = "Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).",
      id = "FirewallPolicyRule",
      properties = {
        action = {
          description = "The Action to perform when the client connection triggers the rule. Valid actions are \"allow\", \"deny\" and \"goto_next\".",
          type = "string",
        },
        description = {
          description = "An optional description for this resource.",
          type = "string",
        },
        direction = {
          description = "The direction in which this rule applies.",
          enum = {
            "EGRESS",
            "INGRESS",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        disabled = {
          description = "Denotes whether the firewall policy rule is disabled. When set to true, the firewall policy rule is not enforced and traffic behaves as if it did not exist. If this is unspecified, the firewall policy rule will be enabled.",
          type = "boolean",
        },
        enableLogging = {
          description = "Denotes whether to enable logging for a particular rule. If logging is enabled, logs will be exported to the configured export destination in Stackdriver. Logs may be exported to BigQuery or Pub/Sub. Note: you cannot enable logging on \"goto_next\" rules.",
          type = "boolean",
        },
        kind = {
          default = "compute#firewallPolicyRule",
          description = "[Output only] Type of the resource. Always compute#firewallPolicyRule for firewall policy rules",
          type = "string",
        },
        match = {
          ["$ref"] = "FirewallPolicyRuleMatcher",
          description = "A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding 'action' is enforced.",
        },
        priority = {
          description = "An integer indicating the priority of a rule in the list. The priority must be a positive value between 0 and 2147483647. Rules are evaluated from highest to lowest priority where 0 is the highest priority and 2147483647 is the lowest prority.",
          format = "int32",
          type = "integer",
        },
        ruleName = {
          description = "An optional name for the rule. This field is not a unique identifier and can be updated.",
          type = "string",
        },
        ruleTupleCount = {
          description = "[Output Only] Calculation of the complexity of a single firewall policy rule.",
          format = "int32",
          type = "integer",
        },
        targetResources = {
          description = "A list of network resource URLs to which this rule applies. This field allows you to control which network's VMs get this rule. If this field is left blank, all VMs within the organization will receive the rule.",
          items = {
            type = "string",
          },
          type = "array",
        },
        targetSecureTags = {
          description = "A list of secure tags that controls which instances the firewall rule applies to. If targetSecureTag are specified, then the firewall rule applies only to instances in the VPC network that have one of those EFFECTIVE secure tags, if all the target_secure_tag are in INEFFECTIVE state, then this rule will be ignored. targetSecureTag may not be set at the same time as targetServiceAccounts. If neither targetServiceAccounts nor targetSecureTag are specified, the firewall rule applies to all instances on the specified network. Maximum number of target label tags allowed is 256.",
          items = {
            ["$ref"] = "FirewallPolicyRuleSecureTag",
          },
          type = "array",
        },
        targetServiceAccounts = {
          description = "A list of service accounts indicating the sets of instances that are applied with this rule.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    FirewallPolicyRuleMatcher = {
      description = "Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.",
      id = "FirewallPolicyRuleMatcher",
      properties = {
        destIpRanges = {
          description = "CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000.",
          items = {
            type = "string",
          },
          type = "array",
        },
        layer4Configs = {
          description = "Pairs of IP protocols and ports that the rule should match.",
          items = {
            ["$ref"] = "FirewallPolicyRuleMatcherLayer4Config",
          },
          type = "array",
        },
        srcIpRanges = {
          description = "CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.",
          items = {
            type = "string",
          },
          type = "array",
        },
        srcSecureTags = {
          description = "List of secure tag values, which should be matched at the source of the traffic. For INGRESS rule, if all the srcSecureTag are INEFFECTIVE, and there is no srcIpRange, this rule will be ignored. Maximum number of source tag values allowed is 256.",
          items = {
            ["$ref"] = "FirewallPolicyRuleSecureTag",
          },
          type = "array",
        },
      },
      type = "object",
    },
    FirewallPolicyRuleMatcherLayer4Config = {
      id = "FirewallPolicyRuleMatcherLayer4Config",
      properties = {
        ipProtocol = {
          description = "The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp, icmp, esp, ah, ipip, sctp), or the IP protocol number.",
          type = "string",
        },
        ports = {
          description = "An optional list of ports to which this rule applies. This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: [\"22\"], [\"80\",\"443\"], and [\"12345-12349\"].",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    FirewallPolicyRuleSecureTag = {
      id = "FirewallPolicyRuleSecureTag",
      properties = {
        name = {
          description = "Name of the secure tag, created with TagManager's TagValue API.",
          pattern = "tagValues/[0-9]+",
          type = "string",
        },
        state = {
          description = "[Output Only] State of the secure tag, either `EFFECTIVE` or `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted or its network is deleted.",
          enum = {
            "EFFECTIVE",
            "INEFFECTIVE",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    FixedOrPercent = {
      description = "Encapsulates numeric value that can be either absolute or relative.",
      id = "FixedOrPercent",
      properties = {
        calculated = {
          description = "[Output Only] Absolute value of VM instances calculated based on the specific mode. - If the value is fixed, then the calculated value is equal to the fixed value. - If the value is a percent, then the calculated value is percent/100 * targetSize. For example, the calculated value of a 80% of a managed instance group with 150 instances would be (80/100 * 150) = 120 VM instances. If there is a remainder, the number is rounded. ",
          format = "int32",
          type = "integer",
        },
        fixed = {
          description = "Specifies a fixed number of VM instances. This must be a positive integer.",
          format = "int32",
          type = "integer",
        },
        percent = {
          description = "Specifies a percentage of instances between 0 to 100%, inclusive. For example, specify 80 for 80%.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    ForwardingRule = {
      description = "Represents a Forwarding Rule resource. Forwarding rule resources in Google Cloud can be either regional or global in scope: * [Global](https://cloud.google.com/compute/docs/reference/rest/v1/globalForwardingRules) * [Regional](https://cloud.google.com/compute/docs/reference/rest/v1/forwardingRules) A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud Platform load balancer. Forwarding rules can also reference target instances and Cloud VPN Classic gateways (targetVpnGateway). For more information, read Forwarding rule concepts and Using protocol forwarding.",
      id = "ForwardingRule",
      properties = {
        IPAddress = {
          description = "IP address for which this forwarding rule accepts traffic. When a client sends traffic to this IP address, the forwarding rule directs the traffic to the referenced target or backendService. While creating a forwarding rule, specifying an IPAddress is required under the following circumstances: - When the target is set to targetGrpcProxy and validateForProxyless is set to true, the IPAddress should be set to 0.0.0.0. - When the target is a Private Service Connect Google APIs bundle, you must specify an IPAddress. Otherwise, you can optionally specify an IP address that references an existing static (reserved) IP address resource. When omitted, Google Cloud assigns an ephemeral IP address. Use one of the following formats to specify an IP address while creating a forwarding rule: * IP address number, as in `100.1.2.3` * IPv6 address range, as in `2600:1234::/96` * Full resource URL, as in https://www.googleapis.com/compute/v1/projects/ project_id/regions/region/addresses/address-name * Partial URL or by name, as in: - projects/project_id/regions/region/addresses/address-name - regions/region/addresses/address-name - global/addresses/address-name - address-name The forwarding rule's target or backendService, and in most cases, also the loadBalancingScheme, determine the type of IP address that you can use. For detailed information, see [IP address specifications](https://cloud.google.com/load-balancing/docs/forwarding-rule-concepts#ip_address_specifications). When reading an IPAddress, the API always returns the IP address number.",
          type = "string",
        },
        IPProtocol = {
          description = "The IP protocol to which this rule applies. For protocol forwarding, valid options are TCP, UDP, ESP, AH, SCTP, ICMP and L3_DEFAULT. The valid IP protocols are different for different load balancing products as described in [Load balancing features](https://cloud.google.com/load-balancing/docs/features#protocols_from_the_load_balancer_to_the_backends).",
          enum = {
            "AH",
            "ESP",
            "ICMP",
            "L3_DEFAULT",
            "SCTP",
            "TCP",
            "UDP",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        allPorts = {
          description = "This field can only be used: - If IPProtocol is one of TCP, UDP, or SCTP. - By internal TCP/UDP load balancers, backend service-based network load balancers, and internal and external protocol forwarding. Set this field to true to allow packets addressed to any port or packets lacking destination port information (for example, UDP fragments after the first fragment) to be forwarded to the backends configured with this forwarding rule. The ports, port_range, and allPorts fields are mutually exclusive.",
          type = "boolean",
        },
        allowGlobalAccess = {
          description = "This field is used along with the backend_service field for internal load balancing or with the target field for internal TargetInstance. If the field is set to TRUE, clients can access ILB from all regions. Otherwise only allows access from clients in the same region as the internal load balancer.",
          type = "boolean",
        },
        backendService = {
          description = "Identifies the backend service to which the forwarding rule sends traffic. Required for Internal TCP/UDP Load Balancing and Network Load Balancing; must be omitted for all other load balancer types.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ForwardingRule. Include the fingerprint in patch request to ensure that you do not overwrite changes that were applied from another concurrent request. To see the latest fingerprint, make a get() request to retrieve a ForwardingRule.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        ipVersion = {
          description = "The IP Version that will be used by this forwarding rule. Valid options are IPV4 or IPV6.",
          enum = {
            "IPV4",
            "IPV6",
            "UNSPECIFIED_VERSION",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        isMirroringCollector = {
          description = "Indicates whether or not this load balancer can be used as a collector for packet mirroring. To prevent mirroring loops, instances behind this load balancer will not have their traffic mirrored even if a PacketMirroring rule applies to them. This can only be set to true for load balancers that have their loadBalancingScheme set to INTERNAL.",
          type = "boolean",
        },
        kind = {
          default = "compute#forwardingRule",
          description = "[Output Only] Type of the resource. Always compute#forwardingRule for Forwarding Rule resources.",
          type = "string",
        },
        labelFingerprint = {
          description = "A fingerprint for the labels being applied to this resource, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a ForwardingRule.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.",
          type = "object",
        },
        loadBalancingScheme = {
          description = "Specifies the forwarding rule type. For more information about forwarding rules, refer to Forwarding rule concepts.",
          enum = {
            "EXTERNAL",
            "EXTERNAL_MANAGED",
            "INTERNAL",
            "INTERNAL_MANAGED",
            "INTERNAL_SELF_MANAGED",
            "INVALID",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        metadataFilters = {
          description = "Opaque filter criteria used by load balancer to restrict routing configuration to a limited set of xDS compliant clients. In their xDS requests to load balancer, xDS clients present node metadata. When there is a match, the relevant configuration is made available to those proxies. Otherwise, all the resources (e.g. TargetHttpProxy, UrlMap) referenced by the ForwardingRule are not visible to those proxies. For each metadataFilter in this list, if its filterMatchCriteria is set to MATCH_ANY, at least one of the filterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. If multiple metadataFilters are specified, all of them need to be satisfied in order to be considered a match. metadataFilters specified here will be applifed before those specified in the UrlMap that this ForwardingRule references. metadataFilters only applies to Loadbalancers that have their loadBalancingScheme set to INTERNAL_SELF_MANAGED.",
          items = {
            ["$ref"] = "MetadataFilter",
          },
          type = "array",
        },
        name = {
          description = "Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. For Private Service Connect forwarding rules that forward traffic to Google APIs, the forwarding rule name must be a 1-20 characters string with lowercase letters and numbers and must start with a letter.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          description = "This field is not used for external load balancing. For Internal TCP/UDP Load Balancing, this field identifies the network that the load balanced IP should belong to for this Forwarding Rule. If this field is not specified, the default network will be used. For Private Service Connect forwarding rules that forward traffic to Google APIs, a network must be provided.",
          type = "string",
        },
        networkTier = {
          description = "This signifies the networking tier used for configuring this load balancer and can only take the following values: PREMIUM, STANDARD. For regional ForwardingRule, the valid values are PREMIUM and STANDARD. For GlobalForwardingRule, the valid value is PREMIUM. If this field is not specified, it is assumed to be PREMIUM. If IPAddress is specified, this value must be equal to the networkTier of the Address.",
          enum = {
            "FIXED_STANDARD",
            "PREMIUM",
            "STANDARD",
            "STANDARD_OVERRIDES_FIXED_STANDARD",
          },
          enumDescriptions = {
            "Public internet quality with fixed bandwidth.",
            "High quality, Google-grade network tier, support for all networking products.",
            "Public internet quality, only limited support for other networking products.",
            "(Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.",
          },
          type = "string",
        },
        noAutomateDnsZone = {
          description = "This is used in PSC consumer ForwardingRule to control whether it should try to auto-generate a DNS zone or not. Non-PSC forwarding rules do not use this field.",
          type = "boolean",
        },
        portRange = {
          description = "This field can only be used: - If IPProtocol is one of TCP, UDP, or SCTP. - By backend service-based network load balancers, target pool-based network load balancers, internal proxy load balancers, external proxy load balancers, Traffic Director, external protocol forwarding, and Classic VPN. Some products have restrictions on what ports can be used. See port specifications for details. Only packets addressed to ports in the specified range will be forwarded to the backends configured with this forwarding rule. The ports, port_range, and allPorts fields are mutually exclusive. For external forwarding rules, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot have overlapping portRanges. For internal forwarding rules within the same VPC network, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot have overlapping portRanges. @pattern: \\\\d+(?:-\\\\d+)?",
          type = "string",
        },
        ports = {
          description = "This field can only be used: - If IPProtocol is one of TCP, UDP, or SCTP. - By internal TCP/UDP load balancers, backend service-based network load balancers, and internal protocol forwarding. You can specify a list of up to five ports by number, separated by commas. The ports can be contiguous or discontiguous. Only packets addressed to these ports will be forwarded to the backends configured with this forwarding rule. For external forwarding rules, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot share any values defined in ports. For internal forwarding rules within the same VPC network, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot share any values defined in ports. The ports, port_range, and allPorts fields are mutually exclusive. @pattern: \\\\d+(?:-\\\\d+)?",
          items = {
            type = "string",
          },
          type = "array",
        },
        pscConnectionId = {
          description = "[Output Only] The PSC connection id of the PSC Forwarding Rule.",
          format = "uint64",
          type = "string",
        },
        pscConnectionStatus = {
          enum = {
            "ACCEPTED",
            "CLOSED",
            "NEEDS_ATTENTION",
            "PENDING",
            "REJECTED",
            "STATUS_UNSPECIFIED",
          },
          enumDescriptions = {
            "The connection has been accepted by the producer.",
            "The connection has been closed by the producer and will not serve traffic going forward.",
            "The connection has been accepted by the producer, but the producer needs to take further action before the forwarding rule can serve traffic.",
            "The connection is pending acceptance by the producer.",
            "The connection has been rejected by the producer.",
            "",
          },
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the regional forwarding rule resides. This field is not applicable to global forwarding rules. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        serviceDirectoryRegistrations = {
          description = "Service Directory resources to register this forwarding rule with. Currently, only supports a single Service Directory resource.",
          items = {
            ["$ref"] = "ForwardingRuleServiceDirectoryRegistration",
          },
          type = "array",
        },
        serviceLabel = {
          description = "An optional prefix to the service name for this Forwarding Rule. If specified, the prefix is the first label of the fully qualified service name. The label must be 1-63 characters long, and comply with RFC1035. Specifically, the label must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. This field is only used for internal load balancing.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        serviceName = {
          description = "[Output Only] The internal fully qualified service name for this Forwarding Rule. This field is only used for internal load balancing.",
          type = "string",
        },
        subnetwork = {
          description = "This field identifies the subnetwork that the load balanced IP should belong to for this Forwarding Rule, used in internal load balancing and network load balancing with IPv6. If the network specified is in auto subnet mode, this field is optional. However, a subnetwork must be specified if the network is in custom subnet mode or when creating external forwarding rule with IPv6.",
          type = "string",
        },
        target = {
          description = "The URL of the target resource to receive the matched traffic. For regional forwarding rules, this target must be in the same region as the forwarding rule. For global forwarding rules, this target must be a global load balancing resource. The forwarded traffic must be of a type appropriate to the target object. - For load balancers, see the \"Target\" column in [Port specifications](https://cloud.google.com/load-balancing/docs/forwarding-rule-concepts#ip_address_specifications). - For Private Service Connect forwarding rules that forward traffic to Google APIs, provide the name of a supported Google API bundle: - vpc-sc - APIs that support VPC Service Controls. - all-apis - All supported Google APIs. - For Private Service Connect forwarding rules that forward traffic to managed services, the target must be a service attachment. ",
          type = "string",
        },
      },
      type = "object",
    },
    ForwardingRuleAggregatedList = {
      id = "ForwardingRuleAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "ForwardingRulesScopedList",
            description = "Name of the scope containing this set of addresses.",
          },
          description = "A list of ForwardingRulesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#forwardingRuleAggregatedList",
          description = "[Output Only] Type of resource. Always compute#forwardingRuleAggregatedList for lists of forwarding rules.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ForwardingRuleList = {
      description = "Contains a list of ForwardingRule resources.",
      id = "ForwardingRuleList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of ForwardingRule resources.",
          items = {
            ["$ref"] = "ForwardingRule",
          },
          type = "array",
        },
        kind = {
          default = "compute#forwardingRuleList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ForwardingRuleReference = {
      id = "ForwardingRuleReference",
      properties = {
        forwardingRule = {
          type = "string",
        },
      },
      type = "object",
    },
    ForwardingRuleServiceDirectoryRegistration = {
      description = "Describes the auto-registration of the Forwarding Rule to Service Directory. The region and project of the Service Directory resource generated from this registration will be the same as this Forwarding Rule.",
      id = "ForwardingRuleServiceDirectoryRegistration",
      properties = {
        namespace = {
          description = "Service Directory namespace to register the forwarding rule under.",
          type = "string",
        },
        service = {
          description = "Service Directory service to register the forwarding rule under.",
          type = "string",
        },
        serviceDirectoryRegion = {
          description = "[Optional] Service Directory region to register this global forwarding rule under. Default to \"us-central1\". Only used for PSC for Google APIs. All PSC for Google APIs Forwarding Rules on the same network should use the same Service Directory region.",
          type = "string",
        },
      },
      type = "object",
    },
    ForwardingRulesScopedList = {
      id = "ForwardingRulesScopedList",
      properties = {
        forwardingRules = {
          description = "A list of forwarding rules contained in this scope.",
          items = {
            ["$ref"] = "ForwardingRule",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of forwarding rules when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    GRPCHealthCheck = {
      id = "GRPCHealthCheck",
      properties = {
        grpcServiceName = {
          description = "The gRPC service name for the health check. This field is optional. The value of grpc_service_name has the following meanings by convention: - Empty service_name means the overall status of all services at the backend. - Non-empty service_name means the health of that gRPC service, as defined by the owner of the service. The grpc_service_name can only be ASCII.",
          type = "string",
        },
        port = {
          description = "The TCP port number to which the health check prober sends packets. Valid values are 1 through 65535.",
          format = "int32",
          type = "integer",
        },
        portName = {
          description = "Not supported.",
          type = "string",
        },
        portSpecification = {
          description = "Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.",
          enum = {
            "USE_FIXED_PORT",
            "USE_NAMED_PORT",
            "USE_SERVING_PORT",
          },
          enumDescriptions = {
            "The port number in the health check's port is used for health checking. Applies to network endpoint group and instance group backends.",
            "Not supported.",
            "For network endpoint group backends, the health check uses the port number specified on each endpoint in the network endpoint group. For instance group backends, the health check uses the port number specified for the backend service's named port defined in the instance group's named ports.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GlobalNetworkEndpointGroupsAttachEndpointsRequest = {
      id = "GlobalNetworkEndpointGroupsAttachEndpointsRequest",
      properties = {
        networkEndpoints = {
          description = "The list of network endpoints to be attached.",
          items = {
            ["$ref"] = "NetworkEndpoint",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GlobalNetworkEndpointGroupsDetachEndpointsRequest = {
      id = "GlobalNetworkEndpointGroupsDetachEndpointsRequest",
      properties = {
        networkEndpoints = {
          description = "The list of network endpoints to be detached.",
          items = {
            ["$ref"] = "NetworkEndpoint",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GlobalOrganizationSetPolicyRequest = {
      id = "GlobalOrganizationSetPolicyRequest",
      properties = {
        bindings = {
          description = "Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify bindings.",
          items = {
            ["$ref"] = "Binding",
          },
          type = "array",
        },
        etag = {
          description = "Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify the etag.",
          format = "byte",
          type = "string",
        },
        policy = {
          ["$ref"] = "Policy",
          description = "REQUIRED: The complete policy to be applied to the 'resource'. The size of the policy is limited to a few 10s of KB. An empty policy is in general a valid policy but certain services (like Projects) might reject them.",
        },
      },
      type = "object",
    },
    GlobalSetLabelsRequest = {
      id = "GlobalSetLabelsRequest",
      properties = {
        labelFingerprint = {
          description = "The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash when updating or changing labels, otherwise the request will fail with error 412 conditionNotMet. Make a get() request to the resource to get the latest fingerprint.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "A list of labels to apply for this resource. Each label must comply with the requirements for labels. For example, \"webserver-frontend\": \"images\". A label value can also be empty (e.g. \"my-label\": \"\").",
          type = "object",
        },
      },
      type = "object",
    },
    GlobalSetPolicyRequest = {
      id = "GlobalSetPolicyRequest",
      properties = {
        bindings = {
          description = "Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify bindings.",
          items = {
            ["$ref"] = "Binding",
          },
          type = "array",
        },
        etag = {
          description = "Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify the etag.",
          format = "byte",
          type = "string",
        },
        policy = {
          ["$ref"] = "Policy",
          description = "REQUIRED: The complete policy to be applied to the 'resource'. The size of the policy is limited to a few 10s of KB. An empty policy is in general a valid policy but certain services (like Projects) might reject them.",
        },
      },
      type = "object",
    },
    GuestAttributes = {
      description = "A guest attributes entry.",
      id = "GuestAttributes",
      properties = {
        kind = {
          default = "compute#guestAttributes",
          description = "[Output Only] Type of the resource. Always compute#guestAttributes for guest attributes entry.",
          type = "string",
        },
        queryPath = {
          description = "The path to be queried. This can be the default namespace ('') or a nested namespace ('\\/') or a specified key ('\\/\\').",
          type = "string",
        },
        queryValue = {
          ["$ref"] = "GuestAttributesValue",
          description = "[Output Only] The value of the requested queried path.",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        variableKey = {
          description = "The key to search for.",
          type = "string",
        },
        variableValue = {
          description = "[Output Only] The value found for the requested key.",
          type = "string",
        },
      },
      type = "object",
    },
    GuestAttributesEntry = {
      description = "A guest attributes namespace/key/value entry.",
      id = "GuestAttributesEntry",
      properties = {
        key = {
          description = "Key for the guest attribute entry.",
          type = "string",
        },
        namespace = {
          description = "Namespace for the guest attribute entry.",
          type = "string",
        },
        value = {
          description = "Value for the guest attribute entry.",
          type = "string",
        },
      },
      type = "object",
    },
    GuestAttributesValue = {
      description = "Array of guest attribute namespace/key/value tuples.",
      id = "GuestAttributesValue",
      properties = {
        items = {
          items = {
            ["$ref"] = "GuestAttributesEntry",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GuestOsFeature = {
      description = "Guest OS features.",
      id = "GuestOsFeature",
      properties = {
        type = {
          description = "The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values: - VIRTIO_SCSI_MULTIQUEUE - WINDOWS - MULTI_IP_SUBNET - UEFI_COMPATIBLE - GVNIC - SEV_CAPABLE - SUSPEND_RESUME_COMPATIBLE - SEV_SNP_CAPABLE For more information, see Enabling guest operating system features.",
          enum = {
            "FEATURE_TYPE_UNSPECIFIED",
            "GVNIC",
            "MULTI_IP_SUBNET",
            "SECURE_BOOT",
            "SEV_CAPABLE",
            "SEV_SNP_CAPABLE",
            "UEFI_COMPATIBLE",
            "VIRTIO_SCSI_MULTIQUEUE",
            "WINDOWS",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    HTTP2HealthCheck = {
      id = "HTTP2HealthCheck",
      properties = {
        host = {
          description = "The value of the host header in the HTTP/2 health check request. If left empty (default value), the host header is set to the destination IP address to which health check packets are sent. The destination IP address depends on the type of load balancer. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet-dest",
          type = "string",
        },
        port = {
          description = "The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through 65535.",
          format = "int32",
          type = "integer",
        },
        portName = {
          description = "Not supported.",
          type = "string",
        },
        portSpecification = {
          description = "Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.",
          enum = {
            "USE_FIXED_PORT",
            "USE_NAMED_PORT",
            "USE_SERVING_PORT",
          },
          enumDescriptions = {
            "The port number in the health check's port is used for health checking. Applies to network endpoint group and instance group backends.",
            "Not supported.",
            "For network endpoint group backends, the health check uses the port number specified on each endpoint in the network endpoint group. For instance group backends, the health check uses the port number specified for the backend service's named port defined in the instance group's named ports.",
          },
          type = "string",
        },
        proxyHeader = {
          description = "Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.",
          enum = {
            "NONE",
            "PROXY_V1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        requestPath = {
          description = "The request path of the HTTP/2 health check request. The default value is /.",
          type = "string",
        },
        response = {
          description = "Creates a content-based HTTP/2 health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-http",
          type = "string",
        },
      },
      type = "object",
    },
    HTTPHealthCheck = {
      id = "HTTPHealthCheck",
      properties = {
        host = {
          description = "The value of the host header in the HTTP health check request. If left empty (default value), the host header is set to the destination IP address to which health check packets are sent. The destination IP address depends on the type of load balancer. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet-dest",
          type = "string",
        },
        port = {
          description = "The TCP port number to which the health check prober sends packets. The default value is 80. Valid values are 1 through 65535.",
          format = "int32",
          type = "integer",
        },
        portName = {
          description = "Not supported.",
          type = "string",
        },
        portSpecification = {
          description = "Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Also supported in legacy HTTP health checks for target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.",
          enum = {
            "USE_FIXED_PORT",
            "USE_NAMED_PORT",
            "USE_SERVING_PORT",
          },
          enumDescriptions = {
            "The port number in the health check's port is used for health checking. Applies to network endpoint group and instance group backends.",
            "Not supported.",
            "For network endpoint group backends, the health check uses the port number specified on each endpoint in the network endpoint group. For instance group backends, the health check uses the port number specified for the backend service's named port defined in the instance group's named ports.",
          },
          type = "string",
        },
        proxyHeader = {
          description = "Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.",
          enum = {
            "NONE",
            "PROXY_V1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        requestPath = {
          description = "The request path of the HTTP health check request. The default value is /.",
          type = "string",
        },
        response = {
          description = "Creates a content-based HTTP health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-http",
          type = "string",
        },
      },
      type = "object",
    },
    HTTPSHealthCheck = {
      id = "HTTPSHealthCheck",
      properties = {
        host = {
          description = "The value of the host header in the HTTPS health check request. If left empty (default value), the host header is set to the destination IP address to which health check packets are sent. The destination IP address depends on the type of load balancer. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet-dest",
          type = "string",
        },
        port = {
          description = "The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through 65535.",
          format = "int32",
          type = "integer",
        },
        portName = {
          description = "Not supported.",
          type = "string",
        },
        portSpecification = {
          description = "Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.",
          enum = {
            "USE_FIXED_PORT",
            "USE_NAMED_PORT",
            "USE_SERVING_PORT",
          },
          enumDescriptions = {
            "The port number in the health check's port is used for health checking. Applies to network endpoint group and instance group backends.",
            "Not supported.",
            "For network endpoint group backends, the health check uses the port number specified on each endpoint in the network endpoint group. For instance group backends, the health check uses the port number specified for the backend service's named port defined in the instance group's named ports.",
          },
          type = "string",
        },
        proxyHeader = {
          description = "Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.",
          enum = {
            "NONE",
            "PROXY_V1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        requestPath = {
          description = "The request path of the HTTPS health check request. The default value is /.",
          type = "string",
        },
        response = {
          description = "Creates a content-based HTTPS health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-http",
          type = "string",
        },
      },
      type = "object",
    },
    HealthCheck = {
      description = "Represents a Health Check resource. Google Compute Engine has two Health Check resources: * [Global](/compute/docs/reference/rest/v1/healthChecks) * [Regional](/compute/docs/reference/rest/v1/regionHealthChecks) Internal HTTP(S) load balancers must use regional health checks (`compute.v1.regionHealthChecks`). Traffic Director must use global health checks (`compute.v1.HealthChecks`). Internal TCP/UDP load balancers can use either regional or global health checks (`compute.v1.regionHealthChecks` or `compute.v1.HealthChecks`). External HTTP(S), TCP proxy, and SSL proxy load balancers as well as managed instance group auto-healing must use global health checks (`compute.v1.HealthChecks`). Backend service-based network load balancers must use regional health checks (`compute.v1.regionHealthChecks`). Target pool-based network load balancers must use legacy HTTP health checks (`compute.v1.httpHealthChecks`). For more information, see Health checks overview.",
      id = "HealthCheck",
      properties = {
        checkIntervalSec = {
          description = "How often (in seconds) to send a health check. The default value is 5 seconds.",
          format = "int32",
          type = "integer",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in 3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        grpcHealthCheck = {
          ["$ref"] = "GRPCHealthCheck",
        },
        healthyThreshold = {
          description = "A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.",
          format = "int32",
          type = "integer",
        },
        http2HealthCheck = {
          ["$ref"] = "HTTP2HealthCheck",
        },
        httpHealthCheck = {
          ["$ref"] = "HTTPHealthCheck",
        },
        httpsHealthCheck = {
          ["$ref"] = "HTTPSHealthCheck",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#healthCheck",
          description = "Type of the resource.",
          type = "string",
        },
        logConfig = {
          ["$ref"] = "HealthCheckLogConfig",
          description = "Configure logging on this health check.",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. For example, a name that is 1-63 characters long, matches the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`, and otherwise complies with RFC1035. This regular expression describes a name where the first character is a lowercase letter, and all following characters are a dash, lowercase letter, or digit, except the last character, which isn't a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        region = {
          description = "[Output Only] Region where the health check resides. Not applicable to global health checks.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        sslHealthCheck = {
          ["$ref"] = "SSLHealthCheck",
        },
        tcpHealthCheck = {
          ["$ref"] = "TCPHealthCheck",
        },
        timeoutSec = {
          description = "How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec.",
          format = "int32",
          type = "integer",
        },
        type = {
          description = "Specifies the type of the healthCheck, either TCP, SSL, HTTP, HTTPS, HTTP2 or GRPC. Exactly one of the protocol-specific health check fields must be specified, which must match type field.",
          enum = {
            "GRPC",
            "HTTP",
            "HTTP2",
            "HTTPS",
            "INVALID",
            "SSL",
            "TCP",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        unhealthyThreshold = {
          description = "A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    HealthCheckList = {
      description = "Contains a list of HealthCheck resources.",
      id = "HealthCheckList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of HealthCheck resources.",
          items = {
            ["$ref"] = "HealthCheck",
          },
          type = "array",
        },
        kind = {
          default = "compute#healthCheckList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    HealthCheckLogConfig = {
      description = "Configuration of logging on a health check. If logging is enabled, logs will be exported to Stackdriver.",
      id = "HealthCheckLogConfig",
      properties = {
        enable = {
          description = "Indicates whether or not to export logs. This is false by default, which means no health check logging will be done.",
          type = "boolean",
        },
      },
      type = "object",
    },
    HealthCheckReference = {
      description = "A full or valid partial URL to a health check. For example, the following are valid URLs: - https://www.googleapis.com/compute/beta/projects/project-id/global/httpHealthChecks/health-check - projects/project-id/global/httpHealthChecks/health-check - global/httpHealthChecks/health-check ",
      id = "HealthCheckReference",
      properties = {
        healthCheck = {
          type = "string",
        },
      },
      type = "object",
    },
    HealthCheckService = {
      description = "Represents a Health-Check as a Service resource.",
      id = "HealthCheckService",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthCheckService. An up-to-date fingerprint must be provided in order to patch/update the HealthCheckService; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthCheckService.",
          format = "byte",
          type = "string",
        },
        healthChecks = {
          description = "A list of URLs to the HealthCheck resources. Must have at least one HealthCheck, and not more than 10 for regional HealthCheckService, and not more than 1 for global HealthCheckService. HealthCheck resources must have portSpecification=USE_SERVING_PORT or portSpecification=USE_FIXED_PORT. For regional HealthCheckService, the HealthCheck must be regional and in the same region. For global HealthCheckService, HealthCheck must be global. Mix of regional and global HealthChecks is not supported. Multiple regional HealthChecks must belong to the same region. Regional HealthChecks must belong to the same region as zones of NetworkEndpointGroups. For global HealthCheckService using global INTERNET_IP_PORT NetworkEndpointGroups, the global HealthChecks must specify sourceRegions, and HealthChecks that specify sourceRegions can only be used with global INTERNET_IP_PORT NetworkEndpointGroups.",
          items = {
            type = "string",
          },
          type = "array",
        },
        healthStatusAggregationPolicy = {
          description = "Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.",
          enum = {
            "AND",
            "NO_AGGREGATION",
          },
          enumDescriptions = {
            "If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.",
            "An EndpointHealth message is returned for each backend in the health check service.",
          },
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#healthCheckService",
          description = "[Output only] Type of the resource. Always compute#healthCheckServicefor health check services.",
          type = "string",
        },
        name = {
          description = "Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        networkEndpointGroups = {
          description = "A list of URLs to the NetworkEndpointGroup resources. Must not have more than 100. For regional HealthCheckService, NEGs must be in zones in the region of the HealthCheckService. For global HealthCheckServices, the NetworkEndpointGroups must be global INTERNET_IP_PORT.",
          items = {
            type = "string",
          },
          type = "array",
        },
        notificationEndpoints = {
          description = "A list of URLs to the NotificationEndpoint resources. Must not have more than 10. A list of endpoints for receiving notifications of change in health status. For regional HealthCheckService, NotificationEndpoint must be regional and in the same region. For global HealthCheckService, NotificationEndpoint must be global.",
          items = {
            type = "string",
          },
          type = "array",
        },
        region = {
          description = "[Output Only] URL of the region where the health check service resides. This field is not applicable to global health check services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
      },
      type = "object",
    },
    HealthCheckServiceReference = {
      description = "A full or valid partial URL to a health check service. For example, the following are valid URLs: - https://www.googleapis.com/compute/beta/projects/project-id/regions/us-west1/healthCheckServices/health-check-service - projects/project-id/regions/us-west1/healthCheckServices/health-check-service - regions/us-west1/healthCheckServices/health-check-service ",
      id = "HealthCheckServiceReference",
      properties = {
        healthCheckService = {
          type = "string",
        },
      },
      type = "object",
    },
    HealthCheckServicesList = {
      id = "HealthCheckServicesList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of HealthCheckService resources.",
          items = {
            ["$ref"] = "HealthCheckService",
          },
          type = "array",
        },
        kind = {
          default = "compute#healthCheckServicesList",
          description = "[Output Only] Type of the resource. Always compute#healthCheckServicesList for lists of HealthCheckServices.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    HealthChecksAggregatedList = {
      id = "HealthChecksAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "HealthChecksScopedList",
            description = "Name of the scope containing this set of HealthChecks.",
          },
          description = "A list of HealthChecksScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#healthChecksAggregatedList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    HealthChecksScopedList = {
      id = "HealthChecksScopedList",
      properties = {
        healthChecks = {
          description = "A list of HealthChecks contained in this scope.",
          items = {
            ["$ref"] = "HealthCheck",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of backend services when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    HealthStatus = {
      id = "HealthStatus",
      properties = {
        annotations = {
          additionalProperties = {
            type = "string",
          },
          description = "Metadata defined as annotations for network endpoint.",
          type = "object",
        },
        forwardingRule = {
          description = "URL of the forwarding rule associated with the health status of the instance.",
          type = "string",
        },
        forwardingRuleIp = {
          description = "A forwarding rule IP address assigned to this instance.",
          type = "string",
        },
        healthState = {
          description = "Health state of the instance.",
          enum = {
            "HEALTHY",
            "UNHEALTHY",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        instance = {
          description = "URL of the instance resource.",
          type = "string",
        },
        ipAddress = {
          description = "For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip.",
          type = "string",
        },
        port = {
          description = "The named port of the instance group, not necessarily the port that is health-checked.",
          format = "int32",
          type = "integer",
        },
        weight = {
          type = "string",
        },
        weightError = {
          enum = {
            "INVALID_WEIGHT",
            "MISSING_WEIGHT",
            "UNAVAILABLE_WEIGHT",
            "WEIGHT_NONE",
          },
          enumDescriptions = {
            "The response to a Health Check probe had the HTTP response header field X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not a non-negative single-precision floating-point number in decimal string representation).",
            "The response to a Health Check probe did not have the HTTP response header field X-Load-Balancing-Endpoint-Weight.",
            "This is the value when the accompanied health status is either TIMEOUT (i.e.,the Health Check probe was not able to get a response in time) or UNKNOWN. For the latter, it should be typically because there has not been sufficient time to parse and report the weight for a new backend (which is with 0.0.0.0 ip address). However, it can be also due to an outage case for which the health status is explicitly reset to UNKNOWN.",
            "This is the default value when WeightReportMode is DISABLE, and is also the initial value when WeightReportMode has just updated to ENABLE or DRY_RUN and there has not been sufficient time to parse and report the backend weight.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    HealthStatusForNetworkEndpoint = {
      id = "HealthStatusForNetworkEndpoint",
      properties = {
        backendService = {
          ["$ref"] = "BackendServiceReference",
          description = "URL of the backend service associated with the health state of the network endpoint.",
        },
        forwardingRule = {
          ["$ref"] = "ForwardingRuleReference",
          description = "URL of the forwarding rule associated with the health state of the network endpoint.",
        },
        healthCheck = {
          ["$ref"] = "HealthCheckReference",
          description = "URL of the health check associated with the health state of the network endpoint.",
        },
        healthCheckService = {
          ["$ref"] = "HealthCheckServiceReference",
          description = "URL of the health check service associated with the health state of the network endpoint.",
        },
        healthState = {
          description = "Health state of the network endpoint determined based on the health checks configured.",
          enum = {
            "DRAINING",
            "HEALTHY",
            "UNHEALTHY",
            "UNKNOWN",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Help = {
      description = "Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit.",
      id = "Help",
      properties = {
        links = {
          description = "URL(s) pointing to additional information on handling the current error.",
          items = {
            ["$ref"] = "HelpLink",
          },
          type = "array",
        },
      },
      type = "object",
    },
    HelpLink = {
      description = "Describes a URL link.",
      id = "HelpLink",
      properties = {
        description = {
          description = "Describes what the link offers.",
          type = "string",
        },
        url = {
          description = "The URL of the link.",
          type = "string",
        },
      },
      type = "object",
    },
    HostRule = {
      description = "UrlMaps A host-matching rule for a URL. If matched, will use the named PathMatcher to select the BackendService.",
      id = "HostRule",
      properties = {
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        hosts = {
          description = "The list of host patterns to match. They must be valid hostnames with optional port numbers in the format host:port. * matches any string of ([a-z0-9-.]*). In that case, * must be the first character, and if followed by anything, the immediate following character must be either - or .. * based matching is not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.",
          items = {
            type = "string",
          },
          type = "array",
        },
        pathMatcher = {
          description = "The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion.",
          type = "string",
        },
      },
      type = "object",
    },
    HttpFaultAbort = {
      description = "Specification for how requests are aborted as part of fault injection.",
      id = "HttpFaultAbort",
      properties = {
        httpStatus = {
          description = "The HTTP status code used to abort the request. The value must be from 200 to 599 inclusive. For gRPC protocol, the gRPC status code is mapped to HTTP status code according to this mapping table. HTTP status 200 is mapped to gRPC status UNKNOWN. Injecting an OK status is currently not supported by Traffic Director.",
          format = "uint32",
          type = "integer",
        },
        percentage = {
          description = "The percentage of traffic for connections, operations, or requests that is aborted as part of fault injection. The value must be from 0.0 to 100.0 inclusive.",
          format = "double",
          type = "number",
        },
      },
      type = "object",
    },
    HttpFaultDelay = {
      description = "Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection.",
      id = "HttpFaultDelay",
      properties = {
        fixedDelay = {
          ["$ref"] = "Duration",
          description = "Specifies the value of the fixed delay interval.",
        },
        percentage = {
          description = "The percentage of traffic for connections, operations, or requests for which a delay is introduced as part of fault injection. The value must be from 0.0 to 100.0 inclusive.",
          format = "double",
          type = "number",
        },
      },
      type = "object",
    },
    HttpFaultInjection = {
      description = "The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.",
      id = "HttpFaultInjection",
      properties = {
        abort = {
          ["$ref"] = "HttpFaultAbort",
          description = "The specification for how client requests are aborted as part of fault injection.",
        },
        delay = {
          ["$ref"] = "HttpFaultDelay",
          description = "The specification for how client requests are delayed as part of fault injection, before being sent to a backend service.",
        },
      },
      type = "object",
    },
    HttpHeaderAction = {
      description = "The request and response header transformations that take effect before the request is passed along to the selected backendService.",
      id = "HttpHeaderAction",
      properties = {
        requestHeadersToAdd = {
          description = "Headers to add to a matching request before forwarding the request to the backendService.",
          items = {
            ["$ref"] = "HttpHeaderOption",
          },
          type = "array",
        },
        requestHeadersToRemove = {
          description = "A list of header names for headers that need to be removed from the request before forwarding the request to the backendService.",
          items = {
            type = "string",
          },
          type = "array",
        },
        responseHeadersToAdd = {
          description = "Headers to add the response before sending the response back to the client.",
          items = {
            ["$ref"] = "HttpHeaderOption",
          },
          type = "array",
        },
        responseHeadersToRemove = {
          description = "A list of header names for headers that need to be removed from the response before sending the response back to the client.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    HttpHeaderMatch = {
      description = "matchRule criteria for request header matches.",
      id = "HttpHeaderMatch",
      properties = {
        exactMatch = {
          description = "The value should exactly match contents of exactMatch. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set.",
          type = "string",
        },
        headerName = {
          description = "The name of the HTTP header to match. For matching against the HTTP request's authority, use a headerMatch with the header name \":authority\". For matching a request's method, use the headerName \":method\". When the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true, only non-binary user-specified custom metadata and the `content-type` header are supported. The following transport-level headers cannot be used in header matching rules: `:authority`, `:method`, `:path`, `:scheme`, `user-agent`, `accept-encoding`, `content-encoding`, `grpc-accept-encoding`, `grpc-encoding`, `grpc-previous-rpc-attempts`, `grpc-tags-bin`, `grpc-timeout` and `grpc-trace-bin`.",
          type = "string",
        },
        invertMatch = {
          description = "If set to false, the headerMatch is considered a match if the preceding match criteria are met. If set to true, the headerMatch is considered a match if the preceding match criteria are NOT met. The default setting is false. ",
          type = "boolean",
        },
        prefixMatch = {
          description = "The value of the header must start with the contents of prefixMatch. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set.",
          type = "string",
        },
        presentMatch = {
          description = "A header with the contents of headerName must exist. The match takes place whether or not the request's header has a value. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set.",
          type = "boolean",
        },
        rangeMatch = {
          ["$ref"] = "Int64RangeMatch",
          description = "The header value must be an integer and its value must be in the range specified in rangeMatch. If the header does not contain an integer, number or is empty, the match fails. For example for a range [-5, 0] - -3 will match. - 0 will not match. - 0.25 will not match. - -3someString will not match. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set. rangeMatch is not supported for load balancers that have loadBalancingScheme set to EXTERNAL.",
        },
        regexMatch = {
          description = "The value of the header must match the regular expression specified in regexMatch. For more information about regular expression syntax, see Syntax. For matching against a port specified in the HTTP request, use a headerMatch with headerName set to PORT and a regular expression that satisfies the RFC2616 Host header's port specifier. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED.",
          type = "string",
        },
        suffixMatch = {
          description = "The value of the header must end with the contents of suffixMatch. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set.",
          type = "string",
        },
      },
      type = "object",
    },
    HttpHeaderOption = {
      description = "Specification determining how headers are added to requests or responses.",
      id = "HttpHeaderOption",
      properties = {
        headerName = {
          description = "The name of the header.",
          type = "string",
        },
        headerValue = {
          description = "The value of the header to add.",
          type = "string",
        },
        replace = {
          description = "If false, headerValue is appended to any values that already exist for the header. If true, headerValue is set for the header, discarding any values that were set for that header. The default value is false. ",
          type = "boolean",
        },
      },
      type = "object",
    },
    HttpHealthCheck = {
      description = "Represents a legacy HTTP Health Check resource. Legacy HTTP health checks are now only required by target pool-based network load balancers. For all other load balancers, including backend service-based network load balancers, and for managed instance group auto-healing, you must use modern (non-legacy) health checks. For more information, see Health checks overview .",
      id = "HttpHealthCheck",
      properties = {
        checkIntervalSec = {
          description = "How often (in seconds) to send a health check. The default value is 5 seconds.",
          format = "int32",
          type = "integer",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        healthyThreshold = {
          description = "A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.",
          format = "int32",
          type = "integer",
        },
        host = {
          description = "The value of the host header in the HTTP health check request. If left empty (default value), the public IP on behalf of which this health check is performed will be used.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#httpHealthCheck",
          description = "[Output Only] Type of the resource. Always compute#httpHealthCheck for HTTP health checks.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        port = {
          description = "The TCP port number for the HTTP health check request. The default value is 80.",
          format = "int32",
          type = "integer",
        },
        requestPath = {
          description = "The request path of the HTTP health check request. The default value is /. This field does not support query parameters.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        timeoutSec = {
          description = "How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec.",
          format = "int32",
          type = "integer",
        },
        unhealthyThreshold = {
          description = "A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    HttpHealthCheckList = {
      description = "Contains a list of HttpHealthCheck resources.",
      id = "HttpHealthCheckList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of HttpHealthCheck resources.",
          items = {
            ["$ref"] = "HttpHealthCheck",
          },
          type = "array",
        },
        kind = {
          default = "compute#httpHealthCheckList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    HttpQueryParameterMatch = {
      description = "HttpRouteRuleMatch criteria for a request's query parameter.",
      id = "HttpQueryParameterMatch",
      properties = {
        exactMatch = {
          description = "The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch. Only one of presentMatch, exactMatch, or regexMatch must be set. ",
          type = "string",
        },
        name = {
          description = "The name of the query parameter to match. The query parameter must exist in the request, in the absence of which the request match fails.",
          type = "string",
        },
        presentMatch = {
          description = "Specifies that the queryParameterMatch matches if the request contains the query parameter, irrespective of whether the parameter has a value or not. Only one of presentMatch, exactMatch, or regexMatch must be set. ",
          type = "boolean",
        },
        regexMatch = {
          description = "The queryParameterMatch matches if the value of the parameter matches the regular expression specified by regexMatch. For more information about regular expression syntax, see Syntax. Only one of presentMatch, exactMatch, or regexMatch must be set. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED. ",
          type = "string",
        },
      },
      type = "object",
    },
    HttpRedirectAction = {
      description = "Specifies settings for an HTTP redirect.",
      id = "HttpRedirectAction",
      properties = {
        hostRedirect = {
          description = "The host that is used in the redirect response instead of the one that was supplied in the request. The value must be from 1 to 255 characters.",
          type = "string",
        },
        httpsRedirect = {
          description = "If set to true, the URL scheme in the redirected request is set to HTTPS. If set to false, the URL scheme of the redirected request remains the same as that of the request. This must only be set for URL maps used in TargetHttpProxys. Setting this true for TargetHttpsProxy is not permitted. The default is set to false.",
          type = "boolean",
        },
        pathRedirect = {
          description = "The path that is used in the redirect response instead of the one that was supplied in the request. pathRedirect cannot be supplied together with prefixRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect. The value must be from 1 to 1024 characters.",
          type = "string",
        },
        prefixRedirect = {
          description = "The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request. prefixRedirect cannot be supplied together with pathRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect. The value must be from 1 to 1024 characters.",
          type = "string",
        },
        redirectResponseCode = {
          description = "The HTTP Status code to use for this RedirectAction. Supported values are: - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds to 301. - FOUND, which corresponds to 302. - SEE_OTHER which corresponds to 303. - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request method is retained. - PERMANENT_REDIRECT, which corresponds to 308. In this case, the request method is retained. ",
          enum = {
            "FOUND",
            "MOVED_PERMANENTLY_DEFAULT",
            "PERMANENT_REDIRECT",
            "SEE_OTHER",
            "TEMPORARY_REDIRECT",
          },
          enumDescriptions = {
            "Http Status Code 302 - Found.",
            "Http Status Code 301 - Moved Permanently.",
            "Http Status Code 308 - Permanent Redirect maintaining HTTP method.",
            "Http Status Code 303 - See Other.",
            "Http Status Code 307 - Temporary Redirect maintaining HTTP method.",
          },
          type = "string",
        },
        stripQuery = {
          description = "If set to true, any accompanying query portion of the original URL is removed before redirecting the request. If set to false, the query portion of the original URL is retained. The default is set to false. ",
          type = "boolean",
        },
      },
      type = "object",
    },
    HttpRetryPolicy = {
      description = "The retry policy associates with HttpRouteRule",
      id = "HttpRetryPolicy",
      properties = {
        numRetries = {
          description = "Specifies the allowed number retries. This number must be > 0. If not specified, defaults to 1.",
          format = "uint32",
          type = "integer",
        },
        perTryTimeout = {
          ["$ref"] = "Duration",
          description = "Specifies a non-zero timeout per retry attempt. If not specified, will use the timeout set in the HttpRouteAction field. If timeout in the HttpRouteAction field is not set, this field uses the largest timeout among all backend services associated with the route. Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.",
        },
        retryConditions = {
          description = "Specifies one or more conditions when this retry policy applies. Valid values are: - 5xx: retry is attempted if the instance or endpoint responds with any 5xx response code, or if the instance or endpoint does not respond at all. For example, disconnects, reset, read timeout, connection failure, and refused streams. - gateway-error: Similar to 5xx, but only applies to response codes 502, 503 or 504. - connect-failure: a retry is attempted on failures connecting to the instance or endpoint. For example, connection timeouts. - retriable-4xx: a retry is attempted if the instance or endpoint responds with a 4xx response code. The only error that you can retry is error code 409. - refused-stream: a retry is attempted if the instance or endpoint resets the stream with a REFUSED_STREAM error code. This reset type indicates that it is safe to retry. - cancelled: a retry is attempted if the gRPC status code in the response header is set to cancelled. - deadline-exceeded: a retry is attempted if the gRPC status code in the response header is set to deadline-exceeded. - internal: a retry is attempted if the gRPC status code in the response header is set to internal. - resource-exhausted: a retry is attempted if the gRPC status code in the response header is set to resource-exhausted. - unavailable: a retry is attempted if the gRPC status code in the response header is set to unavailable. Only the following codes are supported when the URL map is bound to target gRPC proxy that has validateForProxyless field set to true. - cancelled - deadline-exceeded - internal - resource-exhausted - unavailable ",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    HttpRouteAction = {
      id = "HttpRouteAction",
      properties = {
        corsPolicy = {
          ["$ref"] = "CorsPolicy",
          description = "The specification for allowing client-side cross-origin requests. For more information about the W3C recommendation for cross-origin resource sharing (CORS), see Fetch API Living Standard. Not supported when the URL map is bound to a target gRPC proxy.",
        },
        faultInjectionPolicy = {
          ["$ref"] = "HttpFaultInjection",
          description = "The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by a load balancer on a percentage of requests before sending those requests to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests. timeout and retry_policy is ignored by clients that are configured with a fault_injection_policy if: 1. The traffic is generated by fault injection AND 2. The fault injection is not a delay fault injection. Fault injection is not supported with the global external HTTP(S) load balancer (classic). To see which load balancers support fault injection, see Load balancing: Routing and traffic management features.",
        },
        maxStreamDuration = {
          ["$ref"] = "Duration",
          description = "Specifies the maximum duration (timeout) for streams on the selected route. Unlike the timeout field where the timeout duration starts from the time the request has been fully processed (known as *end-of-stream*), the duration in this field is computed from the beginning of the stream until the response has been processed, including all retries. A stream that does not complete in this duration is closed. If not specified, this field uses the maximum maxStreamDuration value among all backend services associated with the route. This field is only allowed if the Url map is used with backend services with loadBalancingScheme set to INTERNAL_SELF_MANAGED.",
        },
        requestMirrorPolicy = {
          ["$ref"] = "RequestMirrorPolicy",
          description = "Specifies the policy on how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer does not wait for responses from the shadow service. Before sending traffic to the shadow service, the host / authority header is suffixed with -shadow. Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.",
        },
        retryPolicy = {
          ["$ref"] = "HttpRetryPolicy",
          description = "Specifies the retry policy associated with this route.",
        },
        timeout = {
          ["$ref"] = "Duration",
          description = "Specifies the timeout for the selected route. Timeout is computed from the time the request has been fully processed (known as *end-of-stream*) up until the response has been processed. Timeout includes all retries. If not specified, this field uses the largest timeout among all backend services associated with the route. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.",
        },
        urlRewrite = {
          ["$ref"] = "UrlRewrite",
          description = "The spec to modify the URL of the request, before forwarding the request to the matched service. urlRewrite is the only action supported in UrlMaps for external HTTP(S) load balancers. Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.",
        },
        weightedBackendServices = {
          description = "A list of weighted backend services to send traffic to when a route match occurs. The weights determine the fraction of traffic that flows to their corresponding backend service. If all traffic needs to go to a single backend service, there must be one weightedBackendService with weight set to a non-zero number. After a backend service is identified and before forwarding the request to the backend service, advanced routing actions such as URL rewrites and header transformations are applied depending on additional settings specified in this HttpRouteAction.",
          items = {
            ["$ref"] = "WeightedBackendService",
          },
          type = "array",
        },
      },
      type = "object",
    },
    HttpRouteRule = {
      description = "The HttpRouteRule setting specifies how to match an HTTP request and the corresponding routing action that load balancing proxies perform.",
      id = "HttpRouteRule",
      properties = {
        description = {
          description = "The short description conveying the intent of this routeRule. The description can have a maximum length of 1024 characters.",
          type = "string",
        },
        headerAction = {
          ["$ref"] = "HttpHeaderAction",
          description = "Specifies changes to request and response headers that need to take effect for the selected backendService. The headerAction value specified here is applied before the matching pathMatchers[].headerAction and after pathMatchers[].routeRules[].routeAction.weightedBackendService.backendServiceWeightAction[].headerAction HeaderAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.",
        },
        matchRules = {
          description = "The list of criteria for matching attributes of a request to this routeRule. This list has OR semantics: the request matches this routeRule when any of the matchRules are satisfied. However predicates within a given matchRule have AND semantics. All predicates within a matchRule must match for the request to match the rule.",
          items = {
            ["$ref"] = "HttpRouteRuleMatch",
          },
          type = "array",
        },
        priority = {
          description = "For routeRules within a given pathMatcher, priority determines the order in which a load balancer interprets routeRules. RouteRules are evaluated in order of priority, from the lowest to highest number. The priority of a rule decreases as its number increases (1, 2, 3, N+1). The first rule that matches the request is applied. You cannot configure two or more routeRules with the same priority. Priority for each rule must be set to a number from 0 to 2147483647 inclusive. Priority numbers can have gaps, which enable you to add or remove rules in the future without affecting the rest of the rules. For example, 1, 2, 3, 4, 5, 9, 12, 16 is a valid series of priority numbers to which you could add rules numbered from 6 to 8, 10 to 11, and 13 to 15 in the future without any impact on existing rules.",
          format = "int32",
          type = "integer",
        },
        routeAction = {
          ["$ref"] = "HttpRouteAction",
          description = "In response to a matching matchRule, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. If routeAction specifies any weightedBackendServices, service must not be set. Conversely if service is set, routeAction cannot contain any weightedBackendServices. Only one of urlRedirect, service or routeAction.weightedBackendService must be set. URL maps for Classic external HTTP(S) load balancers only support the urlRewrite action within a route rule's routeAction.",
        },
        service = {
          description = "The full or partial URL of the backend service resource to which traffic is directed if this rule is matched. If routeAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. However, if service is specified, routeAction cannot contain any weightedBackendServices. Conversely, if routeAction specifies any weightedBackendServices, service must not be specified. Only one of urlRedirect, service or routeAction.weightedBackendService must be set.",
          type = "string",
        },
        urlRedirect = {
          ["$ref"] = "HttpRedirectAction",
          description = "When this rule is matched, the request is redirected to a URL specified by urlRedirect. If urlRedirect is specified, service or routeAction must not be set. Not supported when the URL map is bound to a target gRPC proxy.",
        },
      },
      type = "object",
    },
    HttpRouteRuleMatch = {
      description = "HttpRouteRuleMatch specifies a set of criteria for matching requests to an HttpRouteRule. All specified criteria must be satisfied for a match to occur.",
      id = "HttpRouteRuleMatch",
      properties = {
        fullPathMatch = {
          description = "For satisfying the matchRule condition, the path of the request must exactly match the value specified in fullPathMatch after removing any query parameters and anchor that may be part of the original URL. fullPathMatch must be from 1 to 1024 characters. Only one of prefixMatch, fullPathMatch or regexMatch must be specified.",
          type = "string",
        },
        headerMatches = {
          description = "Specifies a list of header match criteria, all of which must match corresponding headers in the request.",
          items = {
            ["$ref"] = "HttpHeaderMatch",
          },
          type = "array",
        },
        ignoreCase = {
          description = "Specifies that prefixMatch and fullPathMatch matches are case sensitive. The default value is false. ignoreCase must not be used with regexMatch. Not supported when the URL map is bound to a target gRPC proxy.",
          type = "boolean",
        },
        metadataFilters = {
          description = "Opaque filter criteria used by the load balancer to restrict routing configuration to a limited set of xDS compliant clients. In their xDS requests to the load balancer, xDS clients present node metadata. When there is a match, the relevant routing configuration is made available to those proxies. For each metadataFilter in this list, if its filterMatchCriteria is set to MATCH_ANY, at least one of the filterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. If multiple metadata filters are specified, all of them need to be satisfied in order to be considered a match. metadataFilters specified here is applied after those specified in ForwardingRule that refers to the UrlMap this HttpRouteRuleMatch belongs to. metadataFilters only applies to load balancers that have loadBalancingScheme set to INTERNAL_SELF_MANAGED. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.",
          items = {
            ["$ref"] = "MetadataFilter",
          },
          type = "array",
        },
        prefixMatch = {
          description = "For satisfying the matchRule condition, the request's path must begin with the specified prefixMatch. prefixMatch must begin with a /. The value must be from 1 to 1024 characters. Only one of prefixMatch, fullPathMatch or regexMatch must be specified.",
          type = "string",
        },
        queryParameterMatches = {
          description = "Specifies a list of query parameter match criteria, all of which must match corresponding query parameters in the request. Not supported when the URL map is bound to a target gRPC proxy.",
          items = {
            ["$ref"] = "HttpQueryParameterMatch",
          },
          type = "array",
        },
        regexMatch = {
          description = "For satisfying the matchRule condition, the path of the request must satisfy the regular expression specified in regexMatch after removing any query parameters and anchor supplied with the original URL. For more information about regular expression syntax, see Syntax. Only one of prefixMatch, fullPathMatch or regexMatch must be specified. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED.",
          type = "string",
        },
      },
      type = "object",
    },
    HttpsHealthCheck = {
      description = "Represents a legacy HTTPS Health Check resource. Legacy HTTPS health checks have been deprecated. If you are using a target pool-based network load balancer, you must use a legacy HTTP (not HTTPS) health check. For all other load balancers, including backend service-based network load balancers, and for managed instance group auto-healing, you must use modern (non-legacy) health checks. For more information, see Health checks overview .",
      id = "HttpsHealthCheck",
      properties = {
        checkIntervalSec = {
          description = "How often (in seconds) to send a health check. The default value is 5 seconds.",
          format = "int32",
          type = "integer",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        healthyThreshold = {
          description = "A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.",
          format = "int32",
          type = "integer",
        },
        host = {
          description = "The value of the host header in the HTTPS health check request. If left empty (default value), the public IP on behalf of which this health check is performed will be used.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#httpsHealthCheck",
          description = "Type of the resource.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        port = {
          description = "The TCP port number for the HTTPS health check request. The default value is 443.",
          format = "int32",
          type = "integer",
        },
        requestPath = {
          description = "The request path of the HTTPS health check request. The default value is \"/\".",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        timeoutSec = {
          description = "How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have a greater value than checkIntervalSec.",
          format = "int32",
          type = "integer",
        },
        unhealthyThreshold = {
          description = "A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    HttpsHealthCheckList = {
      description = "Contains a list of HttpsHealthCheck resources.",
      id = "HttpsHealthCheckList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of HttpsHealthCheck resources.",
          items = {
            ["$ref"] = "HttpsHealthCheck",
          },
          type = "array",
        },
        kind = {
          default = "compute#httpsHealthCheckList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    Image = {
      description = "Represents an Image resource. You can use images to create boot disks for your VM instances. For more information, read Images.",
      id = "Image",
      properties = {
        architecture = {
          description = "The architecture of the image. Valid values are ARM64 or X86_64.",
          enum = {
            "ARCHITECTURE_UNSPECIFIED",
            "ARM64",
            "X86_64",
          },
          enumDescriptions = {
            "Default value indicating Architecture is not set.",
            "Machines with architecture ARM64",
            "Machines with architecture X86_64",
          },
          type = "string",
        },
        archiveSizeBytes = {
          description = "Size of the image tar.gz archive stored in Google Cloud Storage (in bytes).",
          format = "int64",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        deprecated = {
          ["$ref"] = "DeprecationStatus",
          description = "The deprecation status associated with this image.",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        diskSizeGb = {
          description = "Size of the image when restored onto a persistent disk (in GB).",
          format = "int64",
          type = "string",
        },
        family = {
          description = "The name of the image family to which this image belongs. You can create disks by specifying an image family instead of a specific image name. The image family always returns its latest image that is not deprecated. The name of the image family must comply with RFC1035.",
          type = "string",
        },
        guestOsFeatures = {
          description = "A list of features to enable on the guest operating system. Applicable only for bootable images. To see a list of available options, see the guestOSfeatures[].type parameter.",
          items = {
            ["$ref"] = "GuestOsFeature",
          },
          type = "array",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        imageEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "Encrypts the image using a customer-supplied encryption key. After you encrypt an image with a customer-supplied key, you must provide the same key if you use the image later (e.g. to create a disk from the image). Customer-supplied encryption keys do not protect access to metadata of the disk. If you do not provide an encryption key when creating the image, then the disk will be encrypted using an automatically generated key and you do not need to provide a key to use the image later.",
        },
        kind = {
          default = "compute#image",
          description = "[Output Only] Type of the resource. Always compute#image for images.",
          type = "string",
        },
        labelFingerprint = {
          description = "A fingerprint for the labels being applied to this image, which is essentially a hash of the labels used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an image.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels to apply to this image. These can be later modified by the setLabels method.",
          type = "object",
        },
        licenseCodes = {
          description = "Integer license codes indicating which licenses are attached to this image.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        licenses = {
          description = "Any applicable license URI.",
          items = {
            type = "string",
          },
          type = "array",
        },
        name = {
          annotations = {
            required = {
              "compute.images.insert",
            },
          },
          description = "Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        rawDisk = {
          description = "The parameters of the raw disk image.",
          properties = {
            containerType = {
              description = "The format used to encode and transmit the block device, which should be TAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created.",
              enum = {
                "TAR",
              },
              enumDescriptions = {
                "",
              },
              type = "string",
            },
            sha1Checksum = {
              description = "[Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created.",
              pattern = "[a-f0-9]{40}",
              type = "string",
            },
            source = {
              description = "The full Google Cloud Storage URL where the raw disk image archive is stored. The following are valid formats for the URL: - https://storage.googleapis.com/bucket_name/image_archive_name - https://storage.googleapis.com/bucket_name/folder_name/ image_archive_name In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL ",
              type = "string",
            },
          },
          type = "object",
        },
        satisfiesPzs = {
          description = "[Output Only] Reserved for future use.",
          type = "boolean",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        shieldedInstanceInitialState = {
          ["$ref"] = "InitialStateConfig",
          description = "Set the secure boot keys of shielded instance.",
        },
        sourceDisk = {
          description = "URL of the source disk used to create this image. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/disks/disk In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL ",
          type = "string",
        },
        sourceDiskEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.",
        },
        sourceDiskId = {
          description = "[Output Only] The ID value of the disk used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given disk name.",
          type = "string",
        },
        sourceImage = {
          description = "URL of the source image used to create this image. The following are valid formats for the URL: - https://www.googleapis.com/compute/v1/projects/project_id/global/ images/image_name - projects/project_id/global/images/image_name In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL ",
          type = "string",
        },
        sourceImageEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key.",
        },
        sourceImageId = {
          description = "[Output Only] The ID value of the image used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given image name.",
          type = "string",
        },
        sourceSnapshot = {
          description = "URL of the source snapshot used to create this image. The following are valid formats for the URL: - https://www.googleapis.com/compute/v1/projects/project_id/global/ snapshots/snapshot_name - projects/project_id/global/snapshots/snapshot_name In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL ",
          type = "string",
        },
        sourceSnapshotEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The customer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key.",
        },
        sourceSnapshotId = {
          description = "[Output Only] The ID value of the snapshot used to create this image. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given snapshot name.",
          type = "string",
        },
        sourceType = {
          default = "RAW",
          description = "The type of the image used to create this disk. The default and only valid value is RAW.",
          enum = {
            "RAW",
          },
          enumDescriptions = {
            "",
          },
          type = "string",
        },
        status = {
          description = "[Output Only] The status of the image. An image can be used to create other resources, such as instances, only after the image has been successfully created and the status is set to READY. Possible values are FAILED, PENDING, or READY.",
          enum = {
            "DELETING",
            "FAILED",
            "PENDING",
            "READY",
          },
          enumDescriptions = {
            "Image is deleting.",
            "Image creation failed due to an error.",
            "Image hasn't been created as yet.",
            "Image has been successfully created.",
          },
          type = "string",
        },
        storageLocations = {
          description = "Cloud Storage bucket storage location of the image (regional or multi-regional).",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ImageFamilyView = {
      id = "ImageFamilyView",
      properties = {
        image = {
          ["$ref"] = "Image",
          description = "The latest image that is part of the specified image family in the requested location, and that is not deprecated.",
        },
      },
      type = "object",
    },
    ImageList = {
      description = "Contains a list of images.",
      id = "ImageList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Image resources.",
          items = {
            ["$ref"] = "Image",
          },
          type = "array",
        },
        kind = {
          default = "compute#imageList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InitialStateConfig = {
      description = "Initial State for shielded instance, these are public keys which are safe to store in public",
      id = "InitialStateConfig",
      properties = {
        dbs = {
          description = "The Key Database (db).",
          items = {
            ["$ref"] = "FileContentBuffer",
          },
          type = "array",
        },
        dbxs = {
          description = "The forbidden key database (dbx).",
          items = {
            ["$ref"] = "FileContentBuffer",
          },
          type = "array",
        },
        keks = {
          description = "The Key Exchange Key (KEK).",
          items = {
            ["$ref"] = "FileContentBuffer",
          },
          type = "array",
        },
        pk = {
          ["$ref"] = "FileContentBuffer",
          description = "The Platform Key (PK).",
        },
      },
      type = "object",
    },
    Instance = {
      description = "Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, read Virtual Machine Instances.",
      id = "Instance",
      properties = {
        advancedMachineFeatures = {
          ["$ref"] = "AdvancedMachineFeatures",
          description = "Controls for advanced machine-related behavior features.",
        },
        canIpForward = {
          description = "Allows this instance to send and receive packets with non-matching destination or source IPs. This is required if you plan to use this instance to forward routes. For more information, see Enabling IP Forwarding .",
          type = "boolean",
        },
        confidentialInstanceConfig = {
          ["$ref"] = "ConfidentialInstanceConfig",
        },
        cpuPlatform = {
          description = "[Output Only] The CPU platform used by this instance.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        deletionProtection = {
          description = "Whether the resource should be protected against deletion.",
          type = "boolean",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        disks = {
          description = "Array of disks associated with this instance. Persistent disks must be created before you can assign them.",
          items = {
            ["$ref"] = "AttachedDisk",
          },
          type = "array",
        },
        displayDevice = {
          ["$ref"] = "DisplayDevice",
          description = "Enables display device for the instance.",
        },
        fingerprint = {
          description = "Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance. You must always provide an up-to-date fingerprint hash in order to update the instance. To see the latest fingerprint, make get() request to the instance.",
          format = "byte",
          type = "string",
        },
        guestAccelerators = {
          description = "A list of the type and count of accelerator cards attached to the instance.",
          items = {
            ["$ref"] = "AcceleratorConfig",
          },
          type = "array",
        },
        hostname = {
          description = "Specifies the hostname of the instance. The specified hostname must be RFC1035 compliant. If hostname is not specified, the default hostname is [INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and [INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        keyRevocationActionType = {
          description = "KeyRevocationActionType of the instance. Supported options are \"STOP\" and \"NONE\". The default value is \"NONE\" if it is not specified.",
          enum = {
            "KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED",
            "NONE",
            "STOP",
          },
          enumDescriptions = {
            "Default value. This value is unused.",
            "Indicates user chose no operation.",
            "Indicates user chose to opt for VM shutdown on key revocation.",
          },
          type = "string",
        },
        kind = {
          default = "compute#instance",
          description = "[Output Only] Type of the resource. Always compute#instance for instances.",
          type = "string",
        },
        labelFingerprint = {
          description = "A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the instance.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels to apply to this instance. These can be later modified by the setLabels method.",
          type = "object",
        },
        lastStartTimestamp = {
          description = "[Output Only] Last start timestamp in RFC3339 text format.",
          type = "string",
        },
        lastStopTimestamp = {
          description = "[Output Only] Last stop timestamp in RFC3339 text format.",
          type = "string",
        },
        lastSuspendedTimestamp = {
          description = "[Output Only] Last suspended timestamp in RFC3339 text format.",
          type = "string",
        },
        machineType = {
          annotations = {
            required = {
              "compute.instances.insert",
            },
          },
          description = "Full or partial URL of the machine type resource to use for this instance, in the format: zones/zone/machineTypes/machine-type. This is provided by the client when the instance is created. For example, the following is a valid partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-standard-1 To create a custom machine type, provide a URL to a machine type in the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the total memory for this instance. Memory must be a multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB): zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/machineTypes/custom-4-5120 For a full list of restrictions, read the Specifications for custom machine types.",
          type = "string",
        },
        metadata = {
          ["$ref"] = "Metadata",
          description = "The metadata key/value pairs assigned to this instance. This includes custom metadata and predefined keys.",
        },
        minCpuPlatform = {
          description = "Specifies a minimum CPU platform for the VM instance. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: \"Intel Haswell\" or minCpuPlatform: \"Intel Sandy Bridge\".",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.instances.insert",
            },
          },
          description = "The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        networkInterfaces = {
          description = "An array of network configurations for this instance. These specify how interfaces are configured to interact with other network services, such as connecting to the internet. Multiple interfaces are supported per instance.",
          items = {
            ["$ref"] = "NetworkInterface",
          },
          type = "array",
        },
        networkPerformanceConfig = {
          ["$ref"] = "NetworkPerformanceConfig",
        },
        params = {
          ["$ref"] = "InstanceParams",
          description = "Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.",
        },
        privateIpv6GoogleAccess = {
          description = "The private IPv6 google access type for the VM. If not specified, use INHERIT_FROM_SUBNETWORK as default.",
          enum = {
            "ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE",
            "ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE",
            "INHERIT_FROM_SUBNETWORK",
          },
          enumDescriptions = {
            "Bidirectional private IPv6 access to/from Google services. If specified, the subnetwork who is attached to the instance's default network interface will be assigned an internal IPv6 prefix if it doesn't have before.",
            "Outbound private IPv6 access from VMs in this subnet to Google services. If specified, the subnetwork who is attached to the instance's default network interface will be assigned an internal IPv6 prefix if it doesn't have before.",
            "Each network interface inherits PrivateIpv6GoogleAccess from its subnetwork.",
          },
          type = "string",
        },
        reservationAffinity = {
          ["$ref"] = "ReservationAffinity",
          description = "Specifies the reservations that this instance can consume from.",
        },
        resourcePolicies = {
          description = "Resource policies applied to this instance.",
          items = {
            type = "string",
          },
          type = "array",
        },
        resourceStatus = {
          ["$ref"] = "ResourceStatus",
          description = "[Output Only] Specifies values set for instance attributes as compared to the values requested by user in the corresponding input only field.",
        },
        satisfiesPzs = {
          description = "[Output Only] Reserved for future use.",
          type = "boolean",
        },
        scheduling = {
          ["$ref"] = "Scheduling",
          description = "Sets the scheduling options for this instance.",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        serviceAccounts = {
          description = "A list of service accounts, with their specified scopes, authorized for this instance. Only one service account per VM instance is supported. Service accounts generate access tokens that can be accessed through the metadata server and used to authenticate applications on the instance. See Service Accounts for more information.",
          items = {
            ["$ref"] = "ServiceAccount",
          },
          type = "array",
        },
        shieldedInstanceConfig = {
          ["$ref"] = "ShieldedInstanceConfig",
        },
        shieldedInstanceIntegrityPolicy = {
          ["$ref"] = "ShieldedInstanceIntegrityPolicy",
        },
        sourceMachineImage = {
          description = "Source machine image",
          type = "string",
        },
        sourceMachineImageEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "Source machine image encryption key when creating an instance from a machine image.",
        },
        startRestricted = {
          description = "[Output Only] Whether a VM has been restricted for start because Compute Engine has detected suspicious activity.",
          type = "boolean",
        },
        status = {
          description = "[Output Only] The status of the instance. One of the following values: PROVISIONING, STAGING, RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING, and TERMINATED. For more information about the status of the instance, see Instance life cycle.",
          enum = {
            "DEPROVISIONING",
            "PROVISIONING",
            "REPAIRING",
            "RUNNING",
            "STAGING",
            "STOPPED",
            "STOPPING",
            "SUSPENDED",
            "SUSPENDING",
            "TERMINATED",
          },
          enumDescriptions = {
            "The Nanny is halted and we are performing tear down tasks like network deprogramming, releasing quota, IP, tearing down disks etc.",
            "Resources are being allocated for the instance.",
            "The instance is in repair.",
            "The instance is running.",
            "All required resources have been allocated and the instance is being started.",
            "The instance has stopped successfully.",
            "The instance is currently stopping (either being deleted or killed).",
            "The instance has suspended.",
            "The instance is suspending.",
            "The instance has stopped (either by explicit action or underlying failure).",
          },
          type = "string",
        },
        statusMessage = {
          description = "[Output Only] An optional, human-readable explanation of the status.",
          type = "string",
        },
        tags = {
          ["$ref"] = "Tags",
          description = "Tags to apply to this instance. Tags are used to identify valid sources or targets for network firewalls and are specified by the client during instance creation. The tags can be later modified by the setTags method. Each tag within the list must comply with RFC1035. Multiple tags can be specified via the 'tags.items' field.",
        },
        zone = {
          description = "[Output Only] URL of the zone where the instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceAggregatedList = {
      id = "InstanceAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "InstancesScopedList",
            description = "[Output Only] Name of the scope containing this set of instances.",
          },
          description = "An object that contains a list of instances scoped by zone.",
          type = "object",
        },
        kind = {
          default = "compute#instanceAggregatedList",
          description = "[Output Only] Type of resource. Always compute#instanceAggregatedList for aggregated lists of Instance resources.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceConsumptionData = {
      id = "InstanceConsumptionData",
      properties = {
        consumptionInfo = {
          ["$ref"] = "InstanceConsumptionInfo",
          description = "Resources consumed by the instance.",
        },
        instance = {
          description = "Server-defined URL for the instance.",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceConsumptionInfo = {
      id = "InstanceConsumptionInfo",
      properties = {
        guestCpus = {
          description = "The number of virtual CPUs that are available to the instance.",
          format = "int32",
          type = "integer",
        },
        localSsdGb = {
          description = "The amount of local SSD storage available to the instance, defined in GiB.",
          format = "int32",
          type = "integer",
        },
        memoryMb = {
          description = "The amount of physical memory available to the instance, defined in MiB.",
          format = "int32",
          type = "integer",
        },
        minNodeCpus = {
          description = "The minimal guaranteed number of virtual CPUs that are reserved.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    InstanceGroup = {
      description = "Represents an Instance Group resource. Instance Groups can be used to configure a target for load balancing. Instance groups can either be managed or unmanaged. To create managed instance groups, use the instanceGroupManager or regionInstanceGroupManager resource instead. Use zonal unmanaged instance groups if you need to apply load balancing to groups of heterogeneous instances or if you need to manage the instances yourself. You cannot create regional unmanaged instance groups. For more information, read Instance groups.",
      id = "InstanceGroup",
      properties = {
        creationTimestamp = {
          description = "[Output Only] The creation timestamp for this instance group in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "[Output Only] The fingerprint of the named ports. The system uses this fingerprint to detect conflicts when multiple users change the named ports concurrently.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] A unique identifier for this instance group, generated by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#instanceGroup",
          description = "[Output Only] The resource type, which is always compute#instanceGroup for instance groups.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.instanceGroups.insert",
            },
          },
          description = "The name of the instance group. The name must be 1-63 characters long, and comply with RFC1035.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        namedPorts = {
          description = " Assigns a name to a port number. For example: {name: \"http\", port: 80} This allows the system to reference ports by the assigned name instead of a port number. Named ports can also contain multiple ports. For example: [{name: \"app1\", port: 8080}, {name: \"app1\", port: 8081}, {name: \"app2\", port: 8082}] Named ports apply to all instances in this instance group. ",
          items = {
            ["$ref"] = "NamedPort",
          },
          type = "array",
        },
        network = {
          description = "[Output Only] The URL of the network to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0).",
          type = "string",
        },
        region = {
          description = "[Output Only] The URL of the region where the instance group is located (for regional resources).",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] The URL for this instance group. The server generates this URL.",
          type = "string",
        },
        size = {
          description = "[Output Only] The total number of instances in the instance group.",
          format = "int32",
          type = "integer",
        },
        subnetwork = {
          description = "[Output Only] The URL of the subnetwork to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0).",
          type = "string",
        },
        zone = {
          description = "[Output Only] The URL of the zone where the instance group is located (for zonal resources).",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceGroupAggregatedList = {
      id = "InstanceGroupAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "InstanceGroupsScopedList",
            description = "The name of the scope that contains this set of instance groups.",
          },
          description = "A list of InstanceGroupsScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#instanceGroupAggregatedList",
          description = "[Output Only] The resource type, which is always compute#instanceGroupAggregatedList for aggregated lists of instance groups.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceGroupList = {
      description = "A list of InstanceGroup resources.",
      id = "InstanceGroupList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of InstanceGroup resources.",
          items = {
            ["$ref"] = "InstanceGroup",
          },
          type = "array",
        },
        kind = {
          default = "compute#instanceGroupList",
          description = "[Output Only] The resource type, which is always compute#instanceGroupList for instance group lists.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceGroupManager = {
      description = "Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, read Instance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use the regionInstanceGroupManagers resource.",
      id = "InstanceGroupManager",
      properties = {
        autoHealingPolicies = {
          description = "The autohealing policy for this managed instance group. You can specify only one value.",
          items = {
            ["$ref"] = "InstanceGroupManagerAutoHealingPolicy",
          },
          type = "array",
        },
        baseInstanceName = {
          annotations = {
            required = {
              "compute.instanceGroupManagers.insert",
            },
          },
          description = "The base instance name to use for instances in this group. The value must be 1-58 characters long. Instances are named by appending a hyphen and a random four-character string to the base instance name. The base instance name must comply with RFC1035.",
          pattern = "[a-z][-a-z0-9]{0,57}",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] The creation timestamp for this managed instance group in RFC3339 text format.",
          type = "string",
        },
        currentActions = {
          ["$ref"] = "InstanceGroupManagerActionsSummary",
          description = "[Output Only] The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions.",
        },
        description = {
          description = "An optional description of this resource.",
          type = "string",
        },
        distributionPolicy = {
          ["$ref"] = "DistributionPolicy",
          description = "Policy specifying the intended distribution of managed instances across zones in a regional managed instance group.",
        },
        fingerprint = {
          description = "Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] A unique identifier for this resource type. The server generates this identifier.",
          format = "uint64",
          type = "string",
        },
        instanceGroup = {
          description = "[Output Only] The URL of the Instance Group resource.",
          type = "string",
        },
        instanceTemplate = {
          description = "The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE.",
          type = "string",
        },
        kind = {
          default = "compute#instanceGroupManager",
          description = "[Output Only] The resource type, which is always compute#instanceGroupManager for managed instance groups.",
          type = "string",
        },
        listManagedInstancesResults = {
          description = "Pagination behavior of the listManagedInstances API method for this managed instance group.",
          enum = {
            "PAGELESS",
            "PAGINATED",
          },
          enumDescriptions = {
            "(Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.",
            "Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.",
          },
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.instanceGroupManagers.insert",
              "compute.regionInstanceGroupManagers.insert",
            },
          },
          description = "The name of the managed instance group. The name must be 1-63 characters long, and comply with RFC1035.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        namedPorts = {
          description = "Named ports configured for the Instance Groups complementary to this Instance Group Manager.",
          items = {
            ["$ref"] = "NamedPort",
          },
          type = "array",
        },
        region = {
          description = "[Output Only] The URL of the region where the managed instance group resides (for regional resources).",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] The URL for this managed instance group. The server defines this URL.",
          type = "string",
        },
        statefulPolicy = {
          ["$ref"] = "StatefulPolicy",
          description = "Stateful configuration for this Instanced Group Manager",
        },
        status = {
          ["$ref"] = "InstanceGroupManagerStatus",
          description = "[Output Only] The status of this managed instance group.",
        },
        targetPools = {
          description = "The URLs for all TargetPool resources to which instances in the instanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group.",
          items = {
            type = "string",
          },
          type = "array",
        },
        targetSize = {
          annotations = {
            required = {
              "compute.instanceGroupManagers.insert",
              "compute.regionInstanceGroupManagers.insert",
            },
          },
          description = "The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number.",
          format = "int32",
          type = "integer",
        },
        updatePolicy = {
          ["$ref"] = "InstanceGroupManagerUpdatePolicy",
          description = "The update policy for this managed instance group.",
        },
        versions = {
          description = "Specifies the instance templates used by this managed instance group to create instances. Each version is defined by an instanceTemplate and a name. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about the relationships between these fields. Exactly one version must leave the targetSize field unset. That version will be applied to all remaining instances. For more information, read about canary updates.",
          items = {
            ["$ref"] = "InstanceGroupManagerVersion",
          },
          type = "array",
        },
        zone = {
          description = "[Output Only] The URL of a zone where the managed instance group is located (for zonal resources).",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceGroupManagerActionsSummary = {
      id = "InstanceGroupManagerActionsSummary",
      properties = {
        abandoning = {
          description = "[Output Only] The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it.",
          format = "int32",
          type = "integer",
        },
        creating = {
          description = "[Output Only] The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated.",
          format = "int32",
          type = "integer",
        },
        creatingWithoutRetries = {
          description = "[Output Only] The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly.",
          format = "int32",
          type = "integer",
        },
        deleting = {
          description = "[Output Only] The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted.",
          format = "int32",
          type = "integer",
        },
        none = {
          description = "[Output Only] The number of instances in the managed instance group that are running and have no scheduled actions.",
          format = "int32",
          type = "integer",
        },
        recreating = {
          description = "[Output Only] The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template.",
          format = "int32",
          type = "integer",
        },
        refreshing = {
          description = "[Output Only] The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance.",
          format = "int32",
          type = "integer",
        },
        restarting = {
          description = "[Output Only] The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted.",
          format = "int32",
          type = "integer",
        },
        resuming = {
          description = "[Output Only] The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed.",
          format = "int32",
          type = "integer",
        },
        starting = {
          description = "[Output Only] The number of instances in the managed instance group that are scheduled to be started or are currently being started.",
          format = "int32",
          type = "integer",
        },
        stopping = {
          description = "[Output Only] The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped.",
          format = "int32",
          type = "integer",
        },
        suspending = {
          description = "[Output Only] The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended.",
          format = "int32",
          type = "integer",
        },
        verifying = {
          description = "[Output Only] The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    InstanceGroupManagerAggregatedList = {
      id = "InstanceGroupManagerAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "InstanceGroupManagersScopedList",
            description = "[Output Only] The name of the scope that contains this set of managed instance groups.",
          },
          description = "A list of InstanceGroupManagersScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#instanceGroupManagerAggregatedList",
          description = "[Output Only] The resource type, which is always compute#instanceGroupManagerAggregatedList for an aggregated list of managed instance groups.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceGroupManagerAutoHealingPolicy = {
      id = "InstanceGroupManagerAutoHealingPolicy",
      properties = {
        healthCheck = {
          description = "The URL for the health check that signals autohealing.",
          type = "string",
        },
        initialDelaySec = {
          description = "The number of seconds that the managed instance group waits before it applies autohealing policies to new instances or recently recreated instances. This initial delay allows instances to initialize and run their startup scripts before the instance group determines that they are UNHEALTHY. This prevents the managed instance group from recreating its instances prematurely. This value must be from range [0, 3600].",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    InstanceGroupManagerList = {
      description = "[Output Only] A list of managed instance groups.",
      id = "InstanceGroupManagerList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of InstanceGroupManager resources.",
          items = {
            ["$ref"] = "InstanceGroupManager",
          },
          type = "array",
        },
        kind = {
          default = "compute#instanceGroupManagerList",
          description = "[Output Only] The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceGroupManagerStatus = {
      id = "InstanceGroupManagerStatus",
      properties = {
        autoscaler = {
          description = "[Output Only] The URL of the Autoscaler that targets this instance group manager.",
          type = "string",
        },
        isStable = {
          description = "[Output Only] A bit indicating whether the managed instance group is in a stable state. A stable state means that: none of the instances in the managed instance group is currently undergoing any type of change (for example, creation, restart, or deletion); no future changes are scheduled for instances in the managed instance group; and the managed instance group itself is not being modified.",
          type = "boolean",
        },
        stateful = {
          ["$ref"] = "InstanceGroupManagerStatusStateful",
          description = "[Output Only] Stateful status of the given Instance Group Manager.",
        },
        versionTarget = {
          ["$ref"] = "InstanceGroupManagerStatusVersionTarget",
          description = "[Output Only] A status of consistency of Instances' versions with their target version specified by version field on Instance Group Manager.",
        },
      },
      type = "object",
    },
    InstanceGroupManagerStatusStateful = {
      id = "InstanceGroupManagerStatusStateful",
      properties = {
        hasStatefulConfig = {
          description = "[Output Only] A bit indicating whether the managed instance group has stateful configuration, that is, if you have configured any items in a stateful policy or in per-instance configs. The group might report that it has no stateful configuration even when there is still some preserved state on a managed instance, for example, if you have deleted all PICs but not yet applied those deletions.",
          type = "boolean",
        },
        perInstanceConfigs = {
          ["$ref"] = "InstanceGroupManagerStatusStatefulPerInstanceConfigs",
          description = "[Output Only] Status of per-instance configurations on the instance.",
        },
      },
      type = "object",
    },
    InstanceGroupManagerStatusStatefulPerInstanceConfigs = {
      id = "InstanceGroupManagerStatusStatefulPerInstanceConfigs",
      properties = {
        allEffective = {
          description = "A bit indicating if all of the group's per-instance configurations (listed in the output of a listPerInstanceConfigs API call) have status EFFECTIVE or there are no per-instance-configs.",
          type = "boolean",
        },
      },
      type = "object",
    },
    InstanceGroupManagerStatusVersionTarget = {
      id = "InstanceGroupManagerStatusVersionTarget",
      properties = {
        isReached = {
          description = "[Output Only] A bit indicating whether version target has been reached in this managed instance group, i.e. all instances are in their target version. Instances' target version are specified by version field on Instance Group Manager.",
          type = "boolean",
        },
      },
      type = "object",
    },
    InstanceGroupManagerUpdatePolicy = {
      id = "InstanceGroupManagerUpdatePolicy",
      properties = {
        instanceRedistributionType = {
          description = "The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled. ",
          enum = {
            "NONE",
            "PROACTIVE",
          },
          enumDescriptions = {
            "No action is being proactively performed in order to bring this IGM to its target instance distribution.",
            "This IGM will actively converge to its target instance distribution.",
          },
          type = "string",
        },
        maxSurge = {
          ["$ref"] = "FixedOrPercent",
          description = "The maximum number of instances that can be created above the specified targetSize during the update process. This value can be either a fixed number or, if the group has 10 or more instances, a percentage. If you set a percentage, the number of instances is rounded if necessary. The default value for maxSurge is a fixed value equal to the number of zones in which the managed instance group operates. At least one of either maxSurge or maxUnavailable must be greater than 0. Learn more about maxSurge.",
        },
        maxUnavailable = {
          ["$ref"] = "FixedOrPercent",
          description = "The maximum number of instances that can be unavailable during the update process. An instance is considered available if all of the following conditions are satisfied: - The instance's status is RUNNING. - If there is a health check on the instance group, the instance's health check status must be HEALTHY at least once. If there is no health check on the group, then the instance only needs to have a status of RUNNING to be considered available. This value can be either a fixed number or, if the group has 10 or more instances, a percentage. If you set a percentage, the number of instances is rounded if necessary. The default value for maxUnavailable is a fixed value equal to the number of zones in which the managed instance group operates. At least one of either maxSurge or maxUnavailable must be greater than 0. Learn more about maxUnavailable.",
        },
        minimalAction = {
          description = "Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary. - To limit disruption as much as possible, set the minimal action to REFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update. - To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. ",
          enum = {
            "NONE",
            "REFRESH",
            "REPLACE",
            "RESTART",
          },
          enumDescriptions = {
            "Do not perform any action.",
            "Updates applied in runtime, instances will not be disrupted.",
            "Old instances will be deleted. New instances will be created from the target template.",
            "Every instance will be restarted.",
          },
          type = "string",
        },
        mostDisruptiveAllowedAction = {
          description = "Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions, REFRESH to allow actions that do not need instance restart, RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all.",
          enum = {
            "NONE",
            "REFRESH",
            "REPLACE",
            "RESTART",
          },
          enumDescriptions = {
            "Do not perform any action.",
            "Updates applied in runtime, instances will not be disrupted.",
            "Old instances will be deleted. New instances will be created from the target template.",
            "Every instance will be restarted.",
          },
          type = "string",
        },
        replacementMethod = {
          description = "What action should be used to replace instances. See minimal_action.REPLACE",
          enum = {
            "RECREATE",
            "SUBSTITUTE",
          },
          enumDescriptions = {
            "Instances will be recreated (with the same name)",
            "Default option: instances will be deleted and created (with a new name)",
          },
          type = "string",
        },
        type = {
          description = "The type of update process. You can specify either PROACTIVE so that the instance group manager proactively executes actions in order to bring instances to their target versions or OPPORTUNISTIC so that no action is proactively executed but the update will be performed as part of other actions (for example, resizes or recreateInstances calls).",
          enum = {
            "OPPORTUNISTIC",
            "PROACTIVE",
          },
          enumDescriptions = {
            "No action is being proactively performed in order to bring this IGM to its target version distribution (regardless of whether this distribution is expressed using instanceTemplate or versions field).",
            "This IGM will actively converge to its target version distribution (regardless of whether this distribution is expressed using instanceTemplate or versions field).",
          },
          type = "string",
        },
      },
      type = "object",
    },
    InstanceGroupManagerVersion = {
      id = "InstanceGroupManagerVersion",
      properties = {
        instanceTemplate = {
          description = "The URL of the instance template that is specified for this managed instance group. The group uses this template to create new instances in the managed instance group until the `targetSize` for this version is reached. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE; in those cases, existing instances are updated until the `targetSize` for this version is reached.",
          type = "string",
        },
        name = {
          description = "Name of the version. Unique among all versions in the scope of this managed instance group.",
          type = "string",
        },
        targetSize = {
          ["$ref"] = "FixedOrPercent",
          description = "Specifies the intended number of instances to be created from the instanceTemplate. The final number of instances created from the template will be equal to: - If expressed as a fixed number, the minimum of either targetSize.fixed or instanceGroupManager.targetSize is used. - if expressed as a percent, the targetSize would be (targetSize.percent/100 * InstanceGroupManager.targetSize) If there is a remainder, the number is rounded. If unset, this version will update any remaining instances not updated by another version. Read Starting a canary update for more information.",
        },
      },
      type = "object",
    },
    InstanceGroupManagersAbandonInstancesRequest = {
      id = "InstanceGroupManagersAbandonInstancesRequest",
      properties = {
        instances = {
          description = "The URLs of one or more instances to abandon. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceGroupManagersApplyUpdatesRequest = {
      description = "InstanceGroupManagers.applyUpdatesToInstances",
      id = "InstanceGroupManagersApplyUpdatesRequest",
      properties = {
        allInstances = {
          description = "Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.",
          type = "boolean",
        },
        instances = {
          description = "The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].",
          items = {
            type = "string",
          },
          type = "array",
        },
        minimalAction = {
          description = "The minimal action that you want to perform on each instance during the update: - REPLACE: At minimum, delete the instance and create it again. - RESTART: Stop the instance and start it again. - REFRESH: Do not stop the instance. - NONE: Do not disrupt the instance at all. By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update.",
          enum = {
            "NONE",
            "REFRESH",
            "REPLACE",
            "RESTART",
          },
          enumDescriptions = {
            "Do not perform any action.",
            "Updates applied in runtime, instances will not be disrupted.",
            "Old instances will be deleted. New instances will be created from the target template.",
            "Every instance will be restarted.",
          },
          type = "string",
        },
        mostDisruptiveAllowedAction = {
          description = "The most disruptive action that you want to perform on each instance during the update: - REPLACE: Delete the instance and create it again. - RESTART: Stop the instance and start it again. - REFRESH: Do not stop the instance. - NONE: Do not disrupt the instance at all. By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail.",
          enum = {
            "NONE",
            "REFRESH",
            "REPLACE",
            "RESTART",
          },
          enumDescriptions = {
            "Do not perform any action.",
            "Updates applied in runtime, instances will not be disrupted.",
            "Old instances will be deleted. New instances will be created from the target template.",
            "Every instance will be restarted.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    InstanceGroupManagersCreateInstancesRequest = {
      description = "InstanceGroupManagers.createInstances",
      id = "InstanceGroupManagersCreateInstancesRequest",
      properties = {
        instances = {
          description = "[Required] List of specifications of per-instance configs.",
          items = {
            ["$ref"] = "PerInstanceConfig",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceGroupManagersDeleteInstancesRequest = {
      id = "InstanceGroupManagersDeleteInstancesRequest",
      properties = {
        instances = {
          description = "The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].",
          items = {
            type = "string",
          },
          type = "array",
        },
        skipInstancesOnValidationError = {
          description = "Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned. If this field is set to `false` and such an instance is specified in the request, the operation fails. The operation always fails if the request contains a malformed instance URL or a reference to an instance that exists in a zone or region other than the group's zone or region.",
          type = "boolean",
        },
      },
      type = "object",
    },
    InstanceGroupManagersDeletePerInstanceConfigsReq = {
      description = "InstanceGroupManagers.deletePerInstanceConfigs",
      id = "InstanceGroupManagersDeletePerInstanceConfigsReq",
      properties = {
        names = {
          description = "The list of instance names for which we want to delete per-instance configs on this managed instance group.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceGroupManagersListErrorsResponse = {
      id = "InstanceGroupManagersListErrorsResponse",
      properties = {
        items = {
          description = "[Output Only] The list of errors of the managed instance group.",
          items = {
            ["$ref"] = "InstanceManagedByIgmError",
          },
          type = "array",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceGroupManagersListManagedInstancesResponse = {
      id = "InstanceGroupManagersListManagedInstancesResponse",
      properties = {
        managedInstances = {
          description = "[Output Only] The list of instances in the managed instance group.",
          items = {
            ["$ref"] = "ManagedInstance",
          },
          type = "array",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceGroupManagersListPerInstanceConfigsResp = {
      id = "InstanceGroupManagersListPerInstanceConfigsResp",
      properties = {
        items = {
          description = "[Output Only] The list of PerInstanceConfig.",
          items = {
            ["$ref"] = "PerInstanceConfig",
          },
          type = "array",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceGroupManagersPatchPerInstanceConfigsReq = {
      description = "InstanceGroupManagers.patchPerInstanceConfigs",
      id = "InstanceGroupManagersPatchPerInstanceConfigsReq",
      properties = {
        perInstanceConfigs = {
          description = "The list of per-instance configurations to insert or patch on this managed instance group.",
          items = {
            ["$ref"] = "PerInstanceConfig",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceGroupManagersRecreateInstancesRequest = {
      id = "InstanceGroupManagersRecreateInstancesRequest",
      properties = {
        instances = {
          description = "The URLs of one or more instances to recreate. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceGroupManagersScopedList = {
      id = "InstanceGroupManagersScopedList",
      properties = {
        instanceGroupManagers = {
          description = "[Output Only] The list of managed instance groups that are contained in the specified project and zone.",
          items = {
            ["$ref"] = "InstanceGroupManager",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] The warning that replaces the list of managed instance groups when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceGroupManagersSetInstanceTemplateRequest = {
      id = "InstanceGroupManagersSetInstanceTemplateRequest",
      properties = {
        instanceTemplate = {
          description = "The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE.",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceGroupManagersSetTargetPoolsRequest = {
      id = "InstanceGroupManagersSetTargetPoolsRequest",
      properties = {
        fingerprint = {
          description = "The fingerprint of the target pools information. Use this optional property to prevent conflicts when multiple users change the target pools settings concurrently. Obtain the fingerprint with the instanceGroupManagers.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request.",
          format = "byte",
          type = "string",
        },
        targetPools = {
          description = "The list of target pool URLs that instances in this managed instance group belong to. The managed instance group applies these target pools to all of the instances in the group. Existing instances and new instances in the group all receive these target pool settings.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceGroupManagersUpdatePerInstanceConfigsReq = {
      description = "InstanceGroupManagers.updatePerInstanceConfigs",
      id = "InstanceGroupManagersUpdatePerInstanceConfigsReq",
      properties = {
        perInstanceConfigs = {
          description = "The list of per-instance configurations to insert or patch on this managed instance group.",
          items = {
            ["$ref"] = "PerInstanceConfig",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceGroupsAddInstancesRequest = {
      id = "InstanceGroupsAddInstancesRequest",
      properties = {
        instances = {
          description = "The list of instances to add to the instance group.",
          items = {
            ["$ref"] = "InstanceReference",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceGroupsListInstances = {
      id = "InstanceGroupsListInstances",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of InstanceWithNamedPorts resources.",
          items = {
            ["$ref"] = "InstanceWithNamedPorts",
          },
          type = "array",
        },
        kind = {
          default = "compute#instanceGroupsListInstances",
          description = "[Output Only] The resource type, which is always compute#instanceGroupsListInstances for the list of instances in the specified instance group.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceGroupsListInstancesRequest = {
      id = "InstanceGroupsListInstancesRequest",
      properties = {
        instanceState = {
          description = "A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state.",
          enum = {
            "ALL",
            "RUNNING",
          },
          enumDescriptions = {
            "Includes all instances in the generated list regardless of their state.",
            "Includes instances in the generated list only if they have a RUNNING state.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    InstanceGroupsRemoveInstancesRequest = {
      id = "InstanceGroupsRemoveInstancesRequest",
      properties = {
        instances = {
          description = "The list of instances to remove from the instance group.",
          items = {
            ["$ref"] = "InstanceReference",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceGroupsScopedList = {
      id = "InstanceGroupsScopedList",
      properties = {
        instanceGroups = {
          description = "[Output Only] The list of instance groups that are contained in this scope.",
          items = {
            ["$ref"] = "InstanceGroup",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] An informational warning that replaces the list of instance groups when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceGroupsSetNamedPortsRequest = {
      id = "InstanceGroupsSetNamedPortsRequest",
      properties = {
        fingerprint = {
          description = "The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with the instanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. A request with an incorrect fingerprint will fail with error 412 conditionNotMet.",
          format = "byte",
          type = "string",
        },
        namedPorts = {
          description = "The list of named ports to set for this instance group.",
          items = {
            ["$ref"] = "NamedPort",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstanceList = {
      description = "Contains a list of instances.",
      id = "InstanceList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Instance resources.",
          items = {
            ["$ref"] = "Instance",
          },
          type = "array",
        },
        kind = {
          default = "compute#instanceList",
          description = "[Output Only] Type of resource. Always compute#instanceList for lists of Instance resources.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceListReferrers = {
      description = "Contains a list of instance referrers.",
      id = "InstanceListReferrers",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Reference resources.",
          items = {
            ["$ref"] = "Reference",
          },
          type = "array",
        },
        kind = {
          default = "compute#instanceListReferrers",
          description = "[Output Only] Type of resource. Always compute#instanceListReferrers for lists of Instance referrers.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceManagedByIgmError = {
      id = "InstanceManagedByIgmError",
      properties = {
        error = {
          ["$ref"] = "InstanceManagedByIgmErrorManagedInstanceError",
          description = "[Output Only] Contents of the error.",
        },
        instanceActionDetails = {
          ["$ref"] = "InstanceManagedByIgmErrorInstanceActionDetails",
          description = "[Output Only] Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional.",
        },
        timestamp = {
          description = "[Output Only] The time that this error occurred. This value is in RFC3339 text format.",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceManagedByIgmErrorInstanceActionDetails = {
      id = "InstanceManagedByIgmErrorInstanceActionDetails",
      properties = {
        action = {
          description = "[Output Only] Action that managed instance group was executing on the instance when the error occurred. Possible values:",
          enum = {
            "ABANDONING",
            "CREATING",
            "CREATING_WITHOUT_RETRIES",
            "DELETING",
            "NONE",
            "RECREATING",
            "REFRESHING",
            "RESTARTING",
            "RESUMING",
            "STARTING",
            "STOPPING",
            "SUSPENDING",
            "VERIFYING",
          },
          enumDescriptions = {
            "The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.",
            "The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.",
            "The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group's targetSize value is decreased.",
            "The managed instance group is permanently deleting this instance.",
            "The managed instance group has not scheduled any actions for this instance.",
            "The managed instance group is recreating this instance.",
            "The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.",
            "The managed instance group is restarting this instance.",
            "The managed instance group is resuming this instance.",
            "The managed instance group is starting this instance.",
            "The managed instance group is stopping this instance.",
            "The managed instance group is suspending this instance.",
            "The managed instance group is verifying this already created instance. Verification happens every time the instance is (re)created or restarted and consists of: 1. Waiting until health check specified as part of this managed instance group's autohealing policy reports HEALTHY. Note: Applies only if autohealing policy has a health check specified 2. Waiting for addition verification steps performed as post-instance creation (subject to future extensions).",
          },
          type = "string",
        },
        instance = {
          description = "[Output Only] The URL of the instance. The URL can be set even if the instance has not yet been created.",
          type = "string",
        },
        version = {
          ["$ref"] = "ManagedInstanceVersion",
          description = "[Output Only] Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created.",
        },
      },
      type = "object",
    },
    InstanceManagedByIgmErrorManagedInstanceError = {
      id = "InstanceManagedByIgmErrorManagedInstanceError",
      properties = {
        code = {
          description = "[Output Only] Error code.",
          type = "string",
        },
        message = {
          description = "[Output Only] Error message.",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceMoveRequest = {
      id = "InstanceMoveRequest",
      properties = {
        destinationZone = {
          description = "The URL of the destination zone to move the instance. This can be a full or partial URL. For example, the following are all valid URLs to a zone: - https://www.googleapis.com/compute/v1/projects/project/zones/zone - projects/project/zones/zone - zones/zone ",
          type = "string",
        },
        targetInstance = {
          description = "The URL of the target instance to move. This can be a full or partial URL. For example, the following are all valid URLs to an instance: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instances/instance - projects/project/zones/zone/instances/instance - zones/zone/instances/instance ",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceParams = {
      description = "Additional instance params.",
      id = "InstanceParams",
      properties = {
        resourceManagerTags = {
          additionalProperties = {
            type = "string",
          },
          description = "Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys must be in the format `tagKeys/{tag_key_id}`, and values are in the format `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.",
          type = "object",
        },
      },
      type = "object",
    },
    InstanceProperties = {
      id = "InstanceProperties",
      properties = {
        advancedMachineFeatures = {
          ["$ref"] = "AdvancedMachineFeatures",
          description = "Controls for advanced machine-related behavior features. Note that for MachineImage, this is not supported yet.",
        },
        canIpForward = {
          description = "Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set to false. See the Enable IP forwarding documentation for more information.",
          type = "boolean",
        },
        confidentialInstanceConfig = {
          ["$ref"] = "ConfidentialInstanceConfig",
          description = "Specifies the Confidential Instance options. Note that for MachineImage, this is not supported yet.",
        },
        description = {
          description = "An optional text description for the instances that are created from these properties.",
          type = "string",
        },
        disks = {
          description = "An array of disks that are associated with the instances that are created from these properties.",
          items = {
            ["$ref"] = "AttachedDisk",
          },
          type = "array",
        },
        guestAccelerators = {
          description = "A list of guest accelerator cards' type and count to use for instances created from these properties.",
          items = {
            ["$ref"] = "AcceleratorConfig",
          },
          type = "array",
        },
        keyRevocationActionType = {
          description = "KeyRevocationActionType of the instance. Supported options are \"STOP\" and \"NONE\". The default value is \"NONE\" if it is not specified.",
          enum = {
            "KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED",
            "NONE",
            "STOP",
          },
          enumDescriptions = {
            "Default value. This value is unused.",
            "Indicates user chose no operation.",
            "Indicates user chose to opt for VM shutdown on key revocation.",
          },
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels to apply to instances that are created from these properties.",
          type = "object",
        },
        machineType = {
          annotations = {
            required = {
              "compute.instanceTemplates.insert",
            },
          },
          description = "The machine type to use for instances that are created from these properties.",
          type = "string",
        },
        metadata = {
          ["$ref"] = "Metadata",
          description = "The metadata key/value pairs to assign to instances that are created from these properties. These pairs can consist of custom metadata or predefined keys. See Project and instance metadata for more information.",
        },
        minCpuPlatform = {
          description = "Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: \"Intel Haswell\" or minCpuPlatform: \"Intel Sandy Bridge\". For more information, read Specifying a Minimum CPU Platform.",
          type = "string",
        },
        networkInterfaces = {
          description = "An array of network access configurations for this interface.",
          items = {
            ["$ref"] = "NetworkInterface",
          },
          type = "array",
        },
        networkPerformanceConfig = {
          ["$ref"] = "NetworkPerformanceConfig",
          description = "Note that for MachineImage, this is not supported yet.",
        },
        privateIpv6GoogleAccess = {
          description = "The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet.",
          enum = {
            "ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE",
            "ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE",
            "INHERIT_FROM_SUBNETWORK",
          },
          enumDescriptions = {
            "Bidirectional private IPv6 access to/from Google services. If specified, the subnetwork who is attached to the instance's default network interface will be assigned an internal IPv6 prefix if it doesn't have before.",
            "Outbound private IPv6 access from VMs in this subnet to Google services. If specified, the subnetwork who is attached to the instance's default network interface will be assigned an internal IPv6 prefix if it doesn't have before.",
            "Each network interface inherits PrivateIpv6GoogleAccess from its subnetwork.",
          },
          type = "string",
        },
        reservationAffinity = {
          ["$ref"] = "ReservationAffinity",
          description = "Specifies the reservations that instances can consume from. Note that for MachineImage, this is not supported yet.",
        },
        resourceManagerTags = {
          additionalProperties = {
            type = "string",
          },
          description = "Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys must be in the format `tagKeys/{tag_key_id}`, and values are in the format `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.",
          type = "object",
        },
        resourcePolicies = {
          description = "Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet.",
          items = {
            type = "string",
          },
          type = "array",
        },
        scheduling = {
          ["$ref"] = "Scheduling",
          description = "Specifies the scheduling options for the instances that are created from these properties.",
        },
        serviceAccounts = {
          description = "A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances.",
          items = {
            ["$ref"] = "ServiceAccount",
          },
          type = "array",
        },
        shieldedInstanceConfig = {
          ["$ref"] = "ShieldedInstanceConfig",
          description = "Note that for MachineImage, this is not supported yet.",
        },
        tags = {
          ["$ref"] = "Tags",
          description = "A list of tags to apply to the instances that are created from these properties. The tags identify valid sources or targets for network firewalls. The setTags method can modify this list of tags. Each tag within the list must comply with RFC1035.",
        },
      },
      type = "object",
    },
    InstanceReference = {
      id = "InstanceReference",
      properties = {
        instance = {
          description = "The URL for a specific instance. @required compute.instancegroups.addInstances/removeInstances",
          type = "string",
        },
      },
      type = "object",
    },
    InstanceTemplate = {
      description = "Represents an Instance Template resource. You can use instance templates to create VM instances and managed instance groups. For more information, read Instance Templates.",
      id = "InstanceTemplate",
      properties = {
        creationTimestamp = {
          description = "[Output Only] The creation timestamp for this instance template in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] A unique identifier for this instance template. The server defines this identifier.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#instanceTemplate",
          description = "[Output Only] The resource type, which is always compute#instanceTemplate for instance templates.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.instanceTemplates.insert",
            },
          },
          description = "Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        properties = {
          ["$ref"] = "InstanceProperties",
          description = "The instance properties for this instance template.",
        },
        selfLink = {
          description = "[Output Only] The URL for this instance template. The server defines this URL.",
          type = "string",
        },
        sourceInstance = {
          description = "The source instance used to create the template. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instances/instance - projects/project/zones/zone/instances/instance ",
          type = "string",
        },
        sourceInstanceParams = {
          ["$ref"] = "SourceInstanceParams",
          description = "The source instance params to use to create this instance template.",
        },
      },
      type = "object",
    },
    InstanceTemplateList = {
      description = "A list of instance templates.",
      id = "InstanceTemplateList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of InstanceTemplate resources.",
          items = {
            ["$ref"] = "InstanceTemplate",
          },
          type = "array",
        },
        kind = {
          default = "compute#instanceTemplateList",
          description = "[Output Only] The resource type, which is always compute#instanceTemplatesListResponse for instance template lists.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstanceWithNamedPorts = {
      id = "InstanceWithNamedPorts",
      properties = {
        instance = {
          description = "[Output Only] The URL of the instance.",
          type = "string",
        },
        namedPorts = {
          description = "[Output Only] The named ports that belong to this instance group.",
          items = {
            ["$ref"] = "NamedPort",
          },
          type = "array",
        },
        status = {
          description = "[Output Only] The status of the instance.",
          enum = {
            "DEPROVISIONING",
            "PROVISIONING",
            "REPAIRING",
            "RUNNING",
            "STAGING",
            "STOPPED",
            "STOPPING",
            "SUSPENDED",
            "SUSPENDING",
            "TERMINATED",
          },
          enumDescriptions = {
            "The Nanny is halted and we are performing tear down tasks like network deprogramming, releasing quota, IP, tearing down disks etc.",
            "Resources are being allocated for the instance.",
            "The instance is in repair.",
            "The instance is running.",
            "All required resources have been allocated and the instance is being started.",
            "The instance has stopped successfully.",
            "The instance is currently stopping (either being deleted or killed).",
            "The instance has suspended.",
            "The instance is suspending.",
            "The instance has stopped (either by explicit action or underlying failure).",
          },
          type = "string",
        },
      },
      type = "object",
    },
    InstancesAddResourcePoliciesRequest = {
      id = "InstancesAddResourcePoliciesRequest",
      properties = {
        resourcePolicies = {
          description = "Resource policies to be added to this instance.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstancesGetEffectiveFirewallsResponse = {
      id = "InstancesGetEffectiveFirewallsResponse",
      properties = {
        firewallPolicys = {
          description = "Effective firewalls from firewall policies.",
          items = {
            ["$ref"] = "InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
          },
          type = "array",
        },
        firewalls = {
          description = "Effective firewalls on the instance.",
          items = {
            ["$ref"] = "Firewall",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy = {
      id = "InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
      properties = {
        displayName = {
          description = "[Output Only] Deprecated, please use short name instead. The display name of the firewall policy.",
          type = "string",
        },
        name = {
          description = "[Output Only] The name of the firewall policy.",
          type = "string",
        },
        rules = {
          description = "The rules that apply to the network.",
          items = {
            ["$ref"] = "FirewallPolicyRule",
          },
          type = "array",
        },
        shortName = {
          description = "[Output Only] The short name of the firewall policy.",
          type = "string",
        },
        type = {
          description = "[Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL.",
          enum = {
            "HIERARCHY",
            "NETWORK",
            "NETWORK_REGIONAL",
            "UNSPECIFIED",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    InstancesRemoveResourcePoliciesRequest = {
      id = "InstancesRemoveResourcePoliciesRequest",
      properties = {
        resourcePolicies = {
          description = "Resource policies to be removed from this instance.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstancesScopedList = {
      id = "InstancesScopedList",
      properties = {
        instances = {
          description = "[Output Only] A list of instances contained in this scope.",
          items = {
            ["$ref"] = "Instance",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of instances when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstancesSetLabelsRequest = {
      id = "InstancesSetLabelsRequest",
      properties = {
        labelFingerprint = {
          description = "Fingerprint of the previous set of labels for this resource, used to prevent conflicts. Provide the latest fingerprint value when making a request to add or change labels.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          type = "object",
        },
      },
      type = "object",
    },
    InstancesSetMachineResourcesRequest = {
      id = "InstancesSetMachineResourcesRequest",
      properties = {
        guestAccelerators = {
          description = "A list of the type and count of accelerator cards attached to the instance.",
          items = {
            ["$ref"] = "AcceleratorConfig",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstancesSetMachineTypeRequest = {
      id = "InstancesSetMachineTypeRequest",
      properties = {
        machineType = {
          description = "Full or partial URL of the machine type resource. See Machine Types for a full list of machine types. For example: zones/us-central1-f/machineTypes/n1-standard-1",
          type = "string",
        },
      },
      type = "object",
    },
    InstancesSetMinCpuPlatformRequest = {
      id = "InstancesSetMinCpuPlatformRequest",
      properties = {
        minCpuPlatform = {
          description = "Minimum cpu/platform this instance should be started at.",
          type = "string",
        },
      },
      type = "object",
    },
    InstancesSetServiceAccountRequest = {
      id = "InstancesSetServiceAccountRequest",
      properties = {
        email = {
          description = "Email address of the service account.",
          type = "string",
        },
        scopes = {
          description = "The list of scopes to be made available for this service account.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InstancesStartWithEncryptionKeyRequest = {
      id = "InstancesStartWithEncryptionKeyRequest",
      properties = {
        disks = {
          description = "Array of disks associated with this instance that are protected with a customer-supplied encryption key. In order to start the instance, the disk url and its corresponding key must be provided. If the disk is not protected with a customer-supplied encryption key it should not be specified.",
          items = {
            ["$ref"] = "CustomerEncryptionKeyProtectedDisk",
          },
          type = "array",
        },
      },
      type = "object",
    },
    Int64RangeMatch = {
      description = "HttpRouteRuleMatch criteria for field values that must stay within the specified integer range.",
      id = "Int64RangeMatch",
      properties = {
        rangeEnd = {
          description = "The end of the range (exclusive) in signed long integer format.",
          format = "int64",
          type = "string",
        },
        rangeStart = {
          description = "The start of the range (inclusive) in signed long integer format.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    Interconnect = {
      description = "Represents an Interconnect resource. An Interconnect resource is a dedicated connection between the GCP network and your on-premises network. For more information, read the Dedicated Interconnect Overview.",
      id = "Interconnect",
      properties = {
        adminEnabled = {
          description = "Administrative status of the interconnect. When this is set to true, the Interconnect is functional and can carry traffic. When set to false, no packets can be carried over the interconnect and no BGP routes are exchanged over it. By default, the status is set to true.",
          type = "boolean",
        },
        circuitInfos = {
          description = "[Output Only] A list of CircuitInfo objects, that describe the individual circuits in this LAG.",
          items = {
            ["$ref"] = "InterconnectCircuitInfo",
          },
          type = "array",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        customerName = {
          description = "Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        expectedOutages = {
          description = "[Output Only] A list of outages expected for this Interconnect.",
          items = {
            ["$ref"] = "InterconnectOutageNotification",
          },
          type = "array",
        },
        googleIpAddress = {
          description = "[Output Only] IP address configured on the Google side of the Interconnect link. This can be used only for ping tests.",
          type = "string",
        },
        googleReferenceId = {
          description = "[Output Only] Google reference ID to be used when raising support tickets with Google or otherwise to debug backend connectivity issues.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        interconnectAttachments = {
          description = "[Output Only] A list of the URLs of all InterconnectAttachments configured to use this Interconnect.",
          items = {
            type = "string",
          },
          type = "array",
        },
        interconnectType = {
          description = "Type of interconnect, which can take one of the following values: - PARTNER: A partner-managed interconnection shared between customers though a partner. - DEDICATED: A dedicated physical interconnection with the customer. Note that a value IT_PRIVATE has been deprecated in favor of DEDICATED.",
          enum = {
            "DEDICATED",
            "IT_PRIVATE",
            "PARTNER",
          },
          enumDescriptions = {
            "A dedicated physical interconnection with the customer.",
            "[Deprecated] A private, physical interconnection with the customer.",
            "A partner-managed interconnection shared between customers via partner.",
          },
          type = "string",
        },
        kind = {
          default = "compute#interconnect",
          description = "[Output Only] Type of the resource. Always compute#interconnect for interconnects.",
          type = "string",
        },
        linkType = {
          description = "Type of link requested, which can take one of the following values: - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. Note that this field indicates the speed of each of the links in the bundle, not the speed of the entire bundle.",
          enum = {
            "LINK_TYPE_ETHERNET_100G_LR",
            "LINK_TYPE_ETHERNET_10G_LR",
          },
          enumDescriptions = {
            "100G Ethernet, LR Optics.",
            "10G Ethernet, LR Optics. [(rate_bps) = 10000000000];",
          },
          type = "string",
        },
        location = {
          description = "URL of the InterconnectLocation object that represents where this connection is to be provisioned.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.interconnects.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        nocContactEmail = {
          description = "Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect. If specified, this will be used for notifications in addition to all other forms described, such as Cloud Monitoring logs alerting and Cloud Notifications. This field is required for users who sign up for Cloud Interconnect using workforce identity federation.",
          type = "string",
        },
        operationalStatus = {
          description = "[Output Only] The current status of this Interconnect's functionality, which can take one of the following values: - OS_ACTIVE: A valid Interconnect, which is turned up and is ready to use. Attachments may be provisioned on this Interconnect. - OS_UNPROVISIONED: An Interconnect that has not completed turnup. No attachments may be provisioned on this Interconnect. - OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal maintenance. No attachments may be provisioned or updated on this Interconnect. ",
          enum = {
            "OS_ACTIVE",
            "OS_UNPROVISIONED",
          },
          enumDescriptions = {
            "The interconnect is valid, turned up, and ready to use. Attachments may be provisioned on this interconnect.",
            "The interconnect has not completed turnup. No attachments may be provisioned on this interconnect.",
          },
          type = "string",
        },
        peerIpAddress = {
          description = "[Output Only] IP address configured on the customer side of the Interconnect link. The customer should configure this IP address during turnup when prompted by Google NOC. This can be used only for ping tests.",
          type = "string",
        },
        provisionedLinkCount = {
          description = "[Output Only] Number of links actually provisioned in this interconnect.",
          format = "int32",
          type = "integer",
        },
        requestedLinkCount = {
          description = "Target number of physical links in the link bundle, as requested by the customer.",
          format = "int32",
          type = "integer",
        },
        satisfiesPzs = {
          description = "[Output Only] Set to true if the resource satisfies the zone separation organization policy constraints and false otherwise. Defaults to false if the field is not present.",
          type = "boolean",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        state = {
          description = "[Output Only] The current state of Interconnect functionality, which can take one of the following values: - ACTIVE: The Interconnect is valid, turned up and ready to use. Attachments may be provisioned on this Interconnect. - UNPROVISIONED: The Interconnect has not completed turnup. No attachments may be provisioned on this Interconnect. - UNDER_MAINTENANCE: The Interconnect is undergoing internal maintenance. No attachments may be provisioned or updated on this Interconnect. ",
          enum = {
            "ACTIVE",
            "UNPROVISIONED",
          },
          enumDescriptions = {
            "The interconnect is valid, turned up, and ready to use. Attachments may be provisioned on this interconnect.",
            "The interconnect has not completed turnup. No attachments may be provisioned on this interconnect.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    InterconnectAttachment = {
      description = "Represents an Interconnect Attachment (VLAN) resource. You can use Interconnect attachments (VLANS) to connect your Virtual Private Cloud networks to your on-premises networks through an Interconnect. For more information, read Creating VLAN Attachments.",
      id = "InterconnectAttachment",
      properties = {
        adminEnabled = {
          description = "Determines whether this Attachment will carry packets. Not present for PARTNER_PROVIDER.",
          type = "boolean",
        },
        bandwidth = {
          description = "Provisioned bandwidth capacity for the interconnect attachment. For attachments of type DEDICATED, the user can set the bandwidth. For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth. Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the following values: - BPS_50M: 50 Mbit/s - BPS_100M: 100 Mbit/s - BPS_200M: 200 Mbit/s - BPS_300M: 300 Mbit/s - BPS_400M: 400 Mbit/s - BPS_500M: 500 Mbit/s - BPS_1G: 1 Gbit/s - BPS_2G: 2 Gbit/s - BPS_5G: 5 Gbit/s - BPS_10G: 10 Gbit/s - BPS_20G: 20 Gbit/s - BPS_50G: 50 Gbit/s ",
          enum = {
            "BPS_100M",
            "BPS_10G",
            "BPS_1G",
            "BPS_200M",
            "BPS_20G",
            "BPS_2G",
            "BPS_300M",
            "BPS_400M",
            "BPS_500M",
            "BPS_50G",
            "BPS_50M",
            "BPS_5G",
          },
          enumDescriptions = {
            "100 Mbit/s",
            "10 Gbit/s",
            "1 Gbit/s",
            "200 Mbit/s",
            "20 Gbit/s",
            "2 Gbit/s",
            "300 Mbit/s",
            "400 Mbit/s",
            "500 Mbit/s",
            "50 Gbit/s",
            "50 Mbit/s",
            "5 Gbit/s",
          },
          type = "string",
        },
        candidateIpv6Subnets = {
          description = "This field is not available.",
          items = {
            type = "string",
          },
          type = "array",
        },
        candidateSubnets = {
          description = "Up to 16 candidate prefixes that can be used to restrict the allocation of cloudRouterIpAddress and customerRouterIpAddress for this attachment. All prefixes must be within link-local address space (169.254.0.0/16) and must be /29 or shorter (/28, /27, etc). Google will attempt to select an unused /29 from the supplied candidate prefix(es). The request will fail if all possible /29s are in use on Google's edge. If not supplied, Google will randomly select an unused /29 from all of link-local space.",
          items = {
            type = "string",
          },
          type = "array",
        },
        cloudRouterIpAddress = {
          description = "[Output Only] IPv4 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment.",
          type = "string",
        },
        cloudRouterIpv6Address = {
          description = "[Output Only] IPv6 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment.",
          type = "string",
        },
        cloudRouterIpv6InterfaceId = {
          description = "This field is not available.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        customerRouterIpAddress = {
          description = "[Output Only] IPv4 address + prefix length to be configured on the customer router subinterface for this interconnect attachment.",
          type = "string",
        },
        customerRouterIpv6Address = {
          description = "[Output Only] IPv6 address + prefix length to be configured on the customer router subinterface for this interconnect attachment.",
          type = "string",
        },
        customerRouterIpv6InterfaceId = {
          description = "This field is not available.",
          type = "string",
        },
        dataplaneVersion = {
          description = "[Output Only] Dataplane version for this InterconnectAttachment. This field is only present for Dataplane version 2 and higher. Absence of this field in the API output indicates that the Dataplane is version 1.",
          format = "int32",
          type = "integer",
        },
        description = {
          description = "An optional description of this resource.",
          type = "string",
        },
        edgeAvailabilityDomain = {
          description = "Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values: - AVAILABILITY_DOMAIN_ANY - AVAILABILITY_DOMAIN_1 - AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure a pair of attachments, one per availability domain. The selected availability domain will be provided to the Partner via the pairing key, so that the provisioned circuit will lie in the specified domain. If not specified, the value will default to AVAILABILITY_DOMAIN_ANY.",
          enum = {
            "AVAILABILITY_DOMAIN_1",
            "AVAILABILITY_DOMAIN_2",
            "AVAILABILITY_DOMAIN_ANY",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        encryption = {
          description = "Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment). Can only be specified at attachment creation for PARTNER or DEDICATED attachments. Possible values are: - NONE - This is the default value, which means that the VLAN attachment carries unencrypted traffic. VMs are able to send traffic to, or receive traffic from, such a VLAN attachment. - IPSEC - The VLAN attachment carries only encrypted traffic that is encrypted by an IPsec device, such as an HA VPN gateway or third-party IPsec VPN. VMs cannot directly send traffic to, or receive traffic from, such a VLAN attachment. To use *HA VPN over Cloud Interconnect*, the VLAN attachment must be created with this option. ",
          enum = {
            "IPSEC",
            "NONE",
          },
          enumDescriptions = {
            "The interconnect attachment will carry only encrypted traffic that is encrypted by an IPsec device such as HA VPN gateway; VMs cannot directly send traffic to or receive traffic from such an interconnect attachment. To use HA VPN over Cloud Interconnect, the interconnect attachment must be created with this option.",
            "This is the default value, which means the Interconnect Attachment will carry unencrypted traffic. VMs will be able to send traffic to or receive traffic from such interconnect attachment.",
          },
          type = "string",
        },
        googleReferenceId = {
          description = "[Output Only] Google reference ID, to be used when raising support tickets with Google or otherwise to debug backend connectivity issues. [Deprecated] This field is not used.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        interconnect = {
          description = "URL of the underlying Interconnect object that this attachment's traffic will traverse through.",
          type = "string",
        },
        ipsecInternalAddresses = {
          description = "A list of URLs of addresses that have been reserved for the VLAN attachment. Used only for the VLAN attachment that has the encryption option as IPSEC. The addresses must be regional internal IP address ranges. When creating an HA VPN gateway over the VLAN attachment, if the attachment is configured to use a regional internal IP address, then the VPN gateway's IP address is allocated from the IP address range specified here. For example, if the HA VPN gateway's interface 0 is paired to this VLAN attachment, then a regional internal IP address for the VPN gateway interface 0 will be allocated from the IP address specified for this VLAN attachment. If this field is not specified when creating the VLAN attachment, then later on when creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's IP address is allocated from the regional external IP address pool. Not currently available publicly. ",
          items = {
            type = "string",
          },
          type = "array",
        },
        kind = {
          default = "compute#interconnectAttachment",
          description = "[Output Only] Type of the resource. Always compute#interconnectAttachment for interconnect attachments.",
          type = "string",
        },
        mtu = {
          description = "Maximum Transmission Unit (MTU), in bytes, of packets passing through this interconnect attachment. Only 1440 and 1500 are allowed. If not specified, the value will default to 1440.",
          format = "int32",
          type = "integer",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        operationalStatus = {
          description = "[Output Only] The current status of whether or not this interconnect attachment is functional, which can take one of the following values: - OS_ACTIVE: The attachment has been turned up and is ready to use. - OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete. ",
          enum = {
            "OS_ACTIVE",
            "OS_UNPROVISIONED",
          },
          enumDescriptions = {
            "Indicates that attachment has been turned up and is ready to use.",
            "Indicates that attachment is not ready to use yet, because turnup is not complete.",
          },
          type = "string",
        },
        pairingKey = {
          description = "[Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of an PARTNER attachment used to initiate provisioning with a selected partner. Of the form \"XXXXX/region/domain\"",
          type = "string",
        },
        partnerAsn = {
          description = "Optional BGP ASN for the router supplied by a Layer 3 Partner if they configured BGP on behalf of the customer. Output only for PARTNER type, input only for PARTNER_PROVIDER, not available for DEDICATED.",
          format = "int64",
          type = "string",
        },
        partnerMetadata = {
          ["$ref"] = "InterconnectAttachmentPartnerMetadata",
          description = "Informational metadata about Partner attachments from Partners to display to customers. Output only for for PARTNER type, mutable for PARTNER_PROVIDER, not available for DEDICATED.",
        },
        privateInterconnectInfo = {
          ["$ref"] = "InterconnectAttachmentPrivateInfo",
          description = "[Output Only] Information specific to an InterconnectAttachment. This property is populated if the interconnect that this is attached to is of type DEDICATED.",
        },
        region = {
          description = "[Output Only] URL of the region where the regional interconnect attachment resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        router = {
          description = "URL of the Cloud Router to be used for dynamic routing. This router must be in the same region as this InterconnectAttachment. The InterconnectAttachment will automatically connect the Interconnect to the network & region within which the Cloud Router is configured.",
          type = "string",
        },
        satisfiesPzs = {
          description = "[Output Only] Set to true if the resource satisfies the zone separation organization policy constraints and false otherwise. Defaults to false if the field is not present.",
          type = "boolean",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        stackType = {
          description = "The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used. This field can be both set at interconnect attachments creation and update interconnect attachment operations.",
          enum = {
            "IPV4_IPV6",
            "IPV4_ONLY",
          },
          enumDescriptions = {
            "The interconnect attachment can have both IPv4 and IPv6 addresses.",
            "The interconnect attachment will only be assigned IPv4 addresses.",
          },
          type = "string",
        },
        state = {
          description = "[Output Only] The current state of this attachment's functionality. Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state can take one of the following values: - ACTIVE: The attachment has been turned up and is ready to use. - UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete. - PENDING_PARTNER: A newly-created PARTNER attachment that has not yet been configured on the Partner side. - PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it. - PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is waiting for a customer to activate it. - DEFUNCT: The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was removed, or because the other side of a Partner attachment was deleted. ",
          enum = {
            "ACTIVE",
            "DEFUNCT",
            "PARTNER_REQUEST_RECEIVED",
            "PENDING_CUSTOMER",
            "PENDING_PARTNER",
            "STATE_UNSPECIFIED",
            "UNPROVISIONED",
          },
          enumDescriptions = {
            "Indicates that attachment has been turned up and is ready to use.",
            "The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was wiped out, or because the other side of a Partner attachment was deleted.",
            "A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it.",
            "PARTNER or PARTNER_PROVIDER attachment that is waiting for the customer to activate.",
            "A newly created PARTNER attachment that has not yet been configured on the Partner side.",
            "",
            "Indicates that attachment is not ready to use yet, because turnup is not complete.",
          },
          type = "string",
        },
        type = {
          description = "The type of interconnect attachment this is, which can take one of the following values: - DEDICATED: an attachment to a Dedicated Interconnect. - PARTNER: an attachment to a Partner Interconnect, created by the customer. - PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the partner. ",
          enum = {
            "DEDICATED",
            "PARTNER",
            "PARTNER_PROVIDER",
          },
          enumDescriptions = {
            "Attachment to a dedicated interconnect.",
            "Attachment to a partner interconnect, created by the customer.",
            "Attachment to a partner interconnect, created by the partner.",
          },
          type = "string",
        },
        vlanTag8021q = {
          description = "The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4094. Only specified at creation time.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    InterconnectAttachmentAggregatedList = {
      id = "InterconnectAttachmentAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "InterconnectAttachmentsScopedList",
            description = "Name of the scope containing this set of interconnect attachments.",
          },
          description = "A list of InterconnectAttachmentsScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#interconnectAttachmentAggregatedList",
          description = "[Output Only] Type of resource. Always compute#interconnectAttachmentAggregatedList for aggregated lists of interconnect attachments.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InterconnectAttachmentList = {
      description = "Response to the list request, and contains a list of interconnect attachments.",
      id = "InterconnectAttachmentList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of InterconnectAttachment resources.",
          items = {
            ["$ref"] = "InterconnectAttachment",
          },
          type = "array",
        },
        kind = {
          default = "compute#interconnectAttachmentList",
          description = "[Output Only] Type of resource. Always compute#interconnectAttachmentList for lists of interconnect attachments.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InterconnectAttachmentPartnerMetadata = {
      description = "Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments.",
      id = "InterconnectAttachmentPartnerMetadata",
      properties = {
        interconnectName = {
          description = "Plain text name of the Interconnect this attachment is connected to, as displayed in the Partner's portal. For instance \"Chicago 1\". This value may be validated to match approved Partner values.",
          type = "string",
        },
        partnerName = {
          description = "Plain text name of the Partner providing this attachment. This value may be validated to match approved Partner values.",
          type = "string",
        },
        portalUrl = {
          description = "URL of the Partner's portal for this Attachment. Partners may customise this to be a deep link to the specific resource on the Partner portal. This value may be validated to match approved Partner values.",
          type = "string",
        },
      },
      type = "object",
    },
    InterconnectAttachmentPrivateInfo = {
      description = "Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED.",
      id = "InterconnectAttachmentPrivateInfo",
      properties = {
        tag8021q = {
          description = "[Output Only] 802.1q encapsulation tag to be used for traffic between Google and the customer, going to and from this network and region.",
          format = "uint32",
          type = "integer",
        },
      },
      type = "object",
    },
    InterconnectAttachmentsScopedList = {
      id = "InterconnectAttachmentsScopedList",
      properties = {
        interconnectAttachments = {
          description = "A list of interconnect attachments contained in this scope.",
          items = {
            ["$ref"] = "InterconnectAttachment",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of addresses when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InterconnectCircuitInfo = {
      description = "Describes a single physical circuit between the Customer and Google. CircuitInfo objects are created by Google, so all fields are output only.",
      id = "InterconnectCircuitInfo",
      properties = {
        customerDemarcId = {
          description = "Customer-side demarc ID for this circuit.",
          type = "string",
        },
        googleCircuitId = {
          description = "Google-assigned unique ID for this circuit. Assigned at circuit turn-up.",
          type = "string",
        },
        googleDemarcId = {
          description = "Google-side demarc ID for this circuit. Assigned at circuit turn-up and provided by Google to the customer in the LOA.",
          type = "string",
        },
      },
      type = "object",
    },
    InterconnectDiagnostics = {
      description = "Diagnostics information about interconnect, contains detailed and current technical information about Google's side of the connection.",
      id = "InterconnectDiagnostics",
      properties = {
        arpCaches = {
          description = "A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect. This will be empty when the Interconnect is not bundled.",
          items = {
            ["$ref"] = "InterconnectDiagnosticsARPEntry",
          },
          type = "array",
        },
        bundleAggregationType = {
          description = "The aggregation type of the bundle interface.",
          enum = {
            "BUNDLE_AGGREGATION_TYPE_LACP",
            "BUNDLE_AGGREGATION_TYPE_STATIC",
          },
          enumDescriptions = {
            "LACP is enabled.",
            "LACP is disabled.",
          },
          type = "string",
        },
        bundleOperationalStatus = {
          description = "The operational status of the bundle interface.",
          enum = {
            "BUNDLE_OPERATIONAL_STATUS_DOWN",
            "BUNDLE_OPERATIONAL_STATUS_UP",
          },
          enumDescriptions = {
            "If bundleAggregationType is LACP: LACP is not established and/or all links in the bundle have DOWN operational status. If bundleAggregationType is STATIC: one or more links in the bundle has DOWN operational status.",
            "If bundleAggregationType is LACP: LACP is established and at least one link in the bundle has UP operational status. If bundleAggregationType is STATIC: all links in the bundle (typically just one) have UP operational status.",
          },
          type = "string",
        },
        links = {
          description = "A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect.",
          items = {
            ["$ref"] = "InterconnectDiagnosticsLinkStatus",
          },
          type = "array",
        },
        macAddress = {
          description = "The MAC address of the Interconnect's bundle interface.",
          type = "string",
        },
      },
      type = "object",
    },
    InterconnectDiagnosticsARPEntry = {
      description = "Describing the ARP neighbor entries seen on this link",
      id = "InterconnectDiagnosticsARPEntry",
      properties = {
        ipAddress = {
          description = "The IP address of this ARP neighbor.",
          type = "string",
        },
        macAddress = {
          description = "The MAC address of this ARP neighbor.",
          type = "string",
        },
      },
      type = "object",
    },
    InterconnectDiagnosticsLinkLACPStatus = {
      id = "InterconnectDiagnosticsLinkLACPStatus",
      properties = {
        googleSystemId = {
          description = "System ID of the port on Google's side of the LACP exchange.",
          type = "string",
        },
        neighborSystemId = {
          description = "System ID of the port on the neighbor's side of the LACP exchange.",
          type = "string",
        },
        state = {
          description = "The state of a LACP link, which can take one of the following values: - ACTIVE: The link is configured and active within the bundle. - DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty. ",
          enum = {
            "ACTIVE",
            "DETACHED",
          },
          enumDescriptions = {
            "The link is configured and active within the bundle.",
            "The link is not configured within the bundle, this means the rest of the object should be empty.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    InterconnectDiagnosticsLinkOpticalPower = {
      id = "InterconnectDiagnosticsLinkOpticalPower",
      properties = {
        state = {
          description = "The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include: - OK: The value has not crossed a warning threshold. - LOW_WARNING: The value has crossed below the low warning threshold. - HIGH_WARNING: The value has crossed above the high warning threshold. - LOW_ALARM: The value has crossed below the low alarm threshold. - HIGH_ALARM: The value has crossed above the high alarm threshold. ",
          enum = {
            "HIGH_ALARM",
            "HIGH_WARNING",
            "LOW_ALARM",
            "LOW_WARNING",
            "OK",
          },
          enumDescriptions = {
            "The value has crossed above the high alarm threshold.",
            "The value of the current optical power has crossed above the high warning threshold.",
            "The value of the current optical power has crossed below the low alarm threshold.",
            "The value of the current optical power has crossed below the low warning threshold.",
            "The value of the current optical power has not crossed a warning threshold.",
          },
          type = "string",
        },
        value = {
          description = "Value of the current receiving or transmitting optical power, read in dBm. Take a known good optical value, give it a 10% margin and trigger warnings relative to that value. In general, a -7dBm warning and a -11dBm alarm are good optical value estimates for most links.",
          format = "float",
          type = "number",
        },
      },
      type = "object",
    },
    InterconnectDiagnosticsLinkStatus = {
      id = "InterconnectDiagnosticsLinkStatus",
      properties = {
        arpCaches = {
          description = "A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled",
          items = {
            ["$ref"] = "InterconnectDiagnosticsARPEntry",
          },
          type = "array",
        },
        circuitId = {
          description = "The unique ID for this link assigned during turn up by Google.",
          type = "string",
        },
        googleDemarc = {
          description = "The Demarc address assigned by Google and provided in the LoA.",
          type = "string",
        },
        lacpStatus = {
          ["$ref"] = "InterconnectDiagnosticsLinkLACPStatus",
        },
        operationalStatus = {
          description = "The operational status of the link.",
          enum = {
            "LINK_OPERATIONAL_STATUS_DOWN",
            "LINK_OPERATIONAL_STATUS_UP",
          },
          enumDescriptions = {
            "The interface is unable to communicate with the remote end.",
            "The interface has low level communication with the remote end.",
          },
          type = "string",
        },
        receivingOpticalPower = {
          ["$ref"] = "InterconnectDiagnosticsLinkOpticalPower",
          description = "An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.",
        },
        transmittingOpticalPower = {
          ["$ref"] = "InterconnectDiagnosticsLinkOpticalPower",
          description = "An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.",
        },
      },
      type = "object",
    },
    InterconnectList = {
      description = "Response to the list request, and contains a list of interconnects.",
      id = "InterconnectList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Interconnect resources.",
          items = {
            ["$ref"] = "Interconnect",
          },
          type = "array",
        },
        kind = {
          default = "compute#interconnectList",
          description = "[Output Only] Type of resource. Always compute#interconnectList for lists of interconnects.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InterconnectLocation = {
      description = "Represents an Interconnect Attachment (VLAN) Location resource. You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.",
      id = "InterconnectLocation",
      properties = {
        address = {
          description = "[Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character.",
          type = "string",
        },
        availabilityZone = {
          description = "[Output Only] Availability zone for this InterconnectLocation. Within a metropolitan area (metro), maintenance will not be simultaneously scheduled in more than one availability zone. Example: \"zone1\" or \"zone2\".",
          type = "string",
        },
        city = {
          description = "[Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: \"Chicago, IL\", \"Amsterdam, Netherlands\".",
          type = "string",
        },
        continent = {
          description = "[Output Only] Continent for this location, which can take one of the following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA - SOUTH_AMERICA ",
          enum = {
            "AFRICA",
            "ASIA_PAC",
            "C_AFRICA",
            "C_ASIA_PAC",
            "C_EUROPE",
            "C_NORTH_AMERICA",
            "C_SOUTH_AMERICA",
            "EUROPE",
            "NORTH_AMERICA",
            "SOUTH_AMERICA",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "[Output Only] An optional description of the resource.",
          type = "string",
        },
        facilityProvider = {
          description = "[Output Only] The name of the provider for this facility (e.g., EQUINIX).",
          type = "string",
        },
        facilityProviderFacilityId = {
          description = "[Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#interconnectLocation",
          description = "[Output Only] Type of the resource. Always compute#interconnectLocation for interconnect locations.",
          type = "string",
        },
        name = {
          description = "[Output Only] Name of the resource.",
          type = "string",
        },
        peeringdbFacilityId = {
          description = "[Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).",
          type = "string",
        },
        regionInfos = {
          description = "[Output Only] A list of InterconnectLocation.RegionInfo objects, that describe parameters pertaining to the relation between this InterconnectLocation and various Google Cloud regions.",
          items = {
            ["$ref"] = "InterconnectLocationRegionInfo",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of this InterconnectLocation, which can take one of the following values: - CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects. - AVAILABLE: The InterconnectLocation is available for provisioning new Interconnects. ",
          enum = {
            "AVAILABLE",
            "CLOSED",
          },
          enumDescriptions = {
            "The InterconnectLocation is available for provisioning new Interconnects.",
            "The InterconnectLocation is closed for provisioning new Interconnects.",
          },
          type = "string",
        },
        supportsPzs = {
          description = "[Output Only] Set to true for locations that support physical zone separation. Defaults to false if the field is not present.",
          type = "boolean",
        },
      },
      type = "object",
    },
    InterconnectLocationList = {
      description = "Response to the list request, and contains a list of interconnect locations.",
      id = "InterconnectLocationList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of InterconnectLocation resources.",
          items = {
            ["$ref"] = "InterconnectLocation",
          },
          type = "array",
        },
        kind = {
          default = "compute#interconnectLocationList",
          description = "[Output Only] Type of resource. Always compute#interconnectLocationList for lists of interconnect locations.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    InterconnectLocationRegionInfo = {
      description = "Information about any potential InterconnectAttachments between an Interconnect at a specific InterconnectLocation, and a specific Cloud Region.",
      id = "InterconnectLocationRegionInfo",
      properties = {
        expectedRttMs = {
          description = "Expected round-trip time in milliseconds, from this InterconnectLocation to a VM in this region.",
          format = "int64",
          type = "string",
        },
        locationPresence = {
          description = "Identifies the network presence of this location.",
          enum = {
            "GLOBAL",
            "LOCAL_REGION",
            "LP_GLOBAL",
            "LP_LOCAL_REGION",
          },
          enumDescriptions = {
            "This region is not in any common network presence with this InterconnectLocation.",
            "This region shares the same regional network presence as this InterconnectLocation.",
            "[Deprecated] This region is not in any common network presence with this InterconnectLocation.",
            "[Deprecated] This region shares the same regional network presence as this InterconnectLocation.",
          },
          type = "string",
        },
        region = {
          description = "URL for the region of this location.",
          type = "string",
        },
      },
      type = "object",
    },
    InterconnectOutageNotification = {
      description = "Description of a planned outage on this Interconnect.",
      id = "InterconnectOutageNotification",
      properties = {
        affectedCircuits = {
          description = "If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.",
          items = {
            type = "string",
          },
          type = "array",
        },
        description = {
          description = "A description about the purpose of the outage.",
          type = "string",
        },
        endTime = {
          description = "Scheduled end time for the outage (milliseconds since Unix epoch).",
          format = "int64",
          type = "string",
        },
        issueType = {
          description = "Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with \"IT_\" have been deprecated in favor of the unprefixed values.",
          enum = {
            "IT_OUTAGE",
            "IT_PARTIAL_OUTAGE",
            "OUTAGE",
            "PARTIAL_OUTAGE",
          },
          enumDescriptions = {
            "[Deprecated] The Interconnect may be completely out of service for some or all of the specified window.",
            "[Deprecated] Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.",
            "The Interconnect may be completely out of service for some or all of the specified window.",
            "Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.",
          },
          type = "string",
        },
        name = {
          description = "Unique identifier for this outage notification.",
          type = "string",
        },
        source = {
          description = "The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.",
          enum = {
            "GOOGLE",
            "NSRC_GOOGLE",
          },
          enumDescriptions = {
            "This notification was generated by Google.",
            "[Deprecated] This notification was generated by Google.",
          },
          type = "string",
        },
        startTime = {
          description = "Scheduled start time for the outage (milliseconds since Unix epoch).",
          format = "int64",
          type = "string",
        },
        state = {
          description = "State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with \"NS_\" have been deprecated in favor of the unprefixed values.",
          enum = {
            "ACTIVE",
            "CANCELLED",
            "COMPLETED",
            "NS_ACTIVE",
            "NS_CANCELED",
          },
          enumDescriptions = {
            "This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.",
            "The outage associated with this notification was cancelled before the outage was due to start.",
            "The outage associated with this notification is complete.",
            "[Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.",
            "[Deprecated] The outage associated with this notification was canceled before the outage was due to start.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    InterconnectsGetDiagnosticsResponse = {
      description = "Response for the InterconnectsGetDiagnosticsRequest.",
      id = "InterconnectsGetDiagnosticsResponse",
      properties = {
        result = {
          ["$ref"] = "InterconnectDiagnostics",
        },
      },
      type = "object",
    },
    License = {
      description = "Represents a License resource. A License represents billing and aggregate usage data for public and marketplace images. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
      id = "License",
      properties = {
        chargesUseFee = {
          description = "[Output Only] Deprecated. This field no longer reflects whether a license charges a usage fee.",
          type = "boolean",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional textual description of the resource; provided by the client when the resource is created.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#license",
          description = "[Output Only] Type of resource. Always compute#license for licenses.",
          type = "string",
        },
        licenseCode = {
          description = "[Output Only] The unique code used to attach this license to images, snapshots, and disks.",
          format = "uint64",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.images.insert",
            },
          },
          description = "Name of the resource. The name must be 1-63 characters long and comply with RFC1035.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        resourceRequirements = {
          ["$ref"] = "LicenseResourceRequirements",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        transferable = {
          description = "If false, licenses will not be copied from the source resource when creating an image from a disk, disk from snapshot, or snapshot from disk.",
          type = "boolean",
        },
      },
      type = "object",
    },
    LicenseCode = {
      description = "Represents a License Code resource. A License Code is a unique identifier used to represent a license resource. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images. ",
      id = "LicenseCode",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "[Output Only] Description of this License Code.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#licenseCode",
          description = "[Output Only] Type of resource. Always compute#licenseCode for licenses.",
          type = "string",
        },
        licenseAlias = {
          description = "[Output Only] URL and description aliases of Licenses with the same License Code.",
          items = {
            ["$ref"] = "LicenseCodeLicenseAlias",
          },
          type = "array",
        },
        name = {
          annotations = {
            required = {
              "compute.licenses.insert",
            },
          },
          description = "[Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer.",
          pattern = "[0-9]{0,20}?",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        state = {
          description = "[Output Only] Current state of this License Code.",
          enum = {
            "DISABLED",
            "ENABLED",
            "RESTRICTED",
            "STATE_UNSPECIFIED",
            "TERMINATED",
          },
          enumDescriptions = {
            "Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected.",
            "Use is allowed for anyone with USE_READ_ONLY access to this License Code.",
            "Use of this license is limited to a project whitelist.",
            "",
            "Reserved state.",
          },
          type = "string",
        },
        transferable = {
          description = "[Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred.",
          type = "boolean",
        },
      },
      type = "object",
    },
    LicenseCodeLicenseAlias = {
      id = "LicenseCodeLicenseAlias",
      properties = {
        description = {
          description = "[Output Only] Description of this License Code.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] URL of license corresponding to this License Code.",
          type = "string",
        },
      },
      type = "object",
    },
    LicenseResourceCommitment = {
      description = "Commitment for a particular license resource.",
      id = "LicenseResourceCommitment",
      properties = {
        amount = {
          description = "The number of licenses purchased.",
          format = "int64",
          type = "string",
        },
        coresPerLicense = {
          description = "Specifies the core range of the instance for which this license applies.",
          type = "string",
        },
        license = {
          description = "Any applicable license URI.",
          type = "string",
        },
      },
      type = "object",
    },
    LicenseResourceRequirements = {
      id = "LicenseResourceRequirements",
      properties = {
        minGuestCpuCount = {
          description = "Minimum number of guest cpus required to use the Instance. Enforced at Instance creation and Instance start.",
          format = "int32",
          type = "integer",
        },
        minMemoryMb = {
          description = "Minimum memory required to use the Instance. Enforced at Instance creation and Instance start.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    LicensesListResponse = {
      id = "LicensesListResponse",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of License resources.",
          items = {
            ["$ref"] = "License",
          },
          type = "array",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    LocalDisk = {
      id = "LocalDisk",
      properties = {
        diskCount = {
          description = "Specifies the number of such disks.",
          format = "int32",
          type = "integer",
        },
        diskSizeGb = {
          description = "Specifies the size of the disk in base-2 GB.",
          format = "int32",
          type = "integer",
        },
        diskType = {
          description = "Specifies the desired disk type on the node. This disk type must be a local storage type (e.g.: local-ssd). Note that for nodeTemplates, this should be the name of the disk type and not its URL.",
          type = "string",
        },
      },
      type = "object",
    },
    LocalizedMessage = {
      description = "Provides a localized error message that is safe to return to the user which can be attached to an RPC error.",
      id = "LocalizedMessage",
      properties = {
        locale = {
          description = "The locale used following the specification defined at https://www.rfc-editor.org/rfc/bcp/bcp47.txt. Examples are: \"en-US\", \"fr-CH\", \"es-MX\"",
          type = "string",
        },
        message = {
          description = "The localized error message in the above locale.",
          type = "string",
        },
      },
      type = "object",
    },
    LocationPolicy = {
      description = "Configuration for location policy among multiple possible locations (e.g. preferences for zone selection among zones in a single region).",
      id = "LocationPolicy",
      properties = {
        locations = {
          additionalProperties = {
            ["$ref"] = "LocationPolicyLocation",
          },
          description = "Location configurations mapped by location name. Currently only zone names are supported and must be represented as valid internal URLs, such as zones/us-central1-a.",
          type = "object",
        },
        targetShape = {
          description = "Strategy for distributing VMs across zones in a region.",
          enum = {
            "ANY",
            "ANY_SINGLE_ZONE",
            "BALANCED",
          },
          enumDescriptions = {
            "GCE picks zones for creating VM instances to fulfill the requested number of VMs within present resource constraints and to maximize utilization of unused zonal reservations. Recommended for batch workloads that do not require high availability.",
            "GCE always selects a single zone for all the VMs, optimizing for resource quotas, available reservations and general capacity. Recommended for batch workloads that cannot tollerate distribution over multiple zones. This the default shape in Bulk Insert and Capacity Advisor APIs.",
            "GCE prioritizes acquisition of resources, scheduling VMs in zones where resources are available while distributing VMs as evenly as possible across allowed zones to minimize the impact of zonal failure. Recommended for highly available serving workloads.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    LocationPolicyLocation = {
      id = "LocationPolicyLocation",
      properties = {
        constraints = {
          ["$ref"] = "LocationPolicyLocationConstraints",
          description = "Constraints that the caller requires on the result distribution in this zone.",
        },
        preference = {
          description = "Preference for a given location. Set to either ALLOW or DENY.",
          enum = {
            "ALLOW",
            "DENY",
            "PREFERENCE_UNSPECIFIED",
          },
          enumDescriptions = {
            "Location is allowed for use.",
            "Location is prohibited.",
            "Default value, unused.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    LocationPolicyLocationConstraints = {
      description = "Per-zone constraints on location policy for this zone.",
      id = "LocationPolicyLocationConstraints",
      properties = {
        maxCount = {
          description = "Maximum number of items that are allowed to be placed in this zone. The value must be non-negative.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    LogConfig = {
      description = "This is deprecated and has no effect. Do not use.",
      id = "LogConfig",
      properties = {
        cloudAudit = {
          ["$ref"] = "LogConfigCloudAuditOptions",
          description = "This is deprecated and has no effect. Do not use.",
        },
        counter = {
          ["$ref"] = "LogConfigCounterOptions",
          description = "This is deprecated and has no effect. Do not use.",
        },
        dataAccess = {
          ["$ref"] = "LogConfigDataAccessOptions",
          description = "This is deprecated and has no effect. Do not use.",
        },
      },
      type = "object",
    },
    LogConfigCloudAuditOptions = {
      description = "This is deprecated and has no effect. Do not use.",
      id = "LogConfigCloudAuditOptions",
      properties = {
        authorizationLoggingOptions = {
          ["$ref"] = "AuthorizationLoggingOptions",
          description = "This is deprecated and has no effect. Do not use.",
        },
        logName = {
          description = "This is deprecated and has no effect. Do not use.",
          enum = {
            "ADMIN_ACTIVITY",
            "DATA_ACCESS",
            "UNSPECIFIED_LOG_NAME",
          },
          enumDescriptions = {
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    LogConfigCounterOptions = {
      description = "This is deprecated and has no effect. Do not use.",
      id = "LogConfigCounterOptions",
      properties = {
        customFields = {
          description = "This is deprecated and has no effect. Do not use.",
          items = {
            ["$ref"] = "LogConfigCounterOptionsCustomField",
          },
          type = "array",
        },
        field = {
          description = "This is deprecated and has no effect. Do not use.",
          type = "string",
        },
        metric = {
          description = "This is deprecated and has no effect. Do not use.",
          type = "string",
        },
      },
      type = "object",
    },
    LogConfigCounterOptionsCustomField = {
      description = "This is deprecated and has no effect. Do not use.",
      id = "LogConfigCounterOptionsCustomField",
      properties = {
        name = {
          description = "This is deprecated and has no effect. Do not use.",
          type = "string",
        },
        value = {
          description = "This is deprecated and has no effect. Do not use.",
          type = "string",
        },
      },
      type = "object",
    },
    LogConfigDataAccessOptions = {
      description = "This is deprecated and has no effect. Do not use.",
      id = "LogConfigDataAccessOptions",
      properties = {
        logMode = {
          description = "This is deprecated and has no effect. Do not use.",
          enum = {
            "LOG_FAIL_CLOSED",
            "LOG_MODE_UNSPECIFIED",
          },
          enumDescriptions = {
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    MachineImage = {
      description = "Represents a machine image resource. A machine image is a Compute Engine resource that stores all the configuration, metadata, permissions, and data from one or more disks required to create a Virtual machine (VM) instance. For more information, see Machine images.",
      id = "MachineImage",
      properties = {
        creationTimestamp = {
          description = "[Output Only] The creation timestamp for this machine image in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        guestFlush = {
          description = "[Input Only] Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process.",
          type = "boolean",
        },
        id = {
          description = "[Output Only] A unique identifier for this machine image. The server defines this identifier.",
          format = "uint64",
          type = "string",
        },
        instanceProperties = {
          ["$ref"] = "InstanceProperties",
          description = "[Output Only] Properties of source instance",
        },
        kind = {
          default = "compute#machineImage",
          description = "[Output Only] The resource type, which is always compute#machineImage for machine image.",
          type = "string",
        },
        machineImageEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "Encrypts the machine image using a customer-supplied encryption key. After you encrypt a machine image using a customer-supplied key, you must provide the same key if you use the machine image later. For example, you must provide the encryption key when you create an instance from the encrypted machine image in a future request. Customer-supplied encryption keys do not protect access to metadata of the machine image. If you do not provide an encryption key when creating the machine image, then the machine image will be encrypted using an automatically generated key and you do not need to provide a key to use the machine image later.",
        },
        name = {
          annotations = {
            required = {
              "compute.machineImages.insert",
            },
          },
          description = "Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        satisfiesPzs = {
          description = "[Output Only] Reserved for future use.",
          type = "boolean",
        },
        savedDisks = {
          description = "An array of Machine Image specific properties for disks attached to the source instance",
          items = {
            ["$ref"] = "SavedDisk",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] The URL for this machine image. The server defines this URL.",
          type = "string",
        },
        sourceDiskEncryptionKeys = {
          description = "[Input Only] The customer-supplied encryption key of the disks attached to the source instance. Required if the source disk is protected by a customer-supplied encryption key.",
          items = {
            ["$ref"] = "SourceDiskEncryptionKey",
          },
          type = "array",
        },
        sourceInstance = {
          description = "The source instance used to create the machine image. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instances/instance - projects/project/zones/zone/instances/instance ",
          type = "string",
        },
        sourceInstanceProperties = {
          ["$ref"] = "SourceInstanceProperties",
          description = "[Output Only] DEPRECATED: Please use instance_properties instead for source instance related properties. New properties will not be added to this field.",
        },
        status = {
          description = "[Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.",
          enum = {
            "CREATING",
            "DELETING",
            "INVALID",
            "READY",
            "UPLOADING",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        storageLocations = {
          description = "The regional or multi-regional Cloud Storage bucket location where the machine image is stored.",
          items = {
            type = "string",
          },
          type = "array",
        },
        totalStorageBytes = {
          description = "[Output Only] Total size of the storage used by the machine image.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    MachineImageList = {
      description = "A list of machine images.",
      id = "MachineImageList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of MachineImage resources.",
          items = {
            ["$ref"] = "MachineImage",
          },
          type = "array",
        },
        kind = {
          default = "compute#machineImageList",
          description = "[Output Only] The resource type, which is always compute#machineImagesListResponse for machine image lists.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    MachineType = {
      description = "Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, read Machine Types.",
      id = "MachineType",
      properties = {
        accelerators = {
          description = "[Output Only] A list of accelerator configurations assigned to this machine type.",
          items = {
            properties = {
              guestAcceleratorCount = {
                description = "Number of accelerator cards exposed to the guest.",
                format = "int32",
                type = "integer",
              },
              guestAcceleratorType = {
                description = "The accelerator type resource name, not a full URL, e.g. 'nvidia-tesla-k80'.",
                type = "string",
              },
            },
            type = "object",
          },
          type = "array",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        deprecated = {
          ["$ref"] = "DeprecationStatus",
          description = "[Output Only] The deprecation status associated with this machine type. Only applicable if the machine type is unavailable.",
        },
        description = {
          description = "[Output Only] An optional textual description of the resource.",
          type = "string",
        },
        guestCpus = {
          description = "[Output Only] The number of virtual CPUs that are available to the instance.",
          format = "int32",
          type = "integer",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        imageSpaceGb = {
          description = "[Deprecated] This property is deprecated and will never be populated with any relevant values.",
          format = "int32",
          type = "integer",
        },
        isSharedCpu = {
          description = "[Output Only] Whether this machine type has a shared CPU. See Shared-core machine types for more information.",
          type = "boolean",
        },
        kind = {
          default = "compute#machineType",
          description = "[Output Only] The type of the resource. Always compute#machineType for machine types.",
          type = "string",
        },
        maximumPersistentDisks = {
          description = "[Output Only] Maximum persistent disks allowed.",
          format = "int32",
          type = "integer",
        },
        maximumPersistentDisksSizeGb = {
          description = "[Output Only] Maximum total persistent disks size (GB) allowed.",
          format = "int64",
          type = "string",
        },
        memoryMb = {
          description = "[Output Only] The amount of physical memory available to the instance, defined in MB.",
          format = "int32",
          type = "integer",
        },
        name = {
          description = "[Output Only] Name of the resource.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        scratchDisks = {
          description = "[Output Only] A list of extended scratch disks assigned to the instance.",
          items = {
            properties = {
              diskGb = {
                description = "Size of the scratch disk, defined in GB.",
                format = "int32",
                type = "integer",
              },
            },
            type = "object",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        zone = {
          description = "[Output Only] The name of the zone where the machine type resides, such as us-central1-a.",
          type = "string",
        },
      },
      type = "object",
    },
    MachineTypeAggregatedList = {
      id = "MachineTypeAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "MachineTypesScopedList",
            description = "[Output Only] Name of the scope containing this set of machine types.",
          },
          description = "A list of MachineTypesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#machineTypeAggregatedList",
          description = "[Output Only] Type of resource. Always compute#machineTypeAggregatedList for aggregated lists of machine types.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    MachineTypeList = {
      description = "Contains a list of machine types.",
      id = "MachineTypeList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of MachineType resources.",
          items = {
            ["$ref"] = "MachineType",
          },
          type = "array",
        },
        kind = {
          default = "compute#machineTypeList",
          description = "[Output Only] Type of resource. Always compute#machineTypeList for lists of machine types.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    MachineTypesScopedList = {
      id = "MachineTypesScopedList",
      properties = {
        machineTypes = {
          description = "[Output Only] A list of machine types contained in this scope.",
          items = {
            ["$ref"] = "MachineType",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] An informational warning that appears when the machine types list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ManagedInstance = {
      description = "A Managed Instance resource.",
      id = "ManagedInstance",
      properties = {
        currentAction = {
          description = "[Output Only] The current action that the managed instance group has scheduled for the instance. Possible values: - NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance. - CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful. - CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group's targetSize value is decreased instead. - RECREATING The managed instance group is recreating this instance. - DELETING The managed instance group is permanently deleting this instance. - ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group. - RESTARTING The managed instance group is restarting the instance. - REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance. - VERIFYING The managed instance group has created the instance and it is in the process of being verified. ",
          enum = {
            "ABANDONING",
            "CREATING",
            "CREATING_WITHOUT_RETRIES",
            "DELETING",
            "NONE",
            "RECREATING",
            "REFRESHING",
            "RESTARTING",
            "RESUMING",
            "STARTING",
            "STOPPING",
            "SUSPENDING",
            "VERIFYING",
          },
          enumDescriptions = {
            "The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.",
            "The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.",
            "The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group's targetSize value is decreased.",
            "The managed instance group is permanently deleting this instance.",
            "The managed instance group has not scheduled any actions for this instance.",
            "The managed instance group is recreating this instance.",
            "The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.",
            "The managed instance group is restarting this instance.",
            "The managed instance group is resuming this instance.",
            "The managed instance group is starting this instance.",
            "The managed instance group is stopping this instance.",
            "The managed instance group is suspending this instance.",
            "The managed instance group is verifying this already created instance. Verification happens every time the instance is (re)created or restarted and consists of: 1. Waiting until health check specified as part of this managed instance group's autohealing policy reports HEALTHY. Note: Applies only if autohealing policy has a health check specified 2. Waiting for addition verification steps performed as post-instance creation (subject to future extensions).",
          },
          type = "string",
        },
        id = {
          description = "[Output only] The unique identifier for this resource. This field is empty when instance does not exist.",
          format = "uint64",
          type = "string",
        },
        instance = {
          description = "[Output Only] The URL of the instance. The URL can exist even if the instance has not yet been created.",
          type = "string",
        },
        instanceHealth = {
          description = "[Output Only] Health state of the instance per health-check.",
          items = {
            ["$ref"] = "ManagedInstanceInstanceHealth",
          },
          type = "array",
        },
        instanceStatus = {
          description = "[Output Only] The status of the instance. This field is empty when the instance does not exist.",
          enum = {
            "DEPROVISIONING",
            "PROVISIONING",
            "REPAIRING",
            "RUNNING",
            "STAGING",
            "STOPPED",
            "STOPPING",
            "SUSPENDED",
            "SUSPENDING",
            "TERMINATED",
          },
          enumDescriptions = {
            "The Nanny is halted and we are performing tear down tasks like network deprogramming, releasing quota, IP, tearing down disks etc.",
            "Resources are being allocated for the instance.",
            "The instance is in repair.",
            "The instance is running.",
            "All required resources have been allocated and the instance is being started.",
            "The instance has stopped successfully.",
            "The instance is currently stopping (either being deleted or killed).",
            "The instance has suspended.",
            "The instance is suspending.",
            "The instance has stopped (either by explicit action or underlying failure).",
          },
          type = "string",
        },
        lastAttempt = {
          ["$ref"] = "ManagedInstanceLastAttempt",
          description = "[Output Only] Information about the last attempt to create or delete the instance.",
        },
        preservedStateFromConfig = {
          ["$ref"] = "PreservedState",
          description = "[Output Only] Preserved state applied from per-instance config for this instance.",
        },
        preservedStateFromPolicy = {
          ["$ref"] = "PreservedState",
          description = "[Output Only] Preserved state generated based on stateful policy for this instance.",
        },
        version = {
          ["$ref"] = "ManagedInstanceVersion",
          description = "[Output Only] Intended version of this instance.",
        },
      },
      type = "object",
    },
    ManagedInstanceInstanceHealth = {
      id = "ManagedInstanceInstanceHealth",
      properties = {
        detailedHealthState = {
          description = "[Output Only] The current detailed instance health state.",
          enum = {
            "DRAINING",
            "HEALTHY",
            "TIMEOUT",
            "UNHEALTHY",
            "UNKNOWN",
          },
          enumDescriptions = {
            "The instance is being drained. The existing connections to the instance have time to complete, but the new ones are being refused.",
            "The instance is reachable i.e. a connection to the application health checking endpoint can be established, and conforms to the requirements defined by the health check.",
            "The instance is unreachable i.e. a connection to the application health checking endpoint cannot be established, or the server does not respond within the specified timeout.",
            "The instance is reachable, but does not conform to the requirements defined by the health check.",
            "The health checking system is aware of the instance but its health is not known at the moment.",
          },
          type = "string",
        },
        healthCheck = {
          description = "[Output Only] The URL for the health check that verifies whether the instance is healthy.",
          type = "string",
        },
      },
      type = "object",
    },
    ManagedInstanceLastAttempt = {
      id = "ManagedInstanceLastAttempt",
      properties = {
        errors = {
          description = "[Output Only] Encountered errors during the last attempt to create or delete the instance.",
          properties = {
            errors = {
              description = "[Output Only] The array of errors encountered while processing this operation.",
              items = {
                properties = {
                  code = {
                    description = "[Output Only] The error type identifier for this error.",
                    type = "string",
                  },
                  errorDetails = {
                    description = "[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED.",
                    items = {
                      properties = {
                        errorInfo = {
                          ["$ref"] = "ErrorInfo",
                        },
                        help = {
                          ["$ref"] = "Help",
                        },
                        localizedMessage = {
                          ["$ref"] = "LocalizedMessage",
                        },
                        quotaInfo = {
                          ["$ref"] = "QuotaExceededInfo",
                        },
                      },
                      type = "object",
                    },
                    type = "array",
                  },
                  location = {
                    description = "[Output Only] Indicates the field in the request that caused the error. This property is optional.",
                    type = "string",
                  },
                  message = {
                    description = "[Output Only] An optional, human-readable error message.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ManagedInstanceVersion = {
      id = "ManagedInstanceVersion",
      properties = {
        instanceTemplate = {
          description = "[Output Only] The intended template of the instance. This field is empty when current_action is one of { DELETING, ABANDONING }.",
          type = "string",
        },
        name = {
          description = "[Output Only] Name of the version.",
          type = "string",
        },
      },
      type = "object",
    },
    Metadata = {
      description = "A metadata key/value entry.",
      id = "Metadata",
      properties = {
        fingerprint = {
          description = "Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the resource.",
          format = "byte",
          type = "string",
        },
        items = {
          description = "Array of key/value pairs. The total size of all keys and values must be less than 512 KB.",
          items = {
            description = "Metadata",
            properties = {
              key = {
                annotations = {
                  required = {
                    "compute.instances.insert",
                    "compute.projects.setCommonInstanceMetadata",
                  },
                },
                description = "Key for the metadata entry. Keys must conform to the following regexp: [a-zA-Z0-9-_]+, and be less than 128 bytes in length. This is reflected as part of a URL in the metadata server. Additionally, to avoid ambiguity, keys must not conflict with any other metadata keys for the project.",
                pattern = "[a-zA-Z0-9-_]{1,128}",
                type = "string",
              },
              value = {
                annotations = {
                  required = {
                    "compute.instances.insert",
                    "compute.projects.setCommonInstanceMetadata",
                  },
                },
                description = "Value for the metadata entry. These are free-form strings, and only have meaning as interpreted by the image running in the instance. The only restriction placed on values is that their size must be less than or equal to 262144 bytes (256 KiB).",
                type = "string",
              },
            },
            type = "object",
          },
          type = "array",
        },
        kind = {
          default = "compute#metadata",
          description = "[Output Only] Type of the resource. Always compute#metadata for metadata.",
          type = "string",
        },
      },
      type = "object",
    },
    MetadataFilter = {
      description = "Opaque filter criteria used by load balancers to restrict routing configuration to a limited set of load balancing proxies. Proxies and sidecars involved in load balancing would typically present metadata to the load balancers that need to match criteria specified here. If a match takes place, the relevant configuration is made available to those proxies. For each metadataFilter in this list, if its filterMatchCriteria is set to MATCH_ANY, at least one of the filterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. An example for using metadataFilters would be: if load balancing involves Envoys, they receive routing configuration when values in metadataFilters match values supplied in of their XDS requests to loadbalancers.",
      id = "MetadataFilter",
      properties = {
        filterLabels = {
          description = "The list of label value pairs that must match labels in the provided metadata based on filterMatchCriteria This list must not be empty and can have at the most 64 entries.",
          items = {
            ["$ref"] = "MetadataFilterLabelMatch",
          },
          type = "array",
        },
        filterMatchCriteria = {
          description = "Specifies how individual filter label matches within the list of filterLabels and contributes toward the overall metadataFilter match. Supported values are: - MATCH_ANY: at least one of the filterLabels must have a matching label in the provided metadata. - MATCH_ALL: all filterLabels must have matching labels in the provided metadata. ",
          enum = {
            "MATCH_ALL",
            "MATCH_ANY",
            "NOT_SET",
          },
          enumDescriptions = {
            "Specifies that all filterLabels must match for the metadataFilter to be considered a match.",
            "Specifies that any filterLabel must match for the metadataFilter to be considered a match.",
            "Indicates that the match criteria was not set. A metadataFilter must never be created with this value.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    MetadataFilterLabelMatch = {
      description = "MetadataFilter label name value pairs that are expected to match corresponding labels presented as metadata to the load balancer.",
      id = "MetadataFilterLabelMatch",
      properties = {
        name = {
          description = "Name of metadata label. The name can have a maximum length of 1024 characters and must be at least 1 character long.",
          type = "string",
        },
        value = {
          description = "The value of the label must match the specified value. value can have a maximum length of 1024 characters.",
          type = "string",
        },
      },
      type = "object",
    },
    NamedPort = {
      description = "The named port. For example: <\"http\", 80>.",
      id = "NamedPort",
      properties = {
        name = {
          description = "The name for this named port. The name must be 1-63 characters long, and comply with RFC1035.",
          type = "string",
        },
        port = {
          description = "The port number, which can be a value between 1 and 65535.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    Network = {
      description = "Represents a VPC Network resource. Networks connect resources to each other and to the internet. For more information, read Virtual Private Cloud (VPC) Network.",
      id = "Network",
      properties = {
        IPv4Range = {
          description = "Deprecated in favor of subnet mode networks. The range of internal addresses that are legal on this network. This range is a CIDR specification, for example: 192.168.0.0/16. Provided by the client when the network is created.",
          pattern = "[0-9]{1,3}(?:\\.[0-9]{1,3}){3}/[0-9]{1,2}",
          type = "string",
        },
        autoCreateSubnetworks = {
          description = "Must be set to create a VPC network. If not set, a legacy network is created. When set to true, the VPC network is created in auto mode. When set to false, the VPC network is created in custom mode. An auto mode VPC network starts with one subnet per region. Each subnet has a predetermined range as described in Auto mode VPC network IP ranges. For custom mode VPC networks, you can add subnets using the subnetworks insert method.",
          type = "boolean",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this field when you create the resource.",
          type = "string",
        },
        enableUlaInternalIpv6 = {
          description = "Enable ULA internal ipv6 on this network. Enabling this feature will assign a /48 from google defined ULA prefix fd20::/20. .",
          type = "boolean",
        },
        firewallPolicy = {
          description = "[Output Only] URL of the firewall policy the network is associated with.",
          type = "string",
        },
        gatewayIPv4 = {
          description = "[Output Only] The gateway address for default routing out of the network, selected by GCP.",
          pattern = "[0-9]{1,3}(?:\\.[0-9]{1,3}){3}",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        internalIpv6Range = {
          description = "When enabling ula internal ipv6, caller optionally can specify the /48 range they want from the google defined ULA prefix fd20::/20. The input must be a valid /48 ULA IPv6 address and must be within the fd20::/20. Operation will fail if the speficied /48 is already in used by another resource. If the field is not speficied, then a /48 range will be randomly allocated from fd20::/20 and returned via this field. .",
          type = "string",
        },
        kind = {
          default = "compute#network",
          description = "[Output Only] Type of the resource. Always compute#network for networks.",
          type = "string",
        },
        mtu = {
          description = "Maximum Transmission Unit in bytes. The minimum value for this field is 1300 and the maximum value is 8896. The suggested value is 1500, which is the default MTU used on the Internet, or 8896 if you want to use Jumbo frames. If unspecified, the value defaults to 1460.",
          format = "int32",
          type = "integer",
        },
        name = {
          annotations = {
            required = {
              "compute.networks.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        networkFirewallPolicyEnforcementOrder = {
          description = "The network firewall policy enforcement order. Can be either AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to AFTER_CLASSIC_FIREWALL if the field is not specified.",
          enum = {
            "AFTER_CLASSIC_FIREWALL",
            "BEFORE_CLASSIC_FIREWALL",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        peerings = {
          description = "[Output Only] A list of network peerings for the resource.",
          items = {
            ["$ref"] = "NetworkPeering",
          },
          type = "array",
        },
        routingConfig = {
          ["$ref"] = "NetworkRoutingConfig",
          description = "The network-level routing configuration for this network. Used by Cloud Router to determine what type of network-wide routing behavior to enforce.",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        selfLinkWithId = {
          description = "[Output Only] Server-defined URL for this resource with the resource id.",
          type = "string",
        },
        subnetworks = {
          description = "[Output Only] Server-defined fully-qualified URLs for all subnetworks in this VPC network.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    NetworkAttachment = {
      description = "NetworkAttachments A network attachment resource ...",
      id = "NetworkAttachment",
      properties = {
        connectionEndpoints = {
          description = "[Output Only] An array of connections for all the producers connected to this network attachment.",
          items = {
            ["$ref"] = "NetworkAttachmentConnectedEndpoint",
          },
          type = "array",
        },
        connectionPreference = {
          enum = {
            "ACCEPT_AUTOMATIC",
            "ACCEPT_MANUAL",
            "INVALID",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "[Output Only] Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. An up-to-date fingerprint must be provided in order to patch.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource type. The server generates this identifier.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#networkAttachment",
          description = "[Output Only] Type of the resource.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.networkAttachments.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          description = "[Output Only] The URL of the network which the Network Attachment belongs to.",
          type = "string",
        },
        producerAcceptLists = {
          description = "Projects that are allowed to connect to this network attachment. The project can be specified using its id or number.",
          items = {
            type = "string",
          },
          type = "array",
        },
        producerRejectLists = {
          description = "Projects that are not allowed to connect to this network attachment. The project can be specified using its id or number.",
          items = {
            type = "string",
          },
          type = "array",
        },
        region = {
          description = "[Output Only] URL of the region where the network attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        selfLinkWithId = {
          description = "[Output Only] Server-defined URL for this resource's resource id.",
          type = "string",
        },
        subnetworks = {
          description = "An array of URLs where each entry is the URL of a subnet provided by the service consumer to use for endpoints in the producers that connect to this network attachment.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    NetworkAttachmentAggregatedList = {
      description = "Contains a list of NetworkAttachmentsScopedList.",
      id = "NetworkAttachmentAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "NetworkAttachmentsScopedList",
            description = "Name of the scope containing this set of NetworkAttachments.",
          },
          description = "A list of NetworkAttachmentsScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#networkAttachmentAggregatedList",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkAttachmentConnectedEndpoint = {
      description = "[Output Only] A connection connected to this network attachment.",
      id = "NetworkAttachmentConnectedEndpoint",
      properties = {
        ipAddress = {
          description = "The IP address assigned to the producer instance network interface. This value will be a range in case of Serverless.",
          type = "string",
        },
        projectIdOrNum = {
          description = "The project id or number of the interface to which the IP was assigned.",
          type = "string",
        },
        secondaryIpCidrRanges = {
          description = "Alias IP ranges from the same subnetwork",
          items = {
            type = "string",
          },
          type = "array",
        },
        status = {
          description = "The status of a connected endpoint to this network attachment.",
          enum = {
            "ACCEPTED",
            "CLOSED",
            "NEEDS_ATTENTION",
            "PENDING",
            "REJECTED",
            "STATUS_UNSPECIFIED",
          },
          enumDescriptions = {
            "The consumer allows traffic from the producer to reach its VPC.",
            "The consumer network attachment no longer exists.",
            "The consumer needs to take further action before traffic can be served.",
            "The consumer neither allows nor prohibits traffic from the producer to reach its VPC.",
            "The consumer prohibits traffic from the producer to reach its VPC.",
            "",
          },
          type = "string",
        },
        subnetwork = {
          description = "The subnetwork used to assign the IP to the producer instance network interface.",
          type = "string",
        },
      },
      type = "object",
    },
    NetworkAttachmentList = {
      id = "NetworkAttachmentList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of NetworkAttachment resources.",
          items = {
            ["$ref"] = "NetworkAttachment",
          },
          type = "array",
        },
        kind = {
          default = "compute#networkAttachmentList",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkAttachmentsScopedList = {
      id = "NetworkAttachmentsScopedList",
      properties = {
        networkAttachments = {
          description = "A list of NetworkAttachments contained in this scope.",
          items = {
            ["$ref"] = "NetworkAttachment",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of network attachments when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkEdgeSecurityService = {
      description = "Represents a Google Cloud Armor network edge security service resource.",
      id = "NetworkEdgeSecurityService",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a NetworkEdgeSecurityService. An up-to-date fingerprint must be provided in order to update the NetworkEdgeSecurityService, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a NetworkEdgeSecurityService.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#networkEdgeSecurityService",
          description = "[Output only] Type of the resource. Always compute#networkEdgeSecurityService for NetworkEdgeSecurityServices",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        securityPolicy = {
          description = "The resource URL for the network edge security service associated with this network edge security service.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        selfLinkWithId = {
          description = "[Output Only] Server-defined URL for this resource with the resource id.",
          type = "string",
        },
      },
      type = "object",
    },
    NetworkEdgeSecurityServiceAggregatedList = {
      id = "NetworkEdgeSecurityServiceAggregatedList",
      properties = {
        etag = {
          type = "string",
        },
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "NetworkEdgeSecurityServicesScopedList",
            description = "Name of the scope containing this set of security policies.",
          },
          description = "A list of NetworkEdgeSecurityServicesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#networkEdgeSecurityServiceAggregatedList",
          description = "[Output Only] Type of resource. Always compute#networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkEdgeSecurityServicesScopedList = {
      id = "NetworkEdgeSecurityServicesScopedList",
      properties = {
        networkEdgeSecurityServices = {
          description = "A list of NetworkEdgeSecurityServices contained in this scope.",
          items = {
            ["$ref"] = "NetworkEdgeSecurityService",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of security policies when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkEndpoint = {
      description = "The network endpoint.",
      id = "NetworkEndpoint",
      properties = {
        annotations = {
          additionalProperties = {
            type = "string",
          },
          description = "Metadata defined as annotations on the network endpoint.",
          type = "object",
        },
        fqdn = {
          description = "Optional fully qualified domain name of network endpoint. This can only be specified when NetworkEndpointGroup.network_endpoint_type is NON_GCP_FQDN_PORT.",
          type = "string",
        },
        instance = {
          description = "The name for a specific VM instance that the IP address belongs to. This is required for network endpoints of type GCE_VM_IP_PORT. The instance must be in the same zone of network endpoint group. The name must be 1-63 characters long, and comply with RFC1035.",
          type = "string",
        },
        ipAddress = {
          description = "Optional IPv4 address of network endpoint. The IP address must belong to a VM in Compute Engine (either the primary IP or as part of an aliased IP range). If the IP address is not specified, then the primary IP address for the VM instance in the network that the network endpoint group belongs to will be used.",
          type = "string",
        },
        port = {
          description = "Optional port number of network endpoint. If not specified, the defaultPort for the network endpoint group will be used.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    NetworkEndpointGroup = {
      description = "Represents a collection of network endpoints. A network endpoint group (NEG) defines how a set of endpoints should be reached, whether they are reachable, and where they are located. For more information about using NEGs, see Setting up external HTTP(S) Load Balancing with internet NEGs, Setting up zonal NEGs, or Setting up external HTTP(S) Load Balancing with serverless NEGs.",
      id = "NetworkEndpointGroup",
      properties = {
        annotations = {
          additionalProperties = {
            type = "string",
          },
          description = "Metadata defined as annotations on the network endpoint group.",
          type = "object",
        },
        appEngine = {
          ["$ref"] = "NetworkEndpointGroupAppEngine",
          description = "Only valid when networkEndpointType is \"SERVERLESS\". Only one of cloudRun, appEngine or cloudFunction may be set.",
        },
        cloudFunction = {
          ["$ref"] = "NetworkEndpointGroupCloudFunction",
          description = "Only valid when networkEndpointType is \"SERVERLESS\". Only one of cloudRun, appEngine or cloudFunction may be set.",
        },
        cloudRun = {
          ["$ref"] = "NetworkEndpointGroupCloudRun",
          description = "Only valid when networkEndpointType is \"SERVERLESS\". Only one of cloudRun, appEngine or cloudFunction may be set.",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        defaultPort = {
          description = "The default port used if the port number is not specified in the network endpoint.",
          format = "int32",
          type = "integer",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#networkEndpointGroup",
          description = "[Output Only] Type of the resource. Always compute#networkEndpointGroup for network endpoint group.",
          type = "string",
        },
        name = {
          description = "Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          type = "string",
        },
        network = {
          description = "The URL of the network to which all network endpoints in the NEG belong. Uses \"default\" project network if unspecified.",
          type = "string",
        },
        networkEndpointType = {
          description = "Type of network endpoints in this network endpoint group. Can be one of GCE_VM_IP, GCE_VM_IP_PORT, NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT, INTERNET_IP_PORT, SERVERLESS, PRIVATE_SERVICE_CONNECT.",
          enum = {
            "GCE_VM_IP",
            "GCE_VM_IP_PORT",
            "INTERNET_FQDN_PORT",
            "INTERNET_IP_PORT",
            "NON_GCP_PRIVATE_IP_PORT",
            "PRIVATE_SERVICE_CONNECT",
            "SERVERLESS",
          },
          enumDescriptions = {
            "The network endpoint is represented by an IP address.",
            "The network endpoint is represented by IP address and port pair.",
            "The network endpoint is represented by fully qualified domain name and port.",
            "The network endpoint is represented by an internet IP address and port.",
            "The network endpoint is represented by an IP address and port. The endpoint belongs to a VM or pod running in a customer's on-premises.",
            "The network endpoint is either public Google APIs or services exposed by other GCP Project with a Service Attachment. The connection is set up by private service connect",
            "The network endpoint is handled by specified serverless infrastructure.",
          },
          type = "string",
        },
        pscData = {
          ["$ref"] = "NetworkEndpointGroupPscData",
        },
        pscTargetService = {
          description = "The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment. An example value is: \"asia-northeast3-cloudkms.googleapis.com\"",
          type = "string",
        },
        region = {
          description = "[Output Only] The URL of the region where the network endpoint group is located.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        size = {
          description = "[Output only] Number of network endpoints in the network endpoint group.",
          format = "int32",
          type = "integer",
        },
        subnetwork = {
          description = "Optional URL of the subnetwork to which all network endpoints in the NEG belong.",
          type = "string",
        },
        zone = {
          description = "[Output Only] The URL of the zone where the network endpoint group is located.",
          type = "string",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupAggregatedList = {
      id = "NetworkEndpointGroupAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "NetworkEndpointGroupsScopedList",
            description = "The name of the scope that contains this set of network endpoint groups.",
          },
          description = "A list of NetworkEndpointGroupsScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#networkEndpointGroupAggregatedList",
          description = "[Output Only] The resource type, which is always compute#networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupAppEngine = {
      description = "Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present. Note: App Engine service must be in the same project and located in the same region as the Serverless NEG.",
      id = "NetworkEndpointGroupAppEngine",
      properties = {
        service = {
          description = "Optional serving service. The service name is case-sensitive and must be 1-63 characters long. Example value: \"default\", \"my-service\".",
          type = "string",
        },
        urlMask = {
          description = "A template to parse service and version fields from a request URL. URL mask allows for routing to multiple App Engine services without having to create multiple Network Endpoint Groups and backend services. For example, the request URLs \"foo1-dot-appname.appspot.com/v1\" and \"foo1-dot-appname.appspot.com/v2\" can be backed by the same Serverless NEG with URL mask \"<service>-dot-appname.appspot.com/<version>\". The URL mask will parse them to { service = \"foo1\", version = \"v1\" } and { service = \"foo1\", version = \"v2\" } respectively.",
          type = "string",
        },
        version = {
          description = "Optional serving version. The version name is case-sensitive and must be 1-100 characters long. Example value: \"v1\", \"v2\".",
          type = "string",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupCloudFunction = {
      description = "Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask. Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG.",
      id = "NetworkEndpointGroupCloudFunction",
      properties = {
        ["function"] = {
          description = "A user-defined name of the Cloud Function. The function name is case-sensitive and must be 1-63 characters long. Example value: \"func1\".",
          type = "string",
        },
        urlMask = {
          description = "A template to parse function field from a request URL. URL mask allows for routing to multiple Cloud Functions without having to create multiple Network Endpoint Groups and backend services. For example, request URLs \" mydomain.com/function1\" and \"mydomain.com/function2\" can be backed by the same Serverless NEG with URL mask \"/<function>\". The URL mask will parse them to { function = \"function1\" } and { function = \"function2\" } respectively.",
          type = "string",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupCloudRun = {
      description = "Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask. Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG.",
      id = "NetworkEndpointGroupCloudRun",
      properties = {
        service = {
          description = "Cloud Run service is the main resource of Cloud Run. The service must be 1-63 characters long, and comply with RFC1035. Example value: \"run-service\".",
          type = "string",
        },
        tag = {
          description = "Optional Cloud Run tag represents the \"named-revision\" to provide additional fine-grained traffic routing information. The tag must be 1-63 characters long, and comply with RFC1035. Example value: \"revision-0010\".",
          type = "string",
        },
        urlMask = {
          description = "A template to parse <service> and <tag> fields from a request URL. URL mask allows for routing to multiple Run services without having to create multiple network endpoint groups and backend services. For example, request URLs \"foo1.domain.com/bar1\" and \"foo1.domain.com/bar2\" can be backed by the same Serverless Network Endpoint Group (NEG) with URL mask \"<tag>.domain.com/<service>\". The URL mask will parse them to { service=\"bar1\", tag=\"foo1\" } and { service=\"bar2\", tag=\"foo2\" } respectively.",
          type = "string",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupList = {
      id = "NetworkEndpointGroupList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of NetworkEndpointGroup resources.",
          items = {
            ["$ref"] = "NetworkEndpointGroup",
          },
          type = "array",
        },
        kind = {
          default = "compute#networkEndpointGroupList",
          description = "[Output Only] The resource type, which is always compute#networkEndpointGroupList for network endpoint group lists.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupPscData = {
      description = "All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.",
      id = "NetworkEndpointGroupPscData",
      properties = {
        consumerPscAddress = {
          description = "[Output Only] Address allocated from given subnetwork for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in L7 PSC-XLB.",
          type = "string",
        },
        pscConnectionId = {
          description = "[Output Only] The PSC connection id of the PSC Network Endpoint Group Consumer.",
          format = "uint64",
          type = "string",
        },
        pscConnectionStatus = {
          description = "[Output Only] The connection status of the PSC Forwarding Rule.",
          enum = {
            "ACCEPTED",
            "CLOSED",
            "NEEDS_ATTENTION",
            "PENDING",
            "REJECTED",
            "STATUS_UNSPECIFIED",
          },
          enumDescriptions = {
            "The connection has been accepted by the producer.",
            "The connection has been closed by the producer and will not serve traffic going forward.",
            "The connection has been accepted by the producer, but the producer needs to take further action before the forwarding rule can serve traffic.",
            "The connection is pending acceptance by the producer.",
            "The connection has been rejected by the producer.",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupsAttachEndpointsRequest = {
      id = "NetworkEndpointGroupsAttachEndpointsRequest",
      properties = {
        networkEndpoints = {
          description = "The list of network endpoints to be attached.",
          items = {
            ["$ref"] = "NetworkEndpoint",
          },
          type = "array",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupsDetachEndpointsRequest = {
      id = "NetworkEndpointGroupsDetachEndpointsRequest",
      properties = {
        networkEndpoints = {
          description = "The list of network endpoints to be detached.",
          items = {
            ["$ref"] = "NetworkEndpoint",
          },
          type = "array",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupsListEndpointsRequest = {
      id = "NetworkEndpointGroupsListEndpointsRequest",
      properties = {
        healthStatus = {
          description = "Optional query parameter for showing the health status of each network endpoint. Valid options are SKIP or SHOW. If you don't specify this parameter, the health status of network endpoints will not be provided.",
          enum = {
            "SHOW",
            "SKIP",
          },
          enumDescriptions = {
            "Show the health status for each network endpoint. Impacts latency of the call.",
            "Health status for network endpoints will not be provided.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupsListNetworkEndpoints = {
      id = "NetworkEndpointGroupsListNetworkEndpoints",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of NetworkEndpointWithHealthStatus resources.",
          items = {
            ["$ref"] = "NetworkEndpointWithHealthStatus",
          },
          type = "array",
        },
        kind = {
          default = "compute#networkEndpointGroupsListNetworkEndpoints",
          description = "[Output Only] The resource type, which is always compute#networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkEndpointGroupsScopedList = {
      id = "NetworkEndpointGroupsScopedList",
      properties = {
        networkEndpointGroups = {
          description = "[Output Only] The list of network endpoint groups that are contained in this scope.",
          items = {
            ["$ref"] = "NetworkEndpointGroup",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] An informational warning that replaces the list of network endpoint groups when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkEndpointWithHealthStatus = {
      id = "NetworkEndpointWithHealthStatus",
      properties = {
        healths = {
          description = "[Output only] The health status of network endpoint;",
          items = {
            ["$ref"] = "HealthStatusForNetworkEndpoint",
          },
          type = "array",
        },
        networkEndpoint = {
          ["$ref"] = "NetworkEndpoint",
          description = "[Output only] The network endpoint;",
        },
      },
      type = "object",
    },
    NetworkInterface = {
      description = "A network interface resource attached to an instance.",
      id = "NetworkInterface",
      properties = {
        accessConfigs = {
          description = "An array of configurations for this interface. Currently, only one access config, ONE_TO_ONE_NAT, is supported. If there are no accessConfigs specified, then this instance will have no external internet access.",
          items = {
            ["$ref"] = "AccessConfig",
          },
          type = "array",
        },
        aliasIpRanges = {
          description = "An array of alias IP ranges for this network interface. You can only specify this field for network interfaces in VPC networks.",
          items = {
            ["$ref"] = "AliasIpRange",
          },
          type = "array",
        },
        fingerprint = {
          description = "Fingerprint hash of contents stored in this network interface. This field will be ignored when inserting an Instance or adding a NetworkInterface. An up-to-date fingerprint must be provided in order to update the NetworkInterface. The request will fail with error 400 Bad Request if the fingerprint is not provided, or 412 Precondition Failed if the fingerprint is out of date.",
          format = "byte",
          type = "string",
        },
        internalIpv6PrefixLength = {
          description = "The prefix length of the primary internal IPv6 range.",
          format = "int32",
          type = "integer",
        },
        ipv6AccessConfigs = {
          description = "An array of IPv6 access configurations for this interface. Currently, only one IPv6 access config, DIRECT_IPV6, is supported. If there is no ipv6AccessConfig specified, then this instance will have no external IPv6 Internet access.",
          items = {
            ["$ref"] = "AccessConfig",
          },
          type = "array",
        },
        ipv6AccessType = {
          description = "[Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6.",
          enum = {
            "EXTERNAL",
            "INTERNAL",
          },
          enumDescriptions = {
            "This network interface can have external IPv6.",
            "This network interface can have internal IPv6.",
          },
          type = "string",
        },
        ipv6Address = {
          description = "An IPv6 internal network address for this network interface.",
          type = "string",
        },
        kind = {
          default = "compute#networkInterface",
          description = "[Output Only] Type of the resource. Always compute#networkInterface for network interfaces.",
          type = "string",
        },
        name = {
          description = "[Output Only] The name of the network interface, which is generated by the server. For a VM, the network interface uses the nicN naming format. Where N is a value between 0 and 7. The default interface value is nic0.",
          type = "string",
        },
        network = {
          description = "URL of the VPC network resource for this instance. When creating an instance, if neither the network nor the subnetwork is specified, the default network global/networks/default is used. If the selected project doesn't have the default network, you must specify a network or subnet. If the network is not specified but the subnetwork is specified, the network is inferred. If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs: - https://www.googleapis.com/compute/v1/projects/project/global/networks/ network - projects/project/global/networks/network - global/networks/default ",
          type = "string",
        },
        networkAttachment = {
          description = "The URL of the network attachment that this interface should connect to in the following format: projects/{project_number}/regions/{region_name}/networkAttachments/{network_attachment_name}.",
          type = "string",
        },
        networkIP = {
          description = "An IPv4 internal IP address to assign to the instance for this network interface. If not specified by the user, an unused internal IP is assigned by the system.",
          type = "string",
        },
        nicType = {
          description = "The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet.",
          enum = {
            "GVNIC",
            "UNSPECIFIED_NIC_TYPE",
            "VIRTIO_NET",
          },
          enumDescriptions = {
            "GVNIC",
            "No type specified.",
            "VIRTIO",
          },
          type = "string",
        },
        queueCount = {
          description = "The networking queue count that's specified by users for the network interface. Both Rx and Tx queues will be set to this number. It'll be empty if not specified by the users.",
          format = "int32",
          type = "integer",
        },
        stackType = {
          description = "The stack type for this network interface to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used. This field can be both set at instance creation and update network interface operations.",
          enum = {
            "IPV4_IPV6",
            "IPV4_ONLY",
          },
          enumDescriptions = {
            "The network interface can have both IPv4 and IPv6 addresses.",
            "The network interface will be assigned IPv4 address.",
          },
          type = "string",
        },
        subnetwork = {
          description = "The URL of the Subnetwork resource for this instance. If the network resource is in legacy mode, do not specify this field. If the network is in auto subnet mode, specifying the subnetwork is optional. If the network is in custom subnet mode, specifying the subnetwork is required. If you specify this field, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs: - https://www.googleapis.com/compute/v1/projects/project/regions/region /subnetworks/subnetwork - regions/region/subnetworks/subnetwork ",
          type = "string",
        },
      },
      type = "object",
    },
    NetworkList = {
      description = "Contains a list of networks.",
      id = "NetworkList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Network resources.",
          items = {
            ["$ref"] = "Network",
          },
          type = "array",
        },
        kind = {
          default = "compute#networkList",
          description = "[Output Only] Type of resource. Always compute#networkList for lists of networks.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NetworkPeering = {
      description = "A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering.",
      id = "NetworkPeering",
      properties = {
        autoCreateRoutes = {
          description = "This field will be deprecated soon. Use the exchange_subnet_routes field instead. Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state is ACTIVE.",
          type = "boolean",
        },
        exchangeSubnetRoutes = {
          description = "Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state is ACTIVE.",
          type = "boolean",
        },
        exportCustomRoutes = {
          description = "Whether to export the custom routes to peer network. The default value is false.",
          type = "boolean",
        },
        exportSubnetRoutesWithPublicIp = {
          description = "Whether subnet routes with public IP range are exported. The default value is true, all subnet routes are exported. IPv4 special-use ranges are always exported to peers and are not controlled by this field.",
          type = "boolean",
        },
        importCustomRoutes = {
          description = "Whether to import the custom routes from peer network. The default value is false.",
          type = "boolean",
        },
        importSubnetRoutesWithPublicIp = {
          description = "Whether subnet routes with public IP range are imported. The default value is false. IPv4 special-use ranges are always imported from peers and are not controlled by this field.",
          type = "boolean",
        },
        name = {
          description = "Name of this peering. Provided by the client when the peering is created. The name must comply with RFC1035. Specifically, the name must be 1-63 characters long and match regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all the following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          type = "string",
        },
        network = {
          description = "The URL of the peer network. It can be either full URL or partial URL. The peer network may belong to a different project. If the partial URL does not contain project, it is assumed that the peer network is in the same project as the current network.",
          type = "string",
        },
        peerMtu = {
          description = "Maximum Transmission Unit in bytes.",
          format = "int32",
          type = "integer",
        },
        stackType = {
          description = "Which IP version(s) of traffic and routes are allowed to be imported or exported between peer networks. The default value is IPV4_ONLY.",
          enum = {
            "IPV4_IPV6",
            "IPV4_ONLY",
          },
          enumDescriptions = {
            "This Peering will allow IPv4 traffic and routes to be exchanged. Additionally if the matching peering is IPV4_IPV6, IPv6 traffic and routes will be exchanged as well.",
            "This Peering will only allow IPv4 traffic and routes to be exchanged, even if the matching peering is IPV4_IPV6.",
          },
          type = "string",
        },
        state = {
          description = "[Output Only] State for the peering, either `ACTIVE` or `INACTIVE`. The peering is `ACTIVE` when there's a matching configuration in the peer network.",
          enum = {
            "ACTIVE",
            "INACTIVE",
          },
          enumDescriptions = {
            "Matching configuration exists on the peer.",
            "There is no matching configuration on the peer, including the case when peer does not exist.",
          },
          type = "string",
        },
        stateDetails = {
          description = "[Output Only] Details about the current state of the peering.",
          type = "string",
        },
      },
      type = "object",
    },
    NetworkPerformanceConfig = {
      id = "NetworkPerformanceConfig",
      properties = {
        totalEgressBandwidthTier = {
          enum = {
            "DEFAULT",
            "TIER_1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    NetworkRoutingConfig = {
      description = "A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.",
      id = "NetworkRoutingConfig",
      properties = {
        routingMode = {
          description = "The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions.",
          enum = {
            "GLOBAL",
            "REGIONAL",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    NetworksAddPeeringRequest = {
      id = "NetworksAddPeeringRequest",
      properties = {
        autoCreateRoutes = {
          description = "This field will be deprecated soon. Use exchange_subnet_routes in network_peering instead. Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state is ACTIVE.",
          type = "boolean",
        },
        name = {
          annotations = {
            required = {
              "compute.networks.addPeering",
            },
          },
          description = "Name of the peering, which should conform to RFC1035.",
          type = "string",
        },
        networkPeering = {
          ["$ref"] = "NetworkPeering",
          description = "Network peering parameters. In order to specify route policies for peering using import and export custom routes, you must specify all peering related parameters (name, peer network, exchange_subnet_routes) in the network_peering field. The corresponding fields in NetworksAddPeeringRequest will be deprecated soon.",
        },
        peerNetwork = {
          description = "URL of the peer network. It can be either full URL or partial URL. The peer network may belong to a different project. If the partial URL does not contain project, it is assumed that the peer network is in the same project as the current network.",
          type = "string",
        },
      },
      type = "object",
    },
    NetworksGetEffectiveFirewallsResponse = {
      id = "NetworksGetEffectiveFirewallsResponse",
      properties = {
        firewallPolicys = {
          description = "Effective firewalls from firewall policy.",
          items = {
            ["$ref"] = "NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
          },
          type = "array",
        },
        firewalls = {
          description = "Effective firewalls on the network.",
          items = {
            ["$ref"] = "Firewall",
          },
          type = "array",
        },
      },
      type = "object",
    },
    NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy = {
      id = "NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
      properties = {
        displayName = {
          description = "[Output Only] Deprecated, please use short name instead. The display name of the firewall policy.",
          type = "string",
        },
        name = {
          description = "[Output Only] The name of the firewall policy.",
          type = "string",
        },
        rules = {
          description = "The rules that apply to the network.",
          items = {
            ["$ref"] = "FirewallPolicyRule",
          },
          type = "array",
        },
        shortName = {
          description = "[Output Only] The short name of the firewall policy.",
          type = "string",
        },
        type = {
          description = "[Output Only] The type of the firewall policy.",
          enum = {
            "HIERARCHY",
            "NETWORK",
            "UNSPECIFIED",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    NetworksRemovePeeringRequest = {
      id = "NetworksRemovePeeringRequest",
      properties = {
        name = {
          description = "Name of the peering, which should conform to RFC1035.",
          type = "string",
        },
      },
      type = "object",
    },
    NetworksUpdatePeeringRequest = {
      id = "NetworksUpdatePeeringRequest",
      properties = {
        networkPeering = {
          ["$ref"] = "NetworkPeering",
        },
      },
      type = "object",
    },
    NodeGroup = {
      description = "Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, read Sole-tenant nodes.",
      id = "NodeGroup",
      properties = {
        autoscalingPolicy = {
          ["$ref"] = "NodeGroupAutoscalingPolicy",
          description = "Specifies how autoscaling should behave.",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#nodeGroup",
          description = "[Output Only] The type of the resource. Always compute#nodeGroup for node group.",
          type = "string",
        },
        locationHint = {
          description = "An opaque location hint used to place the Node close to other resources. This field is for use by internal tools that use the public API. The location hint here on the NodeGroup overrides any location_hint present in the NodeTemplate.",
          type = "string",
        },
        maintenancePolicy = {
          description = "Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT, RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies.",
          enum = {
            "DEFAULT",
            "MAINTENANCE_POLICY_UNSPECIFIED",
            "MIGRATE_WITHIN_NODE_GROUP",
            "RESTART_IN_PLACE",
          },
          enumDescriptions = {
            "Allow the node and corresponding instances to retain default maintenance behavior.",
            "",
            "When maintenance must be done on a node, the instances on that node will be moved to other nodes in the group. Instances with onHostMaintenance = MIGRATE will live migrate to their destinations while instances with onHostMaintenance = TERMINATE will terminate and then restart on their destination nodes if automaticRestart = true.",
            "Instances in this group will restart on the same node when maintenance has completed. Instances must have onHostMaintenance = TERMINATE, and they will only restart if automaticRestart = true.",
          },
          type = "string",
        },
        maintenanceWindow = {
          ["$ref"] = "NodeGroupMaintenanceWindow",
        },
        name = {
          description = "The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          type = "string",
        },
        nodeTemplate = {
          description = "URL of the node template to create the node group from.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        shareSettings = {
          ["$ref"] = "ShareSettings",
          description = "Share-settings for the node group",
        },
        size = {
          description = "[Output Only] The total number of nodes in the node group.",
          format = "int32",
          type = "integer",
        },
        status = {
          enum = {
            "CREATING",
            "DELETING",
            "INVALID",
            "READY",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        zone = {
          description = "[Output Only] The name of the zone where the node group resides, such as us-central1-a.",
          type = "string",
        },
      },
      type = "object",
    },
    NodeGroupAggregatedList = {
      id = "NodeGroupAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "NodeGroupsScopedList",
            description = "[Output Only] Name of the scope containing this set of node groups.",
          },
          description = "A list of NodeGroupsScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#nodeGroupAggregatedList",
          description = "[Output Only] Type of resource.Always compute#nodeGroupAggregatedList for aggregated lists of node groups.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NodeGroupAutoscalingPolicy = {
      id = "NodeGroupAutoscalingPolicy",
      properties = {
        maxNodes = {
          description = "The maximum number of nodes that the group should have. Must be set if autoscaling is enabled. Maximum value allowed is 100.",
          format = "int32",
          type = "integer",
        },
        minNodes = {
          description = "The minimum number of nodes that the group should have.",
          format = "int32",
          type = "integer",
        },
        mode = {
          description = "The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For more information, see Autoscaler modes.",
          enum = {
            "MODE_UNSPECIFIED",
            "OFF",
            "ON",
            "ONLY_SCALE_OUT",
          },
          enumDescriptions = {
            "",
            "Autoscaling is disabled.",
            "Autocaling is fully enabled.",
            "Autoscaling will only scale out and will not remove nodes.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    NodeGroupList = {
      description = "Contains a list of nodeGroups.",
      id = "NodeGroupList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of NodeGroup resources.",
          items = {
            ["$ref"] = "NodeGroup",
          },
          type = "array",
        },
        kind = {
          default = "compute#nodeGroupList",
          description = "[Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NodeGroupMaintenanceWindow = {
      description = "Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window.",
      id = "NodeGroupMaintenanceWindow",
      properties = {
        maintenanceDuration = {
          ["$ref"] = "Duration",
          description = "[Output only] A predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario.",
        },
        startTime = {
          description = "Start time of the window. This must be in UTC format that resolves to one of 00:00, 04:00, 08:00, 12:00, 16:00, or 20:00. For example, both 13:00-5 and 08:00 are valid.",
          type = "string",
        },
      },
      type = "object",
    },
    NodeGroupNode = {
      id = "NodeGroupNode",
      properties = {
        accelerators = {
          description = "Accelerators for this node.",
          items = {
            ["$ref"] = "AcceleratorConfig",
          },
          type = "array",
        },
        consumedResources = {
          ["$ref"] = "InstanceConsumptionInfo",
          description = "Node resources that are reserved by all instances.",
        },
        cpuOvercommitType = {
          description = "CPU overcommit.",
          enum = {
            "CPU_OVERCOMMIT_TYPE_UNSPECIFIED",
            "ENABLED",
            "NONE",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        disks = {
          description = "Local disk configurations.",
          items = {
            ["$ref"] = "LocalDisk",
          },
          type = "array",
        },
        instanceConsumptionData = {
          description = "Instance data that shows consumed resources on the node.",
          items = {
            ["$ref"] = "InstanceConsumptionData",
          },
          type = "array",
        },
        instances = {
          description = "Instances scheduled on this node.",
          items = {
            type = "string",
          },
          type = "array",
        },
        name = {
          description = "The name of the node.",
          type = "string",
        },
        nodeType = {
          description = "The type of this node.",
          type = "string",
        },
        satisfiesPzs = {
          description = "[Output Only] Reserved for future use.",
          type = "boolean",
        },
        serverBinding = {
          ["$ref"] = "ServerBinding",
          description = "Binding properties for the physical server.",
        },
        serverId = {
          description = "Server ID associated with this node.",
          type = "string",
        },
        status = {
          enum = {
            "CREATING",
            "DELETING",
            "INVALID",
            "READY",
            "REPAIRING",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        totalResources = {
          ["$ref"] = "InstanceConsumptionInfo",
          description = "Total amount of available resources on the node.",
        },
      },
      type = "object",
    },
    NodeGroupsAddNodesRequest = {
      id = "NodeGroupsAddNodesRequest",
      properties = {
        additionalNodeCount = {
          description = "Count of additional nodes to be added to the node group.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    NodeGroupsDeleteNodesRequest = {
      id = "NodeGroupsDeleteNodesRequest",
      properties = {
        nodes = {
          description = "Names of the nodes to delete.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    NodeGroupsListNodes = {
      id = "NodeGroupsListNodes",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Node resources.",
          items = {
            ["$ref"] = "NodeGroupNode",
          },
          type = "array",
        },
        kind = {
          default = "compute#nodeGroupsListNodes",
          description = "[Output Only] The resource type, which is always compute.nodeGroupsListNodes for the list of nodes in the specified node group.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NodeGroupsScopedList = {
      id = "NodeGroupsScopedList",
      properties = {
        nodeGroups = {
          description = "[Output Only] A list of node groups contained in this scope.",
          items = {
            ["$ref"] = "NodeGroup",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] An informational warning that appears when the nodeGroup list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NodeGroupsSetNodeTemplateRequest = {
      id = "NodeGroupsSetNodeTemplateRequest",
      properties = {
        nodeTemplate = {
          description = "Full or partial URL of the node template resource to be updated for this node group.",
          type = "string",
        },
      },
      type = "object",
    },
    NodeTemplate = {
      description = "Represent a sole-tenant Node Template resource. You can use a template to define properties for nodes in a node group. For more information, read Creating node groups and instances.",
      id = "NodeTemplate",
      properties = {
        accelerators = {
          items = {
            ["$ref"] = "AcceleratorConfig",
          },
          type = "array",
        },
        cpuOvercommitType = {
          description = "CPU overcommit.",
          enum = {
            "CPU_OVERCOMMIT_TYPE_UNSPECIFIED",
            "ENABLED",
            "NONE",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        disks = {
          items = {
            ["$ref"] = "LocalDisk",
          },
          type = "array",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#nodeTemplate",
          description = "[Output Only] The type of the resource. Always compute#nodeTemplate for node templates.",
          type = "string",
        },
        name = {
          description = "The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          type = "string",
        },
        nodeAffinityLabels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels to use for node affinity, which will be used in instance scheduling.",
          type = "object",
        },
        nodeType = {
          description = "The node type to use for nodes group that are created from this template.",
          type = "string",
        },
        nodeTypeFlexibility = {
          ["$ref"] = "NodeTemplateNodeTypeFlexibility",
          description = "The flexible properties of the desired node type. Node groups that use this node template will create nodes of a type that matches these properties. This field is mutually exclusive with the node_type property; you can only define one or the other, but not both.",
        },
        region = {
          description = "[Output Only] The name of the region where the node template resides, such as us-central1.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        serverBinding = {
          ["$ref"] = "ServerBinding",
          description = "Sets the binding properties for the physical server. Valid values include: - *[Default]* RESTART_NODE_ON_ANY_SERVER: Restarts VMs on any available physical server - RESTART_NODE_ON_MINIMAL_SERVER: Restarts VMs on the same physical server whenever possible See Sole-tenant node options for more information.",
        },
        status = {
          description = "[Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING.",
          enum = {
            "CREATING",
            "DELETING",
            "INVALID",
            "READY",
          },
          enumDescriptions = {
            "Resources are being allocated.",
            "The node template is currently being deleted.",
            "Invalid status.",
            "The node template is ready.",
          },
          type = "string",
        },
        statusMessage = {
          description = "[Output Only] An optional, human-readable explanation of the status.",
          type = "string",
        },
      },
      type = "object",
    },
    NodeTemplateAggregatedList = {
      id = "NodeTemplateAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "NodeTemplatesScopedList",
            description = "[Output Only] Name of the scope containing this set of node templates.",
          },
          description = "A list of NodeTemplatesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#nodeTemplateAggregatedList",
          description = "[Output Only] Type of resource.Always compute#nodeTemplateAggregatedList for aggregated lists of node templates.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NodeTemplateList = {
      description = "Contains a list of node templates.",
      id = "NodeTemplateList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of NodeTemplate resources.",
          items = {
            ["$ref"] = "NodeTemplate",
          },
          type = "array",
        },
        kind = {
          default = "compute#nodeTemplateList",
          description = "[Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NodeTemplateNodeTypeFlexibility = {
      id = "NodeTemplateNodeTypeFlexibility",
      properties = {
        cpus = {
          type = "string",
        },
        localSsd = {
          type = "string",
        },
        memory = {
          type = "string",
        },
      },
      type = "object",
    },
    NodeTemplatesScopedList = {
      id = "NodeTemplatesScopedList",
      properties = {
        nodeTemplates = {
          description = "[Output Only] A list of node templates contained in this scope.",
          items = {
            ["$ref"] = "NodeTemplate",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] An informational warning that appears when the node templates list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NodeType = {
      description = "Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information read Node types.",
      id = "NodeType",
      properties = {
        cpuPlatform = {
          description = "[Output Only] The CPU platform used by this node type.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        deprecated = {
          ["$ref"] = "DeprecationStatus",
          description = "[Output Only] The deprecation status associated with this node type.",
        },
        description = {
          description = "[Output Only] An optional textual description of the resource.",
          type = "string",
        },
        guestCpus = {
          description = "[Output Only] The number of virtual CPUs that are available to the node type.",
          format = "int32",
          type = "integer",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#nodeType",
          description = "[Output Only] The type of the resource. Always compute#nodeType for node types.",
          type = "string",
        },
        localSsdGb = {
          description = "[Output Only] Local SSD available to the node type, defined in GB.",
          format = "int32",
          type = "integer",
        },
        memoryMb = {
          description = "[Output Only] The amount of physical memory available to the node type, defined in MB.",
          format = "int32",
          type = "integer",
        },
        name = {
          description = "[Output Only] Name of the resource.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        zone = {
          description = "[Output Only] The name of the zone where the node type resides, such as us-central1-a.",
          type = "string",
        },
      },
      type = "object",
    },
    NodeTypeAggregatedList = {
      id = "NodeTypeAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "NodeTypesScopedList",
            description = "[Output Only] Name of the scope containing this set of node types.",
          },
          description = "A list of NodeTypesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#nodeTypeAggregatedList",
          description = "[Output Only] Type of resource.Always compute#nodeTypeAggregatedList for aggregated lists of node types.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NodeTypeList = {
      description = "Contains a list of node types.",
      id = "NodeTypeList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of NodeType resources.",
          items = {
            ["$ref"] = "NodeType",
          },
          type = "array",
        },
        kind = {
          default = "compute#nodeTypeList",
          description = "[Output Only] Type of resource.Always compute#nodeTypeList for lists of node types.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NodeTypesScopedList = {
      id = "NodeTypesScopedList",
      properties = {
        nodeTypes = {
          description = "[Output Only] A list of node types contained in this scope.",
          items = {
            ["$ref"] = "NodeType",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] An informational warning that appears when the node types list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    NotificationEndpoint = {
      description = "Represents a notification endpoint. A notification endpoint resource defines an endpoint to receive notifications when there are status changes detected by the associated health check service. For more information, see Health checks overview.",
      id = "NotificationEndpoint",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        grpcSettings = {
          ["$ref"] = "NotificationEndpointGrpcSettings",
          description = "Settings of the gRPC notification endpoint including the endpoint URL and the retry duration.",
        },
        id = {
          description = "[Output Only] A unique identifier for this resource type. The server generates this identifier.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#notificationEndpoint",
          description = "[Output Only] Type of the resource. Always compute#notificationEndpoint for notification endpoints.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the notification endpoint resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
      },
      type = "object",
    },
    NotificationEndpointGrpcSettings = {
      description = "Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint.",
      id = "NotificationEndpointGrpcSettings",
      properties = {
        authority = {
          description = "Optional. If specified, this field is used to set the authority header by the sender of notifications. See https://tools.ietf.org/html/rfc7540#section-8.1.2.3",
          type = "string",
        },
        endpoint = {
          description = "Endpoint to which gRPC notifications are sent. This must be a valid gRPCLB DNS name.",
          type = "string",
        },
        payloadName = {
          description = "Optional. If specified, this field is used to populate the \"name\" field in gRPC requests.",
          type = "string",
        },
        resendInterval = {
          ["$ref"] = "Duration",
          description = "Optional. This field is used to configure how often to send a full update of all non-healthy backends. If unspecified, full updates are not sent. If specified, must be in the range between 600 seconds to 3600 seconds. Nanos are disallowed. Can only be set for regional notification endpoints.",
        },
        retryDurationSec = {
          description = "How much time (in seconds) is spent attempting notification retries until a successful response is received. Default is 30s. Limit is 20m (1200s). Must be a positive number.",
          format = "uint32",
          type = "integer",
        },
      },
      type = "object",
    },
    NotificationEndpointList = {
      id = "NotificationEndpointList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of NotificationEndpoint resources.",
          items = {
            ["$ref"] = "NotificationEndpoint",
          },
          type = "array",
        },
        kind = {
          default = "compute#notificationEndpointList",
          description = "[Output Only] Type of the resource. Always compute#notificationEndpoint for notification endpoints.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    Operation = {
      description = "Represents an Operation resource. Google Compute Engine has three Operation resources: * [Global](/compute/docs/reference/rest/v1/globalOperations) * [Regional](/compute/docs/reference/rest/v1/regionOperations) * [Zonal](/compute/docs/reference/rest/v1/zoneOperations) You can use an operation resource to manage asynchronous API requests. For more information, read Handling API responses. Operations can be global, regional or zonal. - For global operations, use the `globalOperations` resource. - For regional operations, use the `regionOperations` resource. - For zonal operations, use the `zonalOperations` resource. For more information, read Global, Regional, and Zonal Resources.",
      id = "Operation",
      properties = {
        clientOperationId = {
          description = "[Output Only] The value of `requestId` if you provided it in the request. Not present otherwise.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Deprecated] This field is deprecated.",
          type = "string",
        },
        description = {
          description = "[Output Only] A textual description of the operation, which is set when the operation is created.",
          type = "string",
        },
        endTime = {
          description = "[Output Only] The time that this operation was completed. This value is in RFC3339 text format.",
          type = "string",
        },
        error = {
          description = "[Output Only] If errors are generated during processing of the operation, this field will be populated.",
          properties = {
            errors = {
              description = "[Output Only] The array of errors encountered while processing this operation.",
              items = {
                properties = {
                  code = {
                    description = "[Output Only] The error type identifier for this error.",
                    type = "string",
                  },
                  errorDetails = {
                    description = "[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED.",
                    items = {
                      properties = {
                        errorInfo = {
                          ["$ref"] = "ErrorInfo",
                        },
                        help = {
                          ["$ref"] = "Help",
                        },
                        localizedMessage = {
                          ["$ref"] = "LocalizedMessage",
                        },
                        quotaInfo = {
                          ["$ref"] = "QuotaExceededInfo",
                        },
                      },
                      type = "object",
                    },
                    type = "array",
                  },
                  location = {
                    description = "[Output Only] Indicates the field in the request that caused the error. This property is optional.",
                    type = "string",
                  },
                  message = {
                    description = "[Output Only] An optional, human-readable error message.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
          },
          type = "object",
        },
        httpErrorMessage = {
          description = "[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as `NOT FOUND`.",
          type = "string",
        },
        httpErrorStatusCode = {
          description = "[Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a `404` means the resource was not found.",
          format = "int32",
          type = "integer",
        },
        id = {
          description = "[Output Only] The unique identifier for the operation. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        insertTime = {
          description = "[Output Only] The time that this operation was requested. This value is in RFC3339 text format.",
          type = "string",
        },
        kind = {
          default = "compute#operation",
          description = "[Output Only] Type of the resource. Always `compute#operation` for Operation resources.",
          type = "string",
        },
        name = {
          description = "[Output Only] Name of the operation.",
          type = "string",
        },
        operationGroupId = {
          description = "[Output Only] An ID that represents a group of operations, such as when a group of operations results from a `bulkInsert` API request.",
          type = "string",
        },
        operationType = {
          description = "[Output Only] The type of operation, such as `insert`, `update`, or `delete`, and so on.",
          type = "string",
        },
        progress = {
          description = "[Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses.",
          format = "int32",
          type = "integer",
        },
        region = {
          description = "[Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        startTime = {
          description = "[Output Only] The time that this operation was started by the server. This value is in RFC3339 text format.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of the operation, which can be one of the following: `PENDING`, `RUNNING`, or `DONE`.",
          enum = {
            "DONE",
            "PENDING",
            "RUNNING",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        statusMessage = {
          description = "[Output Only] An optional textual description of the current status of the operation.",
          type = "string",
        },
        targetId = {
          description = "[Output Only] The unique target ID, which identifies a specific incarnation of the target resource.",
          format = "uint64",
          type = "string",
        },
        targetLink = {
          description = "[Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the persistent disk that the snapshot was created from.",
          type = "string",
        },
        user = {
          description = "[Output Only] User who requested the operation, for example: `user@example.com`.",
          type = "string",
        },
        warnings = {
          description = "[Output Only] If warning messages are generated during processing of the operation, this field will be populated.",
          items = {
            properties = {
              code = {
                description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
                enum = {
                  "CLEANUP_FAILED",
                  "DEPRECATED_RESOURCE_USED",
                  "DEPRECATED_TYPE_USED",
                  "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                  "EXPERIMENTAL_TYPE_USED",
                  "EXTERNAL_API_WARNING",
                  "FIELD_VALUE_OVERRIDEN",
                  "INJECTED_KERNELS_DEPRECATED",
                  "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                  "LARGE_DEPLOYMENT_WARNING",
                  "MISSING_TYPE_DEPENDENCY",
                  "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                  "NEXT_HOP_CANNOT_IP_FORWARD",
                  "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                  "NEXT_HOP_INSTANCE_NOT_FOUND",
                  "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                  "NEXT_HOP_NOT_RUNNING",
                  "NOT_CRITICAL_ERROR",
                  "NO_RESULTS_ON_PAGE",
                  "PARTIAL_SUCCESS",
                  "REQUIRED_TOS_AGREEMENT",
                  "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                  "RESOURCE_NOT_DELETED",
                  "SCHEMA_VALIDATION_IGNORED",
                  "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                  "UNDECLARED_PROPERTIES",
                  "UNREACHABLE",
                },
                enumDescriptions = {
                  "Warning about failed cleanup of transient changes made by a failed operation.",
                  "A link to a deprecated resource was created.",
                  "When deploying and at least one of the resources has a type marked as deprecated",
                  "The user created a boot disk that is larger than image size.",
                  "When deploying and at least one of the resources has a type marked as experimental",
                  "Warning that is present in an external api call",
                  "Warning that value of a field has been overridden. Deprecated unused field.",
                  "The operation involved use of an injected kernel, which is deprecated.",
                  "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                  "When deploying a deployment with a exceedingly large number of resources",
                  "A resource depends on a missing type",
                  "The route's nextHopIp address is not assigned to an instance on the network.",
                  "The route's next hop instance cannot ip forward.",
                  "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                  "The route's nextHopInstance URL refers to an instance that does not exist.",
                  "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                  "The route's next hop instance does not have a status of RUNNING.",
                  "Error which is not critical. We decided to continue the process despite the mentioned error.",
                  "No results are present on a particular list page.",
                  "Success is reported, but some results may be missing due to errors",
                  "The user attempted to use a resource that requires a TOS they have not accepted.",
                  "Warning that a resource is in use.",
                  "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                  "When a resource schema validation is ignored.",
                  "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                  "When undeclared properties in the schema are present",
                  "A given scope cannot be reached.",
                },
                type = "string",
              },
              data = {
                description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
                items = {
                  properties = {
                    key = {
                      description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                      type = "string",
                    },
                    value = {
                      description = "[Output Only] A warning data value corresponding to the key.",
                      type = "string",
                    },
                  },
                  type = "object",
                },
                type = "array",
              },
              message = {
                description = "[Output Only] A human-readable description of the warning code.",
                type = "string",
              },
            },
            type = "object",
          },
          type = "array",
        },
        zone = {
          description = "[Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations.",
          type = "string",
        },
      },
      type = "object",
    },
    OperationAggregatedList = {
      id = "OperationAggregatedList",
      properties = {
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "OperationsScopedList",
            description = "[Output Only] Name of the scope containing this set of operations.",
          },
          description = "[Output Only] A map of scoped operation lists.",
          type = "object",
        },
        kind = {
          default = "compute#operationAggregatedList",
          description = "[Output Only] Type of resource. Always `compute#operationAggregatedList` for aggregated lists of operations.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than `maxResults`, use the `nextPageToken` as a value for the query parameter `pageToken` in the next list request. Subsequent list requests will have their own `nextPageToken` to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    OperationList = {
      description = "Contains a list of Operation resources.",
      id = "OperationList",
      properties = {
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          type = "string",
        },
        items = {
          description = "[Output Only] A list of Operation resources.",
          items = {
            ["$ref"] = "Operation",
          },
          type = "array",
        },
        kind = {
          default = "compute#operationList",
          description = "[Output Only] Type of resource. Always `compute#operations` for Operations resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than `maxResults`, use the `nextPageToken` as a value for the query parameter `pageToken` in the next list request. Subsequent list requests will have their own `nextPageToken` to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    OperationsScopedList = {
      id = "OperationsScopedList",
      properties = {
        operations = {
          description = "[Output Only] A list of operations contained in this scope.",
          items = {
            ["$ref"] = "Operation",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of operations when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    OutlierDetection = {
      description = "Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.",
      id = "OutlierDetection",
      properties = {
        baseEjectionTime = {
          ["$ref"] = "Duration",
          description = "The base time that a host is ejected for. The real ejection time is equal to the base ejection time multiplied by the number of times the host has been ejected. Defaults to 30000ms or 30s.",
        },
        consecutiveErrors = {
          description = "Number of errors before a host is ejected from the connection pool. When the backend host is accessed over HTTP, a 5xx return code qualifies as an error. Defaults to 5. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          format = "int32",
          type = "integer",
        },
        consecutiveGatewayFailure = {
          description = "The number of consecutive gateway failures (502, 503, 504 status or connection errors that are mapped to one of those status codes) before a consecutive gateway failure ejection occurs. Defaults to 3. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          format = "int32",
          type = "integer",
        },
        enforcingConsecutiveErrors = {
          description = "The percentage chance that a host will be actually ejected when an outlier status is detected through consecutive 5xx. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 0. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          format = "int32",
          type = "integer",
        },
        enforcingConsecutiveGatewayFailure = {
          description = "The percentage chance that a host will be actually ejected when an outlier status is detected through consecutive gateway failures. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.",
          format = "int32",
          type = "integer",
        },
        enforcingSuccessRate = {
          description = "The percentage chance that a host will be actually ejected when an outlier status is detected through success rate statistics. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100.",
          format = "int32",
          type = "integer",
        },
        interval = {
          ["$ref"] = "Duration",
          description = "Time interval between ejection analysis sweeps. This can result in both new ejections as well as hosts being returned to service. Defaults to 1 second.",
        },
        maxEjectionPercent = {
          description = "Maximum percentage of hosts in the load balancing pool for the backend service that can be ejected. Defaults to 50%.",
          format = "int32",
          type = "integer",
        },
        successRateMinimumHosts = {
          description = "The number of hosts in a cluster that must have enough request volume to detect success rate outliers. If the number of hosts is less than this setting, outlier detection via success rate statistics is not performed for any host in the cluster. Defaults to 5.",
          format = "int32",
          type = "integer",
        },
        successRateRequestVolume = {
          description = "The minimum number of total requests that must be collected in one interval (as defined by the interval duration above) to include this host in success rate based outlier detection. If the volume is lower than this setting, outlier detection via success rate statistics is not performed for that host. Defaults to 100.",
          format = "int32",
          type = "integer",
        },
        successRateStdevFactor = {
          description = "This factor is used to determine the ejection threshold for success rate outlier ejection. The ejection threshold is the difference between the mean success rate, and the product of this factor and the standard deviation of the mean success rate: mean - (stdev * success_rate_stdev_factor). This factor is divided by a thousand to get a double. That is, if the desired factor is 1.9, the runtime value should be 1900. Defaults to 1900.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    PacketIntervals = {
      description = "Next free: 7",
      id = "PacketIntervals",
      properties = {
        avgMs = {
          description = "Average observed inter-packet interval in milliseconds.",
          format = "int64",
          type = "string",
        },
        duration = {
          description = "From how long ago in the past these intervals were observed.",
          enum = {
            "DURATION_UNSPECIFIED",
            "HOUR",
            "MAX",
            "MINUTE",
          },
          enumDescriptions = {
            "",
            "",
            "From BfdSession object creation time.",
            "",
          },
          type = "string",
        },
        maxMs = {
          description = "Maximum observed inter-packet interval in milliseconds.",
          format = "int64",
          type = "string",
        },
        minMs = {
          description = "Minimum observed inter-packet interval in milliseconds.",
          format = "int64",
          type = "string",
        },
        numIntervals = {
          description = "Number of inter-packet intervals from which these statistics were derived.",
          format = "int64",
          type = "string",
        },
        type = {
          description = "The type of packets for which inter-packet intervals were computed.",
          enum = {
            "LOOPBACK",
            "RECEIVE",
            "TRANSMIT",
            "TYPE_UNSPECIFIED",
          },
          enumDescriptions = {
            "Only applies to Echo packets. This shows the intervals between sending and receiving the same packet.",
            "Intervals between received packets.",
            "Intervals between transmitted packets.",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PacketMirroring = {
      description = "Represents a Packet Mirroring resource. Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, see Using Packet Mirroring.",
      id = "PacketMirroring",
      properties = {
        collectorIlb = {
          ["$ref"] = "PacketMirroringForwardingRuleInfo",
          description = "The Forwarding Rule resource of type loadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic. The specified forwarding rule must have isMirroringCollector set to true.",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        enable = {
          description = "Indicates whether or not this packet mirroring takes effect. If set to FALSE, this packet mirroring policy will not be enforced on the network. The default is TRUE.",
          enum = {
            "FALSE",
            "TRUE",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        filter = {
          ["$ref"] = "PacketMirroringFilter",
          description = "Filter for mirrored traffic. If unspecified, all traffic is mirrored.",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#packetMirroring",
          description = "[Output Only] Type of the resource. Always compute#packetMirroring for packet mirrorings.",
          type = "string",
        },
        mirroredResources = {
          ["$ref"] = "PacketMirroringMirroredResourceInfo",
          description = "PacketMirroring mirroredResourceInfos. MirroredResourceInfo specifies a set of mirrored VM instances, subnetworks and/or tags for which traffic from/to all VM instances will be mirrored.",
        },
        name = {
          annotations = {
            required = {
              "compute.packetMirrorings.insert",
            },
          },
          description = "Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          ["$ref"] = "PacketMirroringNetworkInfo",
          annotations = {
            required = {
              "compute.packetMirrorings.insert",
            },
          },
          description = "Specifies the mirrored VPC network. Only packets in this network will be mirrored. All mirrored VMs should have a NIC in the given network. All mirrored subnetworks should belong to the given network.",
        },
        priority = {
          description = "The priority of applying this configuration. Priority is used to break ties in cases where there is more than one matching rule. In the case of two rules that apply for a given Instance, the one with the lowest-numbered priority value wins. Default value is 1000. Valid range is 0 through 65535.",
          format = "uint32",
          type = "integer",
        },
        region = {
          description = "[Output Only] URI of the region where the packetMirroring resides.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
      },
      type = "object",
    },
    PacketMirroringAggregatedList = {
      description = "Contains a list of packetMirrorings.",
      id = "PacketMirroringAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "PacketMirroringsScopedList",
            description = "Name of the scope containing this set of packetMirrorings.",
          },
          description = "A list of PacketMirroring resources.",
          type = "object",
        },
        kind = {
          default = "compute#packetMirroringAggregatedList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    PacketMirroringFilter = {
      id = "PacketMirroringFilter",
      properties = {
        IPProtocols = {
          description = "Protocols that apply as filter on mirrored traffic. If no protocols are specified, all traffic that matches the specified CIDR ranges is mirrored. If neither cidrRanges nor IPProtocols is specified, all traffic is mirrored.",
          items = {
            type = "string",
          },
          type = "array",
        },
        cidrRanges = {
          description = "IP CIDR ranges that apply as filter on the source (ingress) or destination (egress) IP in the IP header. Only IPv4 is supported. If no ranges are specified, all traffic that matches the specified IPProtocols is mirrored. If neither cidrRanges nor IPProtocols is specified, all traffic is mirrored.",
          items = {
            type = "string",
          },
          type = "array",
        },
        direction = {
          description = "Direction of traffic to mirror, either INGRESS, EGRESS, or BOTH. The default is BOTH.",
          enum = {
            "BOTH",
            "EGRESS",
            "INGRESS",
          },
          enumDescriptions = {
            "Default, both directions are mirrored.",
            "Only egress traffic is mirrored.",
            "Only ingress traffic is mirrored.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PacketMirroringForwardingRuleInfo = {
      id = "PacketMirroringForwardingRuleInfo",
      properties = {
        canonicalUrl = {
          description = "[Output Only] Unique identifier for the forwarding rule; defined by the server.",
          type = "string",
        },
        url = {
          description = "Resource URL to the forwarding rule representing the ILB configured as destination of the mirrored traffic.",
          type = "string",
        },
      },
      type = "object",
    },
    PacketMirroringList = {
      description = "Contains a list of PacketMirroring resources.",
      id = "PacketMirroringList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of PacketMirroring resources.",
          items = {
            ["$ref"] = "PacketMirroring",
          },
          type = "array",
        },
        kind = {
          default = "compute#packetMirroringList",
          description = "[Output Only] Type of resource. Always compute#packetMirroring for packetMirrorings.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    PacketMirroringMirroredResourceInfo = {
      id = "PacketMirroringMirroredResourceInfo",
      properties = {
        instances = {
          description = "A set of virtual machine instances that are being mirrored. They must live in zones contained in the same region as this packetMirroring. Note that this config will apply only to those network interfaces of the Instances that belong to the network specified in this packetMirroring. You may specify a maximum of 50 Instances.",
          items = {
            ["$ref"] = "PacketMirroringMirroredResourceInfoInstanceInfo",
          },
          type = "array",
        },
        subnetworks = {
          description = "A set of subnetworks for which traffic from/to all VM instances will be mirrored. They must live in the same region as this packetMirroring. You may specify a maximum of 5 subnetworks.",
          items = {
            ["$ref"] = "PacketMirroringMirroredResourceInfoSubnetInfo",
          },
          type = "array",
        },
        tags = {
          description = "A set of mirrored tags. Traffic from/to all VM instances that have one or more of these tags will be mirrored.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    PacketMirroringMirroredResourceInfoInstanceInfo = {
      id = "PacketMirroringMirroredResourceInfoInstanceInfo",
      properties = {
        canonicalUrl = {
          description = "[Output Only] Unique identifier for the instance; defined by the server.",
          type = "string",
        },
        url = {
          description = "Resource URL to the virtual machine instance which is being mirrored.",
          type = "string",
        },
      },
      type = "object",
    },
    PacketMirroringMirroredResourceInfoSubnetInfo = {
      id = "PacketMirroringMirroredResourceInfoSubnetInfo",
      properties = {
        canonicalUrl = {
          description = "[Output Only] Unique identifier for the subnetwork; defined by the server.",
          type = "string",
        },
        url = {
          description = "Resource URL to the subnetwork for which traffic from/to all VM instances will be mirrored.",
          type = "string",
        },
      },
      type = "object",
    },
    PacketMirroringNetworkInfo = {
      id = "PacketMirroringNetworkInfo",
      properties = {
        canonicalUrl = {
          description = "[Output Only] Unique identifier for the network; defined by the server.",
          type = "string",
        },
        url = {
          description = "URL of the network resource.",
          type = "string",
        },
      },
      type = "object",
    },
    PacketMirroringsScopedList = {
      id = "PacketMirroringsScopedList",
      properties = {
        packetMirrorings = {
          description = "A list of packetMirrorings contained in this scope.",
          items = {
            ["$ref"] = "PacketMirroring",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of packetMirrorings when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    PathMatcher = {
      description = "A matcher for the path portion of the URL. The BackendService from the longest-matched rule will serve the URL. If no rule was matched, the default service is used.",
      id = "PathMatcher",
      properties = {
        defaultRouteAction = {
          ["$ref"] = "HttpRouteAction",
          description = "defaultRouteAction takes effect when none of the pathRules or routeRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. If defaultRouteAction specifies any weightedBackendServices, defaultService must not be set. Conversely if defaultService is set, defaultRouteAction cannot contain any weightedBackendServices. Only one of defaultRouteAction or defaultUrlRedirect must be set. URL maps for Classic external HTTP(S) load balancers only support the urlRewrite action within a path matcher's defaultRouteAction.",
        },
        defaultService = {
          description = "The full or partial URL to the BackendService resource. This URL is used if none of the pathRules or routeRules defined by this PathMatcher are matched. For example, the following are all valid URLs to a BackendService resource: - https://www.googleapis.com/compute/v1/projects/project /global/backendServices/backendService - compute/v1/projects/project/global/backendServices/backendService - global/backendServices/backendService If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. However, if defaultService is specified, defaultRouteAction cannot contain any weightedBackendServices. Conversely, if defaultRouteAction specifies any weightedBackendServices, defaultService must not be specified. Only one of defaultService, defaultUrlRedirect , or defaultRouteAction.weightedBackendService must be set. Authorization requires one or more of the following Google IAM permissions on the specified resource default_service: - compute.backendBuckets.use - compute.backendServices.use ",
          type = "string",
        },
        defaultUrlRedirect = {
          ["$ref"] = "HttpRedirectAction",
          description = "When none of the specified pathRules or routeRules match, the request is redirected to a URL specified by defaultUrlRedirect. If defaultUrlRedirect is specified, defaultService or defaultRouteAction must not be set. Not supported when the URL map is bound to a target gRPC proxy.",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        headerAction = {
          ["$ref"] = "HttpHeaderAction",
          description = "Specifies changes to request and response headers that need to take effect for the selected backend service. HeaderAction specified here are applied after the matching HttpRouteRule HeaderAction and before the HeaderAction in the UrlMap HeaderAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.",
        },
        name = {
          description = "The name to which this PathMatcher is referred by the HostRule.",
          type = "string",
        },
        pathRules = {
          description = "The list of path rules. Use this list instead of routeRules when routing based on simple path matching is all that's required. The order by which path rules are specified does not matter. Matches are always done on the longest-path-first basis. For example: a pathRule with a path /a/b/c/* will match before /a/b/* irrespective of the order in which those paths appear in this list. Within a given pathMatcher, only one of pathRules or routeRules must be set.",
          items = {
            ["$ref"] = "PathRule",
          },
          type = "array",
        },
        routeRules = {
          description = "The list of HTTP route rules. Use this list instead of pathRules when advanced route matching and routing actions are desired. routeRules are evaluated in order of priority, from the lowest to highest number. Within a given pathMatcher, you can set only one of pathRules or routeRules.",
          items = {
            ["$ref"] = "HttpRouteRule",
          },
          type = "array",
        },
      },
      type = "object",
    },
    PathRule = {
      description = "A path-matching rule for a URL. If matched, will use the specified BackendService to handle the traffic arriving at this URL.",
      id = "PathRule",
      properties = {
        paths = {
          description = "The list of path patterns to match. Each must start with / and the only place a * is allowed is at the end following a /. The string fed to the path matcher does not include any text after the first ? or #, and those chars are not allowed here.",
          items = {
            type = "string",
          },
          type = "array",
        },
        routeAction = {
          ["$ref"] = "HttpRouteAction",
          description = "In response to a matching path, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. If routeAction specifies any weightedBackendServices, service must not be set. Conversely if service is set, routeAction cannot contain any weightedBackendServices. Only one of routeAction or urlRedirect must be set. URL maps for Classic external HTTP(S) load balancers only support the urlRewrite action within a path rule's routeAction.",
        },
        service = {
          description = "The full or partial URL of the backend service resource to which traffic is directed if this rule is matched. If routeAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. However, if service is specified, routeAction cannot contain any weightedBackendServices. Conversely, if routeAction specifies any weightedBackendServices, service must not be specified. Only one of urlRedirect, service or routeAction.weightedBackendService must be set.",
          type = "string",
        },
        urlRedirect = {
          ["$ref"] = "HttpRedirectAction",
          description = "When a path pattern is matched, the request is redirected to a URL specified by urlRedirect. If urlRedirect is specified, service or routeAction must not be set. Not supported when the URL map is bound to a target gRPC proxy.",
        },
      },
      type = "object",
    },
    PerInstanceConfig = {
      id = "PerInstanceConfig",
      properties = {
        fingerprint = {
          description = "Fingerprint of this per-instance config. This field can be used in optimistic locking. It is ignored when inserting a per-instance config. An up-to-date fingerprint must be provided in order to update an existing per-instance configuration or the field needs to be unset.",
          format = "byte",
          type = "string",
        },
        name = {
          description = "The name of a per-instance configuration and its corresponding instance. Serves as a merge key during UpdatePerInstanceConfigs operations, that is, if a per-instance configuration with the same name exists then it will be updated, otherwise a new one will be created for the VM instance with the same name. An attempt to create a per-instance configconfiguration for a VM instance that either doesn't exist or is not part of the group will result in an error.",
          type = "string",
        },
        preservedState = {
          ["$ref"] = "PreservedState",
          description = "The intended preserved state for the given instance. Does not contain preserved state generated from a stateful policy.",
        },
        status = {
          description = "The status of applying this per-instance configuration on the corresponding managed instance.",
          enum = {
            "APPLYING",
            "DELETING",
            "EFFECTIVE",
            "NONE",
            "UNAPPLIED",
            "UNAPPLIED_DELETION",
          },
          enumDescriptions = {
            "The per-instance configuration is being applied to the instance, but is not yet effective, possibly waiting for the instance to, for example, REFRESH.",
            "The per-instance configuration deletion is being applied on the instance, possibly waiting for the instance to, for example, REFRESH.",
            "The per-instance configuration is effective on the instance, meaning that all disks, ips and metadata specified in this configuration are attached or set on the instance.",
            "*[Default]* The default status, when no per-instance configuration exists.",
            "The per-instance configuration is set on an instance but not been applied yet.",
            "The per-instance configuration has been deleted, but the deletion is not yet applied.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Policy = {
      description = "An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources. A `Policy` is a collection of `bindings`. A `binding` binds one or more `members`, or principals, to a single `role`. Principals can be user accounts, service accounts, Google groups, and domains (such as G Suite). A `role` is a named list of permissions; each `role` can be an IAM predefined role or a user-created custom role. For some types of Google Cloud resources, a `binding` can also specify a `condition`, which is a logical expression that allows access to a resource only if the expression evaluates to `true`. A condition can add constraints based on attributes of the request, the resource, or both. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies). **JSON example:** { \"bindings\": [ { \"role\": \"roles/resourcemanager.organizationAdmin\", \"members\": [ \"user:mike@example.com\", \"group:admins@example.com\", \"domain:google.com\", \"serviceAccount:my-project-id@appspot.gserviceaccount.com\" ] }, { \"role\": \"roles/resourcemanager.organizationViewer\", \"members\": [ \"user:eve@example.com\" ], \"condition\": { \"title\": \"expirable access\", \"description\": \"Does not grant access after Sep 2020\", \"expression\": \"request.time < timestamp('2020-10-01T00:00:00.000Z')\", } } ], \"etag\": \"BwWWja0YfJA=\", \"version\": 3 } **YAML example:** bindings: - members: - user:mike@example.com - group:admins@example.com - domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.com role: roles/resourcemanager.organizationViewer condition: title: expirable access description: Does not grant access after Sep 2020 expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For a description of IAM and its features, see the [IAM documentation](https://cloud.google.com/iam/docs/).",
      id = "Policy",
      properties = {
        auditConfigs = {
          description = "Specifies cloud audit logging configuration for this policy.",
          items = {
            ["$ref"] = "AuditConfig",
          },
          type = "array",
        },
        bindings = {
          description = "Associates a list of `members`, or principals, with a `role`. Optionally, may specify a `condition` that determines how and when the `bindings` are applied. Each of the `bindings` must contain at least one principal. The `bindings` in a `Policy` can refer to up to 1,500 principals; up to 250 of these principals can be Google groups. Each occurrence of a principal counts towards these limits. For example, if the `bindings` grant 50 different roles to `user:alice@example.com`, and not to any other principal, then you can add another 1,450 principals to the `bindings` in the `Policy`.",
          items = {
            ["$ref"] = "Binding",
          },
          type = "array",
        },
        etag = {
          description = "`etag` is used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other. It is strongly suggested that systems make use of the `etag` in the read-modify-write cycle to perform policy updates in order to avoid race conditions: An `etag` is returned in the response to `getIamPolicy`, and systems are expected to put that etag in the request to `setIamPolicy` to ensure that their change will be applied to the same version of the policy. **Important:** If you use IAM Conditions, you must include the `etag` field whenever you call `setIamPolicy`. If you omit this field, then IAM allows you to overwrite a version `3` policy with a version `1` policy, and all of the conditions in the version `3` policy are lost.",
          format = "byte",
          type = "string",
        },
        rules = {
          description = "This is deprecated and has no effect. Do not use.",
          items = {
            ["$ref"] = "Rule",
          },
          type = "array",
        },
        version = {
          description = "Specifies the format of the policy. Valid values are `0`, `1`, and `3`. Requests that specify an invalid value are rejected. Any operation that affects conditional role bindings must specify version `3`. This requirement applies to the following operations: * Getting a policy that includes a conditional role binding * Adding a conditional role binding to a policy * Changing a conditional role binding in a policy * Removing any role binding, with or without a condition, from a policy that includes conditions **Important:** If you use IAM Conditions, you must include the `etag` field whenever you call `setIamPolicy`. If you omit this field, then IAM allows you to overwrite a version `3` policy with a version `1` policy, and all of the conditions in the version `3` policy are lost. If a policy does not include any conditions, operations on that policy may specify any valid version or leave the field unset. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    PreconfiguredWafSet = {
      id = "PreconfiguredWafSet",
      properties = {
        expressionSets = {
          description = "List of entities that are currently supported for WAF rules.",
          items = {
            ["$ref"] = "WafExpressionSet",
          },
          type = "array",
        },
      },
      type = "object",
    },
    PreservedState = {
      description = "Preserved state for a given instance.",
      id = "PreservedState",
      properties = {
        disks = {
          additionalProperties = {
            ["$ref"] = "PreservedStatePreservedDisk",
          },
          description = "Preserved disks defined for this instance. This map is keyed with the device names of the disks.",
          type = "object",
        },
        metadata = {
          additionalProperties = {
            type = "string",
          },
          description = "Preserved metadata defined for this instance.",
          type = "object",
        },
      },
      type = "object",
    },
    PreservedStatePreservedDisk = {
      id = "PreservedStatePreservedDisk",
      properties = {
        autoDelete = {
          description = "These stateful disks will never be deleted during autohealing, update, instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole MIG is deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted.",
          enum = {
            "NEVER",
            "ON_PERMANENT_INSTANCE_DELETION",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        mode = {
          description = "The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode.",
          enum = {
            "READ_ONLY",
            "READ_WRITE",
          },
          enumDescriptions = {
            "Attaches this disk in read-only mode. Multiple VM instances can use a disk in READ_ONLY mode at a time.",
            "*[Default]* Attaches this disk in READ_WRITE mode. Only one VM instance at a time can be attached to a disk in READ_WRITE mode.",
          },
          type = "string",
        },
        source = {
          description = "The URL of the disk resource that is stateful and should be attached to the VM instance.",
          type = "string",
        },
      },
      type = "object",
    },
    Project = {
      description = "Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.",
      id = "Project",
      properties = {
        commonInstanceMetadata = {
          ["$ref"] = "Metadata",
          description = "Metadata key/value pairs available to all instances contained in this project. See Custom metadata for more information.",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        defaultNetworkTier = {
          description = "This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM.",
          enum = {
            "FIXED_STANDARD",
            "PREMIUM",
            "STANDARD",
            "STANDARD_OVERRIDES_FIXED_STANDARD",
          },
          enumDescriptions = {
            "Public internet quality with fixed bandwidth.",
            "High quality, Google-grade network tier, support for all networking products.",
            "Public internet quality, only limited support for other networking products.",
            "(Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.",
          },
          type = "string",
        },
        defaultServiceAccount = {
          description = "[Output Only] Default service account used by VMs running in this project.",
          type = "string",
        },
        description = {
          description = "An optional textual description of the resource.",
          type = "string",
        },
        enabledFeatures = {
          description = "Restricted features enabled for use on this project.",
          items = {
            type = "string",
          },
          type = "array",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is *not* the project ID, and is just a unique ID used by Compute Engine to identify resources.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#project",
          description = "[Output Only] Type of the resource. Always compute#project for projects.",
          type = "string",
        },
        name = {
          description = "The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine.",
          type = "string",
        },
        quotas = {
          description = "[Output Only] Quotas assigned to this project.",
          items = {
            ["$ref"] = "Quota",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        usageExportLocation = {
          ["$ref"] = "UsageExportLocation",
          description = "The naming prefix for daily usage reports and the Google Cloud Storage bucket where they are stored.",
        },
        vmDnsSetting = {
          description = "[Output Only] Default internal DNS setting used by VMs running in this project.",
          enum = {
            "GLOBAL_DEFAULT",
            "UNSPECIFIED_VM_DNS_SETTING",
            "ZONAL_DEFAULT",
            "ZONAL_ONLY",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        xpnProjectStatus = {
          description = "[Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated.",
          enum = {
            "HOST",
            "UNSPECIFIED_XPN_PROJECT_STATUS",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ProjectsDisableXpnResourceRequest = {
      id = "ProjectsDisableXpnResourceRequest",
      properties = {
        xpnResource = {
          ["$ref"] = "XpnResourceId",
          description = "Service resource (a.k.a service project) ID.",
        },
      },
      type = "object",
    },
    ProjectsEnableXpnResourceRequest = {
      id = "ProjectsEnableXpnResourceRequest",
      properties = {
        xpnResource = {
          ["$ref"] = "XpnResourceId",
          description = "Service resource (a.k.a service project) ID.",
        },
      },
      type = "object",
    },
    ProjectsGetXpnResources = {
      id = "ProjectsGetXpnResources",
      properties = {
        kind = {
          default = "compute#projectsGetXpnResources",
          description = "[Output Only] Type of resource. Always compute#projectsGetXpnResources for lists of service resources (a.k.a service projects)",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        resources = {
          description = "Service resources (a.k.a service projects) attached to this project as their shared VPC host.",
          items = {
            ["$ref"] = "XpnResourceId",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ProjectsListXpnHostsRequest = {
      id = "ProjectsListXpnHostsRequest",
      properties = {
        organization = {
          description = "Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project.",
          type = "string",
        },
      },
      type = "object",
    },
    ProjectsSetDefaultNetworkTierRequest = {
      id = "ProjectsSetDefaultNetworkTierRequest",
      properties = {
        networkTier = {
          description = "Default network tier to be set.",
          enum = {
            "FIXED_STANDARD",
            "PREMIUM",
            "STANDARD",
            "STANDARD_OVERRIDES_FIXED_STANDARD",
          },
          enumDescriptions = {
            "Public internet quality with fixed bandwidth.",
            "High quality, Google-grade network tier, support for all networking products.",
            "Public internet quality, only limited support for other networking products.",
            "(Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PublicAdvertisedPrefix = {
      description = "A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.",
      id = "PublicAdvertisedPrefix",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        dnsVerificationIp = {
          description = "The IPv4 address to be used for reverse DNS verification.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-date fingerprint must be provided in order to update the PublicAdvertisedPrefix, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a PublicAdvertisedPrefix.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource type. The server generates this identifier.",
          format = "uint64",
          type = "string",
        },
        ipCidrRange = {
          description = "The IPv4 address range, in CIDR format, represented by this public advertised prefix.",
          type = "string",
        },
        kind = {
          default = "compute#publicAdvertisedPrefix",
          description = "[Output Only] Type of the resource. Always compute#publicAdvertisedPrefix for public advertised prefixes.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.publicAdvertisedPrefixes.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        publicDelegatedPrefixs = {
          description = "[Output Only] The list of public delegated prefixes that exist for this public advertised prefix.",
          items = {
            ["$ref"] = "PublicAdvertisedPrefixPublicDelegatedPrefix",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        sharedSecret = {
          description = "[Output Only] The shared secret to be used for reverse DNS verification.",
          type = "string",
        },
        status = {
          description = "The status of the public advertised prefix. Possible values include: - `INITIAL`: RPKI validation is complete. - `PTR_CONFIGURED`: User has configured the PTR. - `VALIDATED`: Reverse DNS lookup is successful. - `REVERSE_DNS_LOOKUP_FAILED`: Reverse DNS lookup failed. - `PREFIX_CONFIGURATION_IN_PROGRESS`: The prefix is being configured. - `PREFIX_CONFIGURATION_COMPLETE`: The prefix is fully configured. - `PREFIX_REMOVAL_IN_PROGRESS`: The prefix is being removed. ",
          enum = {
            "INITIAL",
            "PREFIX_CONFIGURATION_COMPLETE",
            "PREFIX_CONFIGURATION_IN_PROGRESS",
            "PREFIX_REMOVAL_IN_PROGRESS",
            "PTR_CONFIGURED",
            "REVERSE_DNS_LOOKUP_FAILED",
            "VALIDATED",
          },
          enumDescriptions = {
            "RPKI validation is complete.",
            "The prefix is fully configured.",
            "The prefix is being configured.",
            "The prefix is being removed.",
            "User has configured the PTR.",
            "Reverse DNS lookup failed.",
            "Reverse DNS lookup is successful.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PublicAdvertisedPrefixList = {
      id = "PublicAdvertisedPrefixList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of PublicAdvertisedPrefix resources.",
          items = {
            ["$ref"] = "PublicAdvertisedPrefix",
          },
          type = "array",
        },
        kind = {
          default = "compute#publicAdvertisedPrefixList",
          description = "[Output Only] Type of the resource. Always compute#publicAdvertisedPrefix for public advertised prefixes.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    PublicAdvertisedPrefixPublicDelegatedPrefix = {
      description = "Represents a CIDR range which can be used to assign addresses.",
      id = "PublicAdvertisedPrefixPublicDelegatedPrefix",
      properties = {
        ipRange = {
          description = "The IP address range of the public delegated prefix",
          type = "string",
        },
        name = {
          description = "The name of the public delegated prefix",
          type = "string",
        },
        project = {
          description = "The project number of the public delegated prefix",
          type = "string",
        },
        region = {
          description = "The region of the public delegated prefix if it is regional. If absent, the prefix is global.",
          type = "string",
        },
        status = {
          description = "The status of the public delegated prefix. Possible values are: INITIALIZING: The public delegated prefix is being initialized and addresses cannot be created yet. ANNOUNCED: The public delegated prefix is active.",
          type = "string",
        },
      },
      type = "object",
    },
    PublicDelegatedPrefix = {
      description = "A PublicDelegatedPrefix resource represents an IP block within a PublicAdvertisedPrefix that is configured within a single cloud scope (global or region). IPs in the block can be allocated to resources within that scope. Public delegated prefixes may be further broken up into smaller IP blocks in the same scope as the parent block.",
      id = "PublicDelegatedPrefix",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicDelegatedPrefix. An up-to-date fingerprint must be provided in order to update the PublicDelegatedPrefix, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a PublicDelegatedPrefix.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource type. The server generates this identifier.",
          format = "uint64",
          type = "string",
        },
        ipCidrRange = {
          description = "The IPv4 address range, in CIDR format, represented by this public delegated prefix.",
          type = "string",
        },
        isLiveMigration = {
          description = "If true, the prefix will be live migrated.",
          type = "boolean",
        },
        kind = {
          default = "compute#publicDelegatedPrefix",
          description = "[Output Only] Type of the resource. Always compute#publicDelegatedPrefix for public delegated prefixes.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.publicDelegatedPrefixes.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        parentPrefix = {
          description = "The URL of parent prefix. Either PublicAdvertisedPrefix or PublicDelegatedPrefix.",
          type = "string",
        },
        publicDelegatedSubPrefixs = {
          description = "The list of sub public delegated prefixes that exist for this public delegated prefix.",
          items = {
            ["$ref"] = "PublicDelegatedPrefixPublicDelegatedSubPrefix",
          },
          type = "array",
        },
        region = {
          description = "[Output Only] URL of the region where the public delegated prefix resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of the public delegated prefix, which can be one of following values: - `INITIALIZING` The public delegated prefix is being initialized and addresses cannot be created yet. - `READY_TO_ANNOUNCE` The public delegated prefix is a live migration prefix and is active. - `ANNOUNCED` The public delegated prefix is active. - `DELETING` The public delegated prefix is being deprovsioned. ",
          enum = {
            "ANNOUNCED",
            "DELETING",
            "INITIALIZING",
            "READY_TO_ANNOUNCE",
          },
          enumDescriptions = {
            "The public delegated prefix is active.",
            "The public delegated prefix is being deprovsioned.",
            "The public delegated prefix is being initialized and addresses cannot be created yet.",
            "The public delegated prefix is currently withdrawn but ready to be announced.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PublicDelegatedPrefixAggregatedList = {
      id = "PublicDelegatedPrefixAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "PublicDelegatedPrefixesScopedList",
            description = "[Output Only] Name of the scope containing this set of PublicDelegatedPrefixes.",
          },
          description = "A list of PublicDelegatedPrefixesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#publicDelegatedPrefixAggregatedList",
          description = "[Output Only] Type of the resource. Always compute#publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    PublicDelegatedPrefixList = {
      id = "PublicDelegatedPrefixList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of PublicDelegatedPrefix resources.",
          items = {
            ["$ref"] = "PublicDelegatedPrefix",
          },
          type = "array",
        },
        kind = {
          default = "compute#publicDelegatedPrefixList",
          description = "[Output Only] Type of the resource. Always compute#publicDelegatedPrefixList for public delegated prefixes.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    PublicDelegatedPrefixPublicDelegatedSubPrefix = {
      description = "Represents a sub PublicDelegatedPrefix.",
      id = "PublicDelegatedPrefixPublicDelegatedSubPrefix",
      properties = {
        delegateeProject = {
          description = "Name of the project scoping this PublicDelegatedSubPrefix.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        ipCidrRange = {
          description = "The IPv4 address range, in CIDR format, represented by this sub public delegated prefix.",
          type = "string",
        },
        isAddress = {
          description = "Whether the sub prefix is delegated to create Address resources in the delegatee project.",
          type = "boolean",
        },
        name = {
          description = "The name of the sub public delegated prefix.",
          type = "string",
        },
        region = {
          description = "[Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of the sub public delegated prefix.",
          enum = {
            "ACTIVE",
            "INACTIVE",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PublicDelegatedPrefixesScopedList = {
      id = "PublicDelegatedPrefixesScopedList",
      properties = {
        publicDelegatedPrefixes = {
          description = "[Output Only] A list of PublicDelegatedPrefixes contained in this scope.",
          items = {
            ["$ref"] = "PublicDelegatedPrefix",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of public delegated prefixes when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    Quota = {
      description = "A quotas entry.",
      id = "Quota",
      properties = {
        limit = {
          description = "[Output Only] Quota limit for this metric.",
          format = "double",
          type = "number",
        },
        metric = {
          description = "[Output Only] Name of the quota metric.",
          enum = {
            "A2_CPUS",
            "AFFINITY_GROUPS",
            "AUTOSCALERS",
            "BACKEND_BUCKETS",
            "BACKEND_SERVICES",
            "C2D_CPUS",
            "C2_CPUS",
            "C3_CPUS",
            "COMMITMENTS",
            "COMMITTED_A2_CPUS",
            "COMMITTED_C2D_CPUS",
            "COMMITTED_C2_CPUS",
            "COMMITTED_C3_CPUS",
            "COMMITTED_CPUS",
            "COMMITTED_E2_CPUS",
            "COMMITTED_LICENSES",
            "COMMITTED_LOCAL_SSD_TOTAL_GB",
            "COMMITTED_M3_CPUS",
            "COMMITTED_MEMORY_OPTIMIZED_CPUS",
            "COMMITTED_N2A_CPUS",
            "COMMITTED_N2D_CPUS",
            "COMMITTED_N2_CPUS",
            "COMMITTED_NVIDIA_A100_80GB_GPUS",
            "COMMITTED_NVIDIA_A100_GPUS",
            "COMMITTED_NVIDIA_K80_GPUS",
            "COMMITTED_NVIDIA_P100_GPUS",
            "COMMITTED_NVIDIA_P4_GPUS",
            "COMMITTED_NVIDIA_T4_GPUS",
            "COMMITTED_NVIDIA_V100_GPUS",
            "COMMITTED_T2A_CPUS",
            "COMMITTED_T2D_CPUS",
            "CPUS",
            "CPUS_ALL_REGIONS",
            "DISKS_TOTAL_GB",
            "E2_CPUS",
            "EXTERNAL_MANAGED_FORWARDING_RULES",
            "EXTERNAL_NETWORK_LB_FORWARDING_RULES",
            "EXTERNAL_PROTOCOL_FORWARDING_RULES",
            "EXTERNAL_VPN_GATEWAYS",
            "FIREWALLS",
            "FORWARDING_RULES",
            "GLOBAL_EXTERNAL_MANAGED_BACKEND_SERVICES",
            "GLOBAL_EXTERNAL_MANAGED_FORWARDING_RULES",
            "GLOBAL_EXTERNAL_PROXY_LB_BACKEND_SERVICES",
            "GLOBAL_INTERNAL_ADDRESSES",
            "GLOBAL_INTERNAL_MANAGED_BACKEND_SERVICES",
            "GLOBAL_INTERNAL_TRAFFIC_DIRECTOR_BACKEND_SERVICES",
            "GPUS_ALL_REGIONS",
            "HEALTH_CHECKS",
            "IMAGES",
            "INSTANCES",
            "INSTANCE_GROUPS",
            "INSTANCE_GROUP_MANAGERS",
            "INSTANCE_TEMPLATES",
            "INTERCONNECTS",
            "INTERCONNECT_ATTACHMENTS_PER_REGION",
            "INTERCONNECT_ATTACHMENTS_TOTAL_MBPS",
            "INTERCONNECT_TOTAL_GBPS",
            "INTERNAL_ADDRESSES",
            "INTERNAL_TRAFFIC_DIRECTOR_FORWARDING_RULES",
            "IN_PLACE_SNAPSHOTS",
            "IN_USE_ADDRESSES",
            "IN_USE_BACKUP_SCHEDULES",
            "IN_USE_SNAPSHOT_SCHEDULES",
            "LOCAL_SSD_TOTAL_GB",
            "M1_CPUS",
            "M2_CPUS",
            "M3_CPUS",
            "MACHINE_IMAGES",
            "N2A_CPUS",
            "N2D_CPUS",
            "N2_CPUS",
            "NETWORKS",
            "NETWORK_ENDPOINT_GROUPS",
            "NETWORK_FIREWALL_POLICIES",
            "NODE_GROUPS",
            "NODE_TEMPLATES",
            "NVIDIA_A100_80GB_GPUS",
            "NVIDIA_A100_GPUS",
            "NVIDIA_K80_GPUS",
            "NVIDIA_P100_GPUS",
            "NVIDIA_P100_VWS_GPUS",
            "NVIDIA_P4_GPUS",
            "NVIDIA_P4_VWS_GPUS",
            "NVIDIA_T4_GPUS",
            "NVIDIA_T4_VWS_GPUS",
            "NVIDIA_V100_GPUS",
            "PACKET_MIRRORINGS",
            "PD_EXTREME_TOTAL_PROVISIONED_IOPS",
            "PREEMPTIBLE_CPUS",
            "PREEMPTIBLE_LOCAL_SSD_GB",
            "PREEMPTIBLE_NVIDIA_A100_80GB_GPUS",
            "PREEMPTIBLE_NVIDIA_A100_GPUS",
            "PREEMPTIBLE_NVIDIA_K80_GPUS",
            "PREEMPTIBLE_NVIDIA_P100_GPUS",
            "PREEMPTIBLE_NVIDIA_P100_VWS_GPUS",
            "PREEMPTIBLE_NVIDIA_P4_GPUS",
            "PREEMPTIBLE_NVIDIA_P4_VWS_GPUS",
            "PREEMPTIBLE_NVIDIA_T4_GPUS",
            "PREEMPTIBLE_NVIDIA_T4_VWS_GPUS",
            "PREEMPTIBLE_NVIDIA_V100_GPUS",
            "PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK",
            "PSC_INTERNAL_LB_FORWARDING_RULES",
            "PUBLIC_ADVERTISED_PREFIXES",
            "PUBLIC_DELEGATED_PREFIXES",
            "REGIONAL_AUTOSCALERS",
            "REGIONAL_EXTERNAL_MANAGED_BACKEND_SERVICES",
            "REGIONAL_EXTERNAL_NETWORK_LB_BACKEND_SERVICES",
            "REGIONAL_INSTANCE_GROUP_MANAGERS",
            "REGIONAL_INTERNAL_LB_BACKEND_SERVICES",
            "REGIONAL_INTERNAL_MANAGED_BACKEND_SERVICES",
            "RESERVATIONS",
            "RESOURCE_POLICIES",
            "ROUTERS",
            "ROUTES",
            "SECURITY_POLICIES",
            "SECURITY_POLICIES_PER_REGION",
            "SECURITY_POLICY_CEVAL_RULES",
            "SECURITY_POLICY_RULES",
            "SECURITY_POLICY_RULES_PER_REGION",
            "SERVICE_ATTACHMENTS",
            "SNAPSHOTS",
            "SSD_TOTAL_GB",
            "SSL_CERTIFICATES",
            "STATIC_ADDRESSES",
            "STATIC_BYOIP_ADDRESSES",
            "STATIC_EXTERNAL_IPV6_ADDRESS_RANGES",
            "SUBNETWORKS",
            "T2A_CPUS",
            "T2D_CPUS",
            "TARGET_HTTPS_PROXIES",
            "TARGET_HTTP_PROXIES",
            "TARGET_INSTANCES",
            "TARGET_POOLS",
            "TARGET_SSL_PROXIES",
            "TARGET_TCP_PROXIES",
            "TARGET_VPN_GATEWAYS",
            "URL_MAPS",
            "VPN_GATEWAYS",
            "VPN_TUNNELS",
            "XPN_SERVICE_PROJECTS",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "Guest CPUs",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "The total number of snapshots allowed for a single project.",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        owner = {
          description = "[Output Only] Owning resource. This is the resource on which this quota is applied.",
          type = "string",
        },
        usage = {
          description = "[Output Only] Current usage of this metric.",
          format = "double",
          type = "number",
        },
      },
      type = "object",
    },
    QuotaExceededInfo = {
      description = "Additional details for quota exceeded error for resource quota.",
      id = "QuotaExceededInfo",
      properties = {
        dimensions = {
          additionalProperties = {
            type = "string",
          },
          description = "The map holding related quota dimensions.",
          type = "object",
        },
        limit = {
          description = "Current effective quota limit. The limit's unit depends on the quota type or metric.",
          format = "double",
          type = "number",
        },
        limitName = {
          description = "The name of the quota limit.",
          type = "string",
        },
        metricName = {
          description = "The Compute Engine quota metric name.",
          type = "string",
        },
      },
      type = "object",
    },
    Reference = {
      description = "Represents a reference to a resource.",
      id = "Reference",
      properties = {
        kind = {
          default = "compute#reference",
          description = "[Output Only] Type of the resource. Always compute#reference for references.",
          type = "string",
        },
        referenceType = {
          description = "A description of the reference type with no implied semantics. Possible values include: 1. MEMBER_OF ",
          type = "string",
        },
        referrer = {
          description = "URL of the resource which refers to the target.",
          type = "string",
        },
        target = {
          description = "URL of the resource to which this reference points.",
          type = "string",
        },
      },
      type = "object",
    },
    Region = {
      description = "Represents a Region resource. A region is a geographical area where a resource is located. For more information, read Regions and Zones.",
      id = "Region",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        deprecated = {
          ["$ref"] = "DeprecationStatus",
          description = "[Output Only] The deprecation status associated with this region.",
        },
        description = {
          description = "[Output Only] Textual description of the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#region",
          description = "[Output Only] Type of the resource. Always compute#region for regions.",
          type = "string",
        },
        name = {
          description = "[Output Only] Name of the resource.",
          type = "string",
        },
        quotas = {
          description = "[Output Only] Quotas assigned to this region.",
          items = {
            ["$ref"] = "Quota",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        status = {
          description = "[Output Only] Status of the region, either UP or DOWN.",
          enum = {
            "DOWN",
            "UP",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        supportsPzs = {
          description = "[Output Only] Reserved for future use.",
          type = "boolean",
        },
        zones = {
          description = "[Output Only] A list of zones available in this region, in the form of resource URLs.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionAutoscalerList = {
      description = "Contains a list of autoscalers.",
      id = "RegionAutoscalerList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Autoscaler resources.",
          items = {
            ["$ref"] = "Autoscaler",
          },
          type = "array",
        },
        kind = {
          default = "compute#regionAutoscalerList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    RegionDiskTypeList = {
      id = "RegionDiskTypeList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of DiskType resources.",
          items = {
            ["$ref"] = "DiskType",
          },
          type = "array",
        },
        kind = {
          default = "compute#regionDiskTypeList",
          description = "[Output Only] Type of resource. Always compute#regionDiskTypeList for region disk types.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    RegionDisksAddResourcePoliciesRequest = {
      id = "RegionDisksAddResourcePoliciesRequest",
      properties = {
        resourcePolicies = {
          description = "Resource policies to be added to this disk.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionDisksRemoveResourcePoliciesRequest = {
      id = "RegionDisksRemoveResourcePoliciesRequest",
      properties = {
        resourcePolicies = {
          description = "Resource policies to be removed from this disk.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionDisksResizeRequest = {
      id = "RegionDisksResizeRequest",
      properties = {
        sizeGb = {
          description = "The new size of the regional persistent disk, which is specified in GB.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    RegionInstanceGroupList = {
      description = "Contains a list of InstanceGroup resources.",
      id = "RegionInstanceGroupList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of InstanceGroup resources.",
          items = {
            ["$ref"] = "InstanceGroup",
          },
          type = "array",
        },
        kind = {
          default = "compute#regionInstanceGroupList",
          description = "The resource type.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagerDeleteInstanceConfigReq = {
      description = "RegionInstanceGroupManagers.deletePerInstanceConfigs",
      id = "RegionInstanceGroupManagerDeleteInstanceConfigReq",
      properties = {
        names = {
          description = "The list of instance names for which we want to delete per-instance configs on this managed instance group.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagerList = {
      description = "Contains a list of managed instance groups.",
      id = "RegionInstanceGroupManagerList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of InstanceGroupManager resources.",
          items = {
            ["$ref"] = "InstanceGroupManager",
          },
          type = "array",
        },
        kind = {
          default = "compute#regionInstanceGroupManagerList",
          description = "[Output Only] The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups that exist in th regional scope.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagerPatchInstanceConfigReq = {
      description = "RegionInstanceGroupManagers.patchPerInstanceConfigs",
      id = "RegionInstanceGroupManagerPatchInstanceConfigReq",
      properties = {
        perInstanceConfigs = {
          description = "The list of per-instance configurations to insert or patch on this managed instance group.",
          items = {
            ["$ref"] = "PerInstanceConfig",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagerUpdateInstanceConfigReq = {
      description = "RegionInstanceGroupManagers.updatePerInstanceConfigs",
      id = "RegionInstanceGroupManagerUpdateInstanceConfigReq",
      properties = {
        perInstanceConfigs = {
          description = "The list of per-instance configurations to insert or patch on this managed instance group.",
          items = {
            ["$ref"] = "PerInstanceConfig",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersAbandonInstancesRequest = {
      id = "RegionInstanceGroupManagersAbandonInstancesRequest",
      properties = {
        instances = {
          description = "The URLs of one or more instances to abandon. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersApplyUpdatesRequest = {
      description = "RegionInstanceGroupManagers.applyUpdatesToInstances",
      id = "RegionInstanceGroupManagersApplyUpdatesRequest",
      properties = {
        allInstances = {
          description = "Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.",
          type = "boolean",
        },
        instances = {
          description = "The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].",
          items = {
            type = "string",
          },
          type = "array",
        },
        minimalAction = {
          description = "The minimal action that you want to perform on each instance during the update: - REPLACE: At minimum, delete the instance and create it again. - RESTART: Stop the instance and start it again. - REFRESH: Do not stop the instance. - NONE: Do not disrupt the instance at all. By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update.",
          enum = {
            "NONE",
            "REFRESH",
            "REPLACE",
            "RESTART",
          },
          enumDescriptions = {
            "Do not perform any action.",
            "Updates applied in runtime, instances will not be disrupted.",
            "Old instances will be deleted. New instances will be created from the target template.",
            "Every instance will be restarted.",
          },
          type = "string",
        },
        mostDisruptiveAllowedAction = {
          description = "The most disruptive action that you want to perform on each instance during the update: - REPLACE: Delete the instance and create it again. - RESTART: Stop the instance and start it again. - REFRESH: Do not stop the instance. - NONE: Do not disrupt the instance at all. By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail.",
          enum = {
            "NONE",
            "REFRESH",
            "REPLACE",
            "RESTART",
          },
          enumDescriptions = {
            "Do not perform any action.",
            "Updates applied in runtime, instances will not be disrupted.",
            "Old instances will be deleted. New instances will be created from the target template.",
            "Every instance will be restarted.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersCreateInstancesRequest = {
      description = "RegionInstanceGroupManagers.createInstances",
      id = "RegionInstanceGroupManagersCreateInstancesRequest",
      properties = {
        instances = {
          description = "[Required] List of specifications of per-instance configs.",
          items = {
            ["$ref"] = "PerInstanceConfig",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersDeleteInstancesRequest = {
      id = "RegionInstanceGroupManagersDeleteInstancesRequest",
      properties = {
        instances = {
          description = "The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].",
          items = {
            type = "string",
          },
          type = "array",
        },
        skipInstancesOnValidationError = {
          description = "Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned. If this field is set to `false` and such an instance is specified in the request, the operation fails. The operation always fails if the request contains a malformed instance URL or a reference to an instance that exists in a zone or region other than the group's zone or region.",
          type = "boolean",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersListErrorsResponse = {
      id = "RegionInstanceGroupManagersListErrorsResponse",
      properties = {
        items = {
          description = "[Output Only] The list of errors of the managed instance group.",
          items = {
            ["$ref"] = "InstanceManagedByIgmError",
          },
          type = "array",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersListInstanceConfigsResp = {
      id = "RegionInstanceGroupManagersListInstanceConfigsResp",
      properties = {
        items = {
          description = "[Output Only] The list of PerInstanceConfig.",
          items = {
            ["$ref"] = "PerInstanceConfig",
          },
          type = "array",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersListInstancesResponse = {
      id = "RegionInstanceGroupManagersListInstancesResponse",
      properties = {
        managedInstances = {
          description = "A list of managed instances.",
          items = {
            ["$ref"] = "ManagedInstance",
          },
          type = "array",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersRecreateRequest = {
      id = "RegionInstanceGroupManagersRecreateRequest",
      properties = {
        instances = {
          description = "The URLs of one or more instances to recreate. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersSetTargetPoolsRequest = {
      id = "RegionInstanceGroupManagersSetTargetPoolsRequest",
      properties = {
        fingerprint = {
          description = "Fingerprint of the target pools information, which is a hash of the contents. This field is used for optimistic locking when you update the target pool entries. This field is optional.",
          format = "byte",
          type = "string",
        },
        targetPools = {
          description = "The URL of all TargetPool resources to which instances in the instanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionInstanceGroupManagersSetTemplateRequest = {
      id = "RegionInstanceGroupManagersSetTemplateRequest",
      properties = {
        instanceTemplate = {
          description = "URL of the InstanceTemplate resource from which all new instances will be created.",
          type = "string",
        },
      },
      type = "object",
    },
    RegionInstanceGroupsListInstances = {
      id = "RegionInstanceGroupsListInstances",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of InstanceWithNamedPorts resources.",
          items = {
            ["$ref"] = "InstanceWithNamedPorts",
          },
          type = "array",
        },
        kind = {
          default = "compute#regionInstanceGroupsListInstances",
          description = "The resource type.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    RegionInstanceGroupsListInstancesRequest = {
      id = "RegionInstanceGroupsListInstancesRequest",
      properties = {
        instanceState = {
          description = "Instances in which state should be returned. Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances.",
          enum = {
            "ALL",
            "RUNNING",
          },
          enumDescriptions = {
            "Matches any status of the instances, running, non-running and others.",
            "Instance is in RUNNING state if it is running.",
          },
          type = "string",
        },
        portName = {
          description = "Name of port user is interested in. It is optional. If it is set, only information about this ports will be returned. If it is not set, all the named ports will be returned. Always lists all instances.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
      },
      type = "object",
    },
    RegionInstanceGroupsSetNamedPortsRequest = {
      id = "RegionInstanceGroupsSetNamedPortsRequest",
      properties = {
        fingerprint = {
          description = "The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with the instanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request.",
          format = "byte",
          type = "string",
        },
        namedPorts = {
          description = "The list of named ports to set for this instance group.",
          items = {
            ["$ref"] = "NamedPort",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionList = {
      description = "Contains a list of region resources.",
      id = "RegionList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Region resources.",
          items = {
            ["$ref"] = "Region",
          },
          type = "array",
        },
        kind = {
          default = "compute#regionList",
          description = "[Output Only] Type of resource. Always compute#regionList for lists of regions.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse = {
      id = "RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse",
      properties = {
        firewallPolicys = {
          description = "Effective firewalls from firewall policy.",
          items = {
            ["$ref"] = "RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
          },
          type = "array",
        },
        firewalls = {
          description = "Effective firewalls on the network.",
          items = {
            ["$ref"] = "Firewall",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy = {
      id = "RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
      properties = {
        displayName = {
          description = "[Output Only] The display name of the firewall policy.",
          type = "string",
        },
        name = {
          description = "[Output Only] The name of the firewall policy.",
          type = "string",
        },
        rules = {
          description = "The rules that apply to the network.",
          items = {
            ["$ref"] = "FirewallPolicyRule",
          },
          type = "array",
        },
        type = {
          description = "[Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL.",
          enum = {
            "HIERARCHY",
            "NETWORK",
            "NETWORK_REGIONAL",
            "UNSPECIFIED",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    RegionSetLabelsRequest = {
      id = "RegionSetLabelsRequest",
      properties = {
        labelFingerprint = {
          description = "The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "The labels to set for this resource.",
          type = "object",
        },
      },
      type = "object",
    },
    RegionSetPolicyRequest = {
      id = "RegionSetPolicyRequest",
      properties = {
        bindings = {
          description = "Flatten Policy to create a backwacd compatible wire-format. Deprecated. Use 'policy' to specify bindings.",
          items = {
            ["$ref"] = "Binding",
          },
          type = "array",
        },
        etag = {
          description = "Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify the etag.",
          format = "byte",
          type = "string",
        },
        policy = {
          ["$ref"] = "Policy",
          description = "REQUIRED: The complete policy to be applied to the 'resource'. The size of the policy is limited to a few 10s of KB. An empty policy is in general a valid policy but certain services (like Projects) might reject them.",
        },
      },
      type = "object",
    },
    RegionTargetHttpsProxiesSetSslCertificatesRequest = {
      id = "RegionTargetHttpsProxiesSetSslCertificatesRequest",
      properties = {
        sslCertificates = {
          description = "New set of SslCertificate resources to associate with this TargetHttpsProxy resource.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RegionUrlMapsValidateRequest = {
      id = "RegionUrlMapsValidateRequest",
      properties = {
        resource = {
          ["$ref"] = "UrlMap",
          description = "Content of the UrlMap to be validated.",
        },
      },
      type = "object",
    },
    RequestMirrorPolicy = {
      description = "A policy that specifies how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer doesn't wait for responses from the shadow service. Before sending traffic to the shadow service, the host or authority header is suffixed with -shadow.",
      id = "RequestMirrorPolicy",
      properties = {
        backendService = {
          description = "The full or partial URL to the BackendService resource being mirrored to. The backend service configured for a mirroring policy must reference backends that are of the same type as the original backend service matched in the URL map. Serverless NEG backends are not currently supported as a mirrored backend service. ",
          type = "string",
        },
      },
      type = "object",
    },
    Reservation = {
      description = "Represents a reservation resource. A reservation ensures that capacity is held in a specific zone even if the reserved VMs are not running. For more information, read Reserving zonal resources.",
      id = "Reservation",
      properties = {
        commitment = {
          description = "[Output Only] Full or partial URL to a parent commitment. This field displays for reservations that are tied to a commitment.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#reservation",
          description = "[Output Only] Type of the resource. Always compute#reservations for reservations.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.instances.insert",
            },
          },
          description = "The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        resourceStatus = {
          ["$ref"] = "AllocationResourceStatus",
          description = "[Output Only] Status information for Reservation resource.",
        },
        satisfiesPzs = {
          description = "[Output Only] Reserved for future use.",
          type = "boolean",
        },
        selfLink = {
          description = "[Output Only] Server-defined fully-qualified URL for this resource.",
          type = "string",
        },
        shareSettings = {
          ["$ref"] = "ShareSettings",
          description = "Specify share-settings to create a shared reservation. This property is optional. For more information about the syntax and options for this field and its subfields, see the guide for creating a shared reservation.",
        },
        specificReservation = {
          ["$ref"] = "AllocationSpecificSKUReservation",
          description = "Reservation for instances with specific machine shapes.",
        },
        specificReservationRequired = {
          description = "Indicates whether the reservation can be consumed by VMs with affinity for \"any\" reservation. If the field is set, then only VMs that target the reservation by name can consume from this reservation.",
          type = "boolean",
        },
        status = {
          description = "[Output Only] The status of the reservation.",
          enum = {
            "CREATING",
            "DELETING",
            "INVALID",
            "READY",
            "UPDATING",
          },
          enumDescriptions = {
            "Resources are being allocated for the reservation.",
            "Reservation is currently being deleted.",
            "",
            "Reservation has allocated all its resources.",
            "Reservation is currently being resized.",
          },
          type = "string",
        },
        zone = {
          description = "Zone in which the reservation resides. A zone must be provided if the reservation is created within a commitment.",
          type = "string",
        },
      },
      type = "object",
    },
    ReservationAffinity = {
      description = "Specifies the reservations that this instance can consume from.",
      id = "ReservationAffinity",
      properties = {
        consumeReservationType = {
          description = "Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default), SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples.",
          enum = {
            "ANY_RESERVATION",
            "NO_RESERVATION",
            "SPECIFIC_RESERVATION",
            "UNSPECIFIED",
          },
          enumDescriptions = {
            "Consume any allocation available.",
            "Do not consume from any allocated capacity.",
            "Must consume from a specific reservation. Must specify key value fields for specifying the reservations.",
            "",
          },
          type = "string",
        },
        key = {
          description = "Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, specify googleapis.com/reservation-name as the key and specify the name of your reservation as its value.",
          type = "string",
        },
        values = {
          description = "Corresponds to the label values of a reservation resource. This can be either a name to a reservation in the same project or \"projects/different-project/reservations/some-reservation-name\" to target a shared reservation in the same zone but in a different project.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ReservationAggregatedList = {
      description = "Contains a list of reservations.",
      id = "ReservationAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "ReservationsScopedList",
            description = "Name of the scope containing this set of reservations.",
          },
          description = "A list of Allocation resources.",
          type = "object",
        },
        kind = {
          default = "compute#reservationAggregatedList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ReservationList = {
      id = "ReservationList",
      properties = {
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          type = "string",
        },
        items = {
          description = "[Output Only] A list of Allocation resources.",
          items = {
            ["$ref"] = "Reservation",
          },
          type = "array",
        },
        kind = {
          default = "compute#reservationList",
          description = "[Output Only] Type of resource.Always compute#reservationsList for listsof reservations",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ReservationsResizeRequest = {
      id = "ReservationsResizeRequest",
      properties = {
        specificSkuCount = {
          description = "Number of allocated resources can be resized with minimum = 1 and maximum = 1000.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    ReservationsScopedList = {
      id = "ReservationsScopedList",
      properties = {
        reservations = {
          description = "A list of reservations contained in this scope.",
          items = {
            ["$ref"] = "Reservation",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of reservations when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ResourceCommitment = {
      description = "Commitment for a particular resource (a Commitment is composed of one or more of these).",
      id = "ResourceCommitment",
      properties = {
        acceleratorType = {
          description = "Name of the accelerator type resource. Applicable only when the type is ACCELERATOR.",
          type = "string",
        },
        amount = {
          description = "The amount of the resource purchased (in a type-dependent unit, such as bytes). For vCPUs, this can just be an integer. For memory, this must be provided in MB. Memory must be a multiple of 256 MB, with up to 6.5GB of memory per every vCPU.",
          format = "int64",
          type = "string",
        },
        type = {
          description = "Type of resource for which this commitment applies. Possible values are VCPU, MEMORY, LOCAL_SSD, and ACCELERATOR.",
          enum = {
            "ACCELERATOR",
            "LOCAL_SSD",
            "MEMORY",
            "UNSPECIFIED",
            "VCPU",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ResourceGroupReference = {
      id = "ResourceGroupReference",
      properties = {
        group = {
          description = "A URI referencing one of the instance groups or network endpoint groups listed in the backend service.",
          type = "string",
        },
      },
      type = "object",
    },
    ResourcePoliciesScopedList = {
      id = "ResourcePoliciesScopedList",
      properties = {
        resourcePolicies = {
          description = "A list of resourcePolicies contained in this scope.",
          items = {
            ["$ref"] = "ResourcePolicy",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of resourcePolicies when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ResourcePolicy = {
      description = "Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them to schedule persistent disk snapshots.",
      id = "ResourcePolicy",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          type = "string",
        },
        groupPlacementPolicy = {
          ["$ref"] = "ResourcePolicyGroupPlacementPolicy",
          description = "Resource policy for instances for placement configuration.",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        instanceSchedulePolicy = {
          ["$ref"] = "ResourcePolicyInstanceSchedulePolicy",
          description = "Resource policy for scheduling instance operations.",
        },
        kind = {
          default = "compute#resourcePolicy",
          description = "[Output Only] Type of the resource. Always compute#resource_policies for resource policies.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.instances.insert",
            },
          },
          description = "The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        region = {
          type = "string",
        },
        resourceStatus = {
          ["$ref"] = "ResourcePolicyResourceStatus",
          description = "[Output Only] The system status of the resource policy.",
        },
        selfLink = {
          description = "[Output Only] Server-defined fully-qualified URL for this resource.",
          type = "string",
        },
        snapshotSchedulePolicy = {
          ["$ref"] = "ResourcePolicySnapshotSchedulePolicy",
          description = "Resource policy for persistent disks for creating snapshots.",
        },
        status = {
          description = "[Output Only] The status of resource policy creation.",
          enum = {
            "CREATING",
            "DELETING",
            "EXPIRED",
            "INVALID",
            "READY",
          },
          enumDescriptions = {
            "Resource policy is being created.",
            "Resource policy is being deleted.",
            "Resource policy is expired and will not run again.",
            "",
            "Resource policy is ready to be used.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ResourcePolicyAggregatedList = {
      description = "Contains a list of resourcePolicies.",
      id = "ResourcePolicyAggregatedList",
      properties = {
        etag = {
          type = "string",
        },
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "ResourcePoliciesScopedList",
            description = "Name of the scope containing this set of resourcePolicies.",
          },
          description = "A list of ResourcePolicy resources.",
          type = "object",
        },
        kind = {
          default = "compute#resourcePolicyAggregatedList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ResourcePolicyDailyCycle = {
      description = "Time window specified for daily operations.",
      id = "ResourcePolicyDailyCycle",
      properties = {
        daysInCycle = {
          description = "Defines a schedule with units measured in days. The value determines how many days pass between the start of each cycle.",
          format = "int32",
          type = "integer",
        },
        duration = {
          description = "[Output only] A predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario.",
          type = "string",
        },
        startTime = {
          description = "Start time of the window. This must be in UTC format that resolves to one of 00:00, 04:00, 08:00, 12:00, 16:00, or 20:00. For example, both 13:00-5 and 08:00 are valid.",
          type = "string",
        },
      },
      type = "object",
    },
    ResourcePolicyGroupPlacementPolicy = {
      description = "A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation as well as network locality",
      id = "ResourcePolicyGroupPlacementPolicy",
      properties = {
        availabilityDomainCount = {
          description = "The number of availability domains to spread instances across. If two instances are in different availability domain, they are not in the same low latency network.",
          format = "int32",
          type = "integer",
        },
        collocation = {
          description = "Specifies network collocation",
          enum = {
            "COLLOCATED",
            "UNSPECIFIED_COLLOCATION",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        vmCount = {
          description = "Number of VMs in this placement group. Google does not recommend that you use this field unless you use a compact policy and you want your policy to work only if it contains this exact number of VMs.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    ResourcePolicyHourlyCycle = {
      description = "Time window specified for hourly operations.",
      id = "ResourcePolicyHourlyCycle",
      properties = {
        duration = {
          description = "[Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.",
          type = "string",
        },
        hoursInCycle = {
          description = "Defines a schedule with units measured in hours. The value determines how many hours pass between the start of each cycle.",
          format = "int32",
          type = "integer",
        },
        startTime = {
          description = "Time within the window to start the operations. It must be in format \"HH:MM\", where HH : [00-23] and MM : [00-00] GMT.",
          type = "string",
        },
      },
      type = "object",
    },
    ResourcePolicyInstanceSchedulePolicy = {
      description = "An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.",
      id = "ResourcePolicyInstanceSchedulePolicy",
      properties = {
        expirationTime = {
          description = "The expiration time of the schedule. The timestamp is an RFC3339 string.",
          type = "string",
        },
        startTime = {
          description = "The start time of the schedule. The timestamp is an RFC3339 string.",
          type = "string",
        },
        timeZone = {
          description = "Specifies the time zone to be used in interpreting Schedule.schedule. The value of this field must be a time zone name from the tz database: http://en.wikipedia.org/wiki/Tz_database.",
          type = "string",
        },
        vmStartSchedule = {
          ["$ref"] = "ResourcePolicyInstanceSchedulePolicySchedule",
          description = "Specifies the schedule for starting instances.",
        },
        vmStopSchedule = {
          ["$ref"] = "ResourcePolicyInstanceSchedulePolicySchedule",
          description = "Specifies the schedule for stopping instances.",
        },
      },
      type = "object",
    },
    ResourcePolicyInstanceSchedulePolicySchedule = {
      description = "Schedule for an instance operation.",
      id = "ResourcePolicyInstanceSchedulePolicySchedule",
      properties = {
        schedule = {
          description = "Specifies the frequency for the operation, using the unix-cron format.",
          type = "string",
        },
      },
      type = "object",
    },
    ResourcePolicyList = {
      id = "ResourcePolicyList",
      properties = {
        etag = {
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          type = "string",
        },
        items = {
          description = "[Output Only] A list of ResourcePolicy resources.",
          items = {
            ["$ref"] = "ResourcePolicy",
          },
          type = "array",
        },
        kind = {
          default = "compute#resourcePolicyList",
          description = "[Output Only] Type of resource.Always compute#resourcePoliciesList for listsof resourcePolicies",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ResourcePolicyResourceStatus = {
      description = "Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this \"status\" field should mimic the structure of ResourcePolicy proto specification.",
      id = "ResourcePolicyResourceStatus",
      properties = {
        instanceSchedulePolicy = {
          ["$ref"] = "ResourcePolicyResourceStatusInstanceSchedulePolicyStatus",
          description = "[Output Only] Specifies a set of output values reffering to the instance_schedule_policy system status. This field should have the same name as corresponding policy field.",
        },
      },
      type = "object",
    },
    ResourcePolicyResourceStatusInstanceSchedulePolicyStatus = {
      id = "ResourcePolicyResourceStatusInstanceSchedulePolicyStatus",
      properties = {
        lastRunStartTime = {
          description = "[Output Only] The last time the schedule successfully ran. The timestamp is an RFC3339 string.",
          type = "string",
        },
        nextRunStartTime = {
          description = "[Output Only] The next time the schedule is planned to run. The actual time might be slightly different. The timestamp is an RFC3339 string.",
          type = "string",
        },
      },
      type = "object",
    },
    ResourcePolicySnapshotSchedulePolicy = {
      description = "A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained.",
      id = "ResourcePolicySnapshotSchedulePolicy",
      properties = {
        retentionPolicy = {
          ["$ref"] = "ResourcePolicySnapshotSchedulePolicyRetentionPolicy",
          description = "Retention policy applied to snapshots created by this resource policy.",
        },
        schedule = {
          ["$ref"] = "ResourcePolicySnapshotSchedulePolicySchedule",
          description = "A Vm Maintenance Policy specifies what kind of infrastructure maintenance we are allowed to perform on this VM and when. Schedule that is applied to disks covered by this policy.",
        },
        snapshotProperties = {
          ["$ref"] = "ResourcePolicySnapshotSchedulePolicySnapshotProperties",
          description = "Properties with which snapshots are created such as labels, encryption keys.",
        },
      },
      type = "object",
    },
    ResourcePolicySnapshotSchedulePolicyRetentionPolicy = {
      description = "Policy for retention of scheduled snapshots.",
      id = "ResourcePolicySnapshotSchedulePolicyRetentionPolicy",
      properties = {
        maxRetentionDays = {
          description = "Maximum age of the snapshot that is allowed to be kept.",
          format = "int32",
          type = "integer",
        },
        onSourceDiskDelete = {
          description = "Specifies the behavior to apply to scheduled snapshots when the source disk is deleted.",
          enum = {
            "APPLY_RETENTION_POLICY",
            "KEEP_AUTO_SNAPSHOTS",
            "UNSPECIFIED_ON_SOURCE_DISK_DELETE",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ResourcePolicySnapshotSchedulePolicySchedule = {
      description = "A schedule for disks where the schedueled operations are performed.",
      id = "ResourcePolicySnapshotSchedulePolicySchedule",
      properties = {
        dailySchedule = {
          ["$ref"] = "ResourcePolicyDailyCycle",
        },
        hourlySchedule = {
          ["$ref"] = "ResourcePolicyHourlyCycle",
        },
        weeklySchedule = {
          ["$ref"] = "ResourcePolicyWeeklyCycle",
        },
      },
      type = "object",
    },
    ResourcePolicySnapshotSchedulePolicySnapshotProperties = {
      description = "Specified snapshot properties for scheduled snapshots created by this policy.",
      id = "ResourcePolicySnapshotSchedulePolicySnapshotProperties",
      properties = {
        chainName = {
          description = "Chain name that the snapshot is created in.",
          type = "string",
        },
        guestFlush = {
          description = "Indication to perform a 'guest aware' snapshot.",
          type = "boolean",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty.",
          type = "object",
        },
        storageLocations = {
          description = "Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ResourcePolicyWeeklyCycle = {
      description = "Time window specified for weekly operations.",
      id = "ResourcePolicyWeeklyCycle",
      properties = {
        dayOfWeeks = {
          description = "Up to 7 intervals/windows, one for each day of the week.",
          items = {
            ["$ref"] = "ResourcePolicyWeeklyCycleDayOfWeek",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ResourcePolicyWeeklyCycleDayOfWeek = {
      id = "ResourcePolicyWeeklyCycleDayOfWeek",
      properties = {
        day = {
          description = "Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.",
          enum = {
            "FRIDAY",
            "INVALID",
            "MONDAY",
            "SATURDAY",
            "SUNDAY",
            "THURSDAY",
            "TUESDAY",
            "WEDNESDAY",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        duration = {
          description = "[Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.",
          type = "string",
        },
        startTime = {
          description = "Time within the window to start the operations. It must be in format \"HH:MM\", where HH : [00-23] and MM : [00-00] GMT.",
          type = "string",
        },
      },
      type = "object",
    },
    ResourceStatus = {
      description = "Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.",
      id = "ResourceStatus",
      properties = {
        physicalHost = {
          description = "[Output Only] An opaque ID of the host on which the VM is running.",
          type = "string",
        },
      },
      type = "object",
    },
    Route = {
      description = "Represents a Route resource. A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read the Routes overview.",
      id = "Route",
      properties = {
        asPaths = {
          description = "[Output Only] AS path.",
          items = {
            ["$ref"] = "RouteAsPath",
          },
          type = "array",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this field when you create the resource.",
          type = "string",
        },
        destRange = {
          annotations = {
            required = {
              "compute.routes.insert",
            },
          },
          description = "The destination range of outgoing packets that this route applies to. Both IPv4 and IPv6 are supported.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#route",
          description = "[Output Only] Type of this resource. Always compute#routes for Route resources.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.routes.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          annotations = {
            required = {
              "compute.routes.insert",
            },
          },
          description = "Fully-qualified URL of the network that this route applies to.",
          type = "string",
        },
        nextHopGateway = {
          description = "The URL to a gateway that should handle matching packets. You can only specify the internet gateway using a full or partial valid URL: projects/ project/global/gateways/default-internet-gateway",
          type = "string",
        },
        nextHopIlb = {
          description = "The URL to a forwarding rule of type loadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs: - 10.128.0.56 - https://www.googleapis.com/compute/v1/projects/project/regions/region /forwardingRules/forwardingRule - regions/region/forwardingRules/forwardingRule ",
          type = "string",
        },
        nextHopInstance = {
          description = "The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/",
          type = "string",
        },
        nextHopIp = {
          description = "The network IP address of an instance that should handle matching packets. Only IPv4 is supported.",
          type = "string",
        },
        nextHopNetwork = {
          description = "The URL of the local network if it should handle matching packets.",
          type = "string",
        },
        nextHopPeering = {
          description = "[Output Only] The network peering name that should handle matching packets, which should conform to RFC1035.",
          type = "string",
        },
        nextHopVpnTunnel = {
          description = "The URL to a VpnTunnel that should handle matching packets.",
          type = "string",
        },
        priority = {
          annotations = {
            required = {
              "compute.routes.insert",
            },
          },
          description = "The priority of this route. Priority is used to break ties in cases where there is more than one matching route of equal prefix length. In cases where multiple routes have equal prefix length, the one with the lowest-numbered priority value wins. The default value is `1000`. The priority value must be from `0` to `65535`, inclusive.",
          format = "uint32",
          type = "integer",
        },
        routeStatus = {
          description = "[Output only] The status of the route.",
          enum = {
            "ACTIVE",
            "DROPPED",
            "INACTIVE",
            "PENDING",
          },
          enumDescriptions = {
            "This route is processed and active.",
            "The route is dropped due to the VPC exceeding the dynamic route limit. For dynamic route limit, please refer to the Learned route example",
            "This route is processed but inactive due to failure from the backend. The backend may have rejected the route",
            "This route is being processed internally. The status will change once processed.",
          },
          type = "string",
        },
        routeType = {
          description = "[Output Only] The type of this route, which can be one of the following values: - 'TRANSIT' for a transit route that this router learned from another Cloud Router and will readvertise to one of its BGP peers - 'SUBNET' for a route from a subnet of the VPC - 'BGP' for a route learned from a BGP peer of this router - 'STATIC' for a static route",
          enum = {
            "BGP",
            "STATIC",
            "SUBNET",
            "TRANSIT",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined fully-qualified URL for this resource.",
          type = "string",
        },
        tags = {
          annotations = {
            required = {
              "compute.routes.insert",
            },
          },
          description = "A list of instance tags to which this route applies.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warnings = {
          description = "[Output Only] If potential misconfigurations are detected for this route, this field will be populated with warning messages.",
          items = {
            properties = {
              code = {
                description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
                enum = {
                  "CLEANUP_FAILED",
                  "DEPRECATED_RESOURCE_USED",
                  "DEPRECATED_TYPE_USED",
                  "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                  "EXPERIMENTAL_TYPE_USED",
                  "EXTERNAL_API_WARNING",
                  "FIELD_VALUE_OVERRIDEN",
                  "INJECTED_KERNELS_DEPRECATED",
                  "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                  "LARGE_DEPLOYMENT_WARNING",
                  "MISSING_TYPE_DEPENDENCY",
                  "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                  "NEXT_HOP_CANNOT_IP_FORWARD",
                  "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                  "NEXT_HOP_INSTANCE_NOT_FOUND",
                  "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                  "NEXT_HOP_NOT_RUNNING",
                  "NOT_CRITICAL_ERROR",
                  "NO_RESULTS_ON_PAGE",
                  "PARTIAL_SUCCESS",
                  "REQUIRED_TOS_AGREEMENT",
                  "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                  "RESOURCE_NOT_DELETED",
                  "SCHEMA_VALIDATION_IGNORED",
                  "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                  "UNDECLARED_PROPERTIES",
                  "UNREACHABLE",
                },
                enumDescriptions = {
                  "Warning about failed cleanup of transient changes made by a failed operation.",
                  "A link to a deprecated resource was created.",
                  "When deploying and at least one of the resources has a type marked as deprecated",
                  "The user created a boot disk that is larger than image size.",
                  "When deploying and at least one of the resources has a type marked as experimental",
                  "Warning that is present in an external api call",
                  "Warning that value of a field has been overridden. Deprecated unused field.",
                  "The operation involved use of an injected kernel, which is deprecated.",
                  "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                  "When deploying a deployment with a exceedingly large number of resources",
                  "A resource depends on a missing type",
                  "The route's nextHopIp address is not assigned to an instance on the network.",
                  "The route's next hop instance cannot ip forward.",
                  "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                  "The route's nextHopInstance URL refers to an instance that does not exist.",
                  "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                  "The route's next hop instance does not have a status of RUNNING.",
                  "Error which is not critical. We decided to continue the process despite the mentioned error.",
                  "No results are present on a particular list page.",
                  "Success is reported, but some results may be missing due to errors",
                  "The user attempted to use a resource that requires a TOS they have not accepted.",
                  "Warning that a resource is in use.",
                  "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                  "When a resource schema validation is ignored.",
                  "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                  "When undeclared properties in the schema are present",
                  "A given scope cannot be reached.",
                },
                type = "string",
              },
              data = {
                description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
                items = {
                  properties = {
                    key = {
                      description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                      type = "string",
                    },
                    value = {
                      description = "[Output Only] A warning data value corresponding to the key.",
                      type = "string",
                    },
                  },
                  type = "object",
                },
                type = "array",
              },
              message = {
                description = "[Output Only] A human-readable description of the warning code.",
                type = "string",
              },
            },
            type = "object",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RouteAsPath = {
      id = "RouteAsPath",
      properties = {
        asLists = {
          description = "[Output Only] The AS numbers of the AS Path.",
          items = {
            format = "uint32",
            type = "integer",
          },
          type = "array",
        },
        pathSegmentType = {
          description = "[Output Only] The type of the AS Path, which can be one of the following values: - 'AS_SET': unordered set of autonomous systems that the route in has traversed - 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed - 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed - 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed ",
          enum = {
            "AS_CONFED_SEQUENCE",
            "AS_CONFED_SET",
            "AS_SEQUENCE",
            "AS_SET",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    RouteList = {
      description = "Contains a list of Route resources.",
      id = "RouteList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Route resources.",
          items = {
            ["$ref"] = "Route",
          },
          type = "array",
        },
        kind = {
          default = "compute#routeList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    Router = {
      description = "Represents a Cloud Router resource. For more information about Cloud Router, read the Cloud Router overview.",
      id = "Router",
      properties = {
        bgp = {
          ["$ref"] = "RouterBgp",
          description = "BGP information specific to this router.",
        },
        bgpPeers = {
          description = "BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer to RFC4273.",
          items = {
            ["$ref"] = "RouterBgpPeer",
          },
          type = "array",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        encryptedInterconnectRouter = {
          description = "Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).",
          type = "boolean",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        interfaces = {
          description = "Router interfaces. Each interface requires either one linked resource, (for example, linkedVpnTunnel), or IP address and IP address range (for example, ipRange), or both.",
          items = {
            ["$ref"] = "RouterInterface",
          },
          type = "array",
        },
        kind = {
          default = "compute#router",
          description = "[Output Only] Type of resource. Always compute#router for routers.",
          type = "string",
        },
        md5AuthenticationKeys = {
          description = "Keys used for MD5 authentication.",
          items = {
            ["$ref"] = "RouterMd5AuthenticationKey",
          },
          type = "array",
        },
        name = {
          annotations = {
            required = {
              "compute.routers.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        nats = {
          description = "A list of NAT services created in this router.",
          items = {
            ["$ref"] = "RouterNat",
          },
          type = "array",
        },
        network = {
          annotations = {
            required = {
              "compute.routers.insert",
              "compute.routers.update",
            },
          },
          description = "URI of the network to which this router belongs.",
          type = "string",
        },
        region = {
          description = "[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
      },
      type = "object",
    },
    RouterAdvertisedIpRange = {
      description = "Description-tagged IP ranges for the router to advertise.",
      id = "RouterAdvertisedIpRange",
      properties = {
        description = {
          description = "User-specified description for the IP range.",
          type = "string",
        },
        range = {
          description = "The IP range to advertise. The value must be a CIDR-formatted string.",
          type = "string",
        },
      },
      type = "object",
    },
    RouterAggregatedList = {
      description = "Contains a list of routers.",
      id = "RouterAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "RoutersScopedList",
            description = "Name of the scope containing this set of routers.",
          },
          description = "A list of Router resources.",
          type = "object",
        },
        kind = {
          default = "compute#routerAggregatedList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    RouterBgp = {
      id = "RouterBgp",
      properties = {
        advertiseMode = {
          description = "User-specified flag to indicate which mode to use for advertisement. The options are DEFAULT or CUSTOM.",
          enum = {
            "CUSTOM",
            "DEFAULT",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        advertisedGroups = {
          description = "User-specified list of prefix groups to advertise in custom mode. This field can only be populated if advertise_mode is CUSTOM and is advertised to all peers of the router. These groups will be advertised in addition to any specified prefixes. Leave this field blank to advertise no custom groups.",
          items = {
            enum = {
              "ALL_SUBNETS",
            },
            enumDescriptions = {
              "Advertise all available subnets (including peer VPC subnets).",
            },
            type = "string",
          },
          type = "array",
        },
        advertisedIpRanges = {
          description = "User-specified list of individual IP ranges to advertise in custom mode. This field can only be populated if advertise_mode is CUSTOM and is advertised to all peers of the router. These IP ranges will be advertised in addition to any specified groups. Leave this field blank to advertise no custom IP ranges.",
          items = {
            ["$ref"] = "RouterAdvertisedIpRange",
          },
          type = "array",
        },
        asn = {
          description = "Local BGP Autonomous System Number (ASN). Must be an RFC6996 private ASN, either 16-bit or 32-bit. The value will be fixed for this router resource. All VPN tunnels that link to this router will have the same local ASN.",
          format = "uint32",
          type = "integer",
        },
        keepaliveInterval = {
          description = "The interval in seconds between BGP keepalive messages that are sent to the peer. Hold time is three times the interval at which keepalive messages are sent, and the hold time is the maximum number of seconds allowed to elapse between successive keepalive messages that BGP receives from a peer. BGP will use the smaller of either the local hold time value or the peer's hold time value as the hold time for the BGP connection between the two peers. If set, this value must be between 20 and 60. The default is 20.",
          format = "uint32",
          type = "integer",
        },
      },
      type = "object",
    },
    RouterBgpPeer = {
      id = "RouterBgpPeer",
      properties = {
        advertiseMode = {
          description = "User-specified flag to indicate which mode to use for advertisement.",
          enum = {
            "CUSTOM",
            "DEFAULT",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        advertisedGroups = {
          description = "User-specified list of prefix groups to advertise in custom mode, which can take one of the following options: - ALL_SUBNETS: Advertises all available subnets, including peer VPC subnets. - ALL_VPC_SUBNETS: Advertises the router's own VPC subnets. Note that this field can only be populated if advertise_mode is CUSTOM and overrides the list defined for the router (in the \"bgp\" message). These groups are advertised in addition to any specified prefixes. Leave this field blank to advertise no custom groups.",
          items = {
            enum = {
              "ALL_SUBNETS",
            },
            enumDescriptions = {
              "Advertise all available subnets (including peer VPC subnets).",
            },
            type = "string",
          },
          type = "array",
        },
        advertisedIpRanges = {
          description = "User-specified list of individual IP ranges to advertise in custom mode. This field can only be populated if advertise_mode is CUSTOM and overrides the list defined for the router (in the \"bgp\" message). These IP ranges are advertised in addition to any specified groups. Leave this field blank to advertise no custom IP ranges.",
          items = {
            ["$ref"] = "RouterAdvertisedIpRange",
          },
          type = "array",
        },
        advertisedRoutePriority = {
          description = "The priority of routes advertised to this BGP peer. Where there is more than one matching route of maximum length, the routes with the lowest priority value win.",
          format = "uint32",
          type = "integer",
        },
        bfd = {
          ["$ref"] = "RouterBgpPeerBfd",
          description = "BFD configuration for the BGP peering.",
        },
        enable = {
          description = "The status of the BGP peer connection. If set to FALSE, any active session with the peer is terminated and all associated routing information is removed. If set to TRUE, the peer connection can be established with routing information. The default is TRUE.",
          enum = {
            "FALSE",
            "TRUE",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        enableIpv6 = {
          description = "Enable IPv6 traffic over BGP Peer. If not specified, it is disabled by default.",
          type = "boolean",
        },
        interfaceName = {
          description = "Name of the interface the BGP peer is associated with.",
          type = "string",
        },
        ipAddress = {
          description = "IP address of the interface inside Google Cloud Platform. Only IPv4 is supported.",
          type = "string",
        },
        ipv6NexthopAddress = {
          description = "IPv6 address of the interface inside Google Cloud Platform.",
          type = "string",
        },
        managementType = {
          description = "[Output Only] The resource that configures and manages this BGP peer. - MANAGED_BY_USER is the default value and can be managed by you or other users - MANAGED_BY_ATTACHMENT is a BGP peer that is configured and managed by Cloud Interconnect, specifically by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of BGP peer when the PARTNER InterconnectAttachment is created, updated, or deleted. ",
          enum = {
            "MANAGED_BY_ATTACHMENT",
            "MANAGED_BY_USER",
          },
          enumDescriptions = {
            "The BGP peer is automatically created for PARTNER type InterconnectAttachment; Google will automatically create/delete this BGP peer when the PARTNER InterconnectAttachment is created/deleted, and Google will update the ipAddress and peerIpAddress when the PARTNER InterconnectAttachment is provisioned. This type of BGP peer cannot be created or deleted, but can be modified for all fields except for name, ipAddress and peerIpAddress.",
            "Default value, the BGP peer is manually created and managed by user.",
          },
          type = "string",
        },
        md5AuthenticationKeyName = {
          description = "Present if MD5 authentication is enabled for the peering. Must be the name of one of the entries in the Router.md5_authentication_keys. The field must comply with RFC1035.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.routers.insert",
            },
          },
          description = "Name of this BGP peer. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        peerAsn = {
          annotations = {
            required = {
              "compute.routers.insert",
            },
          },
          description = "Peer BGP Autonomous System Number (ASN). Each BGP interface may use a different value.",
          format = "uint32",
          type = "integer",
        },
        peerIpAddress = {
          description = "IP address of the BGP interface outside Google Cloud Platform. Only IPv4 is supported.",
          type = "string",
        },
        peerIpv6NexthopAddress = {
          description = "IPv6 address of the BGP interface outside Google Cloud Platform.",
          type = "string",
        },
        routerApplianceInstance = {
          description = "URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance must be located in zones contained in the same region as this Cloud Router. The VM instance is the peer side of the BGP session.",
          type = "string",
        },
      },
      type = "object",
    },
    RouterBgpPeerBfd = {
      id = "RouterBgpPeerBfd",
      properties = {
        minReceiveInterval = {
          description = "The minimum interval, in milliseconds, between BFD control packets received from the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the transmit interval of the other router. If set, this value must be between 1000 and 30000. The default is 1000.",
          format = "uint32",
          type = "integer",
        },
        minTransmitInterval = {
          description = "The minimum interval, in milliseconds, between BFD control packets transmitted to the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the corresponding receive interval of the other router. If set, this value must be between 1000 and 30000. The default is 1000.",
          format = "uint32",
          type = "integer",
        },
        multiplier = {
          description = "The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable. If set, the value must be a value between 5 and 16. The default is 5.",
          format = "uint32",
          type = "integer",
        },
        sessionInitializationMode = {
          description = "The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.",
          enum = {
            "ACTIVE",
            "DISABLED",
            "PASSIVE",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    RouterInterface = {
      id = "RouterInterface",
      properties = {
        ipRange = {
          description = "IP address and range of the interface. The IP range must be in the RFC3927 link-local IP address space. The value must be a CIDR-formatted string, for example: 169.254.0.1/30. NOTE: Do not truncate the address as it represents the IP address of the interface.",
          type = "string",
        },
        linkedInterconnectAttachment = {
          description = "URI of the linked Interconnect attachment. It must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a virtual machine instance.",
          type = "string",
        },
        linkedVpnTunnel = {
          description = "URI of the linked VPN tunnel, which must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a virtual machine instance.",
          type = "string",
        },
        managementType = {
          description = "[Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. ",
          enum = {
            "MANAGED_BY_ATTACHMENT",
            "MANAGED_BY_USER",
          },
          enumDescriptions = {
            "The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user.",
            "Default value, the interface is manually created and managed by user.",
          },
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.routers.insert",
            },
          },
          description = "Name of this interface entry. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        privateIpAddress = {
          description = "The regional private internal IP address that is used to establish BGP sessions to a VM instance acting as a third-party Router Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN VM.",
          type = "string",
        },
        redundantInterface = {
          description = "Name of the interface that will be redundant with the current interface you are creating. The redundantInterface must belong to the same Cloud Router as the interface here. To establish the BGP session to a Router Appliance VM, you must create two BGP peers. The two BGP peers must be attached to two separate interfaces that are redundant with each other. The redundant_interface must be 1-63 characters long, and comply with RFC1035. Specifically, the redundant_interface must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        subnetwork = {
          description = "The URI of the subnetwork resource that this interface belongs to, which must be in the same region as the Cloud Router. When you establish a BGP session to a VM instance using this interface, the VM instance must belong to the same subnetwork as the subnetwork specified here.",
          type = "string",
        },
      },
      type = "object",
    },
    RouterList = {
      description = "Contains a list of Router resources.",
      id = "RouterList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Router resources.",
          items = {
            ["$ref"] = "Router",
          },
          type = "array",
        },
        kind = {
          default = "compute#routerList",
          description = "[Output Only] Type of resource. Always compute#router for routers.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    RouterMd5AuthenticationKey = {
      id = "RouterMd5AuthenticationKey",
      properties = {
        key = {
          annotations = {
            required = {
              "compute.routers.insert",
            },
          },
          description = "[Input only] Value of the key. For patch and update calls, it can be skipped to copy the value from the previous configuration. This is allowed if the key with the same name existed before the operation. Maximum length is 80 characters. Can only contain printable ASCII characters.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.routers.insert",
              "compute.routers.update",
            },
          },
          description = "Name used to identify the key. Must be unique within a router. Must be referenced by at least one bgpPeer. Must comply with RFC1035.",
          type = "string",
        },
      },
      type = "object",
    },
    RouterNat = {
      description = "Represents a Nat resource. It enables the VMs within the specified subnetworks to access Internet without external IP addresses. It specifies a list of subnetworks (and the ranges within) that want to use NAT. Customers can also provide the external IPs that would be used for NAT. GCP would auto-allocate ephemeral IPs if no external IPs are provided.",
      id = "RouterNat",
      properties = {
        drainNatIps = {
          description = "A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT only.",
          items = {
            type = "string",
          },
          type = "array",
        },
        enableDynamicPortAllocation = {
          description = "Enable Dynamic Port Allocation. If not specified, it is disabled by default. If set to true, - Dynamic Port Allocation will be enabled on this NAT config. - enableEndpointIndependentMapping cannot be set to true. - If minPorts is set, minPortsPerVm must be set to a power of two greater than or equal to 32. If minPortsPerVm is not set, a minimum of 32 ports will be allocated to a VM from this NAT config. ",
          type = "boolean",
        },
        enableEndpointIndependentMapping = {
          type = "boolean",
        },
        endpointTypes = {
          description = "List of NAT-ted endpoint types supported by the Nat Gateway. If the list is empty, then it will be equivalent to include ENDPOINT_TYPE_VM",
          items = {
            enum = {
              "ENDPOINT_TYPE_SWG",
              "ENDPOINT_TYPE_VM",
            },
            enumDescriptions = {
              "This is used for Secure Web Gateway endpoints.",
              "This is the default.",
            },
            type = "string",
          },
          type = "array",
        },
        icmpIdleTimeoutSec = {
          description = "Timeout (in seconds) for ICMP connections. Defaults to 30s if not set.",
          format = "int32",
          type = "integer",
        },
        logConfig = {
          ["$ref"] = "RouterNatLogConfig",
          description = "Configure logging on this NAT.",
        },
        maxPortsPerVm = {
          description = "Maximum number of ports allocated to a VM from this NAT config when Dynamic Port Allocation is enabled. If Dynamic Port Allocation is not enabled, this field has no effect. If Dynamic Port Allocation is enabled, and this field is set, it must be set to a power of two greater than minPortsPerVm, or 64 if minPortsPerVm is not set. If Dynamic Port Allocation is enabled and this field is not set, a maximum of 65536 ports will be allocated to a VM from this NAT config.",
          format = "int32",
          type = "integer",
        },
        minPortsPerVm = {
          description = "Minimum number of ports allocated to a VM from this NAT config. If not set, a default number of ports is allocated to a VM. This is rounded up to the nearest power of 2. For example, if the value of this field is 50, at least 64 ports are allocated to a VM.",
          format = "int32",
          type = "integer",
        },
        name = {
          description = "Unique name of this Nat service. The name must be 1-63 characters long and comply with RFC1035.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        natIpAllocateOption = {
          description = "Specify the NatIpAllocateOption, which can take one of the following values: - MANUAL_ONLY: Uses only Nat IP addresses provided by customers. When there are not enough specified Nat IPs, the Nat service fails for new VMs. - AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform; customers can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip should be empty. ",
          enum = {
            "AUTO_ONLY",
            "MANUAL_ONLY",
          },
          enumDescriptions = {
            "Nat IPs are allocated by GCP; customers can not specify any Nat IPs.",
            "Only use Nat IPs provided by customers. When specified Nat IPs are not enough then the Nat service fails for new VMs.",
          },
          type = "string",
        },
        natIps = {
          description = "A list of URLs of the IP resources used for this Nat service. These IP addresses must be valid static external IP addresses assigned to the project.",
          items = {
            type = "string",
          },
          type = "array",
        },
        rules = {
          description = "A list of rules associated with this NAT.",
          items = {
            ["$ref"] = "RouterNatRule",
          },
          type = "array",
        },
        sourceSubnetworkIpRangesToNat = {
          description = "Specify the Nat option, which can take one of the following values: - ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are allowed to Nat. - ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP ranges in every Subnetwork are allowed to Nat. - LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field subnetwork below) The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES or ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES, then there should not be any other Router.Nat section in any Router for this network in this region.",
          enum = {
            "ALL_SUBNETWORKS_ALL_IP_RANGES",
            "ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES",
            "LIST_OF_SUBNETWORKS",
          },
          enumDescriptions = {
            "All the IP ranges in every Subnetwork are allowed to Nat.",
            "All the primary IP ranges in every Subnetwork are allowed to Nat.",
            "A list of Subnetworks are allowed to Nat (specified in the field subnetwork below)",
          },
          type = "string",
        },
        subnetworks = {
          description = "A list of Subnetwork resources whose traffic should be translated by NAT Gateway. It is used only when LIST_OF_SUBNETWORKS is selected for the SubnetworkIpRangeToNatOption above.",
          items = {
            ["$ref"] = "RouterNatSubnetworkToNat",
          },
          type = "array",
        },
        tcpEstablishedIdleTimeoutSec = {
          description = "Timeout (in seconds) for TCP established connections. Defaults to 1200s if not set.",
          format = "int32",
          type = "integer",
        },
        tcpTimeWaitTimeoutSec = {
          description = "Timeout (in seconds) for TCP connections that are in TIME_WAIT state. Defaults to 120s if not set.",
          format = "int32",
          type = "integer",
        },
        tcpTransitoryIdleTimeoutSec = {
          description = "Timeout (in seconds) for TCP transitory connections. Defaults to 30s if not set.",
          format = "int32",
          type = "integer",
        },
        udpIdleTimeoutSec = {
          description = "Timeout (in seconds) for UDP connections. Defaults to 30s if not set.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    RouterNatLogConfig = {
      description = "Configuration of logging on a NAT.",
      id = "RouterNatLogConfig",
      properties = {
        enable = {
          description = "Indicates whether or not to export logs. This is false by default.",
          type = "boolean",
        },
        filter = {
          description = "Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values: - ERRORS_ONLY: Export logs only for connection failures. - TRANSLATIONS_ONLY: Export logs only for successful connections. - ALL: Export logs for all connections, successful and unsuccessful. ",
          enum = {
            "ALL",
            "ERRORS_ONLY",
            "TRANSLATIONS_ONLY",
          },
          enumDescriptions = {
            "Export logs for all (successful and unsuccessful) connections.",
            "Export logs for connection failures only.",
            "Export logs for successful connections only.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    RouterNatRule = {
      id = "RouterNatRule",
      properties = {
        action = {
          ["$ref"] = "RouterNatRuleAction",
          description = "The action to be enforced for traffic that matches this rule.",
        },
        description = {
          description = "An optional description of this rule.",
          type = "string",
        },
        match = {
          description = "CEL expression that specifies the match condition that egress traffic from a VM is evaluated against. If it evaluates to true, the corresponding `action` is enforced. The following examples are valid match expressions for public NAT: \"inIpRange(destination.ip, '1.1.0.0/16') || inIpRange(destination.ip, '2.2.0.0/16')\" \"destination.ip == '1.1.0.1' || destination.ip == '8.8.8.8'\" The following example is a valid match expression for private NAT: \"nexthop.hub == 'https://networkconnectivity.googleapis.com/v1alpha1/projects/my-project/global/hub/hub-1'\"",
          type = "string",
        },
        ruleNumber = {
          description = "An integer uniquely identifying a rule in the list. The rule number must be a positive value between 0 and 65000, and must be unique among rules within a NAT.",
          format = "uint32",
          type = "integer",
        },
      },
      type = "object",
    },
    RouterNatRuleAction = {
      id = "RouterNatRuleAction",
      properties = {
        sourceNatActiveIps = {
          description = "A list of URLs of the IP resources used for this NAT rule. These IP addresses must be valid static external IP addresses assigned to the project. This field is used for public NAT.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sourceNatDrainIps = {
          description = "A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT rule only. This field is used for public NAT.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RouterNatSubnetworkToNat = {
      description = "Defines the IP ranges that want to use NAT for a subnetwork.",
      id = "RouterNatSubnetworkToNat",
      properties = {
        name = {
          description = "URL for the subnetwork resource that will use NAT.",
          type = "string",
        },
        secondaryIpRangeNames = {
          description = "A list of the secondary ranges of the Subnetwork that are allowed to use NAT. This can be populated only if \"LIST_OF_SECONDARY_IP_RANGES\" is one of the values in source_ip_ranges_to_nat.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sourceIpRangesToNat = {
          description = "Specify the options for NAT ranges in the Subnetwork. All options of a single value are valid except NAT_IP_RANGE_OPTION_UNSPECIFIED. The only valid option with multiple values is: [\"PRIMARY_IP_RANGE\", \"LIST_OF_SECONDARY_IP_RANGES\"] Default: [ALL_IP_RANGES]",
          items = {
            enum = {
              "ALL_IP_RANGES",
              "LIST_OF_SECONDARY_IP_RANGES",
              "PRIMARY_IP_RANGE",
            },
            enumDescriptions = {
              "The primary and all the secondary ranges are allowed to Nat.",
              "A list of secondary ranges are allowed to Nat.",
              "The primary range is allowed to Nat.",
            },
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RouterStatus = {
      id = "RouterStatus",
      properties = {
        bestRoutes = {
          description = "Best routes for this router's network.",
          items = {
            ["$ref"] = "Route",
          },
          type = "array",
        },
        bestRoutesForRouter = {
          description = "Best routes learned by this router.",
          items = {
            ["$ref"] = "Route",
          },
          type = "array",
        },
        bgpPeerStatus = {
          items = {
            ["$ref"] = "RouterStatusBgpPeerStatus",
          },
          type = "array",
        },
        natStatus = {
          items = {
            ["$ref"] = "RouterStatusNatStatus",
          },
          type = "array",
        },
        network = {
          description = "URI of the network to which this router belongs.",
          type = "string",
        },
      },
      type = "object",
    },
    RouterStatusBgpPeerStatus = {
      id = "RouterStatusBgpPeerStatus",
      properties = {
        advertisedRoutes = {
          description = "Routes that were advertised to the remote BGP peer",
          items = {
            ["$ref"] = "Route",
          },
          type = "array",
        },
        bfdStatus = {
          ["$ref"] = "BfdStatus",
        },
        enableIpv6 = {
          description = "Enable IPv6 traffic over BGP Peer. If not specified, it is disabled by default.",
          type = "boolean",
        },
        ipAddress = {
          description = "IP address of the local BGP interface.",
          type = "string",
        },
        ipv6NexthopAddress = {
          description = "IPv6 address of the local BGP interface.",
          type = "string",
        },
        linkedVpnTunnel = {
          description = "URL of the VPN tunnel that this BGP peer controls.",
          type = "string",
        },
        md5AuthEnabled = {
          description = "Informs whether MD5 authentication is enabled on this BGP peer.",
          type = "boolean",
        },
        name = {
          description = "Name of this BGP peer. Unique within the Routers resource.",
          type = "string",
        },
        numLearnedRoutes = {
          description = "Number of routes learned from the remote BGP Peer.",
          format = "uint32",
          type = "integer",
        },
        peerIpAddress = {
          description = "IP address of the remote BGP interface.",
          type = "string",
        },
        peerIpv6NexthopAddress = {
          description = "IPv6 address of the remote BGP interface.",
          type = "string",
        },
        routerApplianceInstance = {
          description = "[Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session.",
          type = "string",
        },
        state = {
          description = "The state of the BGP session. For a list of possible values for this field, see BGP session states.",
          type = "string",
        },
        status = {
          description = "Status of the BGP peer: {UP, DOWN}",
          enum = {
            "DOWN",
            "UNKNOWN",
            "UP",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        statusReason = {
          description = "Indicates why particular status was returned.",
          enum = {
            "MD5_AUTH_INTERNAL_PROBLEM",
            "STATUS_REASON_UNSPECIFIED",
          },
          enumDescriptions = {
            "Indicates internal problems with configuration of MD5 authentication. This particular reason can only be returned when md5AuthEnabled is true and status is DOWN.",
            "",
          },
          type = "string",
        },
        uptime = {
          description = "Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds",
          type = "string",
        },
        uptimeSeconds = {
          description = "Time this session has been up, in seconds. Format: 145",
          type = "string",
        },
      },
      type = "object",
    },
    RouterStatusNatStatus = {
      description = "Status of a NAT contained in this router.",
      id = "RouterStatusNatStatus",
      properties = {
        autoAllocatedNatIps = {
          description = "A list of IPs auto-allocated for NAT. Example: [\"1.1.1.1\", \"129.2.16.89\"]",
          items = {
            type = "string",
          },
          type = "array",
        },
        drainAutoAllocatedNatIps = {
          description = "A list of IPs auto-allocated for NAT that are in drain mode. Example: [\"1.1.1.1\", \"179.12.26.133\"].",
          items = {
            type = "string",
          },
          type = "array",
        },
        drainUserAllocatedNatIps = {
          description = "A list of IPs user-allocated for NAT that are in drain mode. Example: [\"1.1.1.1\", \"179.12.26.133\"].",
          items = {
            type = "string",
          },
          type = "array",
        },
        minExtraNatIpsNeeded = {
          description = "The number of extra IPs to allocate. This will be greater than 0 only if user-specified IPs are NOT enough to allow all configured VMs to use NAT. This value is meaningful only when auto-allocation of NAT IPs is *not* used.",
          format = "int32",
          type = "integer",
        },
        name = {
          description = "Unique name of this NAT.",
          type = "string",
        },
        numVmEndpointsWithNatMappings = {
          description = "Number of VM endpoints (i.e., Nics) that can use NAT.",
          format = "int32",
          type = "integer",
        },
        ruleStatus = {
          description = "Status of rules in this NAT.",
          items = {
            ["$ref"] = "RouterStatusNatStatusNatRuleStatus",
          },
          type = "array",
        },
        userAllocatedNatIpResources = {
          description = "A list of fully qualified URLs of reserved IP address resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        userAllocatedNatIps = {
          description = "A list of IPs user-allocated for NAT. They will be raw IP strings like \"179.12.26.133\".",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    RouterStatusNatStatusNatRuleStatus = {
      description = "Status of a NAT Rule contained in this NAT.",
      id = "RouterStatusNatStatusNatRuleStatus",
      properties = {
        activeNatIps = {
          description = "A list of active IPs for NAT. Example: [\"1.1.1.1\", \"179.12.26.133\"].",
          items = {
            type = "string",
          },
          type = "array",
        },
        drainNatIps = {
          description = "A list of IPs for NAT that are in drain mode. Example: [\"1.1.1.1\", \"179.12.26.133\"].",
          items = {
            type = "string",
          },
          type = "array",
        },
        minExtraIpsNeeded = {
          description = "The number of extra IPs to allocate. This will be greater than 0 only if the existing IPs in this NAT Rule are NOT enough to allow all configured VMs to use NAT.",
          format = "int32",
          type = "integer",
        },
        numVmEndpointsWithNatMappings = {
          description = "Number of VM endpoints (i.e., NICs) that have NAT Mappings from this NAT Rule.",
          format = "int32",
          type = "integer",
        },
        ruleNumber = {
          description = "Rule number of the rule.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    RouterStatusResponse = {
      id = "RouterStatusResponse",
      properties = {
        kind = {
          default = "compute#routerStatusResponse",
          description = "Type of resource.",
          type = "string",
        },
        result = {
          ["$ref"] = "RouterStatus",
        },
      },
      type = "object",
    },
    RoutersPreviewResponse = {
      id = "RoutersPreviewResponse",
      properties = {
        resource = {
          ["$ref"] = "Router",
          description = "Preview of given router.",
        },
      },
      type = "object",
    },
    RoutersScopedList = {
      id = "RoutersScopedList",
      properties = {
        routers = {
          description = "A list of routers contained in this scope.",
          items = {
            ["$ref"] = "Router",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of routers when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    Rule = {
      description = "This is deprecated and has no effect. Do not use.",
      id = "Rule",
      properties = {
        action = {
          description = "This is deprecated and has no effect. Do not use.",
          enum = {
            "ALLOW",
            "ALLOW_WITH_LOG",
            "DENY",
            "DENY_WITH_LOG",
            "LOG",
            "NO_ACTION",
          },
          enumDescriptions = {
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
            "This is deprecated and has no effect. Do not use.",
          },
          type = "string",
        },
        conditions = {
          description = "This is deprecated and has no effect. Do not use.",
          items = {
            ["$ref"] = "Condition",
          },
          type = "array",
        },
        description = {
          description = "This is deprecated and has no effect. Do not use.",
          type = "string",
        },
        ins = {
          description = "This is deprecated and has no effect. Do not use.",
          items = {
            type = "string",
          },
          type = "array",
        },
        logConfigs = {
          description = "This is deprecated and has no effect. Do not use.",
          items = {
            ["$ref"] = "LogConfig",
          },
          type = "array",
        },
        notIns = {
          description = "This is deprecated and has no effect. Do not use.",
          items = {
            type = "string",
          },
          type = "array",
        },
        permissions = {
          description = "This is deprecated and has no effect. Do not use.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SSLHealthCheck = {
      id = "SSLHealthCheck",
      properties = {
        port = {
          description = "The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through 65535.",
          format = "int32",
          type = "integer",
        },
        portName = {
          description = "Not supported.",
          type = "string",
        },
        portSpecification = {
          description = "Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.",
          enum = {
            "USE_FIXED_PORT",
            "USE_NAMED_PORT",
            "USE_SERVING_PORT",
          },
          enumDescriptions = {
            "The port number in the health check's port is used for health checking. Applies to network endpoint group and instance group backends.",
            "Not supported.",
            "For network endpoint group backends, the health check uses the port number specified on each endpoint in the network endpoint group. For instance group backends, the health check uses the port number specified for the backend service's named port defined in the instance group's named ports.",
          },
          type = "string",
        },
        proxyHeader = {
          description = "Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.",
          enum = {
            "NONE",
            "PROXY_V1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        request = {
          description = "Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection and SSL handshake.",
          type = "string",
        },
        response = {
          description = "Creates a content-based SSL health check. In addition to establishing a TCP connection and the TLS handshake, you can configure the health check to pass only when the backend sends this exact response ASCII string, up to 1024 bytes in length. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-ssl-tcp",
          type = "string",
        },
      },
      type = "object",
    },
    SavedAttachedDisk = {
      description = "DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.",
      id = "SavedAttachedDisk",
      properties = {
        autoDelete = {
          description = "Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).",
          type = "boolean",
        },
        boot = {
          description = "Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.",
          type = "boolean",
        },
        deviceName = {
          description = "Specifies the name of the disk attached to the source instance.",
          type = "string",
        },
        diskEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The encryption key for the disk.",
        },
        diskSizeGb = {
          description = "The size of the disk in base-2 GB.",
          format = "int64",
          type = "string",
        },
        diskType = {
          description = "[Output Only] URL of the disk type resource. For example: projects/project /zones/zone/diskTypes/pd-standard or pd-ssd",
          type = "string",
        },
        guestOsFeatures = {
          description = "A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.",
          items = {
            ["$ref"] = "GuestOsFeature",
          },
          type = "array",
        },
        index = {
          description = "Specifies zero-based index of the disk that is attached to the source instance.",
          format = "int32",
          type = "integer",
        },
        interface = {
          description = "Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.",
          enum = {
            "NVME",
            "SCSI",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        kind = {
          default = "compute#savedAttachedDisk",
          description = "[Output Only] Type of the resource. Always compute#attachedDisk for attached disks.",
          type = "string",
        },
        licenses = {
          description = "[Output Only] Any valid publicly visible licenses.",
          items = {
            type = "string",
          },
          type = "array",
        },
        mode = {
          description = "The mode in which this disk is attached to the source instance, either READ_WRITE or READ_ONLY.",
          enum = {
            "READ_ONLY",
            "READ_WRITE",
          },
          enumDescriptions = {
            "Attaches this disk in read-only mode. Multiple virtual machines can use a disk in read-only mode at a time.",
            "*[Default]* Attaches this disk in read-write mode. Only one virtual machine at a time can be attached to a disk in read-write mode.",
          },
          type = "string",
        },
        source = {
          description = "Specifies a URL of the disk attached to the source instance.",
          type = "string",
        },
        storageBytes = {
          description = "[Output Only] A size of the storage used by the disk's snapshot by this machine image.",
          format = "int64",
          type = "string",
        },
        storageBytesStatus = {
          description = "[Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.",
          enum = {
            "UPDATING",
            "UP_TO_DATE",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        type = {
          description = "Specifies the type of the attached disk, either SCRATCH or PERSISTENT.",
          enum = {
            "PERSISTENT",
            "SCRATCH",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SavedDisk = {
      description = "An instance-attached disk resource.",
      id = "SavedDisk",
      properties = {
        architecture = {
          description = "[Output Only] The architecture of the attached disk.",
          enum = {
            "ARCHITECTURE_UNSPECIFIED",
            "ARM64",
            "X86_64",
          },
          enumDescriptions = {
            "Default value indicating Architecture is not set.",
            "Machines with architecture ARM64",
            "Machines with architecture X86_64",
          },
          type = "string",
        },
        kind = {
          default = "compute#savedDisk",
          description = "[Output Only] Type of the resource. Always compute#savedDisk for attached disks.",
          type = "string",
        },
        sourceDisk = {
          description = "Specifies a URL of the disk attached to the source instance.",
          type = "string",
        },
        storageBytes = {
          description = "[Output Only] Size of the individual disk snapshot used by this machine image.",
          format = "int64",
          type = "string",
        },
        storageBytesStatus = {
          description = "[Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.",
          enum = {
            "UPDATING",
            "UP_TO_DATE",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ScalingScheduleStatus = {
      id = "ScalingScheduleStatus",
      properties = {
        lastStartTime = {
          description = "[Output Only] The last time the scaling schedule became active. Note: this is a timestamp when a schedule actually became active, not when it was planned to do so. The timestamp is in RFC3339 text format.",
          type = "string",
        },
        nextStartTime = {
          description = "[Output Only] The next time the scaling schedule is to become active. Note: this is a timestamp when a schedule is planned to run, but the actual time might be slightly different. The timestamp is in RFC3339 text format.",
          type = "string",
        },
        state = {
          description = "[Output Only] The current state of a scaling schedule.",
          enum = {
            "ACTIVE",
            "DISABLED",
            "OBSOLETE",
            "READY",
          },
          enumDescriptions = {
            "The current autoscaling recommendation is influenced by this scaling schedule.",
            "This scaling schedule has been disabled by the user.",
            "This scaling schedule will never become active again.",
            "The current autoscaling recommendation is not influenced by this scaling schedule.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Scheduling = {
      description = "Sets the scheduling options for an Instance.",
      id = "Scheduling",
      properties = {
        automaticRestart = {
          description = "Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances. Preemptible instances cannot be automatically restarted. By default, this is set to true so an instance is automatically restarted if it is terminated by Compute Engine.",
          type = "boolean",
        },
        instanceTerminationAction = {
          description = "Specifies the termination action for the instance.",
          enum = {
            "DELETE",
            "INSTANCE_TERMINATION_ACTION_UNSPECIFIED",
            "STOP",
          },
          enumDescriptions = {
            "Delete the VM.",
            "Default value. This value is unused.",
            "Stop the VM without storing in-memory content. default action.",
          },
          type = "string",
        },
        locationHint = {
          description = "An opaque location hint used to place the instance close to other resources. This field is for use by internal tools that use the public API.",
          type = "string",
        },
        minNodeCpus = {
          description = "The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.",
          format = "int32",
          type = "integer",
        },
        nodeAffinities = {
          description = "A set of node affinity and anti-affinity configurations. Refer to Configuring node affinity for more information. Overrides reservationAffinity.",
          items = {
            ["$ref"] = "SchedulingNodeAffinity",
          },
          type = "array",
        },
        onHostMaintenance = {
          description = "Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. For preemptible instances, the default and only possible behavior is TERMINATE. For more information, see Set VM host maintenance policy.",
          enum = {
            "MIGRATE",
            "TERMINATE",
          },
          enumDescriptions = {
            "*[Default]* Allows Compute Engine to automatically migrate instances out of the way of maintenance events.",
            "Tells Compute Engine to terminate and (optionally) restart the instance away from the maintenance activity. If you would like your instance to be restarted, set the automaticRestart flag to true. Your instance may be restarted more than once, and it may be restarted outside the window of maintenance events.",
          },
          type = "string",
        },
        preemptible = {
          description = "Defines whether the instance is preemptible. This can only be set during instance creation or while the instance is stopped and therefore, in a `TERMINATED` state. See Instance Life Cycle for more information on the possible instance states.",
          type = "boolean",
        },
        provisioningModel = {
          description = "Specifies the provisioning model of the instance.",
          enum = {
            "SPOT",
            "STANDARD",
          },
          enumDescriptions = {
            "Heavily discounted, no guaranteed runtime.",
            "Standard provisioning with user controlled runtime, no discounts.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SchedulingNodeAffinity = {
      description = "Node Affinity: the configuration of desired nodes onto which this Instance could be scheduled.",
      id = "SchedulingNodeAffinity",
      properties = {
        key = {
          description = "Corresponds to the label key of Node resource.",
          type = "string",
        },
        operator = {
          description = "Defines the operation of node selection. Valid operators are IN for affinity and NOT_IN for anti-affinity.",
          enum = {
            "IN",
            "NOT_IN",
            "OPERATOR_UNSPECIFIED",
          },
          enumDescriptions = {
            "Requires Compute Engine to seek for matched nodes.",
            "Requires Compute Engine to avoid certain nodes.",
            "",
          },
          type = "string",
        },
        values = {
          description = "Corresponds to the label values of Node resource.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    Screenshot = {
      description = "An instance's screenshot.",
      id = "Screenshot",
      properties = {
        contents = {
          description = "[Output Only] The Base64-encoded screenshot data.",
          type = "string",
        },
        kind = {
          default = "compute#screenshot",
          description = "[Output Only] Type of the resource. Always compute#screenshot for the screenshots.",
          type = "string",
        },
      },
      type = "object",
    },
    SecurityPoliciesAggregatedList = {
      id = "SecurityPoliciesAggregatedList",
      properties = {
        etag = {
          type = "string",
        },
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "SecurityPoliciesScopedList",
            description = "Name of the scope containing this set of security policies.",
          },
          description = "A list of SecurityPoliciesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#securityPoliciesAggregatedList",
          description = "[Output Only] Type of resource. Always compute#securityPolicyAggregatedList for lists of Security Policies.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SecurityPoliciesListPreconfiguredExpressionSetsResponse = {
      id = "SecurityPoliciesListPreconfiguredExpressionSetsResponse",
      properties = {
        preconfiguredExpressionSets = {
          ["$ref"] = "SecurityPoliciesWafConfig",
        },
      },
      type = "object",
    },
    SecurityPoliciesScopedList = {
      id = "SecurityPoliciesScopedList",
      properties = {
        securityPolicies = {
          description = "A list of SecurityPolicies contained in this scope.",
          items = {
            ["$ref"] = "SecurityPolicy",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of security policies when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SecurityPoliciesWafConfig = {
      id = "SecurityPoliciesWafConfig",
      properties = {
        wafRules = {
          ["$ref"] = "PreconfiguredWafSet",
        },
      },
      type = "object",
    },
    SecurityPolicy = {
      description = "Represents a Google Cloud Armor security policy resource. Only external backend services that use load balancers can reference a security policy. For more information, see Google Cloud Armor security policy overview.",
      id = "SecurityPolicy",
      properties = {
        adaptiveProtectionConfig = {
          ["$ref"] = "SecurityPolicyAdaptiveProtectionConfig",
        },
        advancedOptionsConfig = {
          ["$ref"] = "SecurityPolicyAdvancedOptionsConfig",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        ddosProtectionConfig = {
          ["$ref"] = "SecurityPolicyDdosProtectionConfig",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make get() request to the security policy.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#securityPolicy",
          description = "[Output only] Type of the resource. Always compute#securityPolicyfor security policies",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        recaptchaOptionsConfig = {
          ["$ref"] = "SecurityPolicyRecaptchaOptionsConfig",
        },
        region = {
          description = "[Output Only] URL of the region where the regional security policy resides. This field is not applicable to global security policies.",
          type = "string",
        },
        rules = {
          description = "A list of rules that belong to this policy. There must always be a default rule which is a rule with priority 2147483647 and match all condition (for the match condition this means match \"*\" for srcIpRanges and for the networkMatch condition every field must be either match \"*\" or not set). If no rules are provided when creating a security policy, a default rule with action \"allow\" will be added.",
          items = {
            ["$ref"] = "SecurityPolicyRule",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        type = {
          description = "The type indicates the intended use of the security policy. - CLOUD_ARMOR: Cloud Armor backend security policies can be configured to filter incoming HTTP requests targeting backend services. They filter requests before they hit the origin servers. - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can be configured to filter incoming HTTP requests targeting backend services (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). They filter requests before the request is served from Google's cache. - CLOUD_ARMOR_INTERNAL_SERVICE: Cloud Armor internal service policies can be configured to filter HTTP requests targeting services managed by Traffic Director in a service mesh. They filter requests before the request is served from the application. This field can be set only at resource creation time.",
          enum = {
            "CLOUD_ARMOR",
            "CLOUD_ARMOR_EDGE",
            "CLOUD_ARMOR_NETWORK",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SecurityPolicyAdaptiveProtectionConfig = {
      description = "Configuration options for Cloud Armor Adaptive Protection (CAAP).",
      id = "SecurityPolicyAdaptiveProtectionConfig",
      properties = {
        layer7DdosDefenseConfig = {
          ["$ref"] = "SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig",
          description = "If set to true, enables Cloud Armor Machine Learning.",
        },
      },
      type = "object",
    },
    SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig = {
      description = "Configuration options for L7 DDoS detection.",
      id = "SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig",
      properties = {
        enable = {
          description = "If set to true, enables CAAP for L7 DDoS detection.",
          type = "boolean",
        },
        ruleVisibility = {
          description = "Rule visibility can be one of the following: STANDARD - opaque rules. (default) PREMIUM - transparent rules.",
          enum = {
            "PREMIUM",
            "STANDARD",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SecurityPolicyAdvancedOptionsConfig = {
      id = "SecurityPolicyAdvancedOptionsConfig",
      properties = {
        jsonCustomConfig = {
          ["$ref"] = "SecurityPolicyAdvancedOptionsConfigJsonCustomConfig",
          description = "Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD.",
        },
        jsonParsing = {
          enum = {
            "DISABLED",
            "STANDARD",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        logLevel = {
          enum = {
            "NORMAL",
            "VERBOSE",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SecurityPolicyAdvancedOptionsConfigJsonCustomConfig = {
      id = "SecurityPolicyAdvancedOptionsConfigJsonCustomConfig",
      properties = {
        contentTypes = {
          description = "A list of custom Content-Type header values to apply the JSON parsing. As per RFC 1341, a Content-Type header value has the following format: Content-Type := type \"/\" subtype *[\";\" parameter] When configuring a custom Content-Type header value, only the type/subtype needs to be specified, and the parameters should be excluded.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SecurityPolicyDdosProtectionConfig = {
      id = "SecurityPolicyDdosProtectionConfig",
      properties = {
        ddosProtection = {
          enum = {
            "ADVANCED",
            "STANDARD",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SecurityPolicyList = {
      id = "SecurityPolicyList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of SecurityPolicy resources.",
          items = {
            ["$ref"] = "SecurityPolicy",
          },
          type = "array",
        },
        kind = {
          default = "compute#securityPolicyList",
          description = "[Output Only] Type of resource. Always compute#securityPolicyList for listsof securityPolicies",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SecurityPolicyRecaptchaOptionsConfig = {
      id = "SecurityPolicyRecaptchaOptionsConfig",
      properties = {
        redirectSiteKey = {
          description = "An optional field to supply a reCAPTCHA site key to be used for all the rules using the redirect action with the type of GOOGLE_RECAPTCHA under the security policy. The specified site key needs to be created from the reCAPTCHA API. The user is responsible for the validity of the specified site key. If not specified, a Google-managed site key is used.",
          type = "string",
        },
      },
      type = "object",
    },
    SecurityPolicyReference = {
      id = "SecurityPolicyReference",
      properties = {
        securityPolicy = {
          type = "string",
        },
      },
      type = "object",
    },
    SecurityPolicyRule = {
      description = "Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).",
      id = "SecurityPolicyRule",
      properties = {
        action = {
          description = "The Action to perform when the rule is matched. The following are the valid actions: - allow: allow access to target. - deny(): deny access to target, returns the HTTP response code specified (valid values are 403, 404, and 502). - rate_based_ban: limit client traffic to the configured threshold and ban the client if the traffic exceeds the threshold. Configure parameters for this action in RateLimitOptions. Requires rate_limit_options to be set. - redirect: redirect to a different target. This can either be an internal reCAPTCHA redirect, or an external URL-based redirect via a 302 response. Parameters for this action can be configured via redirectOptions. - throttle: limit client traffic to the configured threshold. Configure parameters for this action in rateLimitOptions. Requires rate_limit_options to be set for this. ",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        headerAction = {
          ["$ref"] = "SecurityPolicyRuleHttpHeaderAction",
          description = "Optional, additional actions that are performed on headers.",
        },
        kind = {
          default = "compute#securityPolicyRule",
          description = "[Output only] Type of the resource. Always compute#securityPolicyRule for security policy rules",
          type = "string",
        },
        match = {
          ["$ref"] = "SecurityPolicyRuleMatcher",
          description = "A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding 'action' is enforced.",
        },
        preview = {
          description = "If set to true, the specified action is not enforced.",
          type = "boolean",
        },
        priority = {
          description = "An integer indicating the priority of a rule in the list. The priority must be a positive value between 0 and 2147483647. Rules are evaluated from highest to lowest priority where 0 is the highest priority and 2147483647 is the lowest priority.",
          format = "int32",
          type = "integer",
        },
        rateLimitOptions = {
          ["$ref"] = "SecurityPolicyRuleRateLimitOptions",
          description = "Must be specified if the action is \"rate_based_ban\" or \"throttle\". Cannot be specified for any other actions.",
        },
        redirectOptions = {
          ["$ref"] = "SecurityPolicyRuleRedirectOptions",
          description = "Parameters defining the redirect action. Cannot be specified for any other actions.",
        },
      },
      type = "object",
    },
    SecurityPolicyRuleHttpHeaderAction = {
      id = "SecurityPolicyRuleHttpHeaderAction",
      properties = {
        requestHeadersToAdds = {
          description = "The list of request headers to add or overwrite if they're already present.",
          items = {
            ["$ref"] = "SecurityPolicyRuleHttpHeaderActionHttpHeaderOption",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SecurityPolicyRuleHttpHeaderActionHttpHeaderOption = {
      id = "SecurityPolicyRuleHttpHeaderActionHttpHeaderOption",
      properties = {
        headerName = {
          description = "The name of the header to set.",
          type = "string",
        },
        headerValue = {
          description = "The value to set the named header to.",
          type = "string",
        },
      },
      type = "object",
    },
    SecurityPolicyRuleMatcher = {
      description = "Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.",
      id = "SecurityPolicyRuleMatcher",
      properties = {
        config = {
          ["$ref"] = "SecurityPolicyRuleMatcherConfig",
          description = "The configuration options available when specifying versioned_expr. This field must be specified if versioned_expr is specified and cannot be specified if versioned_expr is not specified.",
        },
        expr = {
          ["$ref"] = "Expr",
          description = "User defined CEVAL expression. A CEVAL expression is used to specify match criteria such as origin.ip, source.region_code and contents in the request header.",
        },
        versionedExpr = {
          description = "Preconfigured versioned expression. If this field is specified, config must also be specified. Available preconfigured expressions along with their requirements are: SRC_IPS_V1 - must specify the corresponding src_ip_range field in config.",
          enum = {
            "SRC_IPS_V1",
          },
          enumDescriptions = {
            "Matches the source IP address of a request to the IP ranges supplied in config.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SecurityPolicyRuleMatcherConfig = {
      id = "SecurityPolicyRuleMatcherConfig",
      properties = {
        srcIpRanges = {
          description = "CIDR IP address range. Maximum number of src_ip_ranges allowed is 10.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SecurityPolicyRuleRateLimitOptions = {
      id = "SecurityPolicyRuleRateLimitOptions",
      properties = {
        banDurationSec = {
          description = "Can only be specified if the action for the rule is \"rate_based_ban\". If specified, determines the time (in seconds) the traffic will continue to be banned by the rate limit after the rate falls below the threshold.",
          format = "int32",
          type = "integer",
        },
        banThreshold = {
          ["$ref"] = "SecurityPolicyRuleRateLimitOptionsThreshold",
          description = "Can only be specified if the action for the rule is \"rate_based_ban\". If specified, the key will be banned for the configured 'ban_duration_sec' when the number of requests that exceed the 'rate_limit_threshold' also exceed this 'ban_threshold'.",
        },
        conformAction = {
          description = "Action to take for requests that are under the configured rate limit threshold. Valid option is \"allow\" only.",
          type = "string",
        },
        enforceOnKey = {
          description = "Determines the key to enforce the rate_limit_threshold on. Possible values are: - ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if \"enforceOnKey\" is not configured. - IP: The source IP address of the request is the key. Each IP has this limit enforced separately. - HTTP_HEADER: The value of the HTTP header whose name is configured under \"enforceOnKeyName\". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults to ALL. - XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP. - HTTP_COOKIE: The value of the HTTP cookie whose name is configured under \"enforceOnKeyName\". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults to ALL. - HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes. - SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session. - REGION_CODE: The country/region from which the request originates. ",
          enum = {
            "ALL",
            "HTTP_COOKIE",
            "HTTP_HEADER",
            "HTTP_PATH",
            "IP",
            "REGION_CODE",
            "SNI",
            "XFF_IP",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        enforceOnKeyName = {
          description = "Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.",
          type = "string",
        },
        exceedAction = {
          description = "Action to take for requests that are above the configured rate limit threshold, to either deny with a specified HTTP response code, or redirect to a different endpoint. Valid options are \"deny(status)\", where valid values for status are 403, 404, 429, and 502, and \"redirect\" where the redirect parameters come from exceedRedirectOptions below.",
          type = "string",
        },
        exceedRedirectOptions = {
          ["$ref"] = "SecurityPolicyRuleRedirectOptions",
          description = "Parameters defining the redirect action that is used as the exceed action. Cannot be specified if the exceed action is not redirect.",
        },
        rateLimitThreshold = {
          ["$ref"] = "SecurityPolicyRuleRateLimitOptionsThreshold",
          description = "Threshold at which to begin ratelimiting.",
        },
      },
      type = "object",
    },
    SecurityPolicyRuleRateLimitOptionsThreshold = {
      id = "SecurityPolicyRuleRateLimitOptionsThreshold",
      properties = {
        count = {
          description = "Number of HTTP(S) requests for calculating the threshold.",
          format = "int32",
          type = "integer",
        },
        intervalSec = {
          description = "Interval over which the threshold is computed.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    SecurityPolicyRuleRedirectOptions = {
      id = "SecurityPolicyRuleRedirectOptions",
      properties = {
        target = {
          description = "Target for the redirect action. This is required if the type is EXTERNAL_302 and cannot be specified for GOOGLE_RECAPTCHA.",
          type = "string",
        },
        type = {
          description = "Type of the redirect action.",
          enum = {
            "EXTERNAL_302",
            "GOOGLE_RECAPTCHA",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SecuritySettings = {
      description = "The authentication and authorization settings for a BackendService.",
      id = "SecuritySettings",
      properties = {
        clientTlsPolicy = {
          description = "Optional. A URL referring to a networksecurity.ClientTlsPolicy resource that describes how clients should authenticate with this service's backends. clientTlsPolicy only applies to a global BackendService with the loadBalancingScheme set to INTERNAL_SELF_MANAGED. If left blank, communications are not encrypted. Note: This field currently has no impact.",
          type = "string",
        },
        subjectAltNames = {
          description = "Optional. A list of Subject Alternative Names (SANs) that the client verifies during a mutual TLS handshake with an server/endpoint for this BackendService. When the server presents its X.509 certificate to the client, the client inspects the certificate's subjectAltName field. If the field contains one of the specified values, the communication continues. Otherwise, it fails. This additional check enables the client to verify that the server is authorized to run the requested service. Note that the contents of the server certificate's subjectAltName field are configured by the Public Key Infrastructure which provisions server identities. Only applies to a global BackendService with loadBalancingScheme set to INTERNAL_SELF_MANAGED. Only applies when BackendService has an attached clientTlsPolicy with clientCertificate (mTLS mode). Note: This field currently has no impact.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SerialPortOutput = {
      description = "An instance serial console output.",
      id = "SerialPortOutput",
      properties = {
        contents = {
          description = "[Output Only] The contents of the console output.",
          type = "string",
        },
        kind = {
          default = "compute#serialPortOutput",
          description = "[Output Only] Type of the resource. Always compute#serialPortOutput for serial port output.",
          type = "string",
        },
        next = {
          description = "[Output Only] The position of the next byte of content, regardless of whether the content exists, following the output returned in the `contents` property. Use this value in the next request as the start parameter.",
          format = "int64",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        start = {
          description = "The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer (1 MB), older output is overwritten by newer content. The output start value will indicate the byte position of the output that was returned, which might be different than the `start` value that was specified in the request.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    ServerBinding = {
      id = "ServerBinding",
      properties = {
        type = {
          enum = {
            "RESTART_NODE_ON_ANY_SERVER",
            "RESTART_NODE_ON_MINIMAL_SERVERS",
            "SERVER_BINDING_TYPE_UNSPECIFIED",
          },
          enumDescriptions = {
            "Node may associate with any physical server over its lifetime.",
            "Node may associate with minimal physical servers over its lifetime.",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ServiceAccount = {
      description = "A service account.",
      id = "ServiceAccount",
      properties = {
        email = {
          description = "Email address of the service account.",
          type = "string",
        },
        scopes = {
          description = "The list of scopes to be made available for this service account.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ServiceAttachment = {
      description = "Represents a ServiceAttachment resource. A service attachment represents a service that a producer has exposed. It encapsulates the load balancer which fronts the service runs and a list of NAT IP ranges that the producers uses to represent the consumers connecting to the service. next tag = 20",
      id = "ServiceAttachment",
      properties = {
        connectedEndpoints = {
          description = "[Output Only] An array of connections for all the consumers connected to this service attachment.",
          items = {
            ["$ref"] = "ServiceAttachmentConnectedEndpoint",
          },
          type = "array",
        },
        connectionPreference = {
          description = "The connection preference of service attachment. The value can be set to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service attachment is one that always accepts the connection from consumer forwarding rules.",
          enum = {
            "ACCEPT_AUTOMATIC",
            "ACCEPT_MANUAL",
            "CONNECTION_PREFERENCE_UNSPECIFIED",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        consumerAcceptLists = {
          description = "Projects that are allowed to connect to this service attachment.",
          items = {
            ["$ref"] = "ServiceAttachmentConsumerProjectLimit",
          },
          type = "array",
        },
        consumerRejectLists = {
          description = "Projects that are not allowed to connect to this service attachment. The project can be specified using its id or number.",
          items = {
            type = "string",
          },
          type = "array",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        domainNames = {
          description = "If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS. For example, this is a valid domain name: \"p.mycompany.com.\". Current max number of domain names supported is 1.",
          items = {
            type = "string",
          },
          type = "array",
        },
        enableProxyProtocol = {
          description = "If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.",
          type = "boolean",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ServiceAttachment. An up-to-date fingerprint must be provided in order to patch/update the ServiceAttachment; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the ServiceAttachment.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource type. The server generates this identifier.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#serviceAttachment",
          description = "[Output Only] Type of the resource. Always compute#serviceAttachment for service attachments.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.serviceAttachments.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        natSubnets = {
          description = "An array of URLs where each entry is the URL of a subnet provided by the service producer to use for NAT in this service attachment.",
          items = {
            type = "string",
          },
          type = "array",
        },
        producerForwardingRule = {
          description = "The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is serving the endpoint identified by this service attachment.",
          type = "string",
        },
        pscServiceAttachmentId = {
          ["$ref"] = "Uint128",
          description = "[Output Only] An 128-bit global unique ID of the PSC service attachment.",
        },
        region = {
          description = "[Output Only] URL of the region where the service attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        targetService = {
          description = "The URL of a service serving the endpoint identified by this service attachment.",
          type = "string",
        },
      },
      type = "object",
    },
    ServiceAttachmentAggregatedList = {
      description = "Contains a list of ServiceAttachmentsScopedList.",
      id = "ServiceAttachmentAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "ServiceAttachmentsScopedList",
            description = "Name of the scope containing this set of ServiceAttachments.",
          },
          description = "A list of ServiceAttachmentsScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#serviceAttachmentAggregatedList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ServiceAttachmentConnectedEndpoint = {
      description = "[Output Only] A connection connected to this service attachment.",
      id = "ServiceAttachmentConnectedEndpoint",
      properties = {
        endpoint = {
          description = "The url of a connected endpoint.",
          type = "string",
        },
        pscConnectionId = {
          description = "The PSC connection id of the connected endpoint.",
          format = "uint64",
          type = "string",
        },
        status = {
          description = "The status of a connected endpoint to this service attachment.",
          enum = {
            "ACCEPTED",
            "CLOSED",
            "NEEDS_ATTENTION",
            "PENDING",
            "REJECTED",
            "STATUS_UNSPECIFIED",
          },
          enumDescriptions = {
            "The connection has been accepted by the producer.",
            "The connection has been closed by the producer.",
            "The connection has been accepted by the producer, but the producer needs to take further action before the forwarding rule can serve traffic.",
            "The connection is pending acceptance by the producer.",
            "The consumer is still connected but not using the connection.",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ServiceAttachmentConsumerProjectLimit = {
      id = "ServiceAttachmentConsumerProjectLimit",
      properties = {
        connectionLimit = {
          description = "The value of the limit to set.",
          format = "uint32",
          type = "integer",
        },
        networkUrl = {
          description = "The network URL for the network to set the limit for.",
          type = "string",
        },
        projectIdOrNum = {
          description = "The project id or number for the project to set the limit for.",
          type = "string",
        },
      },
      type = "object",
    },
    ServiceAttachmentList = {
      id = "ServiceAttachmentList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of ServiceAttachment resources.",
          items = {
            ["$ref"] = "ServiceAttachment",
          },
          type = "array",
        },
        kind = {
          default = "compute#serviceAttachmentList",
          description = "[Output Only] Type of the resource. Always compute#serviceAttachment for service attachments.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ServiceAttachmentsScopedList = {
      id = "ServiceAttachmentsScopedList",
      properties = {
        serviceAttachments = {
          description = "A list of ServiceAttachments contained in this scope.",
          items = {
            ["$ref"] = "ServiceAttachment",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of service attachments when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ShareSettings = {
      description = "The share setting for reservations and sole tenancy node groups.",
      id = "ShareSettings",
      properties = {
        projectMap = {
          additionalProperties = {
            ["$ref"] = "ShareSettingsProjectConfig",
          },
          description = "A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS.",
          type = "object",
        },
        shareType = {
          description = "Type of sharing for this shared-reservation",
          enum = {
            "LOCAL",
            "ORGANIZATION",
            "SHARE_TYPE_UNSPECIFIED",
            "SPECIFIC_PROJECTS",
          },
          enumDescriptions = {
            "Default value.",
            "Shared-reservation is open to entire Organization",
            "Default value. This value is unused.",
            "Shared-reservation is open to specific projects",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ShareSettingsProjectConfig = {
      description = "Config for each project in the share settings.",
      id = "ShareSettingsProjectConfig",
      properties = {
        projectId = {
          description = "The project ID, should be same as the key of this project config in the parent map.",
          type = "string",
        },
      },
      type = "object",
    },
    ShieldedInstanceConfig = {
      description = "A set of Shielded Instance options.",
      id = "ShieldedInstanceConfig",
      properties = {
        enableIntegrityMonitoring = {
          description = "Defines whether the instance has integrity monitoring enabled. Enabled by default.",
          type = "boolean",
        },
        enableSecureBoot = {
          description = "Defines whether the instance has Secure Boot enabled. Disabled by default.",
          type = "boolean",
        },
        enableVtpm = {
          description = "Defines whether the instance has the vTPM enabled. Enabled by default.",
          type = "boolean",
        },
      },
      type = "object",
    },
    ShieldedInstanceIdentity = {
      description = "A Shielded Instance Identity.",
      id = "ShieldedInstanceIdentity",
      properties = {
        encryptionKey = {
          ["$ref"] = "ShieldedInstanceIdentityEntry",
          description = "An Endorsement Key (EK) made by the RSA 2048 algorithm issued to the Shielded Instance's vTPM.",
        },
        kind = {
          default = "compute#shieldedInstanceIdentity",
          description = "[Output Only] Type of the resource. Always compute#shieldedInstanceIdentity for shielded Instance identity entry.",
          type = "string",
        },
        signingKey = {
          ["$ref"] = "ShieldedInstanceIdentityEntry",
          description = "An Attestation Key (AK) made by the RSA 2048 algorithm issued to the Shielded Instance's vTPM.",
        },
      },
      type = "object",
    },
    ShieldedInstanceIdentityEntry = {
      description = "A Shielded Instance Identity Entry.",
      id = "ShieldedInstanceIdentityEntry",
      properties = {
        ekCert = {
          description = "A PEM-encoded X.509 certificate. This field can be empty.",
          type = "string",
        },
        ekPub = {
          description = "A PEM-encoded public key.",
          type = "string",
        },
      },
      type = "object",
    },
    ShieldedInstanceIntegrityPolicy = {
      description = "The policy describes the baseline against which Instance boot integrity is measured.",
      id = "ShieldedInstanceIntegrityPolicy",
      properties = {
        updateAutoLearnPolicy = {
          description = "Updates the integrity policy baseline using the measurements from the VM instance's most recent boot.",
          type = "boolean",
        },
      },
      type = "object",
    },
    SignedUrlKey = {
      description = "Represents a customer-supplied Signing Key used by Cloud CDN Signed URLs",
      id = "SignedUrlKey",
      properties = {
        keyName = {
          description = "Name of the key. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        keyValue = {
          description = "128-bit key value used for signing the URL. The key value must be a valid RFC 4648 Section 5 base64url encoded string.",
          type = "string",
        },
      },
      type = "object",
    },
    Snapshot = {
      description = "Represents a Persistent Disk Snapshot resource. You can use snapshots to back up data on a regular interval. For more information, read Creating persistent disk snapshots.",
      id = "Snapshot",
      properties = {
        architecture = {
          description = "[Output Only] The architecture of the snapshot. Valid values are ARM64 or X86_64.",
          enum = {
            "ARCHITECTURE_UNSPECIFIED",
            "ARM64",
            "X86_64",
          },
          enumDescriptions = {
            "Default value indicating Architecture is not set.",
            "Machines with architecture ARM64",
            "Machines with architecture X86_64",
          },
          type = "string",
        },
        autoCreated = {
          description = "[Output Only] Set to true if snapshots are automatically created by applying resource policy on the target disk.",
          type = "boolean",
        },
        chainName = {
          description = "Creates the new snapshot in the snapshot chain labeled with the specified name. The chain name must be 1-63 characters long and comply with RFC1035. This is an uncommon option only for advanced service owners who needs to create separate snapshot chains, for example, for chargeback tracking. When you describe your snapshot resource, this field is visible only if it has a non-empty value.",
          type = "string",
        },
        creationSizeBytes = {
          description = "[Output Only] Size in bytes of the snapshot at creation time.",
          format = "int64",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        diskSizeGb = {
          description = "[Output Only] Size of the source disk, specified in GB.",
          format = "int64",
          type = "string",
        },
        downloadBytes = {
          description = "[Output Only] Number of bytes downloaded to restore a snapshot to a disk.",
          format = "int64",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#snapshot",
          description = "[Output Only] Type of the resource. Always compute#snapshot for Snapshot resources.",
          type = "string",
        },
        labelFingerprint = {
          description = "A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a snapshot.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels to apply to this snapshot. These can be later modified by the setLabels method. Label values may be empty.",
          type = "object",
        },
        licenseCodes = {
          description = "[Output Only] Integer license codes indicating which licenses are attached to this snapshot.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        licenses = {
          description = "[Output Only] A list of public visible licenses that apply to this snapshot. This can be because the original image had licenses attached (such as a Windows image).",
          items = {
            type = "string",
          },
          type = "array",
        },
        locationHint = {
          description = "An opaque location hint used to place the snapshot close to other resources. This field is for use by internal tools that use the public API.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.snapshots.insert",
            },
          },
          description = "Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        satisfiesPzs = {
          description = "[Output Only] Reserved for future use.",
          type = "boolean",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        snapshotEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "Encrypts the snapshot using a customer-supplied encryption key. After you encrypt a snapshot using a customer-supplied key, you must provide the same key if you use the snapshot later. For example, you must provide the encryption key when you create a disk from the encrypted snapshot in a future request. Customer-supplied encryption keys do not protect access to metadata of the snapshot. If you do not provide an encryption key when creating the snapshot, then the snapshot will be encrypted using an automatically generated key and you do not need to provide a key to use the snapshot later.",
        },
        snapshotType = {
          description = "Indicates the type of the snapshot.",
          enum = {
            "ARCHIVE",
            "STANDARD",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        sourceDisk = {
          description = "The source disk used to create this snapshot.",
          type = "string",
        },
        sourceDiskEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.",
        },
        sourceDiskId = {
          description = "[Output Only] The ID value of the disk used to create this snapshot. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given disk name.",
          type = "string",
        },
        sourceSnapshotSchedulePolicy = {
          description = "[Output Only] URL of the resource policy which created this scheduled snapshot.",
          type = "string",
        },
        sourceSnapshotSchedulePolicyId = {
          description = "[Output Only] ID of the resource policy which created this scheduled snapshot.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of the snapshot. This can be CREATING, DELETING, FAILED, READY, or UPLOADING.",
          enum = {
            "CREATING",
            "DELETING",
            "FAILED",
            "READY",
            "UPLOADING",
          },
          enumDescriptions = {
            "Snapshot creation is in progress.",
            "Snapshot is currently being deleted.",
            "Snapshot creation failed.",
            "Snapshot has been created successfully.",
            "Snapshot is being uploaded.",
          },
          type = "string",
        },
        storageBytes = {
          description = "[Output Only] A size of the storage used by the snapshot. As snapshots share storage, this number is expected to change with snapshot creation/deletion.",
          format = "int64",
          type = "string",
        },
        storageBytesStatus = {
          description = "[Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.",
          enum = {
            "UPDATING",
            "UP_TO_DATE",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        storageLocations = {
          description = "Cloud Storage bucket storage location of the snapshot (regional or multi-regional).",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SnapshotList = {
      description = "Contains a list of Snapshot resources.",
      id = "SnapshotList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Snapshot resources.",
          items = {
            ["$ref"] = "Snapshot",
          },
          type = "array",
        },
        kind = {
          default = "compute#snapshotList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SourceDiskEncryptionKey = {
      id = "SourceDiskEncryptionKey",
      properties = {
        diskEncryptionKey = {
          ["$ref"] = "CustomerEncryptionKey",
          description = "The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.",
        },
        sourceDisk = {
          description = "URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/disks/disk ",
          type = "string",
        },
      },
      type = "object",
    },
    SourceInstanceParams = {
      description = "A specification of the parameters to use when creating the instance template from a source instance.",
      id = "SourceInstanceParams",
      properties = {
        diskConfigs = {
          description = "Attached disks configuration. If not provided, defaults are applied: For boot disk and any other R/W disks, new custom images will be created from each disk. For read-only disks, they will be attached in read-only mode. Local SSD disks will be created as blank volumes.",
          items = {
            ["$ref"] = "DiskInstantiationConfig",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SourceInstanceProperties = {
      description = "DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.",
      id = "SourceInstanceProperties",
      properties = {
        canIpForward = {
          description = "Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set to false. See the Enable IP forwarding documentation for more information.",
          type = "boolean",
        },
        deletionProtection = {
          description = "Whether the instance created from this machine image should be protected against deletion.",
          type = "boolean",
        },
        description = {
          description = "An optional text description for the instances that are created from this machine image.",
          type = "string",
        },
        disks = {
          description = "An array of disks that are associated with the instances that are created from this machine image.",
          items = {
            ["$ref"] = "SavedAttachedDisk",
          },
          type = "array",
        },
        guestAccelerators = {
          description = "A list of guest accelerator cards' type and count to use for instances created from this machine image.",
          items = {
            ["$ref"] = "AcceleratorConfig",
          },
          type = "array",
        },
        keyRevocationActionType = {
          description = "KeyRevocationActionType of the instance. Supported options are \"STOP\" and \"NONE\". The default value is \"NONE\" if it is not specified.",
          enum = {
            "KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED",
            "NONE",
            "STOP",
          },
          enumDescriptions = {
            "Default value. This value is unused.",
            "Indicates user chose no operation.",
            "Indicates user chose to opt for VM shutdown on key revocation.",
          },
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels to apply to instances that are created from this machine image.",
          type = "object",
        },
        machineType = {
          description = "The machine type to use for instances that are created from this machine image.",
          type = "string",
        },
        metadata = {
          ["$ref"] = "Metadata",
          description = "The metadata key/value pairs to assign to instances that are created from this machine image. These pairs can consist of custom metadata or predefined keys. See Project and instance metadata for more information.",
        },
        minCpuPlatform = {
          description = "Minimum cpu/platform to be used by instances created from this machine image. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: \"Intel Haswell\" or minCpuPlatform: \"Intel Sandy Bridge\". For more information, read Specifying a Minimum CPU Platform.",
          type = "string",
        },
        networkInterfaces = {
          description = "An array of network access configurations for this interface.",
          items = {
            ["$ref"] = "NetworkInterface",
          },
          type = "array",
        },
        scheduling = {
          ["$ref"] = "Scheduling",
          description = "Specifies the scheduling options for the instances that are created from this machine image.",
        },
        serviceAccounts = {
          description = "A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from this machine image. Use metadata queries to obtain the access tokens for these instances.",
          items = {
            ["$ref"] = "ServiceAccount",
          },
          type = "array",
        },
        tags = {
          ["$ref"] = "Tags",
          description = "A list of tags to apply to the instances that are created from this machine image. The tags identify valid sources or targets for network firewalls. The setTags method can modify this list of tags. Each tag within the list must comply with RFC1035.",
        },
      },
      type = "object",
    },
    SslCertificate = {
      description = "Represents an SSL Certificate resource. Google Compute Engine has two SSL Certificate resources: * [Global](/compute/docs/reference/rest/v1/sslCertificates) * [Regional](/compute/docs/reference/rest/v1/regionSslCertificates) The sslCertificates are used by: - external HTTPS load balancers - SSL proxy load balancers The regionSslCertificates are used by internal HTTPS load balancers. Optionally, certificate file contents that you upload can contain a set of up to five PEM-encoded certificates. The API call creates an object (sslCertificate) that holds this data. You can use SSL keys and certificates to secure connections to a load balancer. For more information, read Creating and using SSL certificates, SSL certificates quotas and limits, and Troubleshooting SSL certificates.",
      id = "SslCertificate",
      properties = {
        certificate = {
          description = "A value read into memory from a certificate file. The certificate file must be in PEM format. The certificate chain must be no greater than 5 certs long. The chain must include at least one intermediate cert.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        expireTime = {
          description = "[Output Only] Expire time of the certificate. RFC3339",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#sslCertificate",
          description = "[Output Only] Type of the resource. Always compute#sslCertificate for SSL certificates.",
          type = "string",
        },
        managed = {
          ["$ref"] = "SslCertificateManagedSslCertificate",
          description = "Configuration and status of a managed SSL certificate.",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        privateKey = {
          description = "A value read into memory from a write-only private key file. The private key file must be in PEM format. For security, only insert requests include this field.",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the regional SSL Certificate resides. This field is not applicable to global SSL Certificate.",
          type = "string",
        },
        selfLink = {
          description = "[Output only] Server-defined URL for the resource.",
          type = "string",
        },
        selfManaged = {
          ["$ref"] = "SslCertificateSelfManagedSslCertificate",
          description = "Configuration and status of a self-managed SSL certificate.",
        },
        subjectAlternativeNames = {
          description = "[Output Only] Domains associated with the certificate via Subject Alternative Name.",
          items = {
            type = "string",
          },
          type = "array",
        },
        type = {
          description = "(Optional) Specifies the type of SSL certificate, either \"SELF_MANAGED\" or \"MANAGED\". If not specified, the certificate is self-managed and the fields certificate and private_key are used.",
          enum = {
            "MANAGED",
            "SELF_MANAGED",
            "TYPE_UNSPECIFIED",
          },
          enumDescriptions = {
            "Google-managed SSLCertificate.",
            "Certificate uploaded by user.",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SslCertificateAggregatedList = {
      id = "SslCertificateAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "SslCertificatesScopedList",
            description = "Name of the scope containing this set of SslCertificates.",
          },
          description = "A list of SslCertificatesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#sslCertificateAggregatedList",
          description = "[Output Only] Type of resource. Always compute#sslCertificateAggregatedList for lists of SSL Certificates.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SslCertificateList = {
      description = "Contains a list of SslCertificate resources.",
      id = "SslCertificateList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of SslCertificate resources.",
          items = {
            ["$ref"] = "SslCertificate",
          },
          type = "array",
        },
        kind = {
          default = "compute#sslCertificateList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SslCertificateManagedSslCertificate = {
      description = "Configuration and status of a managed SSL certificate.",
      id = "SslCertificateManagedSslCertificate",
      properties = {
        domainStatus = {
          additionalProperties = {
            enum = {
              "ACTIVE",
              "DOMAIN_STATUS_UNSPECIFIED",
              "FAILED_CAA_CHECKING",
              "FAILED_CAA_FORBIDDEN",
              "FAILED_NOT_VISIBLE",
              "FAILED_RATE_LIMITED",
              "PROVISIONING",
            },
            enumDescriptions = {
              "A managed certificate can be provisioned, no issues for this domain.",
              "",
              "Failed to check CAA records for the domain.",
              "Certificate issuance forbidden by an explicit CAA record for the domain.",
              "There seems to be problem with the user's DNS or load balancer configuration for this domain.",
              "Reached rate-limit for certificates per top-level private domain.",
              "Certificate provisioning for this domain is under way. GCP will attempt to provision the first certificate.",
            },
            type = "string",
          },
          description = "[Output only] Detailed statuses of the domains specified for managed certificate resource.",
          type = "object",
        },
        domains = {
          description = "The domains for which a managed SSL certificate will be generated. Each Google-managed SSL certificate supports up to the [maximum number of domains per Google-managed SSL certificate](/load-balancing/docs/quotas#ssl_certificates).",
          items = {
            type = "string",
          },
          type = "array",
        },
        status = {
          description = "[Output only] Status of the managed certificate resource.",
          enum = {
            "ACTIVE",
            "MANAGED_CERTIFICATE_STATUS_UNSPECIFIED",
            "PROVISIONING",
            "PROVISIONING_FAILED",
            "PROVISIONING_FAILED_PERMANENTLY",
            "RENEWAL_FAILED",
          },
          enumDescriptions = {
            "The certificate management is working, and a certificate has been provisioned.",
            "",
            "The certificate management is working. GCP will attempt to provision the first certificate.",
            "Certificate provisioning failed due to an issue with the DNS or load balancing configuration. For details of which domain failed, consult domain_status field.",
            "Certificate provisioning failed due to an issue with the DNS or load balancing configuration. It won't be retried. To try again delete and create a new managed SslCertificate resource. For details of which domain failed, consult domain_status field.",
            "Renewal of the certificate has failed due to an issue with the DNS or load balancing configuration. The existing cert is still serving; however, it will expire shortly. To provision a renewed certificate, delete and create a new managed SslCertificate resource. For details on which domain failed, consult domain_status field.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SslCertificateSelfManagedSslCertificate = {
      description = "Configuration and status of a self-managed SSL certificate.",
      id = "SslCertificateSelfManagedSslCertificate",
      properties = {
        certificate = {
          description = "A local certificate file. The certificate must be in PEM format. The certificate chain must be no greater than 5 certs long. The chain must include at least one intermediate cert.",
          type = "string",
        },
        privateKey = {
          description = "A write-only private key in PEM format. Only insert requests will include this field.",
          type = "string",
        },
      },
      type = "object",
    },
    SslCertificatesScopedList = {
      id = "SslCertificatesScopedList",
      properties = {
        sslCertificates = {
          description = "List of SslCertificates contained in this scope.",
          items = {
            ["$ref"] = "SslCertificate",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of backend services when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SslPoliciesAggregatedList = {
      id = "SslPoliciesAggregatedList",
      properties = {
        etag = {
          type = "string",
        },
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "SslPoliciesScopedList",
            description = "Name of the scope containing this set of SSL policies.",
          },
          description = "A list of SslPoliciesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#sslPoliciesAggregatedList",
          description = "[Output Only] Type of resource. Always compute#sslPolicyAggregatedList for lists of SSL Policies.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SslPoliciesList = {
      id = "SslPoliciesList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of SslPolicy resources.",
          items = {
            ["$ref"] = "SslPolicy",
          },
          type = "array",
        },
        kind = {
          default = "compute#sslPoliciesList",
          description = "[Output Only] Type of the resource. Always compute#sslPoliciesList for lists of sslPolicies.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SslPoliciesListAvailableFeaturesResponse = {
      id = "SslPoliciesListAvailableFeaturesResponse",
      properties = {
        features = {
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SslPoliciesScopedList = {
      id = "SslPoliciesScopedList",
      properties = {
        sslPolicies = {
          description = "A list of SslPolicies contained in this scope.",
          items = {
            ["$ref"] = "SslPolicy",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of SSL policies when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SslPolicy = {
      description = "Represents an SSL Policy resource. Use SSL policies to control the SSL features, such as versions and cipher suites, offered by an HTTPS or SSL Proxy load balancer. For more information, read SSL Policy Concepts.",
      id = "SslPolicy",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        customFeatures = {
          description = "A list of features enabled when the selected profile is CUSTOM. The method returns the set of features that can be specified in this list. This field must be empty if the profile is not CUSTOM.",
          items = {
            type = "string",
          },
          type = "array",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        enabledFeatures = {
          description = "[Output Only] The list of features enabled in the SSL policy.",
          items = {
            type = "string",
          },
          type = "array",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a SslPolicy. An up-to-date fingerprint must be provided in order to update the SslPolicy, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an SslPolicy.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#sslPolicy",
          description = "[Output only] Type of the resource. Always compute#sslPolicyfor SSL policies.",
          type = "string",
        },
        minTlsVersion = {
          description = "The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one of TLS_1_0, TLS_1_1, TLS_1_2.",
          enum = {
            "TLS_1_0",
            "TLS_1_1",
            "TLS_1_2",
          },
          enumDescriptions = {
            "TLS 1.0",
            "TLS 1.1",
            "TLS 1.2",
          },
          type = "string",
        },
        name = {
          description = "Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        profile = {
          description = "Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one of COMPATIBLE, MODERN, RESTRICTED, or CUSTOM. If using CUSTOM, the set of SSL features to enable must be specified in the customFeatures field.",
          enum = {
            "COMPATIBLE",
            "CUSTOM",
            "MODERN",
            "RESTRICTED",
          },
          enumDescriptions = {
            "Compatible profile. Allows the broadset set of clients, even those which support only out-of-date SSL features to negotiate with the load balancer.",
            "Custom profile. Allow only the set of allowed SSL features specified in the customFeatures field.",
            "Modern profile. Supports a wide set of SSL features, allowing modern clients to negotiate SSL with the load balancer.",
            "Restricted profile. Supports a reduced set of SSL features, intended to meet stricter compliance requirements.",
          },
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the regional SSL policy resides. This field is not applicable to global SSL policies.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        warnings = {
          description = "[Output Only] If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages.",
          items = {
            properties = {
              code = {
                description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
                enum = {
                  "CLEANUP_FAILED",
                  "DEPRECATED_RESOURCE_USED",
                  "DEPRECATED_TYPE_USED",
                  "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                  "EXPERIMENTAL_TYPE_USED",
                  "EXTERNAL_API_WARNING",
                  "FIELD_VALUE_OVERRIDEN",
                  "INJECTED_KERNELS_DEPRECATED",
                  "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                  "LARGE_DEPLOYMENT_WARNING",
                  "MISSING_TYPE_DEPENDENCY",
                  "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                  "NEXT_HOP_CANNOT_IP_FORWARD",
                  "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                  "NEXT_HOP_INSTANCE_NOT_FOUND",
                  "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                  "NEXT_HOP_NOT_RUNNING",
                  "NOT_CRITICAL_ERROR",
                  "NO_RESULTS_ON_PAGE",
                  "PARTIAL_SUCCESS",
                  "REQUIRED_TOS_AGREEMENT",
                  "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                  "RESOURCE_NOT_DELETED",
                  "SCHEMA_VALIDATION_IGNORED",
                  "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                  "UNDECLARED_PROPERTIES",
                  "UNREACHABLE",
                },
                enumDescriptions = {
                  "Warning about failed cleanup of transient changes made by a failed operation.",
                  "A link to a deprecated resource was created.",
                  "When deploying and at least one of the resources has a type marked as deprecated",
                  "The user created a boot disk that is larger than image size.",
                  "When deploying and at least one of the resources has a type marked as experimental",
                  "Warning that is present in an external api call",
                  "Warning that value of a field has been overridden. Deprecated unused field.",
                  "The operation involved use of an injected kernel, which is deprecated.",
                  "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                  "When deploying a deployment with a exceedingly large number of resources",
                  "A resource depends on a missing type",
                  "The route's nextHopIp address is not assigned to an instance on the network.",
                  "The route's next hop instance cannot ip forward.",
                  "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                  "The route's nextHopInstance URL refers to an instance that does not exist.",
                  "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                  "The route's next hop instance does not have a status of RUNNING.",
                  "Error which is not critical. We decided to continue the process despite the mentioned error.",
                  "No results are present on a particular list page.",
                  "Success is reported, but some results may be missing due to errors",
                  "The user attempted to use a resource that requires a TOS they have not accepted.",
                  "Warning that a resource is in use.",
                  "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                  "When a resource schema validation is ignored.",
                  "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                  "When undeclared properties in the schema are present",
                  "A given scope cannot be reached.",
                },
                type = "string",
              },
              data = {
                description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
                items = {
                  properties = {
                    key = {
                      description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                      type = "string",
                    },
                    value = {
                      description = "[Output Only] A warning data value corresponding to the key.",
                      type = "string",
                    },
                  },
                  type = "object",
                },
                type = "array",
              },
              message = {
                description = "[Output Only] A human-readable description of the warning code.",
                type = "string",
              },
            },
            type = "object",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SslPolicyReference = {
      id = "SslPolicyReference",
      properties = {
        sslPolicy = {
          description = "URL of the SSL policy resource. Set this to empty string to clear any existing SSL policy associated with the target proxy resource.",
          type = "string",
        },
      },
      type = "object",
    },
    StatefulPolicy = {
      id = "StatefulPolicy",
      properties = {
        preservedState = {
          ["$ref"] = "StatefulPolicyPreservedState",
        },
      },
      type = "object",
    },
    StatefulPolicyPreservedState = {
      description = "Configuration of preserved resources.",
      id = "StatefulPolicyPreservedState",
      properties = {
        disks = {
          additionalProperties = {
            ["$ref"] = "StatefulPolicyPreservedStateDiskDevice",
          },
          description = "Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks.",
          type = "object",
        },
      },
      type = "object",
    },
    StatefulPolicyPreservedStateDiskDevice = {
      id = "StatefulPolicyPreservedStateDiskDevice",
      properties = {
        autoDelete = {
          description = "These stateful disks will never be deleted during autohealing, update or VM instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted.",
          enum = {
            "NEVER",
            "ON_PERMANENT_INSTANCE_DELETION",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Subnetwork = {
      description = "Represents a Subnetwork resource. A subnetwork (also known as a subnet) is a logical partition of a Virtual Private Cloud network with one primary IP range and zero or more secondary IP ranges. For more information, read Virtual Private Cloud (VPC) Network.",
      id = "Subnetwork",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource. This field can be set only at resource creation time.",
          type = "string",
        },
        enableFlowLogs = {
          description = "Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. This field isn't supported with the purpose field set to INTERNAL_HTTPS_LOAD_BALANCER.",
          type = "boolean",
        },
        externalIpv6Prefix = {
          description = "The external IPv6 address range that is owned by this subnetwork.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a Subnetwork. An up-to-date fingerprint must be provided in order to update the Subnetwork, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a Subnetwork.",
          format = "byte",
          type = "string",
        },
        gatewayAddress = {
          description = "[Output Only] The gateway address for default routes to reach destination addresses outside this subnetwork.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        internalIpv6Prefix = {
          description = "[Output Only] The internal IPv6 address range that is assigned to this subnetwork.",
          type = "string",
        },
        ipCidrRange = {
          description = "The range of internal addresses that are owned by this subnetwork. Provide this property when you create the subnetwork. For example, 10.0.0.0/8 or 100.64.0.0/10. Ranges must be unique and non-overlapping within a network. Only IPv4 is supported. This field is set at resource creation time. The range can be any range listed in the Valid ranges list. The range can be expanded after creation using expandIpCidrRange.",
          type = "string",
        },
        ipv6AccessType = {
          description = "The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack.",
          enum = {
            "EXTERNAL",
            "INTERNAL",
          },
          enumDescriptions = {
            "VMs on this subnet will be assigned IPv6 addresses that are accessible via the Internet, as well as the VPC network.",
            "VMs on this subnet will be assigned IPv6 addresses that are only accessible over the VPC network.",
          },
          type = "string",
        },
        ipv6CidrRange = {
          description = "[Output Only] This field is for internal use.",
          type = "string",
        },
        kind = {
          default = "compute#subnetwork",
          description = "[Output Only] Type of the resource. Always compute#subnetwork for Subnetwork resources.",
          type = "string",
        },
        logConfig = {
          ["$ref"] = "SubnetworkLogConfig",
          description = "This field denotes the VPC flow logging options for this subnetwork. If logging is enabled, logs are exported to Cloud Logging.",
        },
        name = {
          description = "The name of the resource, provided by the client when initially creating the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          description = "The URL of the network to which this subnetwork belongs, provided by the client when initially creating the subnetwork. This field can be set only at resource creation time.",
          type = "string",
        },
        privateIpGoogleAccess = {
          description = "Whether the VMs in this subnet can access Google services without assigned external IP addresses. This field can be both set at resource creation time and updated using setPrivateIpGoogleAccess.",
          type = "boolean",
        },
        privateIpv6GoogleAccess = {
          description = "This field is for internal use. This field can be both set at resource creation time and updated using patch.",
          enum = {
            "DISABLE_GOOGLE_ACCESS",
            "ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE",
            "ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE",
          },
          enumDescriptions = {
            "Disable private IPv6 access to/from Google services.",
            "Bidirectional private IPv6 access to/from Google services.",
            "Outbound private IPv6 access from VMs in this subnet to Google services.",
          },
          type = "string",
        },
        purpose = {
          description = "The purpose of the resource. This field can be either PRIVATE_RFC_1918 or INTERNAL_HTTPS_LOAD_BALANCER. A subnetwork with purpose set to INTERNAL_HTTPS_LOAD_BALANCER is a user-created subnetwork that is reserved for Internal HTTP(S) Load Balancing. If unspecified, the purpose defaults to PRIVATE_RFC_1918. The enableFlowLogs field isn't supported with the purpose field set to INTERNAL_HTTPS_LOAD_BALANCER.",
          enum = {
            "INTERNAL_HTTPS_LOAD_BALANCER",
            "PRIVATE",
            "PRIVATE_RFC_1918",
            "PRIVATE_SERVICE_CONNECT",
            "REGIONAL_MANAGED_PROXY",
          },
          enumDescriptions = {
            "Subnet reserved for Internal HTTP(S) Load Balancing.",
            "Regular user created or automatically created subnet.",
            "Regular user created or automatically created subnet.",
            "Subnetworks created for Private Service Connect in the producer network.",
            "Subnetwork used for Regional Internal/External HTTP(S) Load Balancing.",
          },
          type = "string",
        },
        region = {
          description = "URL of the region where the Subnetwork resides. This field can be set only at resource creation time.",
          type = "string",
        },
        role = {
          description = "The role of subnetwork. Currently, this field is only used when purpose = INTERNAL_HTTPS_LOAD_BALANCER. The value can be set to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Internal HTTP(S) Load Balancing. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request.",
          enum = {
            "ACTIVE",
            "BACKUP",
          },
          enumDescriptions = {
            "The ACTIVE subnet that is currently used.",
            "The BACKUP subnet that could be promoted to ACTIVE.",
          },
          type = "string",
        },
        secondaryIpRanges = {
          description = "An array of configurations for secondary IP ranges for VM instances contained in this subnetwork. The primary IP of such VM must belong to the primary ipCidrRange of the subnetwork. The alias IPs may belong to either primary or secondary ranges. This field can be updated with a patch request.",
          items = {
            ["$ref"] = "SubnetworkSecondaryRange",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        stackType = {
          description = "The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set to IPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be both set at resource creation time and updated using patch.",
          enum = {
            "IPV4_IPV6",
            "IPV4_ONLY",
          },
          enumDescriptions = {
            "New VMs in this subnet can have both IPv4 and IPv6 addresses.",
            "New VMs in this subnet will only be assigned IPv4 addresses.",
          },
          type = "string",
        },
        state = {
          description = "[Output Only] The state of the subnetwork, which can be one of the following values: READY: Subnetwork is created and ready to use DRAINING: only applicable to subnetworks that have the purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load balancer are being drained. A subnetwork that is draining cannot be used or modified until it reaches a status of READY",
          enum = {
            "DRAINING",
            "READY",
          },
          enumDescriptions = {
            "Subnetwork is being drained.",
            "Subnetwork is ready for use.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SubnetworkAggregatedList = {
      id = "SubnetworkAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "SubnetworksScopedList",
            description = "Name of the scope containing this set of Subnetworks.",
          },
          description = "A list of SubnetworksScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#subnetworkAggregatedList",
          description = "[Output Only] Type of resource. Always compute#subnetworkAggregatedList for aggregated lists of subnetworks.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SubnetworkList = {
      description = "Contains a list of Subnetwork resources.",
      id = "SubnetworkList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Subnetwork resources.",
          items = {
            ["$ref"] = "Subnetwork",
          },
          type = "array",
        },
        kind = {
          default = "compute#subnetworkList",
          description = "[Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SubnetworkLogConfig = {
      description = "The available logging options for this subnetwork.",
      id = "SubnetworkLogConfig",
      properties = {
        aggregationInterval = {
          description = "Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection.",
          enum = {
            "INTERVAL_10_MIN",
            "INTERVAL_15_MIN",
            "INTERVAL_1_MIN",
            "INTERVAL_30_SEC",
            "INTERVAL_5_MIN",
            "INTERVAL_5_SEC",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        enable = {
          description = "Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled.",
          type = "boolean",
        },
        filterExpr = {
          description = "Can only be specified if VPC flow logs for this subnetwork is enabled. The filter expression is used to define which VPC flow logs should be exported to Cloud Logging.",
          type = "string",
        },
        flowSampling = {
          description = "Can only be specified if VPC flow logging for this subnetwork is enabled. The value of the field must be in [0, 1]. Set the sampling rate of VPC flow logs within the subnetwork where 1.0 means all collected logs are reported and 0.0 means no logs are reported. Default is 0.5 unless otherwise specified by the org policy, which means half of all collected logs are reported.",
          format = "float",
          type = "number",
        },
        metadata = {
          description = "Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA.",
          enum = {
            "CUSTOM_METADATA",
            "EXCLUDE_ALL_METADATA",
            "INCLUDE_ALL_METADATA",
          },
          enumDescriptions = {
            "",
            "",
            "",
          },
          type = "string",
        },
        metadataFields = {
          description = "Can only be specified if VPC flow logs for this subnetwork is enabled and \"metadata\" was set to CUSTOM_METADATA.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SubnetworkSecondaryRange = {
      description = "Represents a secondary IP range of a subnetwork.",
      id = "SubnetworkSecondaryRange",
      properties = {
        ipCidrRange = {
          description = "The range of IP addresses belonging to this subnetwork secondary range. Provide this property when you create the subnetwork. Ranges must be unique and non-overlapping with all primary and secondary IP ranges within a network. Only IPv4 is supported. The range can be any range listed in the Valid ranges list.",
          type = "string",
        },
        rangeName = {
          description = "The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance. The name must be 1-63 characters long, and comply with RFC1035. The name must be unique within the subnetwork.",
          type = "string",
        },
      },
      type = "object",
    },
    SubnetworksExpandIpCidrRangeRequest = {
      id = "SubnetworksExpandIpCidrRangeRequest",
      properties = {
        ipCidrRange = {
          description = "The IP (in CIDR format or netmask) of internal addresses that are legal on this Subnetwork. This range should be disjoint from other subnetworks within this network. This range can only be larger than (i.e. a superset of) the range previously defined before the update.",
          type = "string",
        },
      },
      type = "object",
    },
    SubnetworksScopedList = {
      id = "SubnetworksScopedList",
      properties = {
        subnetworks = {
          description = "A list of subnetworks contained in this scope.",
          items = {
            ["$ref"] = "Subnetwork",
          },
          type = "array",
        },
        warning = {
          description = "An informational warning that appears when the list of addresses is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    SubnetworksSetPrivateIpGoogleAccessRequest = {
      id = "SubnetworksSetPrivateIpGoogleAccessRequest",
      properties = {
        privateIpGoogleAccess = {
          type = "boolean",
        },
      },
      type = "object",
    },
    Subsetting = {
      description = "Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director.",
      id = "Subsetting",
      properties = {
        policy = {
          enum = {
            "CONSISTENT_HASH_SUBSETTING",
            "NONE",
          },
          enumDescriptions = {
            "Subsetting based on consistent hashing. For Traffic Director, the number of backends per backend group (the subset size) is based on the `subset_size` parameter. For Internal HTTP(S) load balancing, the number of backends per backend group (the subset size) is dynamically adjusted in two cases: - As the number of proxy instances participating in Internal HTTP(S) load balancing increases, the subset size decreases. - When the total number of backends in a network exceeds the capacity of a single proxy instance, subset sizes are reduced automatically for each service that has backend subsetting enabled.",
            "No Subsetting. Clients may open connections and send traffic to all backends of this backend service. This can lead to performance issues if there is substantial imbalance in the count of clients and backends.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    TCPHealthCheck = {
      id = "TCPHealthCheck",
      properties = {
        port = {
          description = "The TCP port number to which the health check prober sends packets. The default value is 80. Valid values are 1 through 65535.",
          format = "int32",
          type = "integer",
        },
        portName = {
          description = "Not supported.",
          type = "string",
        },
        portSpecification = {
          description = "Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.",
          enum = {
            "USE_FIXED_PORT",
            "USE_NAMED_PORT",
            "USE_SERVING_PORT",
          },
          enumDescriptions = {
            "The port number in the health check's port is used for health checking. Applies to network endpoint group and instance group backends.",
            "Not supported.",
            "For network endpoint group backends, the health check uses the port number specified on each endpoint in the network endpoint group. For instance group backends, the health check uses the port number specified for the backend service's named port defined in the instance group's named ports.",
          },
          type = "string",
        },
        proxyHeader = {
          description = "Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.",
          enum = {
            "NONE",
            "PROXY_V1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        request = {
          description = "Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection.",
          type = "string",
        },
        response = {
          description = "Creates a content-based TCP health check. In addition to establishing a TCP connection, you can configure the health check to pass only when the backend sends this exact response ASCII string, up to 1024 bytes in length. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-ssl-tcp",
          type = "string",
        },
      },
      type = "object",
    },
    Tags = {
      description = "A set of instance tags.",
      id = "Tags",
      properties = {
        fingerprint = {
          description = "Specifies a fingerprint for this request, which is essentially a hash of the tags' contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update tags. You must always provide an up-to-date fingerprint hash in order to update or change tags. To see the latest fingerprint, make get() request to the instance.",
          format = "byte",
          type = "string",
        },
        items = {
          description = "An array of tags. Each tag must be 1-63 characters long, and comply with RFC1035.",
          items = {
            type = "string",
          },
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "array",
        },
      },
      type = "object",
    },
    TargetGrpcProxy = {
      description = "Represents a Target gRPC Proxy resource. A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic. Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.",
      id = "TargetGrpcProxy",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetGrpcProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetGrpcProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetGrpcProxy.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource type. The server generates this identifier.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#targetGrpcProxy",
          description = "[Output Only] Type of the resource. Always compute#targetGrpcProxy for target grpc proxies.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.targetGrpcProxies.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        selfLinkWithId = {
          description = "[Output Only] Server-defined URL with id for the resource.",
          type = "string",
        },
        urlMap = {
          description = "URL to the UrlMap resource that defines the mapping from URL to the BackendService. The protocol field in the BackendService must be set to GRPC.",
          type = "string",
        },
        validateForProxyless = {
          description = "If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy. This will enable configuration checks on urlMap and its referenced BackendServices to not allow unsupported features. A gRPC application must use \"xds:///\" scheme in the target URI of the service it is connecting to. If false, indicates that the BackendServices referenced by the urlMap will be accessed by gRPC applications via a sidecar proxy. In this case, a gRPC application must not use \"xds:///\" scheme in the target URI of the service it is connecting to",
          type = "boolean",
        },
      },
      type = "object",
    },
    TargetGrpcProxyList = {
      id = "TargetGrpcProxyList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of TargetGrpcProxy resources.",
          items = {
            ["$ref"] = "TargetGrpcProxy",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetGrpcProxyList",
          description = "[Output Only] Type of the resource. Always compute#targetGrpcProxy for target grpc proxies.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetHttpProxiesScopedList = {
      id = "TargetHttpProxiesScopedList",
      properties = {
        targetHttpProxies = {
          description = "A list of TargetHttpProxies contained in this scope.",
          items = {
            ["$ref"] = "TargetHttpProxy",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of backend services when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetHttpProxy = {
      description = "Represents a Target HTTP Proxy resource. Google Compute Engine has two Target HTTP Proxy resources: * [Global](/compute/docs/reference/rest/v1/targetHttpProxies) * [Regional](/compute/docs/reference/rest/v1/regionTargetHttpProxies) A target HTTP proxy is a component of GCP HTTP load balancers. * targetHttpProxies are used by external HTTP load balancers and Traffic Director. * regionTargetHttpProxies are used by internal HTTP load balancers. Forwarding rules reference a target HTTP proxy, and the target proxy then references a URL map. For more information, read Using Target Proxies and Forwarding rule concepts.",
      id = "TargetHttpProxy",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetHttpProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetHttpProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetHttpProxy.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#targetHttpProxy",
          description = "[Output Only] Type of resource. Always compute#targetHttpProxy for target HTTP proxies.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        proxyBind = {
          description = "This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set to INTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false.",
          type = "boolean",
        },
        region = {
          description = "[Output Only] URL of the region where the regional Target HTTP Proxy resides. This field is not applicable to global Target HTTP Proxies.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        urlMap = {
          description = "URL to the UrlMap resource that defines the mapping from URL to the BackendService.",
          type = "string",
        },
      },
      type = "object",
    },
    TargetHttpProxyAggregatedList = {
      id = "TargetHttpProxyAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "TargetHttpProxiesScopedList",
            description = "Name of the scope containing this set of TargetHttpProxies.",
          },
          description = "A list of TargetHttpProxiesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#targetHttpProxyAggregatedList",
          description = "[Output Only] Type of resource. Always compute#targetHttpProxyAggregatedList for lists of Target HTTP Proxies.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    TargetHttpProxyList = {
      description = "A list of TargetHttpProxy resources.",
      id = "TargetHttpProxyList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of TargetHttpProxy resources.",
          items = {
            ["$ref"] = "TargetHttpProxy",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetHttpProxyList",
          description = "Type of resource. Always compute#targetHttpProxyList for lists of target HTTP proxies.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetHttpsProxiesScopedList = {
      id = "TargetHttpsProxiesScopedList",
      properties = {
        targetHttpsProxies = {
          description = "A list of TargetHttpsProxies contained in this scope.",
          items = {
            ["$ref"] = "TargetHttpsProxy",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of backend services when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetHttpsProxiesSetCertificateMapRequest = {
      id = "TargetHttpsProxiesSetCertificateMapRequest",
      properties = {
        certificateMap = {
          description = "URL of the Certificate Map to associate with this TargetHttpsProxy.",
          type = "string",
        },
      },
      type = "object",
    },
    TargetHttpsProxiesSetQuicOverrideRequest = {
      id = "TargetHttpsProxiesSetQuicOverrideRequest",
      properties = {
        quicOverride = {
          description = "QUIC policy for the TargetHttpsProxy resource.",
          enum = {
            "DISABLE",
            "ENABLE",
            "NONE",
          },
          enumDescriptions = {
            "The load balancer will not attempt to negotiate QUIC with clients.",
            "The load balancer will attempt to negotiate QUIC with clients.",
            "No overrides to the default QUIC policy. This option is implicit if no QUIC override has been specified in the request.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    TargetHttpsProxiesSetSslCertificatesRequest = {
      id = "TargetHttpsProxiesSetSslCertificatesRequest",
      properties = {
        sslCertificates = {
          description = "New set of SslCertificate resources to associate with this TargetHttpsProxy resource. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    TargetHttpsProxy = {
      description = "Represents a Target HTTPS Proxy resource. Google Compute Engine has two Target HTTPS Proxy resources: * [Global](/compute/docs/reference/rest/v1/targetHttpsProxies) * [Regional](/compute/docs/reference/rest/v1/regionTargetHttpsProxies) A target HTTPS proxy is a component of GCP HTTPS load balancers. * targetHttpsProxies are used by external HTTPS load balancers. * regionTargetHttpsProxies are used by internal HTTPS load balancers. Forwarding rules reference a target HTTPS proxy, and the target proxy then references a URL map. For more information, read Using Target Proxies and Forwarding rule concepts.",
      id = "TargetHttpsProxy",
      properties = {
        authorizationPolicy = {
          description = "Optional. A URL referring to a networksecurity.AuthorizationPolicy resource that describes how the proxy should authorize inbound traffic. If left blank, access will not be restricted by an authorization policy. Refer to the AuthorizationPolicy resource for additional details. authorizationPolicy only applies to a global TargetHttpsProxy attached to globalForwardingRules with the loadBalancingScheme set to INTERNAL_SELF_MANAGED. Note: This field currently has no impact.",
          type = "string",
        },
        certificateMap = {
          description = "URL of a certificate map that identifies a certificate map associated with the given target proxy. This field can only be set for global target proxies. If set, sslCertificates will be ignored.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetHttpsProxy. An up-to-date fingerprint must be provided in order to patch the TargetHttpsProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetHttpsProxy.",
          format = "byte",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#targetHttpsProxy",
          description = "[Output Only] Type of resource. Always compute#targetHttpsProxy for target HTTPS proxies.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        proxyBind = {
          description = "This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set to INTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false.",
          type = "boolean",
        },
        quicOverride = {
          description = "Specifies the QUIC override policy for this TargetHttpsProxy resource. This setting determines whether the load balancer attempts to negotiate QUIC with clients. You can specify NONE, ENABLE, or DISABLE. - When quic-override is set to NONE, Google manages whether QUIC is used. - When quic-override is set to ENABLE, the load balancer uses QUIC when possible. - When quic-override is set to DISABLE, the load balancer doesn't use QUIC. - If the quic-override flag is not specified, NONE is implied. ",
          enum = {
            "DISABLE",
            "ENABLE",
            "NONE",
          },
          enumDescriptions = {
            "The load balancer will not attempt to negotiate QUIC with clients.",
            "The load balancer will attempt to negotiate QUIC with clients.",
            "No overrides to the default QUIC policy. This option is implicit if no QUIC override has been specified in the request.",
          },
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the regional TargetHttpsProxy resides. This field is not applicable to global TargetHttpsProxies.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        serverTlsPolicy = {
          description = "Optional. A URL referring to a networksecurity.ServerTlsPolicy resource that describes how the proxy should authenticate inbound traffic. serverTlsPolicy only applies to a global TargetHttpsProxy attached to globalForwardingRules with the loadBalancingScheme set to INTERNAL_SELF_MANAGED. If left blank, communications are not encrypted. Note: This field currently has no impact.",
          type = "string",
        },
        sslCertificates = {
          description = "URLs to SslCertificate resources that are used to authenticate connections between users and the load balancer. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates. sslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sslPolicy = {
          description = "URL of SslPolicy resource that will be associated with the TargetHttpsProxy resource. If not set, the TargetHttpsProxy resource has no SSL policy configured.",
          type = "string",
        },
        urlMap = {
          description = "A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService. For example, the following are all valid URLs for specifying a URL map: - https://www.googleapis.compute/v1/projects/project/global/urlMaps/ url-map - projects/project/global/urlMaps/url-map - global/urlMaps/url-map ",
          type = "string",
        },
      },
      type = "object",
    },
    TargetHttpsProxyAggregatedList = {
      id = "TargetHttpsProxyAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "TargetHttpsProxiesScopedList",
            description = "Name of the scope containing this set of TargetHttpsProxies.",
          },
          description = "A list of TargetHttpsProxiesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#targetHttpsProxyAggregatedList",
          description = "[Output Only] Type of resource. Always compute#targetHttpsProxyAggregatedList for lists of Target HTTP Proxies.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetHttpsProxyList = {
      description = "Contains a list of TargetHttpsProxy resources.",
      id = "TargetHttpsProxyList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of TargetHttpsProxy resources.",
          items = {
            ["$ref"] = "TargetHttpsProxy",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetHttpsProxyList",
          description = "Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetInstance = {
      description = "Represents a Target Instance resource. You can use a target instance to handle traffic for one or more forwarding rules, which is ideal for forwarding protocol traffic that is managed by a single source. For example, ESP, AH, TCP, or UDP. For more information, read Target instances.",
      id = "TargetInstance",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        instance = {
          description = "A URL to the virtual machine instance that handles traffic for this target instance. When creating a target instance, you can provide the fully-qualified URL or a valid partial URL to the desired virtual machine. For example, the following are all valid URLs: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instances/instance - projects/project/zones/zone/instances/instance - zones/zone/instances/instance ",
          type = "string",
        },
        kind = {
          default = "compute#targetInstance",
          description = "[Output Only] The type of the resource. Always compute#targetInstance for target instances.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        natPolicy = {
          description = "Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.",
          enum = {
            "NO_NAT",
          },
          enumDescriptions = {
            "No NAT performed.",
          },
          type = "string",
        },
        network = {
          description = "The URL of the network this target instance uses to forward traffic. If not specified, the traffic will be forwarded to the network that the default network interface belongs to.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        zone = {
          description = "[Output Only] URL of the zone where the target instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
      },
      type = "object",
    },
    TargetInstanceAggregatedList = {
      id = "TargetInstanceAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "TargetInstancesScopedList",
            description = "Name of the scope containing this set of target instances.",
          },
          description = "A list of TargetInstance resources.",
          type = "object",
        },
        kind = {
          default = "compute#targetInstanceAggregatedList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetInstanceList = {
      description = "Contains a list of TargetInstance resources.",
      id = "TargetInstanceList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of TargetInstance resources.",
          items = {
            ["$ref"] = "TargetInstance",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetInstanceList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetInstancesScopedList = {
      id = "TargetInstancesScopedList",
      properties = {
        targetInstances = {
          description = "A list of target instances contained in this scope.",
          items = {
            ["$ref"] = "TargetInstance",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of addresses when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetPool = {
      description = "Represents a Target Pool resource. Target pools are used for network TCP/UDP load balancing. A target pool references member instances, an associated legacy HttpHealthCheck resource, and, optionally, a backup target pool. For more information, read Using target pools.",
      id = "TargetPool",
      properties = {
        backupPool = {
          description = "The server-defined URL for the resource. This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool, and its failoverRatio field is properly set to a value between [0, 1]. backupPool and failoverRatio together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below failoverRatio, traffic arriving at the load-balanced IP will be directed to the backup pool. In case where failoverRatio and backupPool are not set, or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the \"force\" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        failoverRatio = {
          description = "This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool). The value of the field must be in [0, 1]. If set, backupPool must also be set. They together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below this number, traffic arriving at the load-balanced IP will be directed to the backup pool. In case where failoverRatio is not set or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the \"force\" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy.",
          format = "float",
          type = "number",
        },
        healthChecks = {
          description = "The URL of the HttpHealthCheck resource. A member instance in this pool is considered healthy if and only if the health checks pass. Only legacy HttpHealthChecks are supported. Only one health check may be specified.",
          items = {
            type = "string",
          },
          type = "array",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        instances = {
          description = "A list of resource URLs to the virtual machine instances serving this pool. They must live in zones contained in the same region as this pool.",
          items = {
            type = "string",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetPool",
          description = "[Output Only] Type of the resource. Always compute#targetPool for target pools.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the target pool resides.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        sessionAffinity = {
          description = "Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy.",
          enum = {
            "CLIENT_IP",
            "CLIENT_IP_NO_DESTINATION",
            "CLIENT_IP_PORT_PROTO",
            "CLIENT_IP_PROTO",
            "GENERATED_COOKIE",
            "HEADER_FIELD",
            "HTTP_COOKIE",
            "NONE",
          },
          enumDescriptions = {
            "2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy.",
            "1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing.",
            "5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing.",
            "3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing.",
            "Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing.",
            "The hash is based on a user specified header field.",
            "The hash is based on a user provided cookie.",
            "No session affinity. Connections from the same client IP may go to any instance in the pool.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    TargetPoolAggregatedList = {
      id = "TargetPoolAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "TargetPoolsScopedList",
            description = "Name of the scope containing this set of target pools.",
          },
          description = "A list of TargetPool resources.",
          type = "object",
        },
        kind = {
          default = "compute#targetPoolAggregatedList",
          description = "[Output Only] Type of resource. Always compute#targetPoolAggregatedList for aggregated lists of target pools.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetPoolInstanceHealth = {
      id = "TargetPoolInstanceHealth",
      properties = {
        healthStatus = {
          items = {
            ["$ref"] = "HealthStatus",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetPoolInstanceHealth",
          description = "[Output Only] Type of resource. Always compute#targetPoolInstanceHealth when checking the health of an instance.",
          type = "string",
        },
      },
      type = "object",
    },
    TargetPoolList = {
      description = "Contains a list of TargetPool resources.",
      id = "TargetPoolList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of TargetPool resources.",
          items = {
            ["$ref"] = "TargetPool",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetPoolList",
          description = "[Output Only] Type of resource. Always compute#targetPoolList for lists of target pools.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetPoolsAddHealthCheckRequest = {
      id = "TargetPoolsAddHealthCheckRequest",
      properties = {
        healthChecks = {
          description = "The HttpHealthCheck to add to the target pool.",
          items = {
            ["$ref"] = "HealthCheckReference",
          },
          type = "array",
        },
      },
      type = "object",
    },
    TargetPoolsAddInstanceRequest = {
      id = "TargetPoolsAddInstanceRequest",
      properties = {
        instances = {
          description = "A full or partial URL to an instance to add to this target pool. This can be a full or partial URL. For example, the following are valid URLs: - https://www.googleapis.com/compute/v1/projects/project-id/zones/zone /instances/instance-name - projects/project-id/zones/zone/instances/instance-name - zones/zone/instances/instance-name ",
          items = {
            ["$ref"] = "InstanceReference",
          },
          type = "array",
        },
      },
      type = "object",
    },
    TargetPoolsRemoveHealthCheckRequest = {
      id = "TargetPoolsRemoveHealthCheckRequest",
      properties = {
        healthChecks = {
          description = "Health check URL to be removed. This can be a full or valid partial URL. For example, the following are valid URLs: - https://www.googleapis.com/compute/beta/projects/project /global/httpHealthChecks/health-check - projects/project/global/httpHealthChecks/health-check - global/httpHealthChecks/health-check ",
          items = {
            ["$ref"] = "HealthCheckReference",
          },
          type = "array",
        },
      },
      type = "object",
    },
    TargetPoolsRemoveInstanceRequest = {
      id = "TargetPoolsRemoveInstanceRequest",
      properties = {
        instances = {
          description = "URLs of the instances to be removed from target pool.",
          items = {
            ["$ref"] = "InstanceReference",
          },
          type = "array",
        },
      },
      type = "object",
    },
    TargetPoolsScopedList = {
      id = "TargetPoolsScopedList",
      properties = {
        targetPools = {
          description = "A list of target pools contained in this scope.",
          items = {
            ["$ref"] = "TargetPool",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of addresses when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetReference = {
      id = "TargetReference",
      properties = {
        target = {
          type = "string",
        },
      },
      type = "object",
    },
    TargetSslProxiesSetBackendServiceRequest = {
      id = "TargetSslProxiesSetBackendServiceRequest",
      properties = {
        service = {
          description = "The URL of the new BackendService resource for the targetSslProxy.",
          type = "string",
        },
      },
      type = "object",
    },
    TargetSslProxiesSetCertificateMapRequest = {
      id = "TargetSslProxiesSetCertificateMapRequest",
      properties = {
        certificateMap = {
          description = "URL of the Certificate Map to associate with this TargetSslProxy.",
          type = "string",
        },
      },
      type = "object",
    },
    TargetSslProxiesSetProxyHeaderRequest = {
      id = "TargetSslProxiesSetProxyHeaderRequest",
      properties = {
        proxyHeader = {
          description = "The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed.",
          enum = {
            "NONE",
            "PROXY_V1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    TargetSslProxiesSetSslCertificatesRequest = {
      id = "TargetSslProxiesSetSslCertificatesRequest",
      properties = {
        sslCertificates = {
          description = "New set of URLs to SslCertificate resources to associate with this TargetSslProxy. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    TargetSslProxy = {
      description = "Represents a Target SSL Proxy resource. A target SSL proxy is a component of a SSL Proxy load balancer. Global forwarding rules reference a target SSL proxy, and the target proxy then references an external backend service. For more information, read Using Target Proxies.",
      id = "TargetSslProxy",
      properties = {
        certificateMap = {
          description = "URL of a certificate map that identifies a certificate map associated with the given target proxy. This field can only be set for global target proxies. If set, sslCertificates will be ignored.",
          type = "string",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#targetSslProxy",
          description = "[Output Only] Type of the resource. Always compute#targetSslProxy for target SSL proxies.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        proxyHeader = {
          description = "Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.",
          enum = {
            "NONE",
            "PROXY_V1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        service = {
          description = "URL to the BackendService resource.",
          type = "string",
        },
        sslCertificates = {
          description = "URLs to SslCertificate resources that are used to authenticate connections to Backends. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates. sslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sslPolicy = {
          description = "URL of SslPolicy resource that will be associated with the TargetSslProxy resource. If not set, the TargetSslProxy resource will not have any SSL policy configured.",
          type = "string",
        },
      },
      type = "object",
    },
    TargetSslProxyList = {
      description = "Contains a list of TargetSslProxy resources.",
      id = "TargetSslProxyList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of TargetSslProxy resources.",
          items = {
            ["$ref"] = "TargetSslProxy",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetSslProxyList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetTcpProxiesScopedList = {
      id = "TargetTcpProxiesScopedList",
      properties = {
        targetTcpProxies = {
          description = "A list of TargetTcpProxies contained in this scope.",
          items = {
            ["$ref"] = "TargetTcpProxy",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of backend services when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetTcpProxiesSetBackendServiceRequest = {
      id = "TargetTcpProxiesSetBackendServiceRequest",
      properties = {
        service = {
          description = "The URL of the new BackendService resource for the targetTcpProxy.",
          type = "string",
        },
      },
      type = "object",
    },
    TargetTcpProxiesSetProxyHeaderRequest = {
      id = "TargetTcpProxiesSetProxyHeaderRequest",
      properties = {
        proxyHeader = {
          description = "The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed.",
          enum = {
            "NONE",
            "PROXY_V1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    TargetTcpProxy = {
      description = "Represents a Target TCP Proxy resource. A target TCP proxy is a component of a TCP Proxy load balancer. Global forwarding rules reference target TCP proxy, and the target proxy then references an external backend service. For more information, read TCP Proxy Load Balancing overview.",
      id = "TargetTcpProxy",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#targetTcpProxy",
          description = "[Output Only] Type of the resource. Always compute#targetTcpProxy for target TCP proxies.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        proxyBind = {
          description = "This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set to INTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false.",
          type = "boolean",
        },
        proxyHeader = {
          description = "Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.",
          enum = {
            "NONE",
            "PROXY_V1",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the regional TCP proxy resides. This field is not applicable to global TCP proxy.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        service = {
          description = "URL to the BackendService resource.",
          type = "string",
        },
      },
      type = "object",
    },
    TargetTcpProxyAggregatedList = {
      id = "TargetTcpProxyAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "TargetTcpProxiesScopedList",
            description = "Name of the scope containing this set of TargetTcpProxies.",
          },
          description = "A list of TargetTcpProxiesScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#targetTcpProxyAggregatedList",
          description = "[Output Only] Type of resource. Always compute#targetTcpProxyAggregatedList for lists of Target TCP Proxies.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetTcpProxyList = {
      description = "Contains a list of TargetTcpProxy resources.",
      id = "TargetTcpProxyList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of TargetTcpProxy resources.",
          items = {
            ["$ref"] = "TargetTcpProxy",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetTcpProxyList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetVpnGateway = {
      description = "Represents a Target VPN Gateway resource. The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read the the Cloud VPN Overview.",
      id = "TargetVpnGateway",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        forwardingRules = {
          description = "[Output Only] A list of URLs to the ForwardingRule resources. ForwardingRules are created using compute.forwardingRules.insert and associated with a VPN gateway.",
          items = {
            type = "string",
          },
          type = "array",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#targetVpnGateway",
          description = "[Output Only] Type of resource. Always compute#targetVpnGateway for target VPN gateways.",
          type = "string",
        },
        name = {
          annotations = {
            required = {
              "compute.targetVpnGateways.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          annotations = {
            required = {
              "compute.targetVpnGateways.insert",
            },
          },
          description = "URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created.",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the target VPN gateway resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING.",
          enum = {
            "CREATING",
            "DELETING",
            "FAILED",
            "READY",
          },
          enumDescriptions = {
            "",
            "",
            "",
            "",
          },
          type = "string",
        },
        tunnels = {
          description = "[Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are created using the compute.vpntunnels.insert method and associated with a VPN gateway.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    TargetVpnGatewayAggregatedList = {
      id = "TargetVpnGatewayAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "TargetVpnGatewaysScopedList",
            description = "[Output Only] Name of the scope containing this set of target VPN gateways.",
          },
          description = "A list of TargetVpnGateway resources.",
          type = "object",
        },
        kind = {
          default = "compute#targetVpnGatewayAggregatedList",
          description = "[Output Only] Type of resource. Always compute#targetVpnGateway for target VPN gateways.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetVpnGatewayList = {
      description = "Contains a list of TargetVpnGateway resources.",
      id = "TargetVpnGatewayList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of TargetVpnGateway resources.",
          items = {
            ["$ref"] = "TargetVpnGateway",
          },
          type = "array",
        },
        kind = {
          default = "compute#targetVpnGatewayList",
          description = "[Output Only] Type of resource. Always compute#targetVpnGateway for target VPN gateways.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TargetVpnGatewaysScopedList = {
      id = "TargetVpnGatewaysScopedList",
      properties = {
        targetVpnGateways = {
          description = "[Output Only] A list of target VPN gateways contained in this scope.",
          items = {
            ["$ref"] = "TargetVpnGateway",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of addresses when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    TestFailure = {
      id = "TestFailure",
      properties = {
        actualOutputUrl = {
          description = "The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.",
          type = "string",
        },
        actualRedirectResponseCode = {
          description = "Actual HTTP status code for rule with `urlRedirect` calculated by load balancer",
          format = "int32",
          type = "integer",
        },
        actualService = {
          description = "BackendService or BackendBucket returned by load balancer.",
          type = "string",
        },
        expectedOutputUrl = {
          description = "The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.",
          type = "string",
        },
        expectedRedirectResponseCode = {
          description = "Expected HTTP status code for rule with `urlRedirect` calculated by load balancer",
          format = "int32",
          type = "integer",
        },
        expectedService = {
          description = "Expected BackendService or BackendBucket resource the given URL should be mapped to.",
          type = "string",
        },
        headers = {
          description = "HTTP headers of the request.",
          items = {
            ["$ref"] = "UrlMapTestHeader",
          },
          type = "array",
        },
        host = {
          description = "Host portion of the URL.",
          type = "string",
        },
        path = {
          description = "Path portion including query parameters in the URL.",
          type = "string",
        },
      },
      type = "object",
    },
    TestPermissionsRequest = {
      id = "TestPermissionsRequest",
      properties = {
        permissions = {
          description = "The set of permissions to check for the 'resource'. Permissions with wildcards (such as '*' or 'storage.*') are not allowed.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    TestPermissionsResponse = {
      id = "TestPermissionsResponse",
      properties = {
        permissions = {
          description = "A subset of `TestPermissionsRequest.permissions` that the caller is allowed.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    Uint128 = {
      id = "Uint128",
      properties = {
        high = {
          format = "uint64",
          type = "string",
        },
        low = {
          format = "uint64",
          type = "string",
        },
      },
      type = "object",
    },
    UrlMap = {
      description = "Represents a URL Map resource. Compute Engine has two URL Map resources: * [Global](/compute/docs/reference/rest/v1/urlMaps) * [Regional](/compute/docs/reference/rest/v1/regionUrlMaps) A URL map resource is a component of certain types of cloud load balancers and Traffic Director: * urlMaps are used by external HTTP(S) load balancers and Traffic Director. * regionUrlMaps are used by internal HTTP(S) load balancers. For a list of supported URL map features by the load balancer type, see the Load balancing features: Routing and traffic management table. For a list of supported URL map features for Traffic Director, see the Traffic Director features: Routing and traffic management table. This resource defines mappings from hostnames and URL paths to either a backend service or a backend bucket. To use the global urlMaps resource, the backend service must have a loadBalancingScheme of either EXTERNAL or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the backend service must have a loadBalancingScheme of INTERNAL_MANAGED. For more information, read URL Map Concepts.",
      id = "UrlMap",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        defaultRouteAction = {
          ["$ref"] = "HttpRouteAction",
          description = "defaultRouteAction takes effect when none of the hostRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. If defaultRouteAction specifies any weightedBackendServices, defaultService must not be set. Conversely if defaultService is set, defaultRouteAction cannot contain any weightedBackendServices. Only one of defaultRouteAction or defaultUrlRedirect must be set. URL maps for Classic external HTTP(S) load balancers only support the urlRewrite action within defaultRouteAction. defaultRouteAction has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.",
        },
        defaultService = {
          description = "The full or partial URL of the defaultService resource to which traffic is directed if none of the hostRules match. If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. However, if defaultService is specified, defaultRouteAction cannot contain any weightedBackendServices. Conversely, if routeAction specifies any weightedBackendServices, service must not be specified. Only one of defaultService, defaultUrlRedirect , or defaultRouteAction.weightedBackendService must be set. defaultService has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.",
          type = "string",
        },
        defaultUrlRedirect = {
          ["$ref"] = "HttpRedirectAction",
          description = "When none of the specified hostRules match, the request is redirected to a URL specified by defaultUrlRedirect. If defaultUrlRedirect is specified, defaultService or defaultRouteAction must not be set. Not supported when the URL map is bound to a target gRPC proxy.",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        fingerprint = {
          description = "Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field is ignored when inserting a UrlMap. An up-to-date fingerprint must be provided in order to update the UrlMap, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a UrlMap.",
          format = "byte",
          type = "string",
        },
        headerAction = {
          ["$ref"] = "HttpHeaderAction",
          description = "Specifies changes to request and response headers that need to take effect for the selected backendService. The headerAction specified here take effect after headerAction specified under pathMatcher. headerAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.",
        },
        hostRules = {
          description = "The list of host rules to use against the URL.",
          items = {
            ["$ref"] = "HostRule",
          },
          type = "array",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#urlMap",
          description = "[Output Only] Type of the resource. Always compute#urlMaps for url maps.",
          type = "string",
        },
        name = {
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        pathMatchers = {
          description = "The list of named PathMatchers to use against the URL.",
          items = {
            ["$ref"] = "PathMatcher",
          },
          type = "array",
        },
        region = {
          description = "[Output Only] URL of the region where the regional URL map resides. This field is not applicable to global URL maps. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        tests = {
          description = "The list of expected URL mapping tests. Request to update the UrlMap succeeds only if all test cases pass. You can specify a maximum of 100 tests per UrlMap. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.",
          items = {
            ["$ref"] = "UrlMapTest",
          },
          type = "array",
        },
      },
      type = "object",
    },
    UrlMapList = {
      description = "Contains a list of UrlMap resources.",
      id = "UrlMapList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of UrlMap resources.",
          items = {
            ["$ref"] = "UrlMap",
          },
          type = "array",
        },
        kind = {
          default = "compute#urlMapList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    UrlMapReference = {
      id = "UrlMapReference",
      properties = {
        urlMap = {
          type = "string",
        },
      },
      type = "object",
    },
    UrlMapTest = {
      description = "Message for the expected URL mappings.",
      id = "UrlMapTest",
      properties = {
        description = {
          description = "Description of this test case.",
          type = "string",
        },
        expectedOutputUrl = {
          description = "The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters. For rules that forward requests to backends, the test passes only when expectedOutputUrl matches the request forwarded by the load balancer to backends. For rules with urlRewrite, the test verifies that the forwarded request matches hostRewrite and pathPrefixRewrite in the urlRewrite action. When service is specified, expectedOutputUrl`s scheme is ignored. For rules with urlRedirect, the test passes only if expectedOutputUrl matches the URL in the load balancer's redirect response. If urlRedirect specifies https_redirect, the test passes only if the scheme in expectedOutputUrl is also set to HTTPS. If urlRedirect specifies strip_query, the test passes only if expectedOutputUrl does not contain any query parameters. expectedOutputUrl is optional when service is specified.",
          type = "string",
        },
        expectedRedirectResponseCode = {
          description = "For rules with urlRedirect, the test passes only if expectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response. expectedRedirectResponseCode cannot be set when service is set.",
          format = "int32",
          type = "integer",
        },
        headers = {
          description = "HTTP headers for this request. If headers contains a host header, then host must also match the header value.",
          items = {
            ["$ref"] = "UrlMapTestHeader",
          },
          type = "array",
        },
        host = {
          description = "Host portion of the URL. If headers contains a host header, then host must also match the header value.",
          type = "string",
        },
        path = {
          description = "Path portion of the URL.",
          type = "string",
        },
        service = {
          description = "Expected BackendService or BackendBucket resource the given URL should be mapped to. The service field cannot be set if expectedRedirectResponseCode is set.",
          type = "string",
        },
      },
      type = "object",
    },
    UrlMapTestHeader = {
      description = "HTTP headers used in UrlMapTests.",
      id = "UrlMapTestHeader",
      properties = {
        name = {
          description = "Header name.",
          type = "string",
        },
        value = {
          description = "Header value.",
          type = "string",
        },
      },
      type = "object",
    },
    UrlMapValidationResult = {
      description = "Message representing the validation result for a UrlMap.",
      id = "UrlMapValidationResult",
      properties = {
        loadErrors = {
          items = {
            type = "string",
          },
          type = "array",
        },
        loadSucceeded = {
          description = "Whether the given UrlMap can be successfully loaded. If false, 'loadErrors' indicates the reasons.",
          type = "boolean",
        },
        testFailures = {
          items = {
            ["$ref"] = "TestFailure",
          },
          type = "array",
        },
        testPassed = {
          description = "If successfully loaded, this field indicates whether the test passed. If false, 'testFailures's indicate the reason of failure.",
          type = "boolean",
        },
      },
      type = "object",
    },
    UrlMapsAggregatedList = {
      id = "UrlMapsAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "UrlMapsScopedList",
            description = "Name of the scope containing this set of UrlMaps.",
          },
          description = "A list of UrlMapsScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#urlMapsAggregatedList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    UrlMapsScopedList = {
      id = "UrlMapsScopedList",
      properties = {
        urlMaps = {
          description = "A list of UrlMaps contained in this scope.",
          items = {
            ["$ref"] = "UrlMap",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of backend services when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    UrlMapsValidateRequest = {
      id = "UrlMapsValidateRequest",
      properties = {
        loadBalancingSchemes = {
          description = "Specifies the load balancer type(s) this validation request is for. Use EXTERNAL_MANAGED for HTTP/HTTPS External Global Load Balancer with Advanced Traffic Management. Use EXTERNAL for Classic HTTP/HTTPS External Global Load Balancer. Other load balancer types are not supported. For more information, refer to Choosing a load balancer. If unspecified, the load balancing scheme will be inferred from the backend service resources this URL map references. If that can not be inferred (for example, this URL map only references backend buckets, or this Url map is for rewrites and redirects only and doesn't reference any backends), EXTERNAL will be used as the default type. If specified, the scheme(s) must not conflict with the load balancing scheme of the backend service resources this Url map references.",
          items = {
            enum = {
              "EXTERNAL",
              "EXTERNAL_MANAGED",
              "LOAD_BALANCING_SCHEME_UNSPECIFIED",
            },
            enumDescriptions = {
              "Signifies that this will be used for Classic L7 External Load Balancing.",
              "Signifies that this will be used for Envoy-based L7 External Load Balancing.",
              "If unspecified, the validation will try to infer the scheme from the backend service resources this Url map references. If the inferrence is not possible, EXTERNAL will be used as the default type.",
            },
            type = "string",
          },
          type = "array",
        },
        resource = {
          ["$ref"] = "UrlMap",
          description = "Content of the UrlMap to be validated.",
        },
      },
      type = "object",
    },
    UrlMapsValidateResponse = {
      id = "UrlMapsValidateResponse",
      properties = {
        result = {
          ["$ref"] = "UrlMapValidationResult",
        },
      },
      type = "object",
    },
    UrlRewrite = {
      description = "The spec for modifying the path before sending the request to the matched backend service.",
      id = "UrlRewrite",
      properties = {
        hostRewrite = {
          description = "Before forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite. The value must be from 1 to 255 characters.",
          type = "string",
        },
        pathPrefixRewrite = {
          description = "Before forwarding the request to the selected backend service, the matching portion of the request's path is replaced by pathPrefixRewrite. The value must be from 1 to 1024 characters.",
          type = "string",
        },
      },
      type = "object",
    },
    UsableSubnetwork = {
      description = "Subnetwork which the current user has compute.subnetworks.use permission on.",
      id = "UsableSubnetwork",
      properties = {
        externalIpv6Prefix = {
          description = "[Output Only] The external IPv6 address range that is assigned to this subnetwork.",
          type = "string",
        },
        internalIpv6Prefix = {
          description = "[Output Only] The internal IPv6 address range that is assigned to this subnetwork.",
          type = "string",
        },
        ipCidrRange = {
          description = "The range of internal addresses that are owned by this subnetwork.",
          type = "string",
        },
        ipv6AccessType = {
          description = "The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack.",
          enum = {
            "EXTERNAL",
            "INTERNAL",
          },
          enumDescriptions = {
            "VMs on this subnet will be assigned IPv6 addresses that are accessible via the Internet, as well as the VPC network.",
            "VMs on this subnet will be assigned IPv6 addresses that are only accessible over the VPC network.",
          },
          type = "string",
        },
        network = {
          description = "Network URL.",
          type = "string",
        },
        purpose = {
          description = "The purpose of the resource. This field can be either PRIVATE_RFC_1918 or INTERNAL_HTTPS_LOAD_BALANCER. A subnetwork with purpose set to INTERNAL_HTTPS_LOAD_BALANCER is a user-created subnetwork that is reserved for Internal HTTP(S) Load Balancing. If unspecified, the purpose defaults to PRIVATE_RFC_1918. The enableFlowLogs field isn't supported with the purpose field set to INTERNAL_HTTPS_LOAD_BALANCER.",
          enum = {
            "INTERNAL_HTTPS_LOAD_BALANCER",
            "PRIVATE",
            "PRIVATE_RFC_1918",
            "PRIVATE_SERVICE_CONNECT",
            "REGIONAL_MANAGED_PROXY",
          },
          enumDescriptions = {
            "Subnet reserved for Internal HTTP(S) Load Balancing.",
            "Regular user created or automatically created subnet.",
            "Regular user created or automatically created subnet.",
            "Subnetworks created for Private Service Connect in the producer network.",
            "Subnetwork used for Regional Internal/External HTTP(S) Load Balancing.",
          },
          type = "string",
        },
        role = {
          description = "The role of subnetwork. Currently, this field is only used when purpose = INTERNAL_HTTPS_LOAD_BALANCER. The value can be set to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Internal HTTP(S) Load Balancing. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request.",
          enum = {
            "ACTIVE",
            "BACKUP",
          },
          enumDescriptions = {
            "The ACTIVE subnet that is currently used.",
            "The BACKUP subnet that could be promoted to ACTIVE.",
          },
          type = "string",
        },
        secondaryIpRanges = {
          description = "Secondary IP ranges.",
          items = {
            ["$ref"] = "UsableSubnetworkSecondaryRange",
          },
          type = "array",
        },
        stackType = {
          description = "The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set to IPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be both set at resource creation time and updated using patch.",
          enum = {
            "IPV4_IPV6",
            "IPV4_ONLY",
          },
          enumDescriptions = {
            "New VMs in this subnet can have both IPv4 and IPv6 addresses.",
            "New VMs in this subnet will only be assigned IPv4 addresses.",
          },
          type = "string",
        },
        subnetwork = {
          description = "Subnetwork URL.",
          type = "string",
        },
      },
      type = "object",
    },
    UsableSubnetworkSecondaryRange = {
      description = "Secondary IP range of a usable subnetwork.",
      id = "UsableSubnetworkSecondaryRange",
      properties = {
        ipCidrRange = {
          description = "The range of IP addresses belonging to this subnetwork secondary range.",
          type = "string",
        },
        rangeName = {
          description = "The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance. The name must be 1-63 characters long, and comply with RFC1035. The name must be unique within the subnetwork.",
          type = "string",
        },
      },
      type = "object",
    },
    UsableSubnetworksAggregatedList = {
      id = "UsableSubnetworksAggregatedList",
      properties = {
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          type = "string",
        },
        items = {
          description = "[Output] A list of usable subnetwork URLs.",
          items = {
            ["$ref"] = "UsableSubnetwork",
          },
          type = "array",
        },
        kind = {
          default = "compute#usableSubnetworksAggregatedList",
          description = "[Output Only] Type of resource. Always compute#usableSubnetworksAggregatedList for aggregated lists of usable subnetworks.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks and nextPageToken which still should be used to get the next page of results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    UsageExportLocation = {
      description = "The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix.",
      id = "UsageExportLocation",
      properties = {
        bucketName = {
          description = "The name of an existing bucket in Cloud Storage where the usage report object is stored. The Google Service Account is granted write access to this bucket. This can either be the bucket name by itself, such as example-bucket, or the bucket name with gs:// or https://storage.googleapis.com/ in front of it, such as gs://example-bucket.",
          type = "string",
        },
        reportNamePrefix = {
          description = "An optional prefix for the name of the usage report object stored in bucketName. If not supplied, defaults to usage_gce. The report is stored as a CSV file named report_name_prefix_gce_YYYYMMDD.csv where YYYYMMDD is the day of the usage according to Pacific Time. If you supply a prefix, it should conform to Cloud Storage object naming conventions.",
          type = "string",
        },
      },
      type = "object",
    },
    VmEndpointNatMappings = {
      description = "Contain information of Nat mapping for a VM endpoint (i.e., NIC).",
      id = "VmEndpointNatMappings",
      properties = {
        instanceName = {
          description = "Name of the VM instance which the endpoint belongs to",
          type = "string",
        },
        interfaceNatMappings = {
          items = {
            ["$ref"] = "VmEndpointNatMappingsInterfaceNatMappings",
          },
          type = "array",
        },
      },
      type = "object",
    },
    VmEndpointNatMappingsInterfaceNatMappings = {
      description = "Contain information of Nat mapping for an interface of this endpoint.",
      id = "VmEndpointNatMappingsInterfaceNatMappings",
      properties = {
        drainNatIpPortRanges = {
          description = "List of all drain IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: [\"2.2.2.2:12345-12355\", \"1.1.1.1:2234-2234\"].",
          items = {
            type = "string",
          },
          type = "array",
        },
        natIpPortRanges = {
          description = "A list of all IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: [\"2.2.2.2:12345-12355\", \"1.1.1.1:2234-2234\"].",
          items = {
            type = "string",
          },
          type = "array",
        },
        numTotalDrainNatPorts = {
          description = "Total number of drain ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field drain_nat_ip_port_ranges.",
          format = "int32",
          type = "integer",
        },
        numTotalNatPorts = {
          description = "Total number of ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field nat_ip_port_ranges.",
          format = "int32",
          type = "integer",
        },
        ruleMappings = {
          description = "Information about mappings provided by rules in this NAT.",
          items = {
            ["$ref"] = "VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings",
          },
          type = "array",
        },
        sourceAliasIpRange = {
          description = "Alias IP range for this interface endpoint. It will be a private (RFC 1918) IP range. Examples: \"10.33.4.55/32\", or \"192.168.5.0/24\".",
          type = "string",
        },
        sourceVirtualIp = {
          description = "Primary IP of the VM for this NIC.",
          type = "string",
        },
      },
      type = "object",
    },
    VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings = {
      description = "Contains information of NAT Mappings provided by a NAT Rule.",
      id = "VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings",
      properties = {
        drainNatIpPortRanges = {
          description = "List of all drain IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: [\"2.2.2.2:12345-12355\", \"1.1.1.1:2234-2234\"].",
          items = {
            type = "string",
          },
          type = "array",
        },
        natIpPortRanges = {
          description = "A list of all IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: [\"2.2.2.2:12345-12355\", \"1.1.1.1:2234-2234\"].",
          items = {
            type = "string",
          },
          type = "array",
        },
        numTotalDrainNatPorts = {
          description = "Total number of drain ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field drain_nat_ip_port_ranges.",
          format = "int32",
          type = "integer",
        },
        numTotalNatPorts = {
          description = "Total number of ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field nat_ip_port_ranges.",
          format = "int32",
          type = "integer",
        },
        ruleNumber = {
          description = "Rule number of the NAT Rule.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    VmEndpointNatMappingsList = {
      description = "Contains a list of VmEndpointNatMappings.",
      id = "VmEndpointNatMappingsList",
      properties = {
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          type = "string",
        },
        kind = {
          default = "compute#vmEndpointNatMappingsList",
          description = "[Output Only] Type of resource. Always compute#vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        result = {
          description = "[Output Only] A list of Nat mapping information of VM endpoints.",
          items = {
            ["$ref"] = "VmEndpointNatMappings",
          },
          type = "array",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    VpnGateway = {
      description = "Represents a HA VPN gateway. HA VPN is a high-availability (HA) Cloud VPN solution that lets you securely connect your on-premises network to your Google Cloud Virtual Private Cloud network through an IPsec VPN connection in a single region. For more information about Cloud HA VPN solutions, see Cloud VPN topologies .",
      id = "VpnGateway",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#vpnGateway",
          description = "[Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.",
          type = "string",
        },
        labelFingerprint = {
          description = "A fingerprint for the labels being applied to this VpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an VpnGateway.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.",
          type = "object",
        },
        name = {
          annotations = {
            required = {
              "compute.vpnGateways.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        network = {
          annotations = {
            required = {
              "compute.vpnGateways.insert",
            },
          },
          description = "URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created.",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the VPN gateway resides.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        stackType = {
          description = "The stack type for this VPN gateway to identify the IP protocols that are enabled. Possible values are: IPV4_ONLY, IPV4_IPV6. If not specified, IPV4_ONLY will be used.",
          enum = {
            "IPV4_IPV6",
            "IPV4_ONLY",
          },
          enumDescriptions = {
            "Enable VPN gateway with both IPv4 and IPv6 protocols.",
            "Enable VPN gateway with only IPv4 protocol.",
          },
          type = "string",
        },
        vpnInterfaces = {
          description = "The list of VPN interfaces associated with this VPN gateway.",
          items = {
            ["$ref"] = "VpnGatewayVpnGatewayInterface",
          },
          type = "array",
        },
      },
      type = "object",
    },
    VpnGatewayAggregatedList = {
      id = "VpnGatewayAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "VpnGatewaysScopedList",
            description = "[Output Only] Name of the scope containing this set of VPN gateways.",
          },
          description = "A list of VpnGateway resources.",
          type = "object",
        },
        kind = {
          default = "compute#vpnGatewayAggregatedList",
          description = "[Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    VpnGatewayList = {
      description = "Contains a list of VpnGateway resources.",
      id = "VpnGatewayList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of VpnGateway resources.",
          items = {
            ["$ref"] = "VpnGateway",
          },
          type = "array",
        },
        kind = {
          default = "compute#vpnGatewayList",
          description = "[Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    VpnGatewayStatus = {
      id = "VpnGatewayStatus",
      properties = {
        vpnConnections = {
          description = "List of VPN connection for this VpnGateway.",
          items = {
            ["$ref"] = "VpnGatewayStatusVpnConnection",
          },
          type = "array",
        },
      },
      type = "object",
    },
    VpnGatewayStatusHighAvailabilityRequirementState = {
      description = "Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.",
      id = "VpnGatewayStatusHighAvailabilityRequirementState",
      properties = {
        state = {
          description = "Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET, CONNECTION_REDUNDANCY_NOT_MET.",
          enum = {
            "CONNECTION_REDUNDANCY_MET",
            "CONNECTION_REDUNDANCY_NOT_MET",
          },
          enumDescriptions = {
            "VPN tunnels are configured with adequate redundancy from Cloud VPN gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP connections, the adequate redundancy is a pre-requirement for users to get 99.99% availability on GCP side; please note that for any connection, end-to-end 99.99% availability is subject to proper configuration on the peer VPN gateway.",
            "VPN tunnels are not configured with adequate redundancy from the Cloud VPN gateway to the peer gateway",
          },
          type = "string",
        },
        unsatisfiedReason = {
          description = "Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE.",
          enum = {
            "INCOMPLETE_TUNNELS_COVERAGE",
          },
          enumDescriptions = {
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    VpnGatewayStatusTunnel = {
      description = "Contains some information about a VPN tunnel.",
      id = "VpnGatewayStatusTunnel",
      properties = {
        localGatewayInterface = {
          description = "The VPN gateway interface this VPN tunnel is associated with.",
          format = "uint32",
          type = "integer",
        },
        peerGatewayInterface = {
          description = "The peer gateway interface this VPN tunnel is connected to, the peer gateway could either be an external VPN gateway or GCP VPN gateway.",
          format = "uint32",
          type = "integer",
        },
        tunnelUrl = {
          description = "URL reference to the VPN tunnel.",
          type = "string",
        },
      },
      type = "object",
    },
    VpnGatewayStatusVpnConnection = {
      description = "A VPN connection contains all VPN tunnels connected from this VpnGateway to the same peer gateway. The peer gateway could either be a external VPN gateway or GCP VPN gateway.",
      id = "VpnGatewayStatusVpnConnection",
      properties = {
        peerExternalGateway = {
          description = "URL reference to the peer external VPN gateways to which the VPN tunnels in this VPN connection are connected. This field is mutually exclusive with peer_gcp_gateway.",
          type = "string",
        },
        peerGcpGateway = {
          description = "URL reference to the peer side VPN gateways to which the VPN tunnels in this VPN connection are connected. This field is mutually exclusive with peer_gcp_gateway.",
          type = "string",
        },
        state = {
          ["$ref"] = "VpnGatewayStatusHighAvailabilityRequirementState",
          description = "HighAvailabilityRequirementState for the VPN connection.",
        },
        tunnels = {
          description = "List of VPN tunnels that are in this VPN connection.",
          items = {
            ["$ref"] = "VpnGatewayStatusTunnel",
          },
          type = "array",
        },
      },
      type = "object",
    },
    VpnGatewayVpnGatewayInterface = {
      description = "A VPN gateway interface.",
      id = "VpnGatewayVpnGatewayInterface",
      properties = {
        id = {
          description = "[Output Only] Numeric identifier for this VPN interface associated with the VPN gateway.",
          format = "uint32",
          type = "integer",
        },
        interconnectAttachment = {
          description = "URL of the VLAN attachment (interconnectAttachment) resource for this VPN gateway interface. When the value of this field is present, the VPN gateway is used for HA VPN over Cloud Interconnect; all egress or ingress traffic for this VPN gateway interface goes through the specified VLAN attachment resource.",
          type = "string",
        },
        ipAddress = {
          description = "[Output Only] IP address for this VPN interface associated with the VPN gateway. The IP address could be either a regional external IP address or a regional internal IP address. The two IP addresses for a VPN gateway must be all regional external or regional internal IP addresses. There cannot be a mix of regional external IP addresses and regional internal IP addresses. For HA VPN over Cloud Interconnect, the IP addresses for both interfaces could either be regional internal IP addresses or regional external IP addresses. For regular (non HA VPN over Cloud Interconnect) HA VPN tunnels, the IP address must be a regional external IP address.",
          type = "string",
        },
      },
      type = "object",
    },
    VpnGatewaysGetStatusResponse = {
      id = "VpnGatewaysGetStatusResponse",
      properties = {
        result = {
          ["$ref"] = "VpnGatewayStatus",
        },
      },
      type = "object",
    },
    VpnGatewaysScopedList = {
      id = "VpnGatewaysScopedList",
      properties = {
        vpnGateways = {
          description = "[Output Only] A list of VPN gateways contained in this scope.",
          items = {
            ["$ref"] = "VpnGateway",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning which replaces the list of addresses when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    VpnTunnel = {
      description = "Represents a Cloud VPN Tunnel resource. For more information about VPN, read the the Cloud VPN Overview.",
      id = "VpnTunnel",
      properties = {
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        description = {
          description = "An optional description of this resource. Provide this property when you create the resource.",
          type = "string",
        },
        detailedStatus = {
          description = "[Output Only] Detailed status message for the VPN tunnel.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        ikeVersion = {
          description = "IKE protocol version to use when establishing the VPN tunnel with the peer VPN gateway. Acceptable IKE versions are 1 or 2. The default version is 2.",
          format = "int32",
          type = "integer",
        },
        kind = {
          default = "compute#vpnTunnel",
          description = "[Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.",
          type = "string",
        },
        localTrafficSelector = {
          description = "Local traffic selector to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges must be disjoint. Only IPv4 is supported.",
          items = {
            type = "string",
          },
          type = "array",
        },
        name = {
          annotations = {
            required = {
              "compute.vpnTunnels.insert",
            },
          },
          description = "Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.",
          pattern = "[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?",
          type = "string",
        },
        peerExternalGateway = {
          description = "URL of the peer side external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field is exclusive with the field peerGcpGateway.",
          type = "string",
        },
        peerExternalGatewayInterface = {
          description = "The interface ID of the external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. Possible values are: `0`, `1`, `2`, `3`. The number of IDs in use depends on the external VPN gateway redundancy type.",
          format = "int32",
          type = "integer",
        },
        peerGcpGateway = {
          description = "URL of the peer side HA GCP VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field can be used when creating highly available VPN from VPC network to VPC network, the field is exclusive with the field peerExternalGateway. If provided, the VPN tunnel will automatically use the same vpnGatewayInterface ID in the peer GCP VPN gateway.",
          type = "string",
        },
        peerIp = {
          description = "IP address of the peer VPN gateway. Only IPv4 is supported.",
          type = "string",
        },
        region = {
          description = "[Output Only] URL of the region where the VPN tunnel resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.",
          type = "string",
        },
        remoteTrafficSelector = {
          description = "Remote traffic selectors to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges should be disjoint. Only IPv4 is supported.",
          items = {
            type = "string",
          },
          type = "array",
        },
        router = {
          description = "URL of the router resource to be used for dynamic routing.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        sharedSecret = {
          description = "Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway.",
          type = "string",
        },
        sharedSecretHash = {
          description = "Hash of the shared secret.",
          type = "string",
        },
        status = {
          description = "[Output Only] The status of the VPN tunnel, which can be one of the following: - PROVISIONING: Resource is being allocated for the VPN tunnel. - WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route resources are needed to setup the VPN tunnel. - FIRST_HANDSHAKE: Successful first handshake with the peer VPN. - ESTABLISHED: Secure session is successfully established with the peer VPN. - NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS - AUTHORIZATION_ERROR: Auth error (for example, bad shared secret). - NEGOTIATION_FAILURE: Handshake failed. - DEPROVISIONING: Resources are being deallocated for the VPN tunnel. - FAILED: Tunnel creation has failed and the tunnel is not ready to be used. - NO_INCOMING_PACKETS: No incoming packets from peer. - REJECTED: Tunnel configuration was rejected, can be result of being denied access. - ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all required resources. - STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for Classic VPN tunnels or the project is in frozen state. - PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably behind NAT. - TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not allowed for an HA-VPN tunnel. ",
          enum = {
            "ALLOCATING_RESOURCES",
            "AUTHORIZATION_ERROR",
            "DEPROVISIONING",
            "ESTABLISHED",
            "FAILED",
            "FIRST_HANDSHAKE",
            "NEGOTIATION_FAILURE",
            "NETWORK_ERROR",
            "NO_INCOMING_PACKETS",
            "PROVISIONING",
            "REJECTED",
            "STOPPED",
            "WAITING_FOR_FULL_CONFIG",
          },
          enumDescriptions = {
            "Cloud VPN is in the process of allocating all required resources (specifically, a borg task).",
            "Auth error (e.g. bad shared secret).",
            "Resources is being deallocated for the VPN tunnel.",
            "Secure session is successfully established with peer VPN.",
            "Tunnel creation has failed and the tunnel is not ready to be used.",
            "Successful first handshake with peer VPN.",
            "Handshake failed.",
            "Deprecated, replaced by NO_INCOMING_PACKETS",
            "No incoming packets from peer",
            "Resource is being allocated for the VPN tunnel.",
            "Tunnel configuration was rejected, can be result of being denylisted.",
            "Tunnel is stopped due to its Forwarding Rules being deleted.",
            "Waiting to receive all VPN-related configs from user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule and Route resources are needed to setup VPN tunnel.",
          },
          type = "string",
        },
        targetVpnGateway = {
          description = "URL of the Target VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created.",
          type = "string",
        },
        vpnGateway = {
          description = "URL of the VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created. This must be used (instead of target_vpn_gateway) if a High Availability VPN gateway resource is created.",
          type = "string",
        },
        vpnGatewayInterface = {
          description = "The interface ID of the VPN gateway with which this VPN tunnel is associated. Possible values are: `0`, `1`.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    VpnTunnelAggregatedList = {
      id = "VpnTunnelAggregatedList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          additionalProperties = {
            ["$ref"] = "VpnTunnelsScopedList",
            description = "Name of the scope containing this set of VPN tunnels.",
          },
          description = "A list of VpnTunnelsScopedList resources.",
          type = "object",
        },
        kind = {
          default = "compute#vpnTunnelAggregatedList",
          description = "[Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        unreachables = {
          description = "[Output Only] Unreachable resources.",
          items = {
            type = "string",
          },
          type = "array",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    VpnTunnelList = {
      description = "Contains a list of VpnTunnel resources.",
      id = "VpnTunnelList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of VpnTunnel resources.",
          items = {
            ["$ref"] = "VpnTunnel",
          },
          type = "array",
        },
        kind = {
          default = "compute#vpnTunnelList",
          description = "[Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    VpnTunnelsScopedList = {
      id = "VpnTunnelsScopedList",
      properties = {
        vpnTunnels = {
          description = "A list of VPN tunnels contained in this scope.",
          items = {
            ["$ref"] = "VpnTunnel",
          },
          type = "array",
        },
        warning = {
          description = "Informational warning which replaces the list of addresses when the list is empty.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    WafExpressionSet = {
      id = "WafExpressionSet",
      properties = {
        aliases = {
          description = "A list of alternate IDs. The format should be: - E.g. XSS-stable Generic suffix like \"stable\" is particularly useful if a policy likes to avail newer set of expressions without having to change the policy. A given alias name can't be used for more than one entity set.",
          items = {
            type = "string",
          },
          type = "array",
        },
        expressions = {
          description = "List of available expressions.",
          items = {
            ["$ref"] = "WafExpressionSetExpression",
          },
          type = "array",
        },
        id = {
          description = "Google specified expression set ID. The format should be: - E.g. XSS-20170329 required",
          type = "string",
        },
      },
      type = "object",
    },
    WafExpressionSetExpression = {
      id = "WafExpressionSetExpression",
      properties = {
        id = {
          description = "Expression ID should uniquely identify the origin of the expression. E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set version 2.9.1 rule id 973337. The ID could be used to determine the individual attack definition that has been detected. It could also be used to exclude it from the policy in case of false positive. required",
          type = "string",
        },
      },
      type = "object",
    },
    WeightedBackendService = {
      description = "In contrast to a single BackendService in HttpRouteAction to which all matching traffic is directed to, WeightedBackendService allows traffic to be split across multiple backend services. The volume of traffic for each backend service is proportional to the weight specified in each WeightedBackendService",
      id = "WeightedBackendService",
      properties = {
        backendService = {
          description = "The full or partial URL to the default BackendService resource. Before forwarding the request to backendService, the load balancer applies any relevant headerActions specified as part of this backendServiceWeight.",
          type = "string",
        },
        headerAction = {
          ["$ref"] = "HttpHeaderAction",
          description = "Specifies changes to request and response headers that need to take effect for the selected backendService. headerAction specified here take effect before headerAction in the enclosing HttpRouteRule, PathMatcher and UrlMap. headerAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.",
        },
        weight = {
          description = "Specifies the fraction of traffic sent to a backend service, computed as weight / (sum of all weightedBackendService weights in routeAction) . The selection of a backend service is determined only for new traffic. Once a user's request has been directed to a backend service, subsequent requests are sent to the same backend service as determined by the backend service's session affinity policy. The value must be from 0 to 1000.",
          format = "uint32",
          type = "integer",
        },
      },
      type = "object",
    },
    XpnHostList = {
      id = "XpnHostList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "[Output Only] A list of shared VPC host project URLs.",
          items = {
            ["$ref"] = "Project",
          },
          type = "array",
        },
        kind = {
          default = "compute#xpnHostList",
          description = "[Output Only] Type of resource. Always compute#xpnHostList for lists of shared VPC hosts.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    XpnResourceId = {
      description = "Service resource (a.k.a service project) ID.",
      id = "XpnResourceId",
      properties = {
        id = {
          description = "The ID of the service resource. In the case of projects, this field supports project id (e.g., my-project-123) and project number (e.g. 12345678).",
          type = "string",
        },
        type = {
          description = "The type of the service resource.",
          enum = {
            "PROJECT",
            "XPN_RESOURCE_TYPE_UNSPECIFIED",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Zone = {
      description = "Represents a Zone resource. A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-a is located in the us-east1 region. For more information, read Regions and Zones.",
      id = "Zone",
      properties = {
        availableCpuPlatforms = {
          description = "[Output Only] Available cpu/platform selections for the zone.",
          items = {
            type = "string",
          },
          type = "array",
        },
        creationTimestamp = {
          description = "[Output Only] Creation timestamp in RFC3339 text format.",
          type = "string",
        },
        deprecated = {
          ["$ref"] = "DeprecationStatus",
          description = "[Output Only] The deprecation status associated with this zone.",
        },
        description = {
          description = "[Output Only] Textual description of the resource.",
          type = "string",
        },
        id = {
          description = "[Output Only] The unique identifier for the resource. This identifier is defined by the server.",
          format = "uint64",
          type = "string",
        },
        kind = {
          default = "compute#zone",
          description = "[Output Only] Type of the resource. Always compute#zone for zones.",
          type = "string",
        },
        name = {
          description = "[Output Only] Name of the resource.",
          type = "string",
        },
        region = {
          description = "[Output Only] Full URL reference to the region which hosts the zone.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for the resource.",
          type = "string",
        },
        status = {
          description = "[Output Only] Status of the zone, either UP or DOWN.",
          enum = {
            "DOWN",
            "UP",
          },
          enumDescriptions = {
            "",
            "",
          },
          type = "string",
        },
        supportsPzs = {
          description = "[Output Only] Reserved for future use.",
          type = "boolean",
        },
      },
      type = "object",
    },
    ZoneList = {
      description = "Contains a list of zone resources.",
      id = "ZoneList",
      properties = {
        id = {
          description = "[Output Only] Unique identifier for the resource; defined by the server.",
          type = "string",
        },
        items = {
          description = "A list of Zone resources.",
          items = {
            ["$ref"] = "Zone",
          },
          type = "array",
        },
        kind = {
          default = "compute#zoneList",
          description = "Type of resource.",
          type = "string",
        },
        nextPageToken = {
          description = "[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.",
          type = "string",
        },
        selfLink = {
          description = "[Output Only] Server-defined URL for this resource.",
          type = "string",
        },
        warning = {
          description = "[Output Only] Informational warning message.",
          properties = {
            code = {
              description = "[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.",
              enum = {
                "CLEANUP_FAILED",
                "DEPRECATED_RESOURCE_USED",
                "DEPRECATED_TYPE_USED",
                "DISK_SIZE_LARGER_THAN_IMAGE_SIZE",
                "EXPERIMENTAL_TYPE_USED",
                "EXTERNAL_API_WARNING",
                "FIELD_VALUE_OVERRIDEN",
                "INJECTED_KERNELS_DEPRECATED",
                "INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB",
                "LARGE_DEPLOYMENT_WARNING",
                "MISSING_TYPE_DEPENDENCY",
                "NEXT_HOP_ADDRESS_NOT_ASSIGNED",
                "NEXT_HOP_CANNOT_IP_FORWARD",
                "NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE",
                "NEXT_HOP_INSTANCE_NOT_FOUND",
                "NEXT_HOP_INSTANCE_NOT_ON_NETWORK",
                "NEXT_HOP_NOT_RUNNING",
                "NOT_CRITICAL_ERROR",
                "NO_RESULTS_ON_PAGE",
                "PARTIAL_SUCCESS",
                "REQUIRED_TOS_AGREEMENT",
                "RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING",
                "RESOURCE_NOT_DELETED",
                "SCHEMA_VALIDATION_IGNORED",
                "SINGLE_INSTANCE_PROPERTY_TEMPLATE",
                "UNDECLARED_PROPERTIES",
                "UNREACHABLE",
              },
              enumDescriptions = {
                "Warning about failed cleanup of transient changes made by a failed operation.",
                "A link to a deprecated resource was created.",
                "When deploying and at least one of the resources has a type marked as deprecated",
                "The user created a boot disk that is larger than image size.",
                "When deploying and at least one of the resources has a type marked as experimental",
                "Warning that is present in an external api call",
                "Warning that value of a field has been overridden. Deprecated unused field.",
                "The operation involved use of an injected kernel, which is deprecated.",
                "A WEIGHTED_MAGLEV backend service is associated with a health check that is not of type HTTP/HTTPS/HTTP2.",
                "When deploying a deployment with a exceedingly large number of resources",
                "A resource depends on a missing type",
                "The route's nextHopIp address is not assigned to an instance on the network.",
                "The route's next hop instance cannot ip forward.",
                "The route's nextHopInstance URL refers to an instance that does not have an ipv6 interface on the same network as the route.",
                "The route's nextHopInstance URL refers to an instance that does not exist.",
                "The route's nextHopInstance URL refers to an instance that is not on the same network as the route.",
                "The route's next hop instance does not have a status of RUNNING.",
                "Error which is not critical. We decided to continue the process despite the mentioned error.",
                "No results are present on a particular list page.",
                "Success is reported, but some results may be missing due to errors",
                "The user attempted to use a resource that requires a TOS they have not accepted.",
                "Warning that a resource is in use.",
                "One or more of the resources set to auto-delete could not be deleted because they were in use.",
                "When a resource schema validation is ignored.",
                "Instance template used in instance group manager is valid as such, but its application does not make a lot of sense, because it allows only single instance in instance group.",
                "When undeclared properties in the schema are present",
                "A given scope cannot be reached.",
              },
              type = "string",
            },
            data = {
              description = "[Output Only] Metadata about this warning in key: value format. For example: \"data\": [ { \"key\": \"scope\", \"value\": \"zones/us-east1-d\" } ",
              items = {
                properties = {
                  key = {
                    description = "[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).",
                    type = "string",
                  },
                  value = {
                    description = "[Output Only] A warning data value corresponding to the key.",
                    type = "string",
                  },
                },
                type = "object",
              },
              type = "array",
            },
            message = {
              description = "[Output Only] A human-readable description of the warning code.",
              type = "string",
            },
          },
          type = "object",
        },
      },
      type = "object",
    },
    ZoneSetLabelsRequest = {
      id = "ZoneSetLabelsRequest",
      properties = {
        labelFingerprint = {
          description = "The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint.",
          format = "byte",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "The labels to set for this resource.",
          type = "object",
        },
      },
      type = "object",
    },
    ZoneSetPolicyRequest = {
      id = "ZoneSetPolicyRequest",
      properties = {
        bindings = {
          description = "Flatten Policy to create a backwacd compatible wire-format. Deprecated. Use 'policy' to specify bindings.",
          items = {
            ["$ref"] = "Binding",
          },
          type = "array",
        },
        etag = {
          description = "Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify the etag.",
          format = "byte",
          type = "string",
        },
        policy = {
          ["$ref"] = "Policy",
          description = "REQUIRED: The complete policy to be applied to the 'resource'. The size of the policy is limited to a few 10s of KB. An empty policy is in general a valid policy but certain services (like Projects) might reject them.",
        },
      },
      type = "object",
    },
  },
  servicePath = "compute/v1/",
  title = "Compute Engine API",
  version = "v1",
}
